(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17137,        316]
NotebookOptionsPosition[     16081,        276]
NotebookOutlinePosition[     16992,        311]
CellTagsIndexPosition[     16949,        308]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Front Page for GroupLoopHoop6", "Section",
 CellChangeTimes->{{3.42675618384375*^9, 3.42675619828125*^9}}],

Cell[TextData[{
 "\tSymmetry-conserving partial-fraction vector-division \"Hoop Algebras\" \
unify all the algebras relevant to physics because (by Noether's theorem) \
their symmetries lead to forces and particles. They include (degenerate, \
single-symmetry) Real & Complex numbers.\n\tClifford (Geometric) algebras \
cl(p,q) are anti-commutative hoop algebras that have p square roots and q \
fourth roots of +1, ( so -1 is not unique). They unify 2D, 3D, spacetime, \
non-commutative, projective and conformal geometries, whilst generalising \
mechanics and analysis to any number of dimensions. They are graded into \
scalars, monovectors, bivectors,..., pseudoscalar. The pseudoscalar provides \
an anti-commutative replacement for \[ImaginaryI] in many situations. The \
CliffordG package will go into more detail.\n\tHoop theory is based on \
unsigned continuous \"Primal Numbers\" (the half line); these come from set \
theory via Natural Numbers {0,1,...}, unsigned rationals (equivalence \
relationships on ordered Natural Number pairs), and a continuity axiom. \
Premature negation to Reals, with the implicit but unfounded axioms \"minus \
one exists\" and \"minus one is unique\", is avoided.\n\tAlgebraic loops \
define multiplication tables for unsigned vectors. If they have ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry, the loops and the vectors can be \"",
 StyleBox["r",
  FontSlant->"Italic"],
 "-folded\", introducing \"generalised signs\" as orthogonal ",
 StyleBox["r'",
  FontSlant->"Italic"],
 "th roots of unity. Projecting these onto the as-yet-undefined complex plane \
(as cyclotomic numbers) destroys orthogonality. Signs supply the second \
operation that converts a (multiplicative) loop into an algebra.\n\tIf the \
loop has the Moufang properties (including ",
 StyleBox["zx.yz=(z.xy)z",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["), every vector has a multiplicative inverse. If it also has the \
determinant conservation property Det[A] Det[B] = ",
  FontWeight->"Plain"],
 "\[PlusMinus]",
 StyleBox["Det[AB], it has conserved symmetries (I call them \"sizes\") - the \
factors of the determinant of the loop mapped with a conjugate symbolic \
vector. Frobenius showed that all associative tables (groups) have this \
property. I found that all tables folded from groups, and from a few \
non-associative Moufang loops (octonions, etc) also have it. I define hoops \
by this property. Multiplicative inverses split into partial-fraction \
formulations with sizes as denominators (except for degenerate mono-sized \
hoops such as ",
  FontWeight->"Plain"],
 "\[DoubleStruckCapitalR] & ",
 "\[DoubleStruckCapitalC]).",
 StyleBox["\n\tVectors with some (but not all) sizes equal to zero give \
products with the same zeroed sizes - they project onto a sub-hoop with \
reduced symmetries. This eliminates vector division-by-zero - the infinite \
partial fraction does not occur in the projection. The size is related to h \
(=1-q) in h-deformed or q-deformed algebras. \n\tIf hoops are to maintain \
symmetries, so as to describe physics, multiplication and division must \
\"eject\" (\"reject\" in Geometric algebras) \"remainders\" - the symmetries \
that would be lost because of disparate zeroes. Hoop interactions then \
correspond to particle interactions; different hoops conserve different \
symmetry sets, just as different forces conserve different property sets.\n\t\
Abelian groups define hoops that have polar-duals with angles that add on \
vector multiplication. This provides powers and roots and describes \
rotations. ",
  FontWeight->"Plain"],
 "Some unital Polar-duals have (deBroglie-like?, zitterbewegung?) multi-phase \
\"orbits\" and intrinsic (Planck-like) areas. Their elements include \
half-spin quantum operators that are neither real nor complex, together with \
lepton-like 4-phase and quark-like 3, 6, and 12 phase orbits. ",
 StyleBox["Clifford algebras (and some other non-abelian hoops) perform \
rotations by pre- and post-multiplication by a half angle spinor. \
Non-commutativity may introduce uncertainty.",
  FontWeight->"Plain"]
}], "Text",
 CellChangeTimes->{{3.4267564799375*^9, 3.426756603765625*^9}, {
   3.426756641328125*^9, 3.426756969640625*^9}, {3.42675701915625*^9, 
   3.42675704603125*^9}, {3.426757386671875*^9, 3.426757448703125*^9}, {
   3.426757589015625*^9, 3.4267577478125*^9}, {3.42675785478125*^9, 
   3.42675787346875*^9}, {3.426757910203125*^9, 3.426757993078125*^9}, {
   3.42675808634375*^9, 3.42675858828125*^9}, {3.42675865453125*^9, 
   3.42675905421875*^9}, {3.426759105953125*^9, 3.42675913284375*^9}, {
   3.426759173234375*^9, 3.426759726734375*^9}, {3.426774896625*^9, 
   3.42677490740625*^9}, {3.426774947140625*^9, 3.426775180953125*^9}, {
   3.42677522234375*^9, 3.426775243203125*^9}, 3.426775284984375*^9, 
   3.4267753326875*^9, {3.426775364796875*^9, 3.42677537053125*^9}, {
   3.426775408125*^9, 3.426775460171875*^9}, 3.426775583640625*^9, {
   3.4267808700625*^9, 3.426780921484375*^9}, {3.42678102225*^9, 
   3.426781115765625*^9}, {3.426781212359375*^9, 3.426781417015625*^9}, {
   3.4267814595*^9, 3.4267814610625*^9}, {3.4267815453125*^9, 
   3.426781562*^9}, {3.42678180365625*^9, 3.426781843890625*^9}, {
   3.42678198846875*^9, 3.42678203853125*^9}, {3.4267821251875*^9, 
   3.42678214865625*^9}, {3.4267822718125*^9, 3.426782354328125*^9}, 
   3.426782386359375*^9, {3.426782439359375*^9, 3.4267825148125*^9}, {
   3.42678256709375*^9, 3.426782793015625*^9}, {3.426782922828125*^9, 
   3.42678296134375*^9}, {3.42678307990625*^9, 3.426783093109375*^9}, {
   3.4267831303125*^9, 3.426783156203125*^9}, {3.426783217390625*^9, 
   3.426783293875*^9}, {3.426783368375*^9, 3.4267834275*^9}, {
   3.42678350409375*^9, 3.42678353265625*^9}, {3.426783575984375*^9, 
   3.426783693046875*^9}, {3.426785069859375*^9, 3.426785142609375*^9}, {
   3.42678520346875*^9, 3.426785210859375*^9}, {3.4284800195*^9, 
   3.428480288625*^9}, {3.428480522265625*^9, 3.42848052584375*^9}, {
   3.4284805671875*^9, 3.42848056884375*^9}, {3.42848062846875*^9, 
   3.428480697578125*^9}, {3.428480756171875*^9, 3.42848078578125*^9}, 
   3.42848082603125*^9}],

Cell[TextData[{
 "\tGroupLoopHoop6.m is a package of procedures to create, manipulate, \
identify, and use small Groups, algebraic loops, and hoop algebras. A \
database includes over 80 hoops, all groups with up to 72 elements, and all \
non-associative Moufang Loops with up to 32 elements. CliffordG.m (to follow) \
is concerned with the distinctive properties of Clifford (Geometric) \
algebras. GroupLoopTest.nb validates the database, HoopGlossary.nb explains \
the terms employed, GroupLoopDemo.nb and HoopDemo.nb demonstrate the \
procedures. MathSource/6198 was a much smaller and simpler database and \
explanation, restricted to Hoop algbras and omitting the background material \
on Groups & Loops. It has not yet been updated to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Version 6."
}], "Text",
 CellChangeTimes->{{3.426775674203125*^9, 3.42677577225*^9}, {
   3.426775950578125*^9, 3.426775979484375*^9}, {3.4267760125625*^9, 
   3.426776111921875*^9}, {3.426782171859375*^9, 3.426782214890625*^9}, 
   3.4267828006875*^9}],

Cell["\<\
\tHoop algebras give tantalizing suggestions about the re-interpretation of \
mathematical physics, which I (at 79) cannot expect to explore. They may \
describe bosons and fermions. Ternary (quark) symmetries occur without \
invoking octonion triality. Kaluza-Klein orbital velocities could provide \
mass. Unital orbits may explain the \"law of large numbers\". Hoop maths may \
underlie (and simplify) \"M-theory\", describing non-point-like particles \
with three intrinsic scales, \"point-particle size, Planck size, size of the \
universe. Complex numbers can express much of mathematics, but are a \
Procrustean bed; some parts relevant to physics do not fit on it. I have \
scratched the surface of a more fundamental mathematics, and found many \
features that may be relevant to mathematical physics, but \"Non omnia \
possumus omnes\".\
\>", "Text",
 CellChangeTimes->{{3.426785695015625*^9, 3.42678570275*^9}, {
  3.426785740078125*^9, 3.426785743390625*^9}, {3.426785784640625*^9, 
  3.426785837015625*^9}, {3.4267859575625*^9, 3.426786006125*^9}, {
  3.426786059328125*^9, 3.4267860934375*^9}, {3.428480918015625*^9, 
  3.428480928109375*^9}}],

Cell[TextData[{
 "\tUpdated by the author from Mathsource/4894 to Version 6. 22nd August \
2008.\:f35f\n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000>`0@0006`00000000000000?oooooooooo
00000000000J0000^@000215CDH00040/0<001H000040000000000000000000000D00<03001X0@00
3P400000000000000000041n1@2`7P@0AP000;`0002`0000AdA9@`4008000`00/oLYQ@00002H0000
0@090003C00000<070000000100000<11P05000030:i01X01`000?`20000000000040000;@4000P0
003j0P000000000000040000;@4101`0003k0P`02@000000T040000000820TeC85=QKW<PDfEbJFH0
2P0W08X100000?ooooo/`a<0100002d10P030000000A0000300000P0000;00004000004000070000
2@000100000100001`000140000<00001P0000T0000@00006P000;T0000W00006000004000000000
00000000000U000030000040000V0000700000800000000000000000000000009@0000`000020000
DP00070100030000300000T000000000000009010000000000820Td0D`0P05<0H@1^07<0801C06D0
LP1Y06H0000000000000000000000000000000000000000000000000000001<0000F0387TG`30000
60LF00005P1@Na/0b>dC0:S]4`0<l1<06>j@O3P7TGcooooo<PNAO:/6TGc[1Y5l00000>0:G`800000
0@@000QA8`10l1<0L2:AO9HETGc[1Y5l00000800000hMad0<0`QHAh0000X31H0000F00006P0`kQ<0
<PNAO7C`4`0HkY1l>0NAO?oooolb1i5lZ`JAO>/6TG`00000W=N>030<8F4dk;H2b>hC08P0000005H0
b>hC00Q`7`2XkQ<0471R0:c^4`1K:?9gR4cb0BD0000hMad0000`03Qg7@30kQ<0g2ObM``0000`325Q
I7H02000000U0000300000<0000U0000300000L0080U000030000000080`0000300000l0080U0000
300000d0081;00004000000000050000:00000`000010000:00000`000020000:00000`000030000
3P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{5.25, 0.75},
  ImageMargins->0],
 "\n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000>`0@0006`00000000000000?oooooooooo
00000000000J00006P000215CDH00040/0<001H000040000000000000000000000D00<03001X0@00
3P400000000000000000041n1@2`7P@0AP000;`0002`0000AdA9@`4008000`00d`SLH`00002H0000
0@090003C00000<070000000100000<11P050000308J01X01`000?`20000000000040000;@4000P0
003j0P000000000000040000;@4101`0003k0P`02@000000T040000000820TeC85=QKW<PDfEbJFH0
2P0W08X100000?ooooo/`a<0100002d10P030000000A0000300000P0000;00004000004000010000
2@000100000100000@000140000<00001P0000T0000@00006P0001X0000W00006000004000000000
00000000000U000030000040000V0000700000800000000000000000000000009@0000`000020000
DP00070100030000300000T000000000000009010000000000820Td0D`0P05<0H@1^07<0801C06D0
LP1Y06H0000000000000000000000000000000000000000000000000000001<0000F0387TG`30000
60LF00005P1@Na/0b>dC0>d2ool<l1<06>j@O3P7TGcooooo<PNAO:/6TGc[1Y5l00000=01G`800000
0@@000QA8`10l1<0L2:AO9HETGc[1Y5l00000800000hMad0j`/Q6Qh0000X31H0000F00006P0`kQ<0
<PNAO7C`4`0HkY1l>0NAO?oooolb1i5lZ`JAO>/6TG`00000W=N>0>/;8AX003/0<PNAO0<0000003/0
000k00Q`7`0003/0<PNAO:c^4`1K:?9gR4cb0BD0000hMad0000`03Qg7@30kQ<0g2ObM``0003[2b4J
I7H02000000U0000300000<0000U0000300000L0080U000030000000080`0000300000l0080U0000
300000d0081;00004000000000050000:00000`000010000:00000`000020000:00000`000030000
3P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{0.75, 0.75},
  ImageMargins->0],
 "\nSubjects \nMathematics > Algebra > Group Theory\nScience > Physics\n\n\
Keywords \nMoufang loops, conservative algebras, algebras, Cayley-Dickson, \
Cayley-tables, Clifford, Clifford-like, conservative loops & algebras, \
continuous orbits, determinants, directors, Frobenius-conservation, \
generalized signs, Geometric algebras, groups, graded algebras, hoops, loops, \
isomers, isomorphs, m-vecs, plex-conjugate, Primal numbers, Roger algebras, \
shapes & sizes (of vecs), signed-tables, partial-division-by-zero, \
quasigroups, renormalization, roots of unity, vecs.\n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000>`0@0006`00000000000000?oooooooooo
00000000000J00006P000215CDH00040/0<001H000040000000000000000000000D00<03001X0@00
3P400000000000000000041n1@2`7P@0AP000;`0002`0000AdA9@`4008000`00]POLU@00002H0000
0@090003C00000<070000000100000<11P050000308J01X01`000?`20000000000040000;@4000P0
003j0P000000000000040000;@4101`0003k0P`02@000000T040000000820TeC85=QKW<PDfEbJFH0
2P0W08X100000?ooooo/`a<0100002d10P030000000A0000300000P0000;00004000004000010000
2@000100000100000@000140000<00001P0000T0000@00006P0001X0000W00006000004000000000
00000000000U000030000040000V0000700000800000000000000000000000009@0000`000020000
DP00070100030000300000T000000000000009010000000000820Td0D`0P05<0H@1^07<0801C06D0
LP1Y06H0000000000000000000000000000000000000000000000000000001<0000F0387TG`30000
60LF00005P1@Na/0b>dC0>d2ool<l1<06>j@O3P7TGcooooo<PNAO:/6TGc[1Y5l00000=01G`800000
0@@000QA8`10l1<0L2:AO9HETGc[1Y5l00000800000hMad0BP`Q]1h0000X31H0000F00006P0`kQ<0
<PNAO7C`4`0HkY1l>0NAO?oooolb1i5lZ`JAO>/6TG`00000W=N>04X<8K@003/0<PNAO0<0000003/0
000k00Q`7`0003/0<PNAO:c^4`1K:?9gR4cb0BD0000hMad0000`03Qg7@30kQ<0g2ObM``0001:326d
I7H02000000U0000300000<0000U0000300000L0080U000030000000080`0000300000l0080U0000
300000d0081;00004000000000050000:00000`000010000:00000`000020000:00000`000030000
3P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{0.75, 0.75},
  ImageMargins->0]
}], "Text",
 CellChangeTimes->{{3.4267758198125*^9, 3.426775920578125*^9}, {
   3.42677613896875*^9, 3.42677617325*^9}, {3.42677627125*^9, 
   3.42677628846875*^9}, 3.426782857890625*^9, {3.426783747875*^9, 
   3.42678375171875*^9}, {3.4267854975625*^9, 3.426785542890625*^9}, 
   3.4267860461875*^9, {3.42848094453125*^9, 3.42848094640625*^9}}],

Cell["\<\
Vec sizes can be zero; operations are then \"projected\" onto a sub-algebra \
(of reduced symmetry) with the same sizes zeroed. To maintain size \
conservation, hoopTimes may \"project\" results into the sub-algebra and \
\"eject\" remainders. This resembles particle interactions and decays, with \
remainders corresponding to ejected particles with different symmetries. Some \
hoops have Polar-duals with additive angles, generalizing the {x,y} and \
{r,theta} complex plane duality. This allows the calculation of vector powers \
and roots, via \"hoopPower\". Some unital Polar-duals have (deBroglie-like) \
multi-phase orbits and intrinsic (Planck-like) areas. Their elements include \
half-spin quantum operators that are neither real nor complex. Hoop algebras \
give tantalizing suggestions about the re-interpretation of mathematical \
physics, which (at 77) I cannot expect to explore. They may describe bosons \
and fermions. Ternary (quark) symmetries occur without invoking octonion \
triality. Kaluza-Klein orbital velocities could provide mass. Unital orbits \
may explain the \"law of large numbers\". Hoop maths may underlie (and \
simplify) \"M-theory\", describing non-point-like particles with an intrinsic \
Planck scale. Complex numbers can express much of mathematics, but are a \
Procrustean bed; some parts relevant to physics do not fit on it. I have \
scratched the surface of a more fundamental mathematics, and found many \
features that may be relevant to mathematical physics, but \"Non omnia \
possumus omnes\" (Virgil).\
\>", "Text",
 CellChangeTimes->{{3.426785658234375*^9, 3.426785658734375*^9}}]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1079, 742},
WindowMargins->{{Automatic, 58}, {1, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      Cell[
       TextData[{
         CounterBox["Page"]}], "PageNumber"], " ", 
      Cell[
      " ", "Header", CellFrame -> {{0.5, 0}, {0, 0}}, CellFrameMargins -> 4], 
      
      Cell[
       TextData[{
         ValueBox["FileName"]}], "Header"]}], 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, None}, {
  None, None, None}},
PrintingOptions->{"FacingPages"->False,
"FirstPageFooter"->False},
Magnification->2.,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 112, 1, 140, "Section"],
Cell[705, 26, 6186, 100, 1375, "Text"],
Cell[6894, 128, 1050, 18, 319, "Text"],
Cell[7947, 148, 1167, 18, 352, "Text"],
Cell[9117, 168, 5303, 80, 451, "Text"],
Cell[14423, 250, 1642, 23, 550, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
