(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1860208,      50246]
NotebookOptionsPosition[   1834763,      49505]
NotebookOutlinePosition[   1835599,      49537]
CellTagsIndexPosition[   1835556,      49534]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["GroupLoopHoop6' Package.", "Title",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
 TextJustification->0.25,
 FontFamily->"Times New Roman"],

Cell[BoxData[{
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
   RowBox[{"General", "::", "\"\<spell1\>\""}], ",", 
   RowBox[{"Part", "::", "\"\<partd\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"Syntax", "::", "\"\<com\>\""}], ",", 
   RowBox[{"Less", "::", "\"\<nord\>\""}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "That", " ", "allows", " ", "similar", " ", "names", " ", "and", " ", 
     "nulls", " ", "to", " ", "be", " ", "used"}], ",", " ", 
    RowBox[{
    "and", " ", "creates", " ", "the", " ", "package", " ", "if", " ", "the", 
     " ", "reply", " ", "is", " ", 
     RowBox[{"yes", "."}]}]}], "*)"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0.25],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["Mathematica6 version 23/8/8", "Subsection"],

Cell[TextData[{
 "Symmetry-conserving partial-fraction-division \"hoop algebras\" are closely \
related to Groups and Moufang Loops. They subsume most traditional algebras (\
\[DoubleStruckCapitalR], \[DoubleStruckCapitalC], Clifford, Geometric, \
Jordan, Lie, Quaternion, Octonion, Wedge etc). They multiply, divide, add and \
split vectors with generalized signs and employ many new or neglected \
mathematical concepts to re-define physical mathematics.\nTo activate the \
package for use with ",
 StyleBox["GroupLoopDemo.nb ",
  FontSlant->"Italic"],
 "& ",
 StyleBox["HoopDemo.nb",
  FontSlant->"Italic"],
 ", either save it as a package in ",
 StyleBox["Addons/ExtraPackages",
  FontSlant->"Italic"],
 " and use ",
 StyleBox["<<GroupLoopHoop6`",
  FontSlant->"Italic"],
 " or initialise the following cell and answer Yes to the query. ",
 StyleBox["GroupLoopTest.nb",
  FontSlant->"Italic"],
 " can then be used to validate the package. A shorter and simpler account of \
Hoop Algebras (using a much smaller package) is available as ",
 StyleBox["MathSource",
  FontSlant->"Italic"],
 "/6198; it should be studied first if your interest is only in Hoops."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "This package includes:\n (1) A database containing all finite groups with \
up to 73 elements and a few larger groups, together with many loops and hoop \
algebras, in an extension of the GAP Atlas, as \"protoloops\" - preferred \
isomorph Cayley index tables. \n (2) An identification procedure that will \
identify any isomorph of a group or hoop in the database, and provisionally \
identify isomorphs of the other loops.\n (3) Procedures to create, \
manipulate, and analyse groups, loops and hoops.\n (4) Tables of conserved \
shapes for many hoops.\n References are provided in ",
 StyleBox["GroupLoopDemo.nb",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1. Version, Copyright notice.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Version 6a. 23/8/8  Fast routine ",
 StyleBox["clf[p,q]",
  FontSlant->"Italic"],
 " added. r31r etc entered as tables as cl, Walsh, grayinv all deleted.\n\
Version 6. 28/7/8 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6. Clifford shapes corrected. Other Clifford material removed to \
CliffordG.m. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "6 \"improvements\" have destroyed \"generalised signs\" and many matrix \
group formulations.\nVersion 4. dated August 2007. Planarcom (Olariu), Lie \
and Jordan algebras added, Minor edits.\nVersion 3b. Packaged as \
GroupLoopHoop`, without extraneous bits, validation. etc.\nMore \
non-associative Moufang Loops included. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.2 compatible. ",
 StyleBox["genTimes",
  FontSlant->"Italic"],
 " etc replaced by ",
 StyleBox["hoopTimes",
  FontSlant->"Italic"],
 ".\nComments to ",
 StyleBox["rhberesford@btinternet.com ",
  FontSlant->"Italic"],
 "please."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}}],

Cell[TextData[{
 "\[Copyright] Copyright 2003, 2004, 2005, 2006, 2007, 2008",
 StyleBox[" Roger Herbert Beresford, 15, Brook Lane,, Woodhouse Eaves, \
Loughborough, Leics, LE11 3RA, England",
  FontSlant->"Italic"],
 ". \nConsiderable effort has gone into checking this work, but some errors \
probably persist. No responsibility will be accepted for any problems arising \
from its use. Permission is granted to distribute this file for any purpose \
except for inclusion in commercial software or program collections. This \
copyright notice must remain intact."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 CellSize->{808, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Revisions.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Based on and replacing ",
 StyleBox["GroupMLHoops.nb & HoopsDemo",
  FontSlant->"Italic"],
 " originally published as [5], May 2003 and revised up to 13th Sept. 2003.\n\
Version 1. 4th Dec. 2003. Demonstrations re-designed for non-",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "users.",
 StyleBox["\n",
  FontSlant->"Italic"],
 "Version 1a.",
 StyleBox[" ",
  FontSlant->"Italic"],
 "9th Dec. 2003. Database expanded. Appendices included. \nVersion 1b. 11th \
Jan. 2004  C4c from u4[[16]]. genCos & genSin[x,m,j] not genCos[x,m,i] for \
clarity. Duplicate ms removed. Pr changed to P4, msi creates P4, P16c. \
Plex-conjugate appendix enlarged. Extra signed tables added.\nVersion 1c. \
July - November 2004. Quadratic sizes (up to 6 elements) put first for use \
with JuliaSets. Introduced remainders on division by zero-vecs. Minor \
clarifications. hoopTest revised, Q12r corrected, rational units for \
\[DoubleStruckCapitalH] & \[DoubleStruckCapitalO], 3/11/4.\nVersion 1d. C8cn \
in place of QC2n. More u2 matrices and related groups. More 64 element \
incantations. Rl & Rr calculated on multiplication, tested in section 2.11.6. \
Q12 toPol corrected. Qr transposition removed to match standard quaternion \
package, 6/1/05\nVersion 2. 20/2/5 Stand-alone package extracted from \
HoopAlgebras1d. Renamed ",
 StyleBox["GroupLoopHoop",
  FontFamily->"Times New Roman"],
 ".m. Added reductiveQ, quasigroupQ corrected to loopQ, all tests include gpd \
test; 5/7/5. \nVersion 2a. 6/12/5 Octonion compositions added. ",
 StyleBox["alph",
  FontSlant->"Italic"],
 " lengthened to 260. alternativeQ ",
 StyleBox["l",
  FontSlant->"Italic"],
 " error removed.\nC3C4c & C3C4 shapes, D3 & P4 toPol revised, C9j &C9J \
distinguished. Many minor edits.\nVersion 3. Packaged as ",
 StyleBox["GroupLoopHoop.m.",
  FontSlant->"Italic"],
 " 21/4/2006 without tests or Visualizations.\n(Previous versions did not \
create a package.)\ngi corrected for CL22. C3C3j factors, but no pol/vec. ",
 StyleBox["as",
  FontSlant->"Italic"],
 " copied from ",
 StyleBox["HoopData",
  FontSlant->"Italic"],
 ". non-Abelian remainders corrected. Sign removed from hoopPo",
 StyleBox["wer",
  FontSlant->"Italic"],
 ". ",
 StyleBox["cscale",
  FontSlant->"Italic"],
 " deleted. C3C4c  & C3C4 L4a, L4b factors used to give correct ",
 StyleBox["toPol, toVec",
  FontSlant->"Italic"],
 ". QPower included. sh12 extended to all functions conserved in at least one \
case. Noncommutative extensions to ",
 StyleBox["ge, det",
  FontSlant->"Italic"],
 ".\nVersion 3a, 6/6/6. Octr, not Octc. Alt12n second incantation. ",
 StyleBox["cd",
  FontSlant->"Italic"],
 " write-up, accepts incantations. O4k added. Some colour-coding.\nVersion \
3b, 19/9/6 Non-conservative non-associative Moufang Loops D3Mn, D4M1n, ... \
Q12M5n added; Q8M2 and 5 (Q8C2M, P16M, C8pC2M, KiC4M, C4iC4M) conservative \
non-associative 32 element loops added. OctC2 was already known. Moufang \
doubling partially implemented as ",
 StyleBox["md",
  FontSlant->"Italic"],
 ". ",
 StyleBox["Rest, Mod",
  FontSlant->"Italic"],
 " altered to be M4.2 compatible. ",
 StyleBox["genTimes",
  FontSlant->"Italic"],
 " etc changed to ",
 StyleBox["hoopTimes ",
  FontSlant->"Italic"],
 "etc. shape[C3P4] restored.\n(Non-commutative OPScalar' (Mathsource/4291) \
investigations abandoned as it screws up Sqrt[b-a])\nVersion 3c. Isotope \
clarified. shape[\"C5\"] found 17/4/7\nVersion 4. Minor edits, Olariu's \
Planarcom added 24/7/7. Lie[],Lie0[],toLie0[] added 15/8/7. toJordan[] \
26/8/7. ",
 StyleBox["isotope",
  FontSlant->"Italic"],
 " replaced by ",
 StyleBox["mutant",
  FontSlant->"Italic"],
 ".\nVersion 6. 25/7/8 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6. Clifford, Jordan, Lie & Skeletons removed, ",
 StyleBox["Mathematica6 generalised signs problem",
  FontColor->RGBColor[1, 0, 0]],
 ".\n21/8/8 Fast Clifford routine added."
}], "Text",
 PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Keywords.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell["\<\
\tAlgebras, Cayley-Dickson, Cayley-tables, Clifford, Clifford-like, \
conservative loops & algebras, continuous orbits, determinants, directors, \
Frobenius-conservation, generalized signs, groups, Geometric algebras,Hoops, \
Hoop shapes, Hoop sizes, isomers, isomorphs, loops, Moufang Loops, mutant, \
m-vecs, non-associative algebras, plex-conjugate, Primal numbers, \
partial-fraction division, partial-fraction-division-by-zero, quasigroups, \
renormalization, remainders, Roger algebras, roots of unity, signed-tables, \
vecs, monovectors, zero-vectors.\
\>", "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 CellSize->{490, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4. Warnings.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Many of the new concepts transcend and revise those current mathematical \
beliefs that are solely based on real and complex numbers, showing them to be \
specialisations of the more general Hoop concepts.\nGlobal effects -",
 StyleBox[" genel,  globa, matel, mm, nn, gi, gp, R1, Rr, sg, smax, strep ",
  FontSlant->"Italic"],
 "are Global names that are altered by various routines.\n",
 StyleBox["Mathematica6 does not handle generalised signs the way that 4.2 \
did",
  FontColor->RGBColor[1, 0, 0]],
 "."
}], "Text",
 PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5. Limitations.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tOnly a few loops with over 73 elements are included in the database; they \
will not be uniquely identified by ",
 StyleBox["id",
  FontSlant->"Italic"],
 ". All 267 64-element groups are present, but many lack unique \
identification and generation. g4828 cannot be generated by ",
 StyleBox["makeProtoloop.",
  FontSlant->"Italic"],
 " Associativity is (deliberately) not tested by ",
 StyleBox["id",
  FontSlant->"Italic"],
 ", so non-associative tables may be wrongly identified as groups (",
 StyleBox["idc",
  FontSlant->"Italic"],
 " tests for conservation, but not associativity, before attempting an \
identification). Isotopes are included for many Clifford hoops and named \
signed-tables. (Isomorphs correspond to renaming elements; mutants involve \
changing some element signs so that the structure, but not the details, of \
the shape is conserved.)\n\tThe creation of faithful matrix representations \
of groups and signed tables from unitary monomial matrices, using ",
 StyleBox["ma, mg & ms",
  FontSlant->"Italic"],
 ", has only been cursorily investigated. Extra matrices, especially \
traceless matrices, could be included, and systematic search procedures \
(supplied) could be used with more generating matrices.\n\tSigned table & \
generalised plex-conjugate investigations, generalised quadratic and \
simultaneous equation solution procedures are all rudimentary. Most of the \
material related to Clifford (Geometric) algebras removed to CliffordG.m.\n\t\
",
 StyleBox["Mathematica6 cannot handle generalised signs the way that 4.2 did",
  
  FontColor->RGBColor[1, 0, 0]],
 ".."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -2.375}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["6. Note on Implementation.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tA standard methodology has been aimed for. Top-level procedures should \
accept any format for loop arguments:- an indexTable or signed-table (in list \
or traditional matrix form), the name of a predefined table, a mnemonic that \
matches the first element (i.e. the name) of an entry in the ",
 StyleBox["loop",
  FontSlant->"Italic"],
 " data, the table size and position e.g. {12,1} as in the GAP atlas, or an \
instruction that creates an index table, such as ",
 StyleBox["ca[12,1],  co[C3,C4,2],  ge[{3,4},{ba\[Rule]a2b}],  mp[{12,1}],  \
ma[{u2[[10]], u2[[13]]}]].",
  FontSlant->"Italic"],
 " These examples all create \"",
 StyleBox["Q12",
  FontSlant->"Italic"],
 "\" - from a formula, as a non-abelian composition, from relators, as a \
protoloop, and from 2\[Times]2 matrices. Deeper procedures (that are likely \
to be called many times by a top-level procedure) only accept tables as \
lists, for speed. Two global tables, ",
 StyleBox["globa & glo",
  FontSlant->"Italic"],
 ", are set up when a \"target loop\" is established, to eliminate the need \
to copy large tables as far as possible; a global mnemonic ",
 StyleBox["gmn,",
  FontSlant->"Italic"],
 " and two global variables ",
 StyleBox["mm, nn",
  FontSlant->"Italic"],
 " are also set up. Some procedures (e.g. hoopFactor",
 StyleBox["[f]",
  FontSlant->"Italic"],
 ") use ",
 StyleBox["glo",
  FontSlant->"Italic"],
 " implicitly, whilst others (e.g. ",
 StyleBox["sh[]",
  FontSlant->"Italic"],
 ") use ",
 StyleBox["gmn",
  FontSlant->"Italic"],
 " explicitly. Many procedures have a final \"Options\" argument, ",
 StyleBox["o_:0",
  FontSlant->"Italic"],
 ", that modifies the operation; if it is negative the output properties will \
(in many cases) be tested and failures reported. Two-letter abbreviations are \
supplied for frequently used procedures, to reduces clutter in the ",
 StyleBox["loop",
  FontSlant->"Italic"],
 " data file. Tests that yield True or False follow the \"trailing Q\" ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " nomenclature; the reason for falsity is output if ",
 StyleBox["o\[NotEqual]0",
  FontSlant->"Italic"],
 ".\n\t\"Isotopes\" are signed tables that differ from each other by changing \
the sign of some basis elements. (\"Isomorphs\" differ from each other by \
changing the order of the basis elements.) Isotopes are effectively the same \
algebra, and perhaps need correlating to eliminate duplication."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["\tTWO LETTER ABBREVIATIONS.\n",
  FontWeight->"Bold"],
 "as[v,w] maps v with u.,   \tbf=Bold form,\t\nca=Cayley Table from formula,\n\
cd=General Cayley-Dickson,\tcl=Create Clifford Table (clf is faster),\n\
co=Compose Cayley Tables,\tds=Formulae in Dozalcons,\nfa=Find alpha \
determinant,\tfp=Find Powers-of-2 determinant,\ngd=Loop data,\t\t    \t\
ge=create loop from relators,\ngi=group inverse data,\t   \tgp=multiplicity \
data,\nid=Table identity,\t    \tma=make group from matrices,\nmd=Moufang \
Doubling,\t    mg=Make group from matrix list,\nmp=Make Protoloop,\t\t    \
ms=make signed table from matrices,\nmm=No. of elements in target loop,\n\
nn=position of target loop in loop[[mm]],\npe=Create Cayley Table from \
permutations,\npr is a control global variable Pr>0 often gives diagnostics,\n\
Rl,Rr = Left and right remainders after hoopTimes,\ns3,s4,s5=permutations \
defining S3 to S5,\nsg=subgroup indices,    \tsh=shape of target loop,\n\
tf=TraditionalForm,\t    \tts=ToSignedLoop,\nu2,u3,u4 = unitary monomial \
matrices used by ma,mg,ms."
}], "Input",
 FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["7. Set up the GroupLoopHoop6.m package, usage.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[{
 "7.1 Begin, ",
 StyleBox["GroupLoopHoop6 ",
  FontFamily->"Arial"],
 "Usage."
}], "Subsubsection",
 PageWidth->WindowWidth],

Cell["BeginPackage[\"GroupLoopHoop6`\"]; ", "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[TextData[{
 StyleBox["GroupLoopHoop6",
  FontFamily->"Courier New"],
 "::usage = \"",
 StyleBox["GroupLoopHoop6",
  FontFamily->"Courier New"],
 " is a Mathematica6 package that creates a database (based on the GAP group \
atlas) of over 800 loops, including all groups with up to 73 elements. It \
generalizes signs & creates & manipulates Groups & 'Moufang Loops' (ordered \
division quasigroups) as index-Tables (Cayley tables with indices as \
elements) and signed tables (e.g. the Quaternion multiplication table). It \
also sets up symmetry-conserving partial-fraction division algebras (Hoops) \
based on them, and provides procedures & tests for division, powers, roots, \
polar-dual formulations & loop properties. Most physically significant \
algebras are Hoops. Geometric algebras are developed in CliffordG.m; they are \
hoops but have features that are not handled in this package. 28/7/8\";"
}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 Alphabetic list of Usage for functions and procedures.", \
"Subsubsection",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"a", "::", "usage"}], "=", "\"\<Symbol in HoopTbl etc.\>\""}], ";",
   
  RowBox[{
   RowBox[{"b", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"c", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"d", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"e", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"f", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"g", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"h", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"i", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"j", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"k", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"l", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"m", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"n", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"o", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[OHat]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"p", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"q", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"r", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"s", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"t", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"u", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"v", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"w", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"x", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"y", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"z", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Alpha]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Beta]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Gamma]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Delta]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Epsilon]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CurlyEpsilon]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Zeta]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Eta]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Theta]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalTheta]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Iota]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Kappa]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Lambda]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Mu]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Nu]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalXi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CurlyPi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalPi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Rho]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CurlyRho]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Sigma]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalSigma]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Tau]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Upsilon]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Phi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CurlyPhi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalUpsilon]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Chi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Psi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalOmega]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalKoppa]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Sampi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[Mho]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[WeierstrassP]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[AAcute]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[AGrave]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[AHat]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[EAcute]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[EHat]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[IHat]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[OAcute]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[UAcute]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[UHat]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[CapitalSampi]", "::", "usage"}], "=", "\"\<\>\""}], ";", 
  RowBox[{
   RowBox[{"\[EmptySet]", "::", "usage"}], "=", "\"\<\>\""}], ";"}]], "Input",\

 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"abbr", "::", "\"\<usage\>\""}], "=", 
   "\"\<abbr[t_,o_:1] is used by 'dico' & 'trico' to create an abbreviation \
such as {12,\!\(\*SubscriptBox[\(4\), \(5\)]\),15} in which subscripts \
indicate numbers of appearances of elements in a table diagonal, with the \
first element real for abelian and negated for signed tables.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"abbrFactors", "::", "\"\<usage\>\""}], "=", 
   "\"\<abbrFactors[g_indexTableQ:glo,p_:pow2] creates an abbreviation such \
as {\!\(\*SubscriptBox[\(1\), \(2\)]\),2,\!\(\*SubsuperscriptBox[\(2\), \
\(2\), \(2\)]\),\!\(\*SubsuperscriptBox[\(6\), \(2\), \(2\)]\)} for the \
factor structure of the indexTable determinant. In this (Q36) example there \
are two different linear factors, a single quadratic and two repeated \
quadratic factors, and two repeated sixth powers. Note that abelian groups \
(only) have no repeated factors. Uses power2 as pow2 sometimes errs.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"abelGrassmanQ", "::", "\"\<usage\>\""}], "=", 
   "\"\<Tests whether (ab)c=(cb)a for all a,b,c in 'G'\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"abelianQ", "::", "\"\<usage\>\""}], "=", 
   "\"\<Tests whether Transpose[g]==g.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"allFactorGroups", "::", "\"\<usage\>\""}], "=", 
   "\"\<allFactorGroups[gg_:glo,o_:0,i1_:2,i2_:49,p_:{}] finds the  Factor \
groups (quotient groups) for all normal subgroups in the size range {i1,i2} \
of 'gg'. If the global variable 'sg' contains the selected subgroups (i.e. \
after calling subgroups) set 'o' to 1 to avoid recalculation as sg already \
contains the relevant subgroups. A list may be appended; the first matching \
subgroup {i1,p[[_]]} is then reported and the search ends.\>\""}], ";", 
  RowBox[{
   RowBox[{"alph", "::", "\"\<usage\>\""}], "=", 
   "\"\<A list of 292 symbols, {a,b,...\[Alpha],\[Beta]..,a} (the first 72 \
are repeated later) used as symbolic elements of Cayley Tables.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"alpha", "::", "\"\<usage\>\""}], "=", 
   "\"\<Same as alph, with text letters in place of symbols, but only 192 \
characters\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"alternativeQ", "::", "\"\<usage\>\""}], "=", 
   "\"\<alternativeQ[g_:glo,o_:0] tests whether xx.y=x.xy for all x,y.z in \
'g'. It reports the first error if 'o'\[NotEqual]0. See PMA p94, Numbers \
p226.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"amQ", "::", "\"\<usage\>\""}], "=", 
   "\"\<Tests if x(yx.zx)=(xy.xz)x\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"any", "::", "\"\<usage\>\""}], "=", 
   "\"\<Dummy used in various tests\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"arcTanh", "::", "\"\<usage\>\""}], "=", 
   "\"\<arcTanh[adj_,opp_] or arcTanh[{adj_,opp_}] calculates an angle that \
takes account of the octant of the arguments; the angle has an imaginary part \
for three non-standard hyperbolae. Note that opp,adj is the argument order \
used by many mathematicians.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"as", "::", "\"\<usage\>\""}], "=", 
   "\"\</.as[w_] replaces elements of alph by elements of w.  /.as[v_,w_] \
replaces elements of v by elements of w. (included for compatibility with \
Hoops.m)\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"associator", "::", "\"\<usage\>\""}], "=", 
   "\"\<associator[g_:glo,i_,j_,k_] is the standard groupoid function, \
(ij)k-i(jk) \>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"AssociativeQ", "::", "\"\<usage\>\""}], "=", 
   "\"\<AssociativeQ([gg_:glo,o_] tests whether (x(y z))==((x y) z) for all \
x,y,z in 'gg' and reports the first error if 'o'\[NotEqual]0.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"associativeQ", "::", "\"\<usage\>\""}], "=", 
   "\"\<associativeQ([gg_:glo,o_] tests whether (x(y z))==((x y) z) (up to a \
sign) for all x,y,z in 'gg' and reports the first error if 'o'\[NotEqual]0. \
Some non-associative signed tables (including Qr, Octr, Sed) are associative \
'up to a sign'\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontFamily->"Courier New"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"bolQ", "::", "usage"}], "=", 
   "\"\<bolQ([gg_:glo,o_] tests the left & right Bol identities (PMA p97-8) \
(z.yz)x ==z(y.zx) & x(zy.z) ==(xz.y)z for all x,y,z in 'gg' and reports the \
error type if 'o'\[NotEqual]0.\>\""}], ";", 
  RowBox[{
   RowBox[{"c2simeq", "::", "usage"}], "=", 
   "\"\<c2simeq[{a_,b_,c_]solves simultaneous linear equations Ax+B=C in the \
C2 algebra. Wherever the solution is indeterminate, it includes a free x$ \
variable\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ca", "::", "usage"}], "=", 
   "\"\<ca[m_Integer?Positive,a_Integer] or\n   ca[{m_,a_:1}] checks that \
GCD[m,k=Abs[a]] is 1 before creating an m\[Times]m quasigroup indexTable with \
first row and first column containing the 'unity' {1,2,...,m}, and with every \
element occurring once in each row and column (i.e. it is a sorted quasigroup \
or Latin Square). The result is the Cyclic group 'Cm' if 'a' is 0 or absent, \
the Dihedral group 'D[m/2]' if 'k'='m-1' and the generalised Quaternion group \
'Q[m]' if 'k'='m/2-1'; some other values of 'k' give compound Dihedral or \
Quaternion groups. Some other cases give Hamiltonian quasigroups. If 'a' is \
negative, non-associativity is reported. The indexTable is output.\>\""}], 
  ";", 
  RowBox[{
   RowBox[{"caylindex", "::", "usage"}], " ", "=", " ", 
   "\"\<caylindex[gg_] converts a square symbolic table 'gg' to an indexTable \
on the assumption that the first row is the unity.\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cd", "::", "usage"}], "=", 
   "\"\<cd[{gamma__:IntegerQ}] (generalized Cayley-Dickson) takes a list of \
none or more \[PlusMinus]1's and recursively builds signed-tables (including \
P,R,C,H,O,sedenions) by the generalized Cayley-Dickson doubling procedure. \
See Lounesto, Clifford Algebras & Spinors, 2nd. ed., p285.\n    'm' is the \
table (of size q\[Times]q) obtained by dropping the last \[PlusMinus]1; the \
starting case (with no \[PlusMinus]1's) is the primal multiplication table \
{{1}}. The top-left quarter of the new table repeats 'm'; the top right \
quarter is 'm' transposed and shifted by 'q' (using 'modqr' to give a signed \
index); the bottom left quarter is 'm' shifted by 'q', with all but the first \
column multiplied by the current \[PlusMinus]1. The bottom right quarter is \
'm' transposed with all but the first row & column multiplied by the current \
\[PlusMinus]1. An extension takes any of {2, -2, 3, 3., -3,  4, 4. -4, \
-4.,'incantation'} in place of the first \[PlusMinus]1, and also allows '\
\[PlusMinus]1.' (i.e. real) elsewhere. This generates more signed hoop \
algebras and lots of rubbish. ('incantation' is any string that creates a \
hoop.) If the last gamma is {list}, e.g. {2} or {3}, the last stage is the \
composition of the penultimate result with the group ca[list]. This gives a \
parent group.\n    md is a related Moufang Doubling operation.\>\""}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"centralizer", "::", "usage"}], "=", 
   "\"\<standard group function\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"center", "::", "usage"}], "=", 
   "\"\<standard group function\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"centre", "::", "usage"}], "=", 
   "\"\<standard group function\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cl", "::", "usage"}], "=", 
   "\"\<cl[p,q:0] creates Clifford[p,q]; cl[p,list] creates Clifford-like \
algebras with p binary generators, those in list having negative squares. See \
Lounesto[13] ch21. Made obsolete by clf. CliffordG.m has an extended version.\
\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"clf", "::", "usage"}], "=", 
   "\"\<clf[cp,cq] is a fast routine to generate CLpq. The entries are \
'BitXor[i-1, j-1]+1', multiplied by \[PlusMinus]1. It creates a vector 'edig' \
of increasing powers of 2 such that 'Plus@@edig[[i+1]]/2 = i', and a list \
'pt=Table[\!\(\*SuperscriptBox[\(2\), \(i\)]\),{i,cp+1,cp+cq}]'. The \
expression 'Signature[Flatten[{edig[[i]],edig[[i]]+1}]]' then gives the sign \
arising from index swaps, and the expression 'If[OddQ[ Length[ Intersection[ \
pt,edig[[i]], edig[[j]]]]],-1,1]]' corrects this for the number of element \
that square to -1. It is about 4 times faster than cl, which employs Walsh & \
graycode subroutines.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"co", "::", "usage"}], "=", 
   "\"\<co[gg_?indexTableQ,hh_?indexTableQ,a_:0] outputs the direct \
composition of 'gg' & 'hh' if 'a' is 0 or absent; some values of 'a' create \
quasigroups or groups. If 'a' is 1 or negative, non-groupoid & \
non-associative tables will be reported. 'gg' (but not hh) may be a signed \
table. co[g_,h_,gg_,hh_,a_,o_:0,p_:0] and co[g_,gg_,hh_,a_,o_:0] (NB first \
parameter 'a' can be 0, but must be supplied) generate the multiple \
compositions by iteratively composing the inner tables using the leading \
parameters.\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"collect", "::", "usage"}], " ", "=", " ", 
   "\"\<collect[%], collect[sg], or collect[] is used to count the numbers of \
each type of subgroup identified by subgroupTypes and stored in 'sg'\>\""}], 
  ";", 
  RowBox[{
   RowBox[{"conservativeQ", "::", "usage"}], "=", 
   "\"\<conservativeQ[gg_:glo] tests whether \
Det[A]Det[B]=\[PlusMinus]Det[AB], for the (possibly signed) loop 'gg'. \
Frobenius showed that associativity is a sufficient condition; a few \
non-associative Moufang tables are conservative. Random integer values of the \
elements of A & B are tested if 'gg' is signed or not associative. \n   \
conservativeQ[gg_,t_:Complex,r_:{-1-\[ImaginaryI],1+\[ImaginaryI]}/2] used \
random A & B of type 't' in range 'r' but this is not allowed in M6. As \
round-off errors could wrongly give False, the test uses the ratio of the \
minimum to the maximum of the \[PlusMinus] cases. Fails with \
\[DoubleStruckCapitalJ] algebras\>\""}], ";", 
  RowBox[{
   RowBox[{"cosorbit", "::", "usage"}], "=", 
   "\"\<cosorbit[\[Theta]_,phaselist_:{0,1,2,3,4,5},scale_:1,meanlist_:Table[\
0,{24}]] creates an orbit with angle parameter \[Theta]; phaselist defines \
the phase of each element (with null values permitted) and the number of \
elements; scale is a factor that can be adjusted to obtain a unitary result; \
meanlist is an optional offset from zero.\>\""}], ";", 
  RowBox[{
   RowBox[{"cQ", "::", "usage"}], "=", "\"\<Tests if (xy.y)z=x(yy.z)\>\""}], 
  ";", 
  RowBox[{
   RowBox[{"dico", "::", "usage"}], "=", 
   "\"\<dico[g_:glo] is the 'diagonal count' i.e. the count of elements of \
'g' in the table diagonal, compressed via 'abbr' (q.v.). The first entry is \
the number of square roots of unity, and is signed if 'g' is signed, and is \
real if 'g' is abelian.  A specific extra diagnostic integer is added for \
tables with m = 32, 48, 54, 64 or 72. For example \
{12,\!\(\*SubscriptBox[\(4\), \(5\)]\),15} is dico[makeProtoloop['g3207']]. \
There are 12 occurences of the unit; 5 other elements occur 4 times \
(total=32), and there are 15 subgroups of 4 elements.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Distribution", "::", "usage"}], "=", "\"\<From Skiena\>\""}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"det", "::", "usage"}], "=", 
   "\"\<det[aa_?MatrixQ, m_:2,t_:Times] calculates a generalized determinant, \
for a (not necessarily square) matrix, as |m| terms. Putting 'm' ={1,2,3,4} \
gives the {permanent, determinant, tritermanent (involving \[DoubleStruckJ]), \
and 4terminant (involving \[DoubleStruckI])}; if 'm' is negative or >4, the \
result is |m| terms that add, when signed, to a 'det'. In effect, each \
element of 'a' is multiplied by a power of the sign 'J', with \
\!\(\*SuperscriptBox[\(J\), \(\(|\)\(m\)\(|\)\)]\)=1; the final result \
comprises the signed sums of all the determinant-like terms with a given \
power of 'J'. The calculation is recursive via a stripped down version, \
'det1', a signed row or column matrix being the basis. If necessary, 'short' \
matrices are transposed to become 'long', i.e. with more columns than rows. \
'det' sums all the square det's, as in the Moore-Penrose inverse. \>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"det1", "::", "usage"}], "=", "\"\<See det\>\""}], ";"}]}], "Input",\

 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"entropicQ", "::", "usage"}], " ", "=", " ", 
   "\"\<Test whether wx.yz= wy.xz.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"fa", "::", "usage"}], " ", "=", " ", 
   "\"\<fa[g_?indexTableQ] maps the list of symbols 'alph' onto the \
indexTable 'g' unless 'g' is too large (more than 10\[Times]10); it returns \
the determinant factors, dropping any -1. Use 'fp' for larger groups; 'fp' \
with 11\[Times]11 (or larger) is very slow without a lot of zero \
elements.\>\""}], ";", 
  RowBox[{
   RowBox[{"factorGroup", "::", "usage"}], " ", "=", " ", 
   "\"\<factorGroup[n_,gg_:glo] first tests whether the subgroup 'n' of 'g' \
is normal; 'g' must be an indexTable (default 'globa') and 'n' a subgroup \
list (as output by 'lcoset' or 'subgroups'). The factorGroup g/n (also called \
the quotient group) is identified\>\""}], ";", 
  RowBox[{
   RowBox[{"fenyvesQ", "::", "Usage"}], "=", 
   "\"\<fenyvesQ[gg_:glo,o_:0] tests whether (xy.z)x=x.(y.zx) for all x,y,z \
in 'gg'. See Kinyon,Sci.Math.Res,19/8/3\>\""}], ";", 
  RowBox[{
   RowBox[{"flexQ", "::", "usage"}], "=", 
   "\"\<flexQ[gg_:glo] tests whether xy.x=x.yx for all x,y,z in 'gg'. See \
Smith & Romanskowa, PMA p92.\>\""}], ";", 
  RowBox[{
   RowBox[{"flexibleQ", "::", "usage"}], "=", 
   "\"\<flexibleQ[gg_:glo] tests whether \[LeftAngleBracket]x,y,z\
\[RightAngleBracket]=-\[LeftAngleBracket]z,y,x\[RightAngleBracket] for all \
x,y,z in 'gg'. ?ref lost?\>\""}], ";", 
  RowBox[{
   RowBox[{"fp", "::", "usage"}], "=", 
   "\"\<fp[g_?indexTableQ,list_pow2] maps 'list' onto 'g' and factorises the \
determinant. If necessary, 'list' is right padded with zeroes.\>\""}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"frag", "::", "usage"}], "=", 
   "\"\<frag[g_,o_:0] where 'g' may be a hoop or its determinant factors, \
creates (as far as possible) the fragmented form, using known shapes where \
available. The root multiplicity is reported if o>1.\>\""}], ";", 
  RowBox[{
   RowBox[{"frag2", "::", "usage"}], "=", 
   "\"\<frag2[Polynomial_,o_:0] attempts to convert quadratic factors of a \
quasigroup determinant to sums and/or differences of squares. It is Listable, \
and returns non-quadratics unchanged, so it can be applied to 'hoopFactor' & \
'fa' output. The 'polsort' table is printed if o>0. The current version is \
wrong with factors of a few signed tables; use 'o'=1 to test for failure in \
new cases (the unfragmented result is returned if 'o'=0). The correct \
fragmentation can often be deduced from the diagnostic output\>\""}], ";", 
  RowBox[{
   RowBox[{"fromAlph", "::", "usage"}], "=", 
   "\"\</.fromAlph[vec_] replaces 'alph' symbols by those in 'vec'. Also see \
\!\(\*
StyleBox[\"as\",
FontSlant->\"Italic\"]\)\>\""}], ";", 
  RowBox[{
   RowBox[{"fromCycles", "::", "usage"}], "=", 
   "\"\<converts a cycle list to permutation\>\""}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gd", "::", "usage"}], "=", 
   "\"\<gd[] returns {mm,nn,{loop entry}} for the last loop to be identified.\
\n   gd[Mnemonic_],gd[m_,n_] or gd[{m_,n_}] returns the requested 'loop' \
data.\>\""}], ";", 
  RowBox[{
   RowBox[{"ge", "::", "usage"}], " ", "=", " ", 
   "\"\<ge[gp_,pre_,o_:0] creates quasigroups via Relators and re-write \
rules. If 'gp' is {na, nb,...}, 'ge' sets up a vector of ordered string \
elements starting with the empty string followed by up to 'na'-1 repetitions \
of 'a', followed by 'nb'-1 repetitions of 'b', etc but not beyond 'g'. 'pre' \
contains any re-write rules for out-of-order or squared (quaternion-style) \
letters. These are preferably strings, but symbols can be used and will be \
converted to strings. The use of strings emphasises that Relators are roots \
of unity but not cyclotomic (complex) numbers. Many loops involve several \
relators of the same power.\n   Bad rules (with overlong character repeats, \
etc) are rejected if 'o'>=0. A full set of re-write rules is created from \
'pre' by adding any unspecified Abelian rules such as 'ba\[RightArrow]ab'. A \
preliminary array is created by concatenating the elements. The re-write \
rules are then applied to reduce concatenations to elements. If Abs[o]=1, \
non-quasigroups are rejected, non-conservativity is reported, the table is \
put into global list 'matel', and the elements are put into global list \
'genel'. The reduced array is converted to an indexTable g. If the last \
element of gp is a real number r, g will be collapsed to a signed table by \
g=ts[g,r]. Finally, g is output.\>\""}], ";", 
  RowBox[{
   RowBox[{"genel", "::", "usage"}], "=", 
   "\"\<Global. The string elements of the last generator group to have been \
created with 'o'=1\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"genCos", "::", "usage"}], "=", 
   "\"\<genCos[x_,m_:4,j_:0] creates the j'th phase of the generalized \
antisymmetric sinusoid or helix with m phases; generalised Cosh and Sinh \
functions are generated if m=0 or 2.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"genQuadratic", "::", "usage"}], "=", 
   "\"\<genQuadratic[A_?VectorQ,B_?VectorQ,C_?VectorQ,g_:gmn] solves the \
quadratic equation \!\(\*SuperscriptBox[\(Ax\), \(2\)]\)+Bx+C=0 in the \
algebra 'g', provided that 'hoopPower' exists for 'g'. Still has \
PROBLEMS.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"genSin", "::", "usage"}], "=", 
   "\"\<genSin[x_,m_:4,j_:0] creates the j'th phase of the generalized \
symmetric sinusoid or helix with m phases; generalised Cosh and Sinh \
functions are generated if m=0 or 2.\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gi", "::", "usage"}], "=", 
   "\"\<Data required by hoopInverse & set up by sh, shape or hoopFactor, \
consisting of the location of the signed 1's in the indexTable rows, \
multiplied by the inverse sign if the 1 is signed, & followed by the \
multiplicity of the factors (which is zero for factored quartics).\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gInverse", "::", "usage"}], "=", 
   "\"\<finds the element inverses\>\""}], ";", 
  RowBox[{
   RowBox[{"glo", "::", "usage"}], "=", 
   "\"\<Set by 'ge', 'ma', 'pe', 'hoopTest', 'hoopTimes', & 'makeProtoloop' \
as the (global) indexTable of the loop being created or investigated; the \
default argument in many operations. See 'globa', 'gmn'.\>\""}], ";", 
  RowBox[{
   RowBox[{"globa", "::", "usage"}], "=", 
   "\"\<Set by 'subgroups'. The (global) indexTable of the loop being \
analyzed. See 'glo', gmn'\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gmap", "::", "usage"}], " ", "=", " ", 
   "\"\<gmap[gg_,v_] maps the elements of the list 'v' onto the indexTable \
'g', which may include signed elements.\>\""}], ";", 
  RowBox[{
   RowBox[{"gmn", "::", "usage"}], " ", "=", " ", 
   "\"\<Set by 'id' & 'makeProtoloop'; the (global) mnemonic of the current \
loop,used widely as a default argument. See 'globa', glo'\>\""}], ";", 
  RowBox[{
   RowBox[{"gp", "::", "usage"}], "=", 
   "\"\<Size multiplicity data needed by 'hoopPower', set up for the target \
loop by 'sh', 'hoopFactor' & 'toPolar'\>\""}], ";", 
  RowBox[{
   RowBox[{"gpd", "::", "usage"}], "=", 
   "\"\<gpd[gg_] is used on function arguments that should be groupoids (i.e. \
magmas, loops, quasigroups). It removes any TraditionalForm wrapper and \
rejects non-groupoids by 'Abort[] unless pr>3'. The first row must contain \
the elements, which may be matrices; signed elements are permitted in the \
body of the table.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"grayinv", "::", "usage"}], "=", 
   "\"\<grayinv[a_] calculates the inverse Graycode function of 'a', which \
must be an IntegerDigits list. Used in 'cl'\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hamiltonianQ", "::", "usage"}], "=", 
   "\"\<hamiltonianQ[g_:glo] is true if 'g' is not abelian but all subgroups \
are normal\>\""}], ";", 
  RowBox[{
   RowBox[{"hmin", "::", "usage"}], "=", 
   "\"\<hmin is arbitrarily set at 4$MachineEpsilon as the criterion for \
'hoopInverse' to ignore (renormalize) partial fractions with near-zero \
denominators.\>\""}], ";", 
  RowBox[{
   RowBox[{"hoopFactor", "::", "usage"}], "=", 
   "\"\<hoopFactor[f_:fp] is called by 'hoopShape' & 'hoopTest' to create \
'gi' from the indexTable 'glo', for use by 'hoopInverse'; and returns the \
short or (if the first argument is 'fa') the symbolic factor list.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hoopInverse", "::", "usage"}], "=", 
   "\"\<hoopInverse[vec_?VectorQ] finds the multiplicative left inverse of \
'vec' (which is right-padded with zeroes if necessary) in the algebra \
specified by 'glo'. It is effective provided that the algebra is conservative \
- i.e. the determinant of the product is the product of the multiplicand \
determinants (up to a sign). The procedure is related to Cramer's method. If \
the determinant factorises, the inverse splits into partial fractions with \
determinant factors as denominators and their derivations as numerators. The \
sequence of derivation variables is fixed by the location of 1's in the \
IndexTable, and is given in 'gi'.\n   'Partial-fraction division-by-zero' \
(renormalisation) is implemented by omitting partial-fractions with \
denominators (sizes) that are within \[PlusMinus]'hmin' of zero. 'hmin' has \
been arbitrarily set at 4$MachineEpsilon (=2.^-50 on my machine). \
Renormalisation is related to the Moore-Penrose pseudo-inverse (which gives \
minimised root-mean-square solutions to inconsistent sets of equations), and \
corresponds to projecting any vec onto a constrained sub-algebra whilst \
'ejecting' remainders Rl, Rr to maintain conservation if needed.\>\""}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hoopList", "::", "usage"}], "=", "\"\<List of hoop names\>\""}], 
  ";", 
  StyleBox[
   RowBox[{
    RowBox[{"hoopPower", "::", "usage"}], "=", 
    "\"\<hoopPower[A_, r_:1/2] calculates \!\(\*SuperscriptBox[\(A\), \
\(r\)]\) if the target loop has a polar form. r can be negative.\>\""}],
   ShowStringCharacters->True,
   NumberMarks->True], 
  StyleBox[";",
   ShowStringCharacters->True,
   NumberMarks->True], 
  StyleBox[
   RowBox[{
    RowBox[{"hoopRoot", "::", "usage"}], "=", 
    "\"\<hoopRoot[A_?VectorQ] calculates the square root of A in the target \
algebra if it has a polar form. It is faster than using hoopPower.\>\""}],
   ShowStringCharacters->True,
   NumberMarks->True], 
  StyleBox[";",
   ShowStringCharacters->True,
   NumberMarks->True], 
  RowBox[{
   RowBox[{"hoopShape", "::", "usage"}], " ", "=", " ", 
   "\"\<hoopShape[X_,o_:0] accepts either a valid Protoloop identifier \
({mm,nn} or mnemonic) or a loop table. If the loop is symbolic, it creates a \
rule that will apply the symbols to the final result. If the specific \
shape[X] is not available, the indexTable (up to 11\[Cross]11) is found, put \
into 'glo' and used to set 'gi' for use by 'hoopInverse' and to find the \
generalised shape. The output is converted to the loop symbols if necessary. \
Non-conservative loops are rejected unless o<0\>\""}], ";", 
  RowBox[{
   RowBox[{"hoopTimes", "::", "usage"}], " ", "=", " ", 
   "\"\<hoopTimes[a,b] or hoopTimes[a_,b_,gg_] multiplies the vectors 'a' & \
'b' to give a product 'p' according to the indexTable 'gg' (default 'glo'). \
This may include signs. Remainders Rl & Rr are created, so that a=p/b+Rl, \
b=p/a+Rr, maintaining conservation.\>\""}], ";", 
  RowBox[{
   RowBox[{"hoopTest", "::", "usage"}], "=", 
   "\"\<hoopTest[X_:{mm,nn},t_:Real,r_:{-1.,1.}] accepts either a valid \
Protoloop identifier ({mm,nn} or mnemonic) or a groupoid indexTable. It sets \
'glo' to the indexTable and creates two suitable random vectors in the field \
't' with range 'r'. If the shape is known or calculable it is tested for \
conservation and division. If the Polar and Vector forms are known, \
reversion, powers and (if abelian) quadratic equation solutions are tested; \
if the hyPolar and hyVector forms are known, their reversion is tested. \
Successful tests are reported.\>\""}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"id", "::", "usage"}], "=", 
   "\"\<id[G_,L_:{}] uses a range of tests to identify 'G', which may be a \
name, or \!\(\*
StyleBox[\"{\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"mm\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"nn\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"}\",
FontSlant->\"Italic\"]\), or an indexTable; if an index-list 'L' is \
specified, the corresponding subgroup of 'G' is identified. Associativity is \
not tested (for speed of execution) so unknown groupoids may be wrongly \
identified. Names: C\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\), D\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)/2 & Qn are cyclic or generalised Dihedral and \
Quaternion groups with \!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\) elements.\n    \!\(\*
StyleBox[\(A\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)]\) & \!\(\*
StyleBox[\(S\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)]\) have n generators. Alt12n, Oct, D4Mn etc  are \
'Square associative' or 'alternative aa.b=a.ab' groupoids. XY, XiY, XpY are \
the direct or indirect compositions of X & Y. Xa is a second isomorph of X. \
Xr & Xc are conservative signed tables obtained from X that also provide \
conservative algebras on expanding with C2 or (C2 & C4). Loops with names \
ending in \!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\) (the letter, not a number) are not conservative. \
Loops with M in the name are non-associative Moufang loops. \!\(\*
StyleBox[\"gnnmm\",
FontSlant->\"Italic\"]\) is GAP SmallGroups(mm,nn). If the name contains ? \
identification is provisional because all groups of that size have not been \
distinguished. The global variables \!\(\*
StyleBox[\"glo\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gmn\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"mm\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"&\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"nn\",
FontSlant->\"Italic\"]\) are set by id. \!\(\*
StyleBox[\"gmn\",
FontSlant->\"Italic\"]\) is returned and \!\(\*
StyleBox[\"gd\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",
FontSlant->\"Italic\"]\) will provide more details.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"idc", "::", "usage"}], " ", "=", " ", 
   "\"\<idc[G_?MatrixQ,L_:{}] checks that 'G' is conservative before \
attempting identification via 'id'\>\""}], ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"indexTableQ", "::", "usage"}], "=", 
   "\"\<indexTableQ[gg_:glo]] checks that the first row and column are \
Range[Length[gg]] and that every row and column contains each of these \
(possibly signed) integers once\>\""}], ";", 
  RowBox[{
   RowBox[{"jacobiQ", "::", "usage"}], "=", 
   "\"\<jacobiQ[A_,B_,C_] tests whether \
<<A,B>,C>+<<B,C>,A>+<<C,A>,B>=0\>\""}], ";", 
  RowBox[{
   RowBox[{"jordanQ", "::", "usage"}], "=", 
   "\"\<jordanQ[gg_:glo,o_:0] tests whether (xy).xx=x(y.xx) up to a \
sign\>\""}], ";", 
  RowBox[{
   RowBox[{"lcoset", "::", "usage"}], " ", "=", " ", 
   "\"\<lcoset[h_,g_:glo] finds the left coset for the subgrouplist 'h' in \
the indexTable 'g' or in 'glo'. \>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"linearFactor", "::", "usage"}], "=", 
   "\"\<linearFactor[f_,l_] finds the symbolic 'alph' form of a linear factor \
'f' generated by 'fp' for a group of length 'l'.\>\""}], ";", 
  RowBox[{
   RowBox[{"lmatrix", "::", "usage"}], " ", "=", " ", 
   "\"\<lmatrix[gg_?indexTableQ] converts 'gg' into the corresponding matrix \
with 1's on the diagonal and {1,2,3..,m} in the first column. If an ordered \
set of symbols or numbers is mapped onto an lmatrix, the groupoid product is \
given by the left matrix dot product of this matrix and any other ordered \
set. Cf rmatrix.\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"KS", "::", "\"\<usage\>\""}], "=", 
   "\"\<KS[l_List,k_Integer?Positive,gap_:{},lef_:{}] is an adaptation of \
k-subsets in Skiena p44, to create subsets, of length 'k' of group indices \
that give groupoids from 'globa'. It creates a list 'gap' of rejected indices \
and a list 'lef' of elements left in, adding to 'lef' those new elements that \
do not have any products in 'gap'.\>\""}], ";", 
  RowBox[{
   RowBox[{"loop", "::", "\"\<usage\>\""}], "=", 
   "\"\<loop[[mm,nn]] is the data file of 'algebraic loops'. The number of \
elements is 'mm', and 'nn' is the position in the extended GAP Atlas entry. \
For each loop, the first entry is the mnemonic, the second is 'dico', the \
third specifies a test (0 if 'dico' is unique for conservative tables), the \
fourth is a prescription, the 5th & 6th define the relators. If matrix \
formulations are known they are supplied as indices for 2\[Cross]2, \
3\[Cross]3, & 4\[Cross]4 standard matrices u2, u3, u4 MATHEMATICA6 screws \
them up!! In a few cases, extra table creation procedures are \
appended.\>\""}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loopQ", "::", "usage"}], "=", 
   "\"\<loopQ[gg_?MatrixQ,o_:0] tests whether the first row and first column \
are the same set of different elements (i.e. are the unit) and every row and \
column contain every element once (up to a sign). If 'o' \[NotEqual] 0 the \
reason for rejection will be output.\>\""}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ma", "::", "\"\<usage\>\""}], "=", 
   "\"\<ma[{mm__},maxel_:72,o_:0] takes a list of one or more unitary \
monomial signed square matrices (all of the same size) and prepends the unit \
matrix. It then creates the dot products of these matrices and appends any \
that are not already present, until the size exceeds 'maxel' or a group has \
been completed. The group is then created as (global) element list 'matel' \
(forming a faithful matrix representation) which is output if o\[NotEqual]0; \
the indexTable is put into 'glo' and is output.\>\""}], ";", 
  RowBox[{
   RowBox[{"matel", "::", "usage"}], "=", 
   "\"\<Global. The elements of the latest matrix (ma or ms) or relator (ge) \
group. (The last relator acts as a sign in a signed table.)\>\""}], ";", 
  RowBox[{
   RowBox[{"makeProtoloop", "::", "usage"}], " ", "=", 
   "\"\<makeProtoloop[g_:{mm,nn},o_:0] is the full name for 'mp', \
q.v.makeProtoloop[] or makeProtoloop[mm,nn] uses the first available \
prescription in gd[mm,nn] to create the protoloop.\n   \
makeProtoloop[G_:MatrixQ,o_:0] recognises three formats for G - a string \
(mnemonic) as a name, indices {mm,nn} in 'loop' (i.e. the extended GAP Atlas \
identifiers), or a matrix. It then attempts to make the protoloop, returning \
'Unknown' or 'No protoloop' and clearing matel as appropriate. If 'o'=0 it \
uses the first available formulation. If 'o' is 1, 'ge' is used.  If 'o' is \
2, 3, or 4, the corresponding matrix formulation is used in mg. ms is used \
for signed tables\n   If 'o' is 5 or 6, different protoloops may be generated \
(only P16a, P16i, g2003, Alt12n so far). The indexTable is output.\>\""}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"matstrep", "::", "usage"}], " ", "=", " ", 
   "\"\<matstrep[l_,rul_,sm_:smax] performs up to 'sm' string replace \
repetitions on the matrix.\>\""}], ";", 
  RowBox[{
   RowBox[{"md", "::", "usage"}], "=", 
   "\"\<md[g_,l_:{}] (Moufang doubling) creates a non-associative Moufang \
loop from a non-abelian group. l={} uses gInverse to implement Chein \
doubling; 3 known cases use l as a reordering.\>\""}], ";", 
  RowBox[{
   RowBox[{"mg", "::", "usage"}], "=", 
   "\"\<mg[v_?VectorQ,u_] (Matrix Group) creates a matrix by sending the u \
matrices given in 'v' to 'ma'. u may be u2, u3, or u4. The size is limited to \
'mm'+1\>\""}], ";", 
  RowBox[{
   RowBox[{"minsign", "::", "usage"}], "=", 
   "\"\<minsign[g_] finds any signed elements of 'g' and sets up the \
appropriate simplification list from 'unitSigns'\>\""}], ";", 
  RowBox[{
   RowBox[{"mm", "::", "usage"}], "=", 
   "\"\<Global. mm is the table size of entries in 'loop', set by 'id' & \
'gd', used as {mm,nn} in many procedures\>\""}], ";", 
  RowBox[{
   RowBox[{"modqr", "::", "usage"}], "=", 
   "\"\<The 'modqr[q,r,s:2]' function shifts a signed index 'r' by 'q' whilst \
keeping in the range \[PlusMinus]{1,s q}. e.g. modqr[3,-2] = -5. Used in \
'cd'.\>\""}], ";", 
  RowBox[{
   RowBox[{"MoufangQ", "::", "usage"}], "=", 
   "\"\<MoufangQ tests if zx.yz=(z.xy)z, the 3rd Moufang Identity. See PMA \
p92. As this fails for many conservative signed tables such as Qr, unsigned \
tests can be performed by moufangQ.\>\""}], ";", 
  RowBox[{
   RowBox[{"moufangQ", "::", "usage"}], "=", 
   "\"\<Tests if |zx.yz|=|(z.xy)z|, the (unsigned) 3rd Moufang Identity. See \
PMA p92\>\""}], ";", 
  RowBox[{
   RowBox[{"moufangLQ", "::", "usage"}], "=", 
   "\"\<Tests if |(zy.z)x|=|z(y.zx)|, the (unsigned) Left Moufang Identity. \
See PMA p93\>\""}], ";", 
  RowBox[{
   RowBox[{"moufangRQ", "::", "usage"}], "=", 
   "\"\<Tests if |x(z.yz)|=|(xz.y)z|, the (unsigned) Right Moufang Identity. \
See PMA p93\>\""}], ";", 
  RowBox[{
   RowBox[{"mp", "::", "usage"}], "=", 
   "\"\<mp[] or mp[mm,nn] uses the first available prescription in gd[mm,nn] \
to create the protoloop.\n   mp[G_,o_:0] recognises three formats for G - a \
string (mnemonic) as a name, indices {mm,nn} in 'loop' (i.e. the extended GAP \
Atlas identifiers), or a matrix. It then attempts to make the protoloop, \
returning 'Unknown' or 'No protoloop' and clearing matel as appropriate. If \
'o'=0 it uses the first available formulation. If 'o' is 1, 'ge' is used. If \
'o' is 2, 3, or 4, the corresponding matrix formulation is used in \!\(\*
StyleBox[\"mg\",
FontSlant->\"Italic\"]\). \!\(\*
StyleBox[\"ms\",
FontSlant->\"Italic\"]\) is used to create signed signed tables.\n   If 'o' \
is 5 or 6, different protoloops may be generated (only P16a, P16i, g2003, \
Alt12n so far). The indexTable is output.\>\""}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ms", "::", "usage"}], "=", 
   "\"\<ms[v__?ListQ,l_:u2,maxel_:33] makes signed tables that may be hoops, \
from the specified unitary monomial matrices. It puts the unit matrix and \
either the matrices in v (or if v is a list of indices, possibly signed, the \
listed matrices from l, where l is u2, u3 or u4), into matel. It then creates \
a table from their dot products, adding any that do not match signed existing \
ones, up to a limit maxel. \!\(\*
StyleBox[\"ms\",
FontSlant->\"Italic\"]\) is used in place of \!\(\*
StyleBox[\"mg\",
FontSlant->\"Italic\"]\) in \!\(\*
StyleBox[\"mp\",
FontSlant->\"Italic\"]\) for signed tables\>\""}], ";", 
  RowBox[{
   RowBox[{"msi", "::", "usage"}], "=", 
   "\"\<msi[v__?ListQ,l_:u2,si={1,-1,\[ImaginaryI],-\[ImaginaryI]},maxel_:64] \
is a variation on \!\(\*
StyleBox[\"ms\",
FontSlant->\"Italic\"]\) that handles P4 and P16c\>\""}], ";", 
  RowBox[{
   RowBox[{"mstst", "::", "usage"}], "=", 
   "\"\<mstst[m_,s_] tests whether matel contains a version of the matrix m, \
multiplied by the signs in s, returning 0 or the corresponding sign for use \
in \!\(\*
StyleBox[\"ms\",
FontSlant->\"Italic\"]\).\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mutant", "::", "usage"}], " ", "=", " ", 
   "\"\<mutant[gg_?indexTableQ,ps_List] generates the indexTable of groupoid \
'gg' as reordered by the signed permutation 'ps'; short permutations are \
extended to full size. ps[[1]] must be \[PlusMinus]1. Each element of gg \
(apart from the first row and column) is given the required sign and put into \
the result. See also 'reorder', which allows elements to be reordered\>\""}], 
  ";", 
  RowBox[{
   RowBox[{"negatableQ", "::", "usage"}], "=", 
   "\"\<negatableQ[gg_:glo,f_:2] tests whether the table 'gg' has the same \
elements in each 1/f \[Times] 1/f fraction with elements shifted by 'm/f' \
(allowing for signs). If so, the top left fraction may describe a \
signedTable.\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"nn", "::", "usage"}], "=", 
   "\"\<Global. 'nn' is set by 'id', 'hoopTest', 'hoopTimes & 'gd', and used \
in {mm,nn} to identify the position of an entry (of length mm) in \
'loop'\>\""}], ";", 
  RowBox[{
   RowBox[{"normalSubgroup", "::", "usage"}], " ", "=", " ", 
   "\"\<normalSubgroup[h,g] tests whether 'h' is a normal subgroup of 'g', \
i.e. gh\!\(\*OverscriptBox[\(g\), \(_\)]\)\[Epsilon]H, all g,h.\>\""}], ";", 
  RowBox[{
   RowBox[{"orderCount", "::", "usage"}], "=", 
   "\"\<gives the order of each element in 'g'\>\""}], ";", 
  RowBox[{
   RowBox[{"pe", "::", "usage"}], "=", 
   "\"\<Generates a loop from a list of permutations such as s4\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"period", "::", "usage"}], "=", 
   "\"\<standard group function\>\""}], ";", 
  RowBox[{
   RowBox[{"permute", "::", "usage"}], "=", 
   "\"\<If 'p' is a valid sub-permutation, permute[P_List,p_List] returns the \
sublist of 'P'\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"permfromQ", "::", "usage"}], "=", "\"\<used in permute\>\""}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pick", "::", "usage"}], "=", 
   "\"\<pick[g_,m_List,n_List] picks out the rows 'm' & columns 'n' from \
'g'\>\""}], ";", 
  RowBox[{
   RowBox[{"planarCom", "::", "usage"}], "=", 
   "\"\<planarCom[m] creates Olariu's planar complex algebras \
(http://arxiv.org/pdf/math.CV/0011044) as hoops. These are m-element folded \
cyclic groups with all indices negated below the anti-diagonal. Cl3r \
\[TildeTilde] planarCom[6]; planarCom[9] is the largest in the \
databank.\>\""}], ";", 
  RowBox[{
   RowBox[{"plex", "::", "usage"}], "=", 
   "\"\<The vec used to give a plex-conjugate to {a,b,...}; set up by some \
shapes. If it does not give the standard shape in an obvious way, the plex \
form of the shape is supplied as a comment. Conjugates are a \
meta-mathematical trick that provide a quadratic size in some algebras; the \
more general approach is via the explicit 'shape' functions that give all the \
conserved sizes.\>\""}], ";", 
  RowBox[{
   RowBox[{"polsort", "::", "usage"}], "=", 
   "\"\<creates a sorted list of elements in the polynomial P, for use in \
'frag'\>\""}], ";", 
  RowBox[{
   RowBox[{"pos", "::", "usage"}], "=", 
   "\"\<pos[a_] negates 'a' if the first term is negated, so that 'frag2' \
squared terms match.\>\""}], ";", 
  RowBox[{
   RowBox[{"pow2", "::", "usage"}], "=", 
   "\"\<A list {a,1,2,4,8..} used as elements of Cayley Tables to allow fast \
determinant evaluation via fp & 'linearFactor'. (May have problems with some \
Clifford algebras - use fp[G,power2 or power3].)\>\""}], ";", 
  RowBox[{
   RowBox[{"power2", "::", "usage"}], "=", 
   "\"\<A list {a,3,7,1,2,4,8..} (where a is a string, unlike pow2) used as \
elements of Cayley Tables to allow fast determinant evaluation via \
'fp'\>\""}], ";", 
  RowBox[{
   RowBox[{"power3", "::", "usage"}], "=", 
   "\"\<A list {a,2,4,1,3,9,27,81..} (where a is a string) used as elements \
of Cayley Tables to allow fast determinant evaluation via 'fp'.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr", "::", "usage"}], "=", "\"\<Output control parameter\>\""}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QPower", "::", "usage"}], "=", 
   "\"\<QPower[{a,b,c,d},r]  raises the quaternion (or biquaternion, as the \
coefficients can be complex) to the power or root r, giving the square root \
if r is omitted\>\""}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"rcoset", "::", "usage"}], " ", "=", " ", 
   "\"\<rcoset[h_,g_] finds the right coset for the subgrouplist 'h' in the \
indexTable'g' or in 'glo'\>\""}], ";", 
  RowBox[{
   RowBox[{"reductiveQ", "::", "usage"}], "=", 
   "\"\<tests xy.xx=x(y.xx)\>\""}], ";", 
  RowBox[{
   RowBox[{"reim", "::", "usage"}], " ", "=", " ", 
   "\"\<Replaces Derivative[Re] by Re, etc\>\""}], ";", 
  RowBox[{
   RowBox[{"reorder", "::", "usage"}], " ", "=", " ", 
   "\"\<reorder[gg_?indexTableQ,p_] generates the indexTable of 'gg' as \
reordered by the permutation 'p'; short permutations give sub-tables. See \
also 'mutant', which allows signed elements to be reordered\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"riffQ", "::", "usage"}], "=", 
   "\"\<Tests if xy(z.xy)=((x.yz).x)y\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"r3", "::", "usage"}], "=", "\"\<1/Sqrt[3]\>\""}], ";", 
  RowBox[{
   RowBox[{"Rl", "::", "usage"}], "=", 
   "\"\<The left remainder from the last P=hoopTimes[A,B], containing the \
sizes of A that are zero in P\>\""}], ";", 
  RowBox[{
   RowBox[{"Rr", "::", "usage"}], "=", 
   "\"\<The right remainder from the last P=hoopTimes[A,B], containing the \
sizes of B that are zero in P\>\""}], ";", 
  RowBox[{
   RowBox[{"rmatrix", "::", "usage"}], " ", "=", " ", 
   "\"\<rmatrix[gg_?indexTableQ] converts 'gg' into the corresponding matrix \
with 1's on the diagonal and {1,2,3..,m) in the first row. If an ordered set \
of symbols or numbers is mapped onto an rmatrix, the groupoid product is \
given by the right matrix dot product of this matrix and any other ordered \
set. Cf lmatrix\>\""}], ";", 
  RowBox[{
   RowBox[{"rotateQOP", "::", "usage"}], "=", 
   "\"\<rotateQOP[{vecs},axis,angle,hoop:gmn] rotates the vecs (truncated or \
padded with zeroes if necessary) through angle about axis (which is also \
truncated or padded) The hoop must be Qr,Octr, or P4. \!\(\*
StyleBox[\"gmn\",
FontSlant->\"Italic\"]\) is set for further use. The classic Euler defnition \
is used, multiplying twice by half angles.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ruleExpand", "::", "usage"}], " ", "=", " ", 
   "\"\<ruleExpand[a] applies 'stringExpand' to a list of compressed rules \
e.g a4b2\[ShortRightArrow]aaaabb.\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"select", "::", "usage"}], "=", 
   "\"\<select[l_] finds all elements appearing as products in the subarray \
'l' of 'globa'\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"s3", "::", "usage"}], "=", 
   "\"\<s3 is the list of permutations that define S3\>\""}], ";", 
  RowBox[{
   RowBox[{"s4", "::", "usage"}], "=", 
   "\"\<s4 is the list of permutations that define S4\>\""}], ";", 
  RowBox[{
   RowBox[{"s5", "::", "usage"}], "=", 
   "\"\<s5 is the list of permutations that define S5\>\""}], ";", 
  RowBox[{
   RowBox[{"sg", "::", "usage"}], "=", 
   "\"\<sg is the (global) list of subgroup indices created by 'subgroups'; \
used by 'subgroupTypes'\>\""}], ";", 
  RowBox[{
   RowBox[{"sh", "::", "usage"}], "=", 
   "\"\<sh[hoop] is the list of factors of the symbolic hoop \
determinant.\>\""}], ";", 
  RowBox[{
   RowBox[{"shape", "::", "usage"}], "=", 
   "\"\<shape[vec_,mnemonic_] obtains specific shape data (where known) from \
sh for the current or specified loop. The real determinant factors (i.e. \
those that are conserved) are supplied, and the lists gi & gp are set up for \
use by hoopInverse & toPolar. Plex conjugates are also supplied (where known) \
for completeness.\>\""}], ";", 
  RowBox[{
   RowBox[{"sgroup", "::", "usage"}], " ", "=", " ", 
   "\"\<sgroup[m_?IntegerQ] is adapted from Skiena p17. It creates the \
indexTable for S[m]\>\""}], ";", 
  RowBox[{
   RowBox[{"sh12", "::", "usage"}], "=", 
   "\"\<sh12[{12vec}] is the standard shape data for Dozal, the 12-element \
groups C3C4, C3K, Q12, D3C2, A4. It includes functions that are conserved on \
general multiplication but are not determinant factors, and others that are \
only conserved in some multiplications of orbits\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"signlist", "::", "usage"}], "=", 
   "\"\<signlist={\[DoubleStruckD],\[DoubleStruckO],\[DoubleStruckG],\
\[DoubleStruckH],\[DoubleStruckP],\[DoubleStruckCapitalI],\
\[DoubleStruckCapitalY],\[DoubleStruckCapitalJ],\[DoubleStruckM],\
\[DoubleStruckN],\[DoubleStruckS]} is the list of extended signs. These are \
different 12th, 8th, 7th, 6th, 5th, 4th, 3rd, 3rd, 2nd, 2nd & 9th roots of +1 \
respectively. \[DoubleStruckS] is the general sign or \[DoubleStruckR]'th \
root of +1. See also 'unitSigns'.\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckD]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckD]\), \(12\)]\)=1\
\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckG]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckG]\), \
\(7\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckH]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckH]\), \
\(6\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckCapitalI]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckCapitalI]\), \
\(4\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckCapitalJ]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckCapitalJ]\), \
\(3\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckK]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckK]\), \
\(2\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckL]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckL]\), \
\(2\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckM]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckM]\), \
\(2\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckN]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckN]\), \
\(9\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckO]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckO]\), \
\(8\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckP]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckP]\), \
\(5\)]\)=1\>\""}], ";", 
  RowBox[{
   RowBox[{"\[DoubleStruckS]", "::", "usage"}], "=", 
   "\"\<Generalised Extended Sign, the \[DoubleStruckR]'th root of unity. \
\!\(\*SuperscriptBox[\(\[DoubleStruckS]\), \(\[DoubleStruckR]\)]\)=1\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[DoubleStruckCapitalY]", "::", "usage"}], "=", 
   "\"\<Extended Sign. \!\(\*SuperscriptBox[\(\[DoubleStruckCapitalY]\), \
\(3\)]\)=1\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"signedTableQ", "::", "usage"}], "=", 
   "\"\<tests whether the group is an indexTable with signed elements\>\""}], 
  ";", 
  RowBox[{
   RowBox[{"simC2", "::", "usage"}], "=", 
   "\"\<simc2[a_,b_,o_:0] solves a set of simultaneous equations ax+b=0 for x \
in the C2 algebra. The determinant factorises into p and n (i.e. \
\[PlusMinus]); if either is zero, the indeterminate solution has a degree of \
freedom $x. If o\[NotEqual]0 the solution is collapsed to real numbers\>\""}],
   ";", 
  RowBox[{
   RowBox[{"strep", "::", "usage"}], " ", "=", " ", 
   "\"\<created by ge[...,\[PlusMinus]1] as string replacement rules.\>\""}], 
  ";", 
  RowBox[{
   RowBox[{"streprpt", "::", "usage"}], " ", "=", " ", 
   "\"\<streprpt[str_,rul_,imax_] performs up to 'imax' string replace \
repetitions using the list 'rul'.\>\""}], ";", 
  RowBox[{
   RowBox[{"stringExpand", "::", "usage"}], " ", "=", " ", 
   "\"\<stringExpand[t] replaces 'letter integer' by 'integer' repetitions of \
'letter' in the string 't'.\>\""}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"subgroupTypes", "::", "usage"}], " ", "=", " ", 
   "\"\<subgroupTypes[] or subgroupTypes[%] may be used after subgroups[g] to \
identify them in order.\>\""}], ";", " ", 
  RowBox[{
   RowBox[{"subgrpPerm", "::", "usage"}], "=", 
   "\"\<subgrpPerm[G_,a_:0] & subgrpPerm[G_,a_,b_,c_] are implementations of \
RandomPermutation from Skiena p7. They permute the group to increase the \
chance of pruning, and usually speed up the determination of subgroups for \
groups with 'm'>47. a, b, & c are arguments that are passed through.\>\""}], 
  ";", 
  RowBox[{
   RowBox[{"subgroups", "::", "usage"}], " ", "=", " ", 
   "\"\<subgroups[g_,o_,i1_,i2_,p_:associativeQ] finds all the subloops, in \
the IndexTable 'g' that pass the 'p' test, so the default finds subgroups, \
within the optional length range {i1,i2}, as sublists of indices. 'globa' is \
set to 'g'. If 'o'=0, the number of subloops is output; if 'o'=1 the sublist \
is put into 'sg', for use by 'id' and is output; o=2 gives both.\n   \
subgroups[g_,-n,i1_] or subgroups[g_,any,i1_,any,{n__}] test whether the \
subgroup identified as {i1,n} or {i1,n__} is a subgroup of 'g', returning 0 \
or the first matching n__ found. Used by 'id'\>\""}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"tf", "::", "usage"}], "=", "\"\<TraditionalForm\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tidy", "::", "usage"}], " ", "=", " ", 
   "\"\<tidy[g_:globa,n_:-1,o_:1,p_:{}] uses the list 'n' (or the n'th \
subgroup if 'n' is an integer; the default is the last found subgroup) in the \
top-left corner of a reordering of 'g'; 'o' is the (optional) element at the \
beginning  of the next column. 'p' is the (optional) starting  element (or \
list) for the remainder. The reorder list and the new table are output. The \
default group is 'globa', as set up by 'subgroups'. It is faster to specify a \
subgroup as an element-list than to specify a position in the subgroup list, \
as the latter has to proceed via 'subgroups', which is slow for large \
groups\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toCycles", "::", "\"\<usage\>\""}], "=", 
   "\"\<toCycles[perm_?VectorQ] generates the cycles from the \
permutation.\>\""}], ";", 
  RowBox[{
   RowBox[{"toIndexTable", "::", "usage"}], " ", "=", " ", 
   "\"\<toIndexTable[g_?MatrixQ] rearranges a shuffled indexTable to make the \
first row and column into {1,2,...m}\>\""}], ";", 
  RowBox[{
   RowBox[{"tohyPol", "::", "usage"}], "=", 
   "\"\<tohyPol[{radius,angle}__,mnemonic_] contains the hyperbolic \
forms\>\""}], ";", 
  RowBox[{
   RowBox[{"tohyPolar", "::", "usage"}], "=", 
   "\"\<tohyPolar[vec_,mnemonic_] obtains the hyperbolic form for the current \
groupoid\>\""}], ";", 
  RowBox[{
   RowBox[{"tohyVec", "::", "usage"}], "=", 
   "\"\<tohyVec[{ulna,angle}__,mnemonic_] contains the hyperbolic \
forms\>\""}], ";", 
  RowBox[{
   RowBox[{"tohyVector", "::", "usage"}], "=", 
   "\"\<tohyVector[hpf_,mnemonic_] reverts the hyperbolic form for the \
current groupoid\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "::", "usage"}], "=", 
   "\"\<toPol[vec_,mnemonic_] gives the polar form of vec in the specified \
loop. (toPolar uses the current loop.)\>\""}], ";", 
  RowBox[{
   RowBox[{"toPolar", "::", "usage"}], "=", 
   "\"\<toPolar[vec_,mnemonic_:gmn] obtains the polar form from the vector \
form for the named or the current loop\>\""}], ";", 
  RowBox[{
   RowBox[{"toSignedTable", "::", "usage"}], " ", "=", " ", 
   "\"\<toSignedTable[g_?MatrixQ,r_:2,reo_:{},o_:0] (abbreviation ts) \
attempts to collapse 'g' to a signed table of length m/|r|, after reordering \
if 'reo' is provided. Non-conservative tables are rejected unless \
'r'<0.\>\""}], ";", 
  RowBox[{
   RowBox[{"toVec", "::", "usage"}], "=", 
   "\"\<toVec[mnemonic_] gives the symbolic vector form, using 'alph' \
variables. (toVector uses the current loop.)\>\""}], ";", 
  RowBox[{
   RowBox[{"toVector", "::", "usage"}], "=", 
   "\"\<toVector[pf_,mnemonic_:gmn] reverts the polar form to the vector form \
for the current or named loop\>\""}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"trico", "::", "usage"}], "=", 
   "\"\<trico[g_] is the count of elements of 'g' having cube roots, with the \
unit roots first \>\""}], ";", 
  RowBox[{
   RowBox[{"ts", "::", "usage"}], " ", "=", " ", 
   "\"\<ts[a___] is an abbreviation, used in data, for \
toSignedTable[g_?MatrixQ,r_:2,reo_:{},o_:0]. It attempts to collapse 'g' to a \
signed table of length m/|r|, after reordering if 'reo' is provided. \
Non-conservative tables are rejected unless 'r'<0.\>\""}], ";", 
  RowBox[{
   RowBox[{"union", "::", "usage"}], "=", 
   "\"\<Finds the unsorted union. Same as UnionNoSort of EAAM\>\""}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"u2", "::", "usage"}], "=", 
   "\"\<u2, u3, & u4 are lists of 2\[Times]2, 3\[Times]3, & 4\[Cross]4 \
monomial unit matrices that include the Pauli Sigma and Dirac Gamma and Tau \
matrices. These allow development of matrix groups with different symmetries \
via \!\(\*
StyleBox[\"ma\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"mg\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"ms\",
FontSlant->\"Italic\"]\). Only some root matrices are included; dot \
multiplying them together generates many more. In combination with 'loop' & \
'makeProtoloop', they allow the generation of many small groups with sets of \
matrices as elements. Further work is needed to increase the number of groups \
handled. FAILS IN M6\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u3", "::", "usage"}], "=", "\"\<See u2\>\""}], ";", 
  RowBox[{
   RowBox[{"u4", "::", "usage"}], "=", "\"\<See u2\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"unitSigns", "::", "usage"}], "=", 
   "\"\<\[DoubleStruckD], \[DoubleStruckG], \[DoubleStruckH], \
\[DoubleStruckCapitalI], \[DoubleStruckCapitalJ], \[DoubleStruckL], \
\[DoubleStruckK], \[DoubleStruckM], \[DoubleStruckN], \[DoubleStruckO], \
\[DoubleStruckP], \[DoubleStruckS] and \[DoubleStruckCapitalY] are set up to \
act as unit signs related to \[ImaginaryI], with \
\[DoubleStruckD]=\!\(\*RadicalBox[\(+1\), \(12\)]\), \
\[DoubleStruckG]=\!\(\*RadicalBox[\(+1\), \(7\)]\), \
\[DoubleStruckCapitalI]=\!\(\*RadicalBox[\(+1\), \(4\)]\) (and distinct from \
\[ImaginaryI] and I), \[DoubleStruckCapitalJ]=\!\(\*RadicalBox[\(+1\), \(3\)]\
\) and \[DoubleStruckCapitalY]=\!\(\*RadicalBox[\(+1\), \(3\)]\)(both \
distinct from \!\(\*FormBox[\"\[ImaginaryJ]\",
TraditionalForm]\)  which is synonymous with \[ImaginaryI] and I in \
Mathematica), \[DoubleStruckH]=\!\(\*SqrtBox[\(+1\)]\), \[DoubleStruckK]=\!\(\
\*SqrtBox[\(+1\)]\), \[DoubleStruckM]=\!\(\*SqrtBox[\(+1\)]\) (all being \
extra negations), \[DoubleStruckN]=\!\(\*RadicalBox[\(+1\), \(9\)]\), \
\[DoubleStruckO]=\!\(\*RadicalBox[\(+1\), \(8\)]\), \
\[DoubleStruckP]=\!\(\*RadicalBox[\(+1\), \(5\)]\), \
\[DoubleStruckS]=\!\(\*RadicalBox[\(+1\), \(\[DoubleStruckR]\)]\). They are \
all non-Positive, with NumberQ=True, Abs=1, Re=0, Im=0 and equal their own \
Sign, so that 'gmap' treats them correctly. 'unitSigns' reduces their powers \
to their primary range, whilst minsign creates a specific reduction rule. \
\[DoubleStruckS] is general \[DoubleStruckR]'th root of unity.\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"unshuffle", "::", "usage"}], "=", "\"\<used in caylIndex\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"unsign", "::", "usage"}], "=", 
   "\"\<unsign[g] replaces negated or complex signed elements in 'g' by the \
indices of the expanded table.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Use", "::", "usage"}], "=", 
   "\"\<Use[H_] sets up H as the target loop, for compatibility with the \
Hoops.nb package.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"walsh", "::", "usage"}], "=", 
   "\"\<walsh[a_] calculates the Walsh function, \[PlusMinus]1, for 'a', \
which must be an IntegerDigits list;\n  walsh[a_,list_] calculates the \
modified Walsh function with 'n' defining `negative-square` elements of 'a'. \
Used in 'cl'\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "::", "usage"}], "=", 
   "\"\<\[Omega]=2\[Pi]/3 used in many orbits\>\""}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3 Usage for Predefined Index & Signed Tables.", "Subsubsection",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"2", ",", 
    RowBox[{"3", " ", "elements"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"C2", "::", "usage"}], "=", "\"\<indexTable for C2\>\""}], ";", 
    RowBox[{
     RowBox[{"C3", "::", "usage"}], "=", "\"\<indexTable for C3\>\""}], ";", 
    RowBox[{
     RowBox[{"C3n", "::", "usage"}], "=", 
     "\"\<non-conservative 3-element table\>\""}], ";", 
    RowBox[{
     RowBox[{"C3C3j", "::", "usage"}], "=", 
     "\"\<conservative \[DoubleStruckCapitalJ]-signedTable from C3C3, though \
conservativeQ and idc fail to simplify and so fail\>\""}], ";", 
    RowBox[{
     RowBox[{"C9J", "::", "usage"}], "=", 
     "\"\<conservative \[DoubleStruckCapitalJ]-signedTable from C9, though \
conservativeQ and idc fail to simplify and so fail\>\""}], ";", 
    RowBox[{
     RowBox[{"C9j", "::", "usage"}], "=", 
     "\"\<conservative \[DoubleStruckCapitalJ]-signedTable from a C9 \
isomorph, though conservativeQ and idc fail to simplify and so fail\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"C4C3c", "::", "usage"}], "=", 
     "\"\<conservative \[ImaginaryI]-signedTable\>\""}], ";", 
    RowBox[{
     RowBox[{"C3i", "::", "usage"}], "=", 
     "\"\<conservative \[ImaginaryI]-signedTable\>\""}], ";", 
    RowBox[{
     RowBox[{"C12c", "::", "usage"}], "=", 
     "\"\<conservative \[ImaginaryI]-signedTable\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"4", " ", "elements"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"C4", "::", "usage"}], "=", "\"\<indexTable for C4\>\""}], ";", 
    RowBox[{
     RowBox[{"K", "::", "usage"}], "=", 
     "\"\<indexTable for K \[Congruent] C2C2\>\""}], ";", 
    RowBox[{
     RowBox[{"P4", "::", "usage"}], "=", 
     "\"\<complexTable from P16 \[Congruent] Pauli algebra\>\""}], ";", 
    RowBox[{
     RowBox[{"P16c", "::", "usage"}], "=", "\"\<complexTable from P16\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"C4C3c", "::", "usage"}], "=", "\"\<signedTable from C4C3\>\""}],
     ";", 
    RowBox[{
     RowBox[{"Q4n", "::", "usage"}], "=", 
     "\"\<non-conservative signedTable related to Q4 & P4\>\""}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"5", "elements"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"C5", "::", "usage"}], "=", "\"\<indexTable for C5\>\""}], ";", 
    RowBox[{
     RowBox[{"C5n", "::", "usage"}], "=", 
     "\"\<The smallest non-associative Jacobi-identity loop \
(arXiv:hep-th/0111292 v1)\>\""}], ";", 
    RowBox[{
     RowBox[{"L5n", "::", "usage"}], "=", 
     "\"\<A 5-element Latin Square that passes entropicQ, hamiltonianQ & \
JacobiQ\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"6", " ", "elements"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"C3C2", "::", "usage"}], "=", "\"\<indexTable for C3C2\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"D3", "::", "usage"}], "=", 
     "\"\<indexTable for D3 \[Congruent] S3\>\""}], ";", 
    RowBox[{
     RowBox[{"D3C2c", "::", "usage"}], "=", 
     "\"\<signed indexTable from D3C2\>\""}], ";", 
    RowBox[{
     RowBox[{"C6n", "::", "usage"}], "=", 
     "\"\<A table with the repeated quadratic size of D3 replaced by two \
signed sums of 6 squares. Passes the hamiltonian test (only)\>\""}], 
    ";"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"8", ",", " ", 
    RowBox[{"9", " ", "elements"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"C4C2", "::", "usage"}], "=", "\"\<indexTable for C4C2\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"C8", "::", "usage"}], "=", "\"\<indexTable for C8\>\""}], ";", 
    RowBox[{
     RowBox[{"KC2", "::", "usage"}], "=", 
     "\"\<indexTable for KC2 \[Congruent]\!\(\*SuperscriptBox[\(C2\), \
\(3\)]\)\>\""}], ";", 
    RowBox[{
     RowBox[{"D4", "::", "usage"}], "=", "\"\<indexTable for D4\>\""}], ";", 
    RowBox[{
     RowBox[{"Q8", "::", "usage"}], "=", 
     "\"\<indexTable for quaternion group\>\""}], ";", 
    RowBox[{
     RowBox[{"CL12", "::", "usage"}], "=", 
     "\"\<signedTable Clifford(1,2)\>\""}], ";", 
    RowBox[{
     RowBox[{"P8", "::", "usage"}], "=", "\"\<signedTable from KK\>\""}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Octs", "::", "usage"}], "=", 
     "\"\<'SplitOctonion' signedTable from M(16,2)\>\""}], ";", 
    RowBox[{
     RowBox[{"Octr", "::", "usage"}], "=", 
     "\"\<signedTable from Oct or M(16,3)\>\""}], ";", 
    RowBox[{
     RowBox[{"O4", "::", "usage"}], "=", 
     "\"\<signedTable from C4K; O4a & O4b are isomorphs.\>\""}], ";", 
    RowBox[{
     RowBox[{"O4k", "::", "usage"}], "=", 
     "\"\<A signedTable from C4K with 4 linear and two quadratic \
sizes.\>\""}], ";", 
    RowBox[{
     RowBox[{"Q8C2r", "::", "usage"}], "=", "\"\<signedTable from Q8C2\>\""}],
     ";", 
    RowBox[{
     RowBox[{"Q8n", "::", "usage"}], "=", 
     "\"\<non-conservative Table related to Q8 & P8\>\""}], ";", 
    RowBox[{
     RowBox[{"C8an", "::", "usage"}], "=", 
     "\"\<signedTable cd[{2,-1.,-1}] that passes associativeQ & moufangQ but \
does not conserve its single factor\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"9", " ", "elements"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"C3C3", "::", "usage"}], "=", "\"\<indexTable for C3C3\>\""}], 
    ";"}]}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"12", " ", "elements"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"C3C4", "::", "usage"}], "=", "\"\<indexTable for C3C4\>\""}], 
   ";", 
   RowBox[{
    RowBox[{"C3K", "::", "usage"}], "=", 
    "\"\<indexTable for C3K \[Congruent] C3C2C2\>\""}], ";", 
   RowBox[{
    RowBox[{"Q12", "::", "usage"}], "=", "\"\<indexTable for Q12\>\""}], ";", 
   
   RowBox[{
    RowBox[{"A4", "::", "usage"}], "=", "\"\<indexTable for A4\>\""}], ";", 
   RowBox[{
    RowBox[{"A4a", "::", "usage"}], "=", "\"\<second indexTable for A4\>\""}],
    ";", 
   RowBox[{
    RowBox[{"D3C2", "::", "usage"}], "=", "\"\<indexTable for D3C2\>\""}], 
   ";", 
   RowBox[{
    RowBox[{"C3P4", "::", "usage"}], "=", 
    "\"\<conservative 12-element complexTable\>\""}], ";", 
   RowBox[{
    RowBox[{"D3Mn", "::", "usage"}], "=", 
    "\"\<indexTable for GAP M1201, 12-element non-associative Moufang Loop \
from D3\>\""}], ";", 
   RowBox[{
    RowBox[{"Alt12n", "::", "usage"}], "=", 
    "\"\<non-conservative alternative 12-element indexTable\>\""}], 
   ";"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"16", " ", "elements"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Q16", "::", "usage"}], "=", "\"\<indexTable for Q16\>\""}], ";",
     
    RowBox[{
     RowBox[{"D4C2", "::", "usage"}], "=", "\"\<indexTable for D4C2\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"C4C4", "::", "usage"}], "=", "\"\<indexTable for C4C4\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"Q8C2", "::", "usage"}], "=", "\"\<indexTable for Q8C2\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"C8pC2", "::", "usage"}], "=", "\"\<indexTable for C8pC2\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"KK", "::", "usage"}], "=", 
     "\"\<indexTable for KK \[Congruent] \!\(\*SuperscriptBox[\(C2\), \
\(4\)]\)\>\""}], ";", 
    RowBox[{
     RowBox[{"C4K", "::", "usage"}], "=", "\"\<indexTable for C4K\>\""}], ";",
     
    RowBox[{
     RowBox[{"KiC4", "::", "usage"}], "=", "\"\<indexTable for KiC4\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"C4iC4", "::", "usage"}], "=", "\"\<indexTable for C4iC4\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"P16", "::", "usage"}], "=", 
     "\"\<indexTable for Pauli group P16\>\""}], ";", 
    RowBox[{
     RowBox[{"P16a", "::", "usage"}], "=", 
     "\"\<second indexTable for Pauli group P16\>\""}], ";", 
    RowBox[{
     RowBox[{"P16i", "::", "usage"}], "=", 
     "\"\<third indexTable for Pauli group P16\>\""}], ";", 
    RowBox[{
     RowBox[{"Oct", "::", "usage"}], "=", 
     "\"\<conservative alternative 16-element indexTable\>\""}], ";", 
    RowBox[{
     RowBox[{"r31r", "::", "usage"}], "=", 
     "\"\<16 element signedTable from g3249\>\""}], ";", 
    RowBox[{
     RowBox[{"CL4", "::", "usage"}], "=", 
     "\"\<16 element Clifford signedTable from g3250\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CL31", "::", "usage"}], "=", 
     "\"\<16 element Clifford signedTable\>\""}], ";", 
    RowBox[{
     RowBox[{"CL22", "::", "usage"}], "=", 
     "\"\<16 element Clifford signedTable\>\""}], ";", 
    RowBox[{
     RowBox[{"CL13", "::", "usage"}], "=", 
     "\"\<16 element Clifford signedTable\>\""}], ";", 
    RowBox[{
     RowBox[{"CL04", "::", "usage"}], "=", 
     "\"\<16 element Clifford signedTable from g3250\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"D4M1n", "::", "usage"}], "=", 
     "\"\<indexTable for 16-element non-associative Moufang Loop from D4, GAP \
M1601\>\""}], ";", 
    RowBox[{
     RowBox[{"Q8M2", "::", "usage"}], "=", 
     "\"\<indexTable for 16-element associative Moufang Loop from Q8, GAP \
M1602\>\""}], ";", 
    RowBox[{
     RowBox[{"D4M4n", "::", "usage"}], "=", 
     "\"\<indexTable for 16-element non-associative Moufang Loop from D4, GAP \
M1604\>\""}], ";", 
    RowBox[{
     RowBox[{"D4M5n", "::", "usage"}], "=", 
     "\"\<indexTable for 16-element non-associative Moufang Loop from Q8, GAP \
M1605\>\""}], ";", 
    RowBox[{
     RowBox[{"r31r", "::", "usage"}], "=", 
     "\"\<Mixed signature Clifford algebra.\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r31s", "::", "usage"}], "=", 
     "\"\<Mixed signature Clifford algebra.\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r31t", "::", "usage"}], "=", 
     "\"\<Mixed signature Clifford algebra.\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r31u", "::", "usage"}], "=", 
     "\"\<Mixed signature Clifford algebra.\>\""}], ";", 
    RowBox[{
     RowBox[{"Sed", "::", "usage"}], "=", 
     "\"\<The Sedenion (hexadecimilion) non-conservative non-alternative \
Cayley-Dickson algebra\>\""}], ";"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"20", "+", " ", "elements"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D5Mn", "::", "usage"}], "=", 
     "\"\<indexTable for 20-element non-associative Moufang Loop from D5, GAP \
M2001\>\""}], ";", 
    RowBox[{
     RowBox[{"D3C2Mn", "::", "usage"}], "=", 
     "\"\<indexTable for 24-element non-associative Moufang Loop from D3C2, \
GAP M2401\>\""}], ";", 
    RowBox[{
     RowBox[{"A4Mn", "::", "usage"}], "=", 
     "\"\<indexTable for 24-element non-associative Moufang Loop from A4, GAP \
M402\>\""}], ";", 
    RowBox[{
     RowBox[{"Q12M3n", "::", "usage"}], "=", 
     "\"\<indexTable for 24-element non-associative Moufang Loop from Q12, \
GAP M2403\>\""}], ";", 
    RowBox[{
     RowBox[{"Q12M4n", "::", "usage"}], "=", 
     "\"\<indexTable for 24-element non-associative Moufang Loop from Q12, \
GAP M2405\>\""}], ";", 
    RowBox[{
     RowBox[{"Q12M5n", "::", "usage"}], "=", 
     "\"\<indexTable for 24-element non-associative Moufang Loop from Q12, \
GAP M2405\>\""}], ";", 
    RowBox[{
     RowBox[{"SL23", "::", "usage"}], "=", 
     "\"\<indexTable for 24-element group SL[2,3]\>\""}], ";", 
    RowBox[{
     RowBox[{"OctrC3", "::", "usage"}], "=", 
     "\"\<conservative alternative 24-element signedTable\>\""}], ";", 
    RowBox[{
     RowBox[{"Alt12nC2", "::", "usage"}], "=", 
     "\"\<non-conservative alternative 24-element indexTable\>\""}], ";", 
    RowBox[{
     RowBox[{"P27", "::", "usage"}], "=", 
     "\"\<indexTable for group P27\>\""}], ";", 
    RowBox[{
     RowBox[{"g2704", "::", "usage"}], "=", 
     "\"\<indexTable for group 27-element without prescription\>\""}], ";", 
    RowBox[{
     RowBox[{"OctC2", "::", "usage"}], "=", 
     "\"\<conservative alternative 32-element signedTable\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"OctC2M", "::", "usage"}], "=", 
     "\"\<conservative alternative 32-element indexTable, GAP M3216\>\""}], 
    ";", 
    RowBox[{
     RowBox[{"P16M", "::", "usage"}], "=", 
     "\"\<indexTable for 32-element non-associative Moufang Loop from P16, \
GAP M3221\>\""}], ";", 
    RowBox[{
     RowBox[{"C8pC2M", "::", "usage"}], "=", 
     "\"\<indexTable for 32-element non-associative Moufang Loop from C8pC2 \
GAP M3235\>\""}], ";", 
    RowBox[{
     RowBox[{"KiC4M", "::", "usage"}], "=", 
     "\"\<indexTable for 32-element non-associative Moufang Loop from KiC4, \
GAP M3254\>\""}], ";", 
    RowBox[{
     RowBox[{"C4iC4M", "::", "usage"}], "=", 
     "\"\<indexTable for 32-element non-associative Moufang Loop from C4iC4, \
GAP M4365\>\""}], ";", 
    RowBox[{
     RowBox[{"Alt12nC3", "::", "usage"}], "=", 
     "\"\<non-conservative alternative 36-element indexTable\>\""}], ";", 
    RowBox[{
     RowBox[{"OctC3", "::", "usage"}], "=", 
     "\"\<conservative alternative 48-element indexTable\>\""}], 
    ";"}]}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["8. Start Private definitions.  Create Database.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "1 Begin Private."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}}],

Cell[TextData[{
 "Begin[",
 StyleBox["\"`Private`\"",
  FontFamily->"Courier New"],
 "];\nprotected = Unprotect[NumberQ, NumericQ, Positive, Abs, Sign, Re, Im];"
}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "2 Miscellaneous definitions ",
 StyleBox["arcTanh, det, grayinv, pos, walsh",
  FontSlant->"Italic"],
 ", etc."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}}],

Cell["\<\
The following are general definitions that extend Mathematica without being \
specific to groups, loops, or hoops.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"arcTanh", "[", 
    RowBox[{"adj_", ",", "opp_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "=", 
        RowBox[{"Chop", "[", "adj", "]"}]}], ",", 
       RowBox[{"y", "=", 
        RowBox[{"Chop", "[", "opp", "]"}]}], ",", "b"}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "\[Equal]", "y"}], "||", 
         RowBox[{"x", "\[Equal]", 
          RowBox[{"-", "y"}]}]}], ")"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x", "\[NotEqual]", "0"}], ",", 
         RowBox[{"\[Infinity]", " ", 
          RowBox[{
           RowBox[{"Sign", "[", "y", "]"}], "/", 
           RowBox[{"Sign", "[", " ", "x", "]"}]}]}], ",", "0", ",", "0"}], 
        "]"}], ",", 
       RowBox[{
        RowBox[{"b", "=", 
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "+", "y"}], ")"}], "/", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["x", "2"], "-", 
              SuperscriptBox["y", "2"]}]]}], "//", "N"}], "]"}]}], ";", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"Re", "[", "b", "]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Chop", "[", 
            RowBox[{"Im", "[", "b", "]"}], "]"}]}]}], "]"}]}]}], "]"}]}], 
    "]"}]}], ";", 
  RowBox[{
   RowBox[{"arcTanh", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_"}], "}"}], "]"}], ":=", 
   RowBox[{"arcTanh", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"pos", "[", "a_", "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Head", "[", "a", "]"}], "===", "TraditionalForm"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{
           RowBox[{"a", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"-", "_"}]}], "]"}], "===", 
         RowBox[{"{", 
          RowBox[{"{", "}"}], "}"}]}], ",", 
        RowBox[{"-", 
         RowBox[{"a", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{"a", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{
           RowBox[{"a", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"-", "_"}]}], "]"}], "===", 
         RowBox[{"{", 
          RowBox[{"{", "}"}], "}"}]}], ",", 
        RowBox[{"-", "a"}], ",", "a"}], "]"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"used", " ", "in", " ", "frag"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"symdiff", "[", 
    RowBox[{"a_Real", ",", 
     RowBox[{"b_Real:", "0."}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"a", "<", "b"}], ",", 
     RowBox[{"b", "-", "a"}], ",", 
     RowBox[{"a", "-", "b"}], ",", 
     RowBox[{"a", "-", "b"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"symdiff", "[", 
    RowBox[{"a_Integer", ",", 
     RowBox[{"b_Integer:", "0"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"a", "<", "b"}], ",", 
     RowBox[{"b", "-", "a"}], ",", 
     RowBox[{"a", "-", "b"}], ",", 
     RowBox[{"a", "-", "b"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reim", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["Re", 
       TagBox[
        RowBox[{"(", "any_", ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "Re"}], ",", 
     RowBox[{
      SuperscriptBox["Im", 
       TagBox[
        RowBox[{"(", "any_", ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "Im"}]}], "}"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"det", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", "aa_", ")"}], "?", "MatrixQ"}], ",", 
      RowBox[{"m_:", "2"}], ",", 
      RowBox[{"t_:", "Times"}]}], "]"}], " ", ":=", " ", 
    StyleBox["\[IndentingNewLine]",
     FontColor->RGBColor[1, 0, 0]], 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"am", "=", 
         RowBox[{"Abs", "[", "m", "]"}]}], ",", 
        RowBox[{"bb", "=", "aa"}], ",", "cc", ",", "dd", ",", "ii", ",", "J", 
        ",", 
        RowBox[{"ln", "=", 
         RowBox[{"Length", "[", "aa", "]"}]}], ",", 
        RowBox[{"lm", "=", 
         RowBox[{"Length", "[", 
          RowBox[{"aa", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "==", "0"}], "||", 
          RowBox[{"!", 
           RowBox[{"IntegerQ", "[", "m", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"Print", " ", "[", 
           RowBox[{"\"\<m cannot be \>\"", ",", "m"}], "]"}], ";", 
          RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{"ln", " ", "==", " ", "1"}], ",", " ", 
         RowBox[{"dd", " ", "=", " ", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"J", "^", 
              RowBox[{"(", 
               RowBox[{"ii", " ", "-", " ", "1"}], ")"}]}], "*", 
             RowBox[{"aa", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "ii"}], "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"ii", ",", " ", "1", ",", " ", "lm"}], "}"}]}], "]"}]}], 
         ",", " ", "\n", "      ", 
         RowBox[{"lm", " ", "==", " ", "1"}], ",", " ", 
         RowBox[{"dd", " ", "=", " ", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"J", "^", 
              RowBox[{"(", 
               RowBox[{"ii", " ", "-", " ", "1"}], ")"}]}], "*", 
             RowBox[{"aa", "[", 
              RowBox[{"[", 
               RowBox[{"ii", ",", "1"}], "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"ii", ",", " ", "1", ",", " ", "ln"}], "}"}]}], "]"}]}], 
         ",", " ", "True", ",", " ", "\n", "      ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"ln", " ", ">", " ", "lm"}], ",", " ", 
            RowBox[{
             RowBox[{"bb", "=", " ", 
              RowBox[{"Transpose", "[", "aa", "]"}]}], ";", " ", 
             RowBox[{"lm", " ", "=", " ", "ln"}]}]}], "]"}], ";", " ", 
          RowBox[{"cc", " ", "=", " ", 
           RowBox[{"J", "*", 
            RowBox[{"bb", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], ";", " ", 
          RowBox[{"bb", " ", "=", " ", 
           RowBox[{"Transpose", "[", 
            RowBox[{"Drop", "[", 
             RowBox[{"bb", ",", " ", "1"}], "]"}], "]"}]}], ";", "        ", 
          RowBox[{"dd", " ", "=", " ", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"cc", "[", 
                 RowBox[{"[", "ii", "]"}], "]"}], " ", "===", " ", "0"}], ",",
                " ", "0", ",", " ", 
               RowBox[{
                RowBox[{"J", "^", "ii"}], "*", 
                RowBox[{"t", "[", 
                 RowBox[{
                  RowBox[{"cc", "[", 
                   RowBox[{"[", "ii", "]"}], "]"}], ",", " ", 
                  RowBox[{"det1", "[", 
                   RowBox[{
                    RowBox[{"Drop", "[", 
                    RowBox[{"bb", ",", " ", 
                    RowBox[{"{", "ii", "}"}]}], "]"}], ",", " ", "J", ",", 
                    " ", "t"}], "]"}]}], "]"}]}]}], "]"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"ii", ",", " ", "1", ",", " ", "lm"}], "}"}]}], 
            "]"}]}]}]}], "]"}], ";", "      ", 
       RowBox[{"bb", "=", 
        RowBox[{
         RowBox[{"CoefficientList", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", "dd", "]"}], "//.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"J", "^", "any_"}], "->", 
              RowBox[{"J", "^", 
               RowBox[{"Mod", "[", 
                RowBox[{"any", ",", "am"}], "]"}]}]}], "}"}]}], ",", "J"}], 
          "]"}], "/.", 
         RowBox[{"J", "->", 
          RowBox[{"Switch", "[", 
           RowBox[{"am", ",", "1", ",", "1", ",", "2", ",", 
            RowBox[{"-", "1"}], ",", "3", ",", "\[DoubleStruckJ]", ",", "4", 
            ",", "\[ImaginaryI]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Expand", "[", 
        RowBox[{"Switch", "[", 
         RowBox[{"m", ",", "2", ",", 
          RowBox[{
           RowBox[{"bb", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "-", 
           RowBox[{"bb", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ",", "3", ",", 
          RowBox[{
           RowBox[{"bb", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "+", 
           RowBox[{"\[DoubleStruckJ]", " ", 
            RowBox[{"bb", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "+", 
           RowBox[{"\[DoubleStruckJ]", " ", "\[DoubleStruckJ]", " ", 
            RowBox[{"bb", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}]}], ",", "4", ",", 
          RowBox[{
           RowBox[{"bb", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"bb", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "-", " ", 
           RowBox[{"bb", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"bb", "[", 
             RowBox[{"[", "4", "]"}], "]"}]}]}], ",", "_", ",", "bb"}], "]"}],
         "]"}]}]}], "]"}]}], ";"}], " ", "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"det1", "[", 
     RowBox[{"aa_", ",", " ", "J_", ",", " ", "t_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ln", " ", "=", " ", 
         RowBox[{"Length", "[", "aa", "]"}]}], ",", " ", 
        RowBox[{"lm", " ", "=", " ", 
         RowBox[{"Length", "[", 
          RowBox[{"aa", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", " ", "bb", ",", " ", 
        "cc", ",", "ii"}], "}"}], ",", " ", "\n", "    ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"lm", " ", "==", " ", "1"}], ",", " ", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"J", "^", 
            RowBox[{"(", 
             RowBox[{"ii", " ", "-", " ", "1"}], ")"}]}], "*", 
           RowBox[{"aa", "[", 
            RowBox[{"[", 
             RowBox[{"ii", ",", "1"}], "]"}], "]"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"ii", ",", " ", "1", ",", " ", "ln"}], "}"}]}], "]"}], ",",
         " ", 
        RowBox[{
         RowBox[{"bb", " ", "=", " ", 
          RowBox[{"Transpose", "[", "aa", "]"}]}], ";", " ", 
         RowBox[{"cc", " ", "=", " ", 
          RowBox[{"J", "*", 
           RowBox[{"bb", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], ";", " ", "\n", "      ", 
         RowBox[{"bb", " ", "=", " ", 
          RowBox[{"Transpose", "[", 
           RowBox[{"Drop", "[", 
            RowBox[{"bb", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"cc", "[", 
               RowBox[{"[", "ii", "]"}], "]"}], " ", "===", " ", "0"}], ",", 
             " ", "0", ",", " ", 
             RowBox[{
              RowBox[{"J", "^", "ii"}], "*", 
              RowBox[{"t", "[", 
               RowBox[{
                RowBox[{"cc", "[", 
                 RowBox[{"[", "ii", "]"}], "]"}], ",", " ", 
                RowBox[{"det1", "[", 
                 RowBox[{
                  RowBox[{"Drop", "[", 
                   RowBox[{"bb", ",", " ", 
                    RowBox[{"{", "ii", "}"}]}], "]"}], ",", " ", "J", ",", 
                  " ", "t"}], "]"}]}], "]"}]}]}], "]"}], ",", " ", "\n", 
           "       ", 
           RowBox[{"{", 
            RowBox[{"ii", ",", " ", "1", ",", " ", "ln"}], "}"}]}], "]"}]}]}],
        "]"}]}], "]"}]}], ";"}], " "}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 FontFamily->"Courier New",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"det", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", "a_", ")"}], "?", "MatrixQ"}], ",", " ", 
      RowBox[{"m_:", "2"}]}], "]"}], " ", ":=", " ", 
    StyleBox[
     RowBox[{"(*", 
      RowBox[{"FAILS", " ", "IN", " ", "M6"}], "*)"}],
     FontSize->18,
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["\[IndentingNewLine]",
     FontColor->RGBColor[1, 0, 0]], 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"am", " ", "=", " ", 
         RowBox[{"Abs", "[", "m", "]"}]}], ",", " ", 
        RowBox[{"b", " ", "=", " ", "a"}], ",", " ", "c", ",", " ", "d", ",", 
        " ", "i", ",", " ", "J", ",", " ", 
        RowBox[{"ln", " ", "=", " ", 
         RowBox[{"Length", "[", "a", "]"}]}], ",", " ", "\n", "     ", 
        RowBox[{"lm", " ", "=", " ", 
         RowBox[{"Length", "[", 
          RowBox[{"a", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", " ", 
        RowBox[{"t", " ", "=", " ", "Times"}]}], "}"}], ",", " ", 
      RowBox[{
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{"ln", " ", "==", " ", "1"}], ",", " ", 
         RowBox[{"d", " ", "=", " ", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"J", "^", 
              RowBox[{"(", 
               RowBox[{"i", " ", "-", " ", "1"}], ")"}]}], "*", 
             RowBox[{"a", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "i"}], "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "1", ",", " ", "lm"}], "}"}]}], "]"}]}], 
         ",", " ", "\n", "      ", 
         RowBox[{"lm", " ", "==", " ", "1"}], ",", " ", 
         RowBox[{"d", " ", "=", " ", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"J", "^", 
              RowBox[{"(", 
               RowBox[{"i", " ", "-", " ", "1"}], ")"}]}], "*", 
             RowBox[{"a", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "1", ",", " ", "ln"}], "}"}]}], "]"}]}], 
         ",", " ", "True", ",", " ", "\n", "      ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"ln", " ", ">", " ", "lm"}], ",", " ", 
            RowBox[{
             RowBox[{"b", " ", "=", " ", 
              RowBox[{"Transpose", "[", "a", "]"}]}], ";", " ", 
             RowBox[{"lm", " ", "=", " ", "ln"}]}]}], "]"}], ";", " ", 
          RowBox[{"c", " ", "=", " ", 
           RowBox[{"J", "*", 
            RowBox[{"b", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], ";", " ", 
          RowBox[{"b", " ", "=", " ", 
           RowBox[{"Transpose", "[", 
            RowBox[{"Drop", "[", 
             RowBox[{"b", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", "\n", 
          "       ", 
          RowBox[{"d", " ", "=", " ", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"c", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "===", " ", "0"}], ",", 
               " ", "0", ",", " ", 
               RowBox[{
                RowBox[{"J", "^", "i"}], "*", 
                RowBox[{"t", "[", 
                 RowBox[{
                  RowBox[{"c", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
                  RowBox[{"det1", "[", 
                   RowBox[{
                    RowBox[{"Drop", "[", 
                    RowBox[{"b", ",", " ", 
                    RowBox[{"{", "i", "}"}]}], "]"}], ",", " ", "J", ",", " ",
                     "t"}], "]"}]}], "]"}]}]}], "]"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"i", ",", " ", "1", ",", " ", "lm"}], "}"}]}], 
            "]"}]}]}]}], "]"}], ";", " ", "\n", "     ", 
       RowBox[{
        RowBox[{"CoefficientList", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", "d", "]"}], " ", "//.", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"J", "^", 
              RowBox[{"(", "any_", ")"}]}], " ", "->", " ", 
             RowBox[{"J", "^", 
              RowBox[{"Mod", "[", 
               RowBox[{"any", ",", " ", "am"}], "]"}]}]}], "}"}]}], ",", " ", 
          "J"}], "]"}], " ", "/.", " ", "\n", "      ", 
        RowBox[{"J", " ", "->", " ", 
         RowBox[{"Switch", "[", 
          RowBox[{
          "am", ",", " ", "1", ",", " ", "1", ",", " ", "2", ",", " ", 
           RowBox[{"-", "1"}], ",", " ", "3", ",", " ", "\[DoubleStruckJ]", 
           ",", " ", "4", ",", " ", "\[DoubleStruckI]"}], "]"}]}]}]}]}], 
     "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"det1", "[", 
     RowBox[{"a_", ",", " ", "J_", ",", " ", "t_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ln", " ", "=", " ", 
         RowBox[{"Length", "[", "a", "]"}]}], ",", " ", 
        RowBox[{"lm", " ", "=", " ", 
         RowBox[{"Length", "[", 
          RowBox[{"a", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", " ", "b", ",", " ", 
        "c"}], "}"}], ",", " ", "\n", "    ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"lm", " ", "==", " ", "1"}], ",", " ", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"J", "^", 
            RowBox[{"(", 
             RowBox[{"i", " ", "-", " ", "1"}], ")"}]}], "*", 
           RowBox[{"a", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "1", ",", " ", "ln"}], "}"}]}], "]"}], ",", 
        " ", 
        RowBox[{
         RowBox[{"b", " ", "=", " ", 
          RowBox[{"Transpose", "[", "a", "]"}]}], ";", " ", 
         RowBox[{"c", " ", "=", " ", 
          RowBox[{"J", "*", 
           RowBox[{"b", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], ";", " ", "\n", "      ", 
         RowBox[{"b", " ", "=", " ", 
          RowBox[{"Transpose", "[", 
           RowBox[{"Drop", "[", 
            RowBox[{"b", ",", " ", "1"}], "]"}], "]"}]}], ";", " ", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"c", "[", 
               RowBox[{"[", "i", "]"}], "]"}], " ", "===", " ", "0"}], ",", 
             " ", "0", ",", " ", 
             RowBox[{
              RowBox[{"J", "^", "i"}], "*", 
              RowBox[{"t", "[", 
               RowBox[{
                RowBox[{"c", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
                RowBox[{"det1", "[", 
                 RowBox[{
                  RowBox[{"Drop", "[", 
                   RowBox[{"b", ",", " ", 
                    RowBox[{"{", "i", "}"}]}], "]"}], ",", " ", "J", ",", " ",
                   "t"}], "]"}]}], "]"}]}]}], "]"}], ",", " ", "\n", 
           "       ", 
           RowBox[{"{", 
            RowBox[{"i", ",", " ", "1", ",", " ", "ln"}], "}"}]}], "]"}]}]}], 
       "]"}]}], "]"}]}], ";"}], " "}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 Evaluatable->False,
 FontFamily->"Courier New",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"walsh", "[", "a_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"EvenQ", "[", 
      RowBox[{"Length", "[", 
       RowBox[{"Position", "[", 
        RowBox[{"a", ",", "1"}], "]"}], "]"}], "]"}], ",", "1", ",", 
     RowBox[{"-", "1"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"walsh", "[", 
    RowBox[{"a_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"EvenQ", "[", 
      RowBox[{"Length", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"a", "[", 
          RowBox[{"[", "n", "]"}], "]"}], ",", "1"}], "]"}], "]"}], "]"}], 
     ",", "1", ",", 
     RowBox[{"-", "1"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"grayinv", "[", "a_", "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{
       RowBox[{"Plus", "@@", 
        RowBox[{"Take", "[", 
         RowBox[{"a", ",", "i"}], "]"}]}], ",", "2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "a", "]"}]}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Distribution", "[", "l_List", "]"}], ":=", 
    RowBox[{"Distribution", "[", 
     RowBox[{"l", ",", 
      RowBox[{"Union", "[", "l", "]"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"From", " ", "Skiena", " ", "p106"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Distribution", "[", 
    RowBox[{"l_List", ",", "set_List"}], "]"}], ":=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", "Count", ")"}], "[", 
       RowBox[{"l", ",", "#"}], "]"}], "&"}], ",", "set"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"select", "[", 
    RowBox[{"l_", "?", "ListQ"}], "]"}], " ", ":=", 
   RowBox[{"Union", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"globa", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"l", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", 
         RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"j", ",", " ", 
         RowBox[{"Length", "[", "l", "]"}]}], "}"}]}], "]"}], "]"}], "]"}]}], 
  ";", 
  RowBox[{
   RowBox[{"union", "[", "lst_", "]"}], ":=", 
   RowBox[{"(*", " ", 
    RowBox[{"Union", " ", "No", " ", "Sort", " ", "as", " ", "in", " ", 
     RowBox[{"EEAM", ".", " ", "Available"}], " ", "as", " ", "UnsortedUnion",
      " ", "in", " ", "Functions"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{
     RowBox[{"Head", "[", "lst", "]"}], ",", 
     RowBox[{"Fold", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{"#1", ",", "#2"}], "]"}], ",", "#1", ",", 
          RowBox[{"Append", "[", 
           RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"First", "[", "lst", "]"}], "}"}], ",", 
       RowBox[{"Drop", "[", 
        RowBox[{"lst", ",", "1"}], "]"}]}], "]"}]}], "]"}]}]}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"permfromQ", "[", 
    RowBox[{"p_List", ",", "n_Integer"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Length", "[", 
      RowBox[{"Complement", "[", 
       RowBox[{"p", ",", 
        RowBox[{"Range", "[", "n", "]"}]}], "]"}], "]"}], "\[Equal]", "0"}], "&&",
     
    RowBox[{
     RowBox[{"Sort", "[", "p", "]"}], "\[Equal]", 
     RowBox[{"Union", "[", "p", "]"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"permute", "[", 
    RowBox[{"P_List", ",", "p_List"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"permfromQ", "[", 
      RowBox[{"p", ",", 
       RowBox[{"Length", "[", "P", "]"}]}], "]"}], ",", 
     RowBox[{"P", "[", 
      RowBox[{"[", "p", "]"}], "]"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"{", 
       RowBox[{"P", ",", "p", ",", "\"\< error\>\""}], "}"}], "]"}]}], 
    "]"}]}], ";", 
  RowBox[{
   RowBox[{"toCycles", "[", 
    RowBox[{"perm_", "?", "VectorQ"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "i", ",", "m", ",", "n", ",", 
       RowBox[{"p", "=", "perm"}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sort", "[", "p", "]"}], "==", 
        RowBox[{"Range", "[", 
         RowBox[{"Max", "[", "p", "]"}], "]"}]}], ",", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"m", "=", 
             RowBox[{"n", "=", 
              RowBox[{
              "p", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}]}],
             ";", 
            RowBox[{"c", "=", 
             RowBox[{"{", "}"}]}], ";", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
               "p", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "\[NotEqual]", "0"}], ",", 
              RowBox[{
               RowBox[{"AppendTo", "[", 
                RowBox[{"c", ",", 
                 RowBox[{"m", "=", "n"}]}], "]"}], ";", 
               RowBox[{"n", "=", 
                RowBox[{
                "p", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}],
                ";", 
               RowBox[{
                RowBox[{
                "p", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
                "=", "0"}]}]}], "]"}], ";", "c"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "p", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"#1", "=!=", 
           RowBox[{"{", "}"}]}], "&"}]}], "]"}], ",", 
       "\"\<Not a Permutation\>\""}], "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"fromCycles", "[", "cyc_List", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Range", "[", 
         RowBox[{"Max", "[", 
          RowBox[{"Flatten", "[", "cyc", "]"}], "]"}], "]"}]}], ",", "pos"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"Scan", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pos", "=", 
            RowBox[{"Last", "[", "#1", "]"}]}], ";", 
           RowBox[{"Scan", "[", 
            RowBox[{
             RowBox[{"Function", "[", 
              RowBox[{"c", ",", 
               RowBox[{"pos", "=", 
                RowBox[{
                 RowBox[{
                 "p", "\[LeftDoubleBracket]", "pos", 
                  "\[RightDoubleBracket]"}], "=", "c"}]}]}], "]"}], ",", 
             "#1"}], "]"}]}], ")"}], "&"}], ",", "cyc"}], "]"}], ";", "p"}]}],
     "]"}]}], ";", 
  RowBox[{
   RowBox[{"as", "[", "A_", "]"}], ":=", 
   RowBox[{"(*", 
    RowBox[{
    "Relace", " ", "alph", " ", "dummy", " ", "variables", " ", "by", " ", 
     "the", " ", "coefficients", " ", "in", " ", "A"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"alph", "[", 
       RowBox[{"[", "ii", "]"}], "]"}], "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"[", "ii", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", 
       RowBox[{"Min", "[", 
        RowBox[{"mm", ",", 
         RowBox[{"Length", "[", "A", "]"}]}], "]"}]}], "}"}]}], "]"}]}], ";", 
  
  RowBox[{
   RowBox[{"as", "[", 
    RowBox[{"A_", ",", "B_"}], "]"}], ":=", 
   RowBox[{"(*", 
    RowBox[{
    "Relace", " ", "B", " ", "variables", " ", "by", " ", "the", " ", 
     "coefficients", " ", "in", " ", "A"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"B", "[", 
       RowBox[{"[", "ii", "]"}], "]"}], "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{"[", "ii", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", 
       RowBox[{"Min", "[", 
        RowBox[{"mm", ",", 
         RowBox[{"Length", "[", "A", "]"}], ",", 
         RowBox[{"Length", "[", "B", "]"}]}], "]"}]}], "}"}]}], "]"}]}], ";", 
  
  RowBox[{"tf", "=", "TraditionalForm"}], ";", 
  RowBox[{"r3", "=", 
   RowBox[{"1", "/", 
    RowBox[{"Sqrt", "[", "3", "]"}]}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Use", "[", "H_", "]"}], ":=", 
   RowBox[{"(*", 
    RowBox[{"Included", " ", "for", " ", "compatibility", " ", "with", " ", 
     RowBox[{"Hoops", ".", "nb"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<Target Loop\>\"", " ", 
      RowBox[{"id", "[", "H", "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "3 Extended (generalized) signs.",
 StyleBox[" Problems in V6",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}}],

Cell[TextData[{
 "\tExtended signs are roots of unity. They (and their low powers) are \
orthogonal to each other; several distinct r'th roots occur in many groups. \
(Projecting them onto the complex unit circle as cyclotomic numbers destroys \
these important properties.) A set of symbols is proposed as a standard \
(together with -, \[ImaginaryI], & -\[ImaginaryI]).  \[DoubleStruckCapitalI] \
and \[DoubleStruckCapitalJ] differ from related letters used in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", where I & \[DoubleStruckJ] are synonymous with \[ImaginaryI]. Whilst ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "4 allowed NumberQ[symbol]=True, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6 does not; NumericQ[symbol] is allowed.\n\t\[DoubleStruckS] is a \
generalized sign, the \[DoubleStruckR]'th root of unity; \[DoubleStruckR] can \
be a positive integer. The others are specific extended signs. ",
 StyleBox["unitSigns",
  FontSlant->"Italic"],
 " is a simplifying function for expressions that include extended signs; ",
 StyleBox["minsign[expression] ",
  FontSlant->"Italic"],
 "creates a selective version for just those signs in ",
 StyleBox["expression",
  FontSlant->"Italic"],
 ". I suggest the convention that \"readable-ASCII-only\" documents use 'd, \
'g,...'Y (read as sign d, etc) for these double-struck letters.\n\t",
 StyleBox["\[ImaginaryI] behaves differently in V6 cf V4. Replaced by \
\[DoubleStruckCapitalI] in u2,u2,u4",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", 
   RowBox[{
   "NumberQ", ",", "NumericQ", ",", "Positive", ",", "Abs", ",", "Sign", ",", 
    "Re", ",", "Im"}], "]"}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[DoubleStruckR]", "=."}], ";", 
  RowBox[{"unitSigns", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubleStruckD]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckD]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "12"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckG]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckG]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "7"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckH]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckH]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "6"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox[
       StyleBox["\[DoubleStruckCapitalI]",
        FontWeight->"Plain"], "any_"], "\[Rule]", 
      SuperscriptBox[
       StyleBox["\[DoubleStruckCapitalI]",
        FontWeight->"Plain"], 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "4"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox[
       StyleBox["\[DoubleStruckCapitalJ]",
        FontWeight->"Plain"], "any_"], "\[Rule]", 
      SuperscriptBox[
       StyleBox["\[DoubleStruckCapitalJ]",
        FontWeight->"Plain"], 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "3"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckK]", 
       RowBox[{"any_", "?", "OddQ"}]], "\[Rule]", "\[DoubleStruckK]"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckK]", 
       RowBox[{"any_", "?", "EvenQ"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckL]", 
       RowBox[{"any_", "?", "OddQ"}]], "\[Rule]", "\[DoubleStruckL]"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckL]", 
       RowBox[{"any_", "?", "EvenQ"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SuperscriptBox[
       StyleBox["\[DoubleStruckM]",
        FontWeight->"Plain"], 
       RowBox[{"any_", "?", "OddQ"}]], "\[Rule]", 
      StyleBox["\[DoubleStruckM]",
       FontWeight->"Plain"]}], ",", 
     RowBox[{
      SuperscriptBox[
       StyleBox["\[DoubleStruckM]",
        FontWeight->"Plain"], 
       RowBox[{"any_", "?", "EvenQ"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SuperscriptBox[
       StyleBox["\[DoubleStruckN]",
        FontWeight->"Plain"], "any_"], "\[Rule]", 
      StyleBox[
       SuperscriptBox["\[DoubleStruckN]", 
        RowBox[{"Mod", "[", 
         RowBox[{"any", ",", "9"}], "]"}]],
       FontWeight->"Plain"]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckO]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckO]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "8"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckP]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckP]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "5"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckS]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckS]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "\[DoubleStruckR]"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckCapitalY]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckCapitalY]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "3"}], "]"}]]}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"signlist", "=", 
   RowBox[{"{", 
    RowBox[{
    "\[ImaginaryI]", ",", "\[DoubleStruckD]", ",", "\[DoubleStruckG]", ",", 
     "\[DoubleStruckH]", ",", "\[DoubleStruckCapitalI]", ",", 
     "\[DoubleStruckCapitalJ]", ",", "\[DoubleStruckK]", ",", 
     "\[DoubleStruckL]", ",", "\[DoubleStruckM]", ",", "\[DoubleStruckN]", 
     ",", "\[DoubleStruckO]", ",", "\[DoubleStruckP]", ",", 
     "\[DoubleStruckS]", ",", "\[DoubleStruckCapitalY]"}], "}"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckD]", "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckG]", "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckH]", "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckCapitalI]", "]"}], "=", "True"}], 
  ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckCapitalJ]", "]"}], "=", "True"}], 
  ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckK]", "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckL]", "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", 
    StyleBox["\[DoubleStruckM]",
     FontWeight->"Plain"], "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", 
    StyleBox["\[DoubleStruckN]",
     FontWeight->"Plain"], "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckO]", "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckP]", "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckS]", "]"}], "=", "True"}], ";", 
  RowBox[{
   RowBox[{"NumberQ", "[", "\[DoubleStruckCapitalY]", "]"}], "=", "True"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Positive", "[", "\[DoubleStruckD]", "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckD]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", "\[DoubleStruckG]", "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckG]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", "\[DoubleStruckH]", "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckH]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", "\[DoubleStruckCapitalI]", "]"}], "=", "False"}], 
  ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckCapitalI]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", "\[DoubleStruckCapitalJ]", "]"}], "=", "False"}], 
  ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckCapitalJ]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", "\[DoubleStruckK]", "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckK]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", "\[DoubleStruckL]", "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckL]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    StyleBox["\[DoubleStruckM]",
     FontWeight->"Plain"], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", 
     StyleBox["\[DoubleStruckM]",
      FontWeight->"Plain"]}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    StyleBox["\[DoubleStruckN]",
     FontWeight->"Plain"], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", 
     StyleBox["\[DoubleStruckN]",
      FontWeight->"Plain"]}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    StyleBox["\[DoubleStruckO]",
     FontWeight->"Plain"], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckO]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    StyleBox["\[DoubleStruckP]",
     FontWeight->"Plain"], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckP]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    StyleBox["\[DoubleStruckS]",
     FontWeight->"Plain"], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckS]"}], "]"}], "=", "False"}], ";", 
  RowBox[{
   RowBox[{"Positive", "[", "\[DoubleStruckCapitalY]", "]"}], "=", "False"}], 
  ";", 
  RowBox[{
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckCapitalY]"}], "]"}], "=", "False"}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckD]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckG]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckH]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckCapitalI]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckCapitalJ]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckK]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckL]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", 
    StyleBox["\[DoubleStruckM]",
     FontWeight->"Plain"], "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", 
    StyleBox["\[DoubleStruckN]",
     FontWeight->"Plain"], "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckO]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckP]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckS]", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"Abs", "[", "\[DoubleStruckCapitalY]", "]"}], "=", "1"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckD]", "]"}], "=", "\[DoubleStruckD]"}], 
  ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckG]", "]"}], "=", "\[DoubleStruckG]"}], 
  ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckH]", "]"}], "=", "\[DoubleStruckH]"}], 
  ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckCapitalI]", "]"}], "=", 
   "\[DoubleStruckCapitalI]"}], ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckCapitalJ]", "]"}], "=", 
   "\[DoubleStruckCapitalJ]"}], ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckK]", "]"}], "=", "\[DoubleStruckK]"}], 
  ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckL]", "]"}], "=", "\[DoubleStruckL]"}], 
  ";", 
  RowBox[{
   RowBox[{"Sign", "[", 
    StyleBox["\[DoubleStruckM]",
     FontWeight->"Plain"], "]"}], "=", 
   StyleBox["\[DoubleStruckM]",
    FontWeight->"Plain"]}], ";", 
  RowBox[{
   RowBox[{"Sign", "[", 
    StyleBox["\[DoubleStruckN]",
     FontWeight->"Plain"], "]"}], "=", 
   StyleBox["\[DoubleStruckN]",
    FontWeight->"Plain"]}], ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckO]", "]"}], "=", "\[DoubleStruckO]"}], 
  ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckP]", "]"}], "=", "\[DoubleStruckP]"}], 
  ";", 
  RowBox[{
   RowBox[{"Sign", "[", 
    StyleBox["\[DoubleStruckS]",
     FontWeight->"Plain"], "]"}], "=", 
   StyleBox["\[DoubleStruckS]",
    FontWeight->"Plain"]}], ";", 
  RowBox[{
   RowBox[{"Sign", "[", "\[DoubleStruckCapitalY]", "]"}], "=", 
   "\[DoubleStruckCapitalY]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckD]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckG]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckH]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckCapitalI]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckCapitalJ]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckK]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckL]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", 
    StyleBox["\[DoubleStruckM]",
     FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", 
    StyleBox["\[DoubleStruckN]",
     FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckO]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckP]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", 
    StyleBox["\[DoubleStruckS]",
     FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "\[DoubleStruckCapitalY]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckD]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckG]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckH]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckCapitalI]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckCapitalJ]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckK]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", 
    StyleBox["\[DoubleStruckL]",
     FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", 
    StyleBox["\[DoubleStruckM]",
     FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", 
    StyleBox["\[DoubleStruckN]",
     FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckO]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckP]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", 
    StyleBox["\[DoubleStruckS]",
     FontWeight->"Plain"], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", "\[DoubleStruckCapitalY]", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "   ", 
    RowBox[{"a_", " ", 
     RowBox[{"\[DoubleStruckCapitalJ]", "^", "b_"}]}], "]"}], ":=", "0"}], 
  ";", 
  RowBox[{
   RowBox[{"Im", "[", "  ", 
    RowBox[{"a_", "  ", 
     RowBox[{"\[DoubleStruckCapitalJ]", "^", "b_"}]}], "]"}], ":=", "0"}], 
  ";", 
  RowBox[{
   RowBox[{"Re", "[", " ", 
    RowBox[{"\[DoubleStruckCapitalJ]", "^", "b_"}], "]"}], ":=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{"\[DoubleStruckCapitalJ]", "^", "b_"}], "]"}], ":=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"a_", "  ", "\[DoubleStruckCapitalJ]"}], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{"a_", " ", "\[DoubleStruckCapitalJ]"}], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", "   ", 
    RowBox[{"a_", " ", 
     RowBox[{"\[DoubleStruckCapitalY]", "^", "b_"}]}], "]"}], ":=", "0"}], 
  ";", 
  RowBox[{
   RowBox[{"Im", "[", "  ", 
    RowBox[{"a_", "  ", 
     RowBox[{"\[DoubleStruckCapitalY]", "^", "b_"}]}], "]"}], ":=", "0"}], 
  ";", 
  RowBox[{
   RowBox[{"Re", "[", " ", 
    RowBox[{"\[DoubleStruckCapitalY]", "^", "b_"}], "]"}], ":=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{"\[DoubleStruckCapitalY]", "^", "b_"}], "]"}], ":=", "0"}], ";", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"a_", "  ", "\[DoubleStruckCapitalY]"}], "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{"a_", " ", "\[DoubleStruckCapitalY]"}], "]"}], "=", "0"}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"minsign", "[", "g_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "=", 
       RowBox[{"Intersection", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Union", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<\[ImaginaryI]\>\"", ",", 
             RowBox[{"Variables", "[", "g", "]"}]}], "}"}], "]"}], "]"}], ",",
          "signlist"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"s", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"unitSigns", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "===", 
            RowBox[{"a", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"s", ",", 
             RowBox[{"unitSigns", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", "unitSigns", "]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", 
         RowBox[{"Length", "[", "a", "]"}]}], "}"}]}], "]"}], ";", "s"}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "4 Predefined Index & Signed Tables."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell["\<\
hoopList names all the loops for which determinant factors have been found, \
in their order in sections 8.2 et seq (but non-conservative loops are moved \
to the end).\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"hoopList", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<C2\>\"", ",", "\"\<C4c\>\"", ",", "\"\<C3\>\"", ",", "\"\<C3C2c\>\"",
      ",", "\"\<C12c\>\"", ",", "\"\<C3i\>\"", ",", "\"\<C4C3c\>\"", ",", 
     "\"\<C3C3j\>\"", ",", "\"\<C9j\>\"", ",", "\"\<C9J\>\"", ",", 
     "\"\<C4\>\"", ",", "\"\<K\>\"", ",", "\"\<Qr\>\"", ",", "\"\<P4\>\"", 
     ",", "\"\<C5\>\"", ",", "\"\<Dav\>\"", ",", "\"\<O2\>\"", ",", 
     "\"\<C8r\>\"", ",", "\"\<C3C4j\>\"", ",", "\"\<CL2\>\"", ",", 
     "\"\<C4C2r\>\"", ",", "\"\<P16c\>\"", ",", "\"\<C8c\>\"", ",", 
     "\"\<C5\>\"", ",", "\"\<C3C2\>\"", ",", "\"\<D3\>\"", ",", 
     "\"\<C3C4c\>\"", ",", "\"\<Q12c\>\"", ",", "\"\<Q12r\>\"", ",", 
     "\"\<Q12r\>\"", ",", "\"\<g2401c\>\"", ",", "\"\<D6r\>\"", ",", 
     "\"\<D3C2c\>\"", ",", "\"\<KC3c\>\"", ",", "\"\<C3Kr\>\"", ",", 
     "\"\<Cl3r\>\"", ",", "\"\<Clm3r\>\"", ",", "\"\<C8\>\"", ",", 
     "\"\<KC2\>\"", ",", "\"\<C4C2\>\"", ",", "\"\<D4\>\"", ",", "\"\<Q8\>\"",
      ",", "\"\<Octr\>\"", ",", "\"\<KiC4c\>\"", ",", "\"\<O4\>\"", ",", 
     "\"\<O4a\>\"", ",", "\"\<O4b\>\"", ",", "\"\<C4C4c\>\"", ",", 
     "\"\<C4C4r\>\"", ",", "\"\<Q8C2r\>\"", ",", "\"\<C2D4r\>\"", ",", 
     "\"\<P8\>\"", ",", "\"\<CL3\>\"", ",", "\"\<C4iC4c\>\"", ",", 
     "\"\<QC2r\>\"", ",", "\"\<KiC4r\>\"", ",", "\"\<CL21\>\"", ",", 
     "\"\<CL03\>\"", ",", "\"\<Octs\>\"", ",", "\"\<C3C3\>\"", ",", 
     "\"\<C9\>\"", ",", "\"\<C6C3c\>\"", ",", "\"\<C3C4\>\"", ",", 
     "\"\<C3K\>\"", ",", "\"\<D8\>\"", ",", "\"\<Q12\>\"", ",", 
     "\"\<D3C2\>\"", ",", "\"\<A4\>\"", ",", "\"\<C3Qr\>\"", ",", 
     "\"\<C3P4\>\"", ",", "\"\<C6Kr\>\"", ",", "\"\<C3KC2r\>\"", ",", 
     "\"\<Q12C2c\>\"", ",", "\"\<Q16\>\"", ",", "\"\<D4C2\>\"", ",", 
     "\"\<C4C4\>\"", ",", "\"\<Q8C2\>\"", ",", "\"\<KK\>\"", ",", 
     "\"\<C4K\>\"", ",", "\"\<KiC4\>\"", ",", "\"\<C4iC4\>\"", ",", 
     "\"\<P16\>\"", ",", "\"\<Oct\>\"", ",", "\"\<Q8M2\>\"", ",", 
     "\"\<CL4\>\"", ",", "\"\<CL13\>\"", ",", "\"\<CL22\>\"", ",", 
     "\"\<CL31\>\"", ",", "\"\<r31r\>\"", ",", "\"\<CL04\>\"", ",", 
     "\"\<O8\>\"", ",", "\"\<C3C4C2\>\"", ",", "\"\<Q4n\>\"", ",", 
     "\"\<C6n\>\"", ",", "\"\<Q8n\>\"", ",", "\"\<D3Mn\>\""}], "}"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"C2", "=", 
   RowBox[{"ca", "[", "2", "]"}]}], ";", 
  RowBox[{"C3", "=", 
   RowBox[{"ca", "[", "3", "]"}]}], ";", 
  RowBox[{"C3n", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "2"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C3C3j", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", 
       "\[DoubleStruckCapitalJ]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "\[DoubleStruckCapitalJ]", ",", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}]}], 
  ";", 
  RowBox[{"C9j", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", "1"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"2", " ", "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}]}], ";",
   
  RowBox[{"C9J", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "\[DoubleStruckCapitalJ]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "\[DoubleStruckCapitalJ]", ",", 
       RowBox[{"2", " ", "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}]}], ";",
   
  FormBox[
   RowBox[{"C3i", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "\[ImaginaryI]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "\[ImaginaryI]", ",", 
        RowBox[{"2", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}]}],
   TraditionalForm], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C12c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "\[ImaginaryI]"}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C4", "=", 
   RowBox[{"ca", "[", "4", "]"}]}], ";", 
  RowBox[{"K", "=", 
   RowBox[{"ca", "[", 
    RowBox[{"4", ",", "3"}], "]"}]}], ";", 
  RowBox[{"P4", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"4", " ", "\[ImaginaryI]"}], ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{
        RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"2", " ", "\[ImaginaryI]"}], ",", "1"}], "}"}]}], "}"}]}], ";",
   
  RowBox[{"C4C3c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"3", " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P16c", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{
        RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"4", " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"3", " ", "\[ImaginaryI]"}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}], ",", "1"}], "}"}]}], 
    "}"}]}], ";", 
  RowBox[{"Q4n", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "4", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}], ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3", ",", 
       RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "}"}]}], ";", 
  RowBox[{"C5", "=", 
   RowBox[{"ca", "[", "5", "]"}]}], ";", 
  RowBox[{"C5n", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "4", ",", "5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", "1", ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3", ",", "5", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4", ",", "2", ",", "3", ",", "1"}], "}"}]}], "}"}]}],
   ";", 
  RowBox[{"L5n", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "1", ",", "5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", "4", ",", "2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1", ",", "5", ",", "3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", "2", ",", "1", ",", "4"}], "}"}]}], "}"}]}],
   ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"C3C2", "=", 
   RowBox[{"co", "[", 
    RowBox[{"C3", ",", "C2"}], "]"}]}], ";", 
  RowBox[{"D3", "=", 
   RowBox[{"ca", "[", 
    RowBox[{"6", ",", "5"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D3C2c", "=", 
   RowBox[{"ms", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "7"}], "}"}], ",", "u3"}], "]"}]}], ";", 
  RowBox[{"C6n", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "1", ",", "6", ",", "4", ",", "5"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "2", ",", "5", ",", "6", ",", "4"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5", ",", "6", ",", "2", ",", "1", ",", "3"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "6", ",", "4", ",", "1", ",", "3", ",", "2"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "4", ",", "5", ",", "3", ",", "2", ",", "1"}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"C4C2", "=", 
   RowBox[{"co", "[", 
    RowBox[{"C4", ",", "C2"}], "]"}]}], ";", 
  RowBox[{"KC2", "=", 
   RowBox[{"co", "[", 
    RowBox[{"K", ",", "C2"}], "]"}]}], ";", 
  RowBox[{"D4", "=", 
   RowBox[{"ca", "[", 
    RowBox[{"8", ",", "7"}], "]"}]}], ";", 
  RowBox[{"C8", "=", 
   RowBox[{"ca", "[", "8", "]"}]}], ";", 
  RowBox[{"Q8", "=", 
   RowBox[{"ca", "[", 
    RowBox[{"8", ",", "3"}], "]"}]}], ";", 
  RowBox[{"Oct", "=", 
   RowBox[{"cd", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"{", "2", "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Q8C2r", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "5"}], ",", "1", ",", "8", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}], ",", "6", ",", 
       RowBox[{"-", "7"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "2"}], ",", "7", ",", 
       RowBox[{"-", "8"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "6"}], ",", "8", ",", 
       RowBox[{"-", "5"}], ",", "7", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "2"}], ",", "7", ",", "1", ",", "8", ",", "4", ",", "6"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "7", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "8", ",", 
       RowBox[{"-", "5"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", 
       RowBox[{"-", "8"}], ",", "6", ",", 
       RowBox[{"-", "1"}], ",", "4", ",", "2", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "4", ",", 
       RowBox[{"-", "7"}], ",", "3", ",", "6", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "5"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P8", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"3", " ", "\[ImaginaryI]"}], ",", "6", ",", "5", ",", 
       RowBox[{
        RowBox[{"-", "8"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"7", " ", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"4", " ", "\[ImaginaryI]"}], ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}], ",", "7", ",", 
       RowBox[{"8", " ", "\[ImaginaryI]"}], ",", "5", ",", 
       RowBox[{
        RowBox[{"-", "6"}], " ", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{
        RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"2", " ", "\[ImaginaryI]"}], ",", "1", ",", "8", ",", 
       RowBox[{
        RowBox[{"-", "7"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"6", " ", "\[ImaginaryI]"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "6", ",", "7", ",", "8", ",", "1", ",", "2", ",", "3", ",", 
       "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "5", ",", 
       RowBox[{
        RowBox[{"-", "8"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"7", " ", "\[ImaginaryI]"}], ",", "2", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", 
       RowBox[{"8", " ", "\[ImaginaryI]"}], ",", "5", ",", 
       RowBox[{
        RowBox[{"-", "6"}], " ", "\[ImaginaryI]"}], ",", "3", ",", 
       RowBox[{"4", " ", "\[ImaginaryI]"}], ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", 
       RowBox[{
        RowBox[{"-", "7"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"6", " ", "\[ImaginaryI]"}], ",", "5", ",", "4", ",", 
       RowBox[{
        RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], ",", 
       RowBox[{"2", " ", "\[ImaginaryI]"}], ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Q8n", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1", ",", "4", ",", "7", ",", "6", ",", "5", ",", "8", ",", 
       "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "8", ",", "1", ",", "2", ",", "7", ",", "4", ",", "5", ",", 
       "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "3", ",", "6", ",", "1", ",", "8", ",", "7", ",", "2", ",", 
       "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "6", ",", "7", ",", "8", ",", "1", ",", "2", ",", "3", ",", 
       "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "5", ",", "8", ",", "3", ",", "2", ",", "1", ",", "4", ",", 
       "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "7", ",", "4", ",", "5", ",", "6", ",", "3", ",", "8", ",", "1", ",", 
       "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "8", ",", "7", ",", "2", ",", "5", ",", "4", ",", "3", ",", "6", ",", 
       "1"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CL12", "=", 
    RowBox[{"clf", "[", 
     RowBox[{"1", ",", "2"}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"CL3", " ", "isomorph"}], "*)"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"C3C3", "=", 
   RowBox[{"co", "[", 
    RowBox[{"C3", ",", "C3"}], "]"}]}], ";", 
  RowBox[{"C3C4", "=", 
   RowBox[{"co", "[", 
    RowBox[{"C3", ",", "C4"}], "]"}]}], ";", 
  RowBox[{"C3K", "=", 
   RowBox[{"co", "[", 
    RowBox[{"C3", ",", "K"}], "]"}]}], ";", 
  RowBox[{"Q12", "=", 
   RowBox[{"co", "[", 
    RowBox[{"C3", ",", "C4", ",", "2"}], "]"}]}], ";", 
  RowBox[{"D3C2", "=", 
   RowBox[{"co", "[", 
    RowBox[{"C3", ",", "K", ",", "2"}], "]"}]}], ";", 
  RowBox[{"A4", "=", 
   RowBox[{"ge", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
       RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}]}], "]"}]}], 
  ";", 
  RowBox[{"A4a", "=", 
   RowBox[{"Transpose", "[", "A4", "]"}]}], ";", 
  RowBox[{"D3C4r", "=", 
   RowBox[{"ms", "[", 
    RowBox[{"{", 
     RowBox[{"3", ",", "15"}], "}"}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"C3P4", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "1", ",", " ", "2", ",", " ", "3", ",", " ", "4", ",", " ", "5", ",", 
        " ", "6", ",", " ", "7", ",", " ", "8", ",", " ", "9", ",", " ", "10",
         ",", " ", "11", ",", " ", "12"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
       "2", ",", " ", "3", ",", " ", "1", ",", " ", "5", ",", " ", "6", ",", 
        " ", "4", ",", " ", "8", ",", " ", "9", ",", " ", "7", ",", " ", "11",
         ",", " ", "12", ",", " ", "10"}], "}"}], ",", " ", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{
       "3", ",", " ", "1", ",", " ", "2", ",", " ", "6", ",", " ", "4", ",", 
        " ", "5", ",", " ", "9", ",", " ", "7", ",", " ", "8", ",", " ", "12",
         ",", " ", "10", ",", " ", "11"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
       "4", ",", " ", "5", ",", " ", "6", ",", " ", "1", ",", " ", "2", ",", 
        " ", "3", ",", " ", 
        RowBox[{"10", "*", "I"}], ",", " ", 
        RowBox[{"11", "*", "I"}], ",", " ", 
        RowBox[{"12", "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "7"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "8"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "9"}], "*", "I"}]}], "}"}], ",", " ", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{
       "5", ",", " ", "6", ",", " ", "4", ",", " ", "2", ",", " ", "3", ",", 
        " ", "1", ",", " ", 
        RowBox[{"11", "*", "I"}], ",", " ", 
        RowBox[{"12", "*", "I"}], ",", " ", 
        RowBox[{"10", "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "8"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "9"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "7"}], "*", "I"}]}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
       "6", ",", " ", "4", ",", " ", "5", ",", " ", "3", ",", " ", "1", ",", 
        " ", "2", ",", " ", 
        RowBox[{"12", "*", "I"}], ",", " ", 
        RowBox[{"10", "*", "I"}], ",", " ", 
        RowBox[{"11", "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "9"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "7"}], "*", "I"}], ",", " ", "\n", "     ", 
        RowBox[{
         RowBox[{"-", "8"}], "*", "I"}]}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"7", ",", " ", "8", ",", " ", "9", ",", " ", 
        RowBox[{
         RowBox[{"-", "10"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "11"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "12"}], "*", "I"}], ",", " ", "1", ",", " ", "2", ",", 
        " ", "3", ",", " ", 
        RowBox[{"4", "*", "I"}], ",", " ", 
        RowBox[{"5", "*", "I"}], ",", " ", 
        RowBox[{"6", "*", "I"}]}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"8", ",", " ", "9", ",", " ", "7", ",", " ", 
        RowBox[{
         RowBox[{"-", "11"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "12"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "10"}], "*", "I"}], ",", " ", "2", ",", " ", "3", ",", 
        " ", "1", ",", " ", "\n", "     ", 
        RowBox[{"5", "*", "I"}], ",", " ", 
        RowBox[{"6", "*", "I"}], ",", " ", 
        RowBox[{"4", "*", "I"}]}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"9", ",", " ", "7", ",", " ", "8", ",", " ", 
        RowBox[{
         RowBox[{"-", "12"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "10"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "11"}], "*", "I"}], ",", " ", "3", ",", " ", "1", ",", 
        " ", "2", ",", " ", 
        RowBox[{"6", "*", "I"}], ",", " ", 
        RowBox[{"4", "*", "I"}], ",", " ", 
        RowBox[{"5", "*", "I"}]}], "}"}], ",", " ", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{"10", ",", " ", "11", ",", " ", "12", ",", " ", 
        RowBox[{"7", "*", "I"}], ",", " ", 
        RowBox[{"8", "*", "I"}], ",", " ", 
        RowBox[{"9", "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "4"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "5"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "6"}], "*", "I"}], ",", " ", "1", ",", " ", "2", ",", 
        " ", "3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"11", ",", " ", "12", ",", " ", "10", ",", " ", 
        RowBox[{"8", "*", "I"}], ",", " ", 
        RowBox[{"9", "*", "I"}], ",", " ", 
        RowBox[{"7", "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "5"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "6"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "4"}], "*", "I"}], ",", " ", "2", ",", " ", "\n", 
        "     ", "3", ",", " ", "1"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"12", ",", " ", "10", ",", " ", "11", ",", " ", 
        RowBox[{"9", "*", "I"}], ",", " ", 
        RowBox[{"7", "*", "I"}], ",", " ", 
        RowBox[{"8", "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "6"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "4"}], "*", "I"}], ",", " ", 
        RowBox[{
         RowBox[{"-", "5"}], "*", "I"}], ",", " ", "3", ",", " ", "1", ",", 
        " ", "2"}], "}"}]}], "}"}]}], ";"}], " "}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0,
 FontFamily->"Courier New",
 FontSize->10],

Cell[BoxData[{
 RowBox[{
  RowBox[{"P16i", "=", 
   RowBox[{"ge", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
       RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}]}], "]"}]}], 
  ";", 
  RowBox[{"P16a", "=", 
   RowBox[{"co", "[", 
    RowBox[{"Q8", ",", "C2", ",", "4"}], "]"}]}], ";", 
  RowBox[{"P16", "=", 
   RowBox[{"co", "[", 
    RowBox[{"P4", ",", "C4"}], "]"}]}], ";", 
  RowBox[{"C8pC2", "=", 
   RowBox[{"co", "[", 
    RowBox[{
     RowBox[{"ca", "[", "8", "]"}], ",", "C2", ",", "4"}], "]"}]}], ";", 
  RowBox[{"g2101", "=", 
   RowBox[{"ge", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<aab\>\""}], "}"}]}], "]"}]}], ";",
   
  RowBox[{"CL13", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
       ",", "15", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", 
       "7", ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", 
       ",", "16", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "1"}], ",", "2", ",", "7", ",", 
       RowBox[{"-", "8"}], ",", 
       RowBox[{"-", "5"}], ",", "6", ",", "11", ",", 
       RowBox[{"-", "12"}], ",", 
       RowBox[{"-", "9"}], ",", "10", ",", "15", ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "13"}], ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "2"}], ",", "1", ",", "8", ",", 
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "6"}], ",", "5", ",", "12", ",", 
       RowBox[{"-", "11"}], ",", 
       RowBox[{"-", "10"}], ",", "9", ",", "16", ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "14"}], ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", "8", ",", 
       RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
       RowBox[{"-", "4"}], ",", "13", ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "15"}], ",", "16", ",", 
       RowBox[{"-", "9"}], ",", "10", ",", "11", ",", 
       RowBox[{"-", "12"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", "7", ",", 
       RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
       RowBox[{"-", "3"}], ",", "14", ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "16"}], ",", "15", ",", 
       RowBox[{"-", "10"}], ",", "9", ",", "12", ",", 
       RowBox[{"-", "11"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "8", ",", "5", ",", "6", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}], ",", "15", ",", "16", ",", "13", ",", "14", ",", 
       RowBox[{"-", "11"}], ",", 
       RowBox[{"-", "12"}], ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "7", ",", "6", ",", "5", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "1"}], ",", "16", ",", "15", ",", "14", ",", "13", ",", 
       RowBox[{"-", "12"}], ",", 
       RowBox[{"-", "11"}], ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "11"}], ",", "12", ",", 
       RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
       RowBox[{"-", "4"}], ",", "5", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "12"}], ",", "11", ",", 
       RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
       RowBox[{"-", "3"}], ",", "6", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "12", ",", "9", ",", "10", ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}], ",", "7", ",", "8", ",", "5", ",", "6"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "11", ",", "10", ",", "9", ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "1"}], ",", "8", ",", "7", ",", "6", ",", "5"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", ",", "11", 
       ",", "12", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "8"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "14", ",", "13", ",", "16", ",", "15", ",", "10", ",", "9", ",", "12", 
       ",", "11", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", 
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "13"}], ",", "14", ",", "11", ",", 
       RowBox[{"-", "12"}], ",", 
       RowBox[{"-", "9"}], ",", "10", ",", 
       RowBox[{"-", "7"}], ",", "8", ",", "5", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "3"}], ",", "4", ",", "1", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "14"}], ",", "13", ",", "12", ",", 
       RowBox[{"-", "11"}], ",", 
       RowBox[{"-", "10"}], ",", "9", ",", 
       RowBox[{"-", "8"}], ",", "7", ",", "6", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "4"}], ",", "3", ",", "2", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CL22", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
       ",", "15", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", 
       "7", ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", 
       ",", "16", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}], ",", "1", ",", 
       RowBox[{"-", "2"}], ",", "7", ",", 
       RowBox[{"-", "8"}], ",", "5", ",", 
       RowBox[{"-", "6"}], ",", "11", ",", 
       RowBox[{"-", "12"}], ",", "9", ",", 
       RowBox[{"-", "10"}], ",", "15", ",", 
       RowBox[{"-", "16"}], ",", "13", ",", 
       RowBox[{"-", "14"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "3"}], ",", "2", ",", 
       RowBox[{"-", "1"}], ",", "8", ",", 
       RowBox[{"-", "7"}], ",", "6", ",", 
       RowBox[{"-", "5"}], ",", "12", ",", 
       RowBox[{"-", "11"}], ",", "10", ",", 
       RowBox[{"-", "9"}], ",", "16", ",", 
       RowBox[{"-", "15"}], ",", "14", ",", 
       RowBox[{"-", "13"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", "8", ",", 
       RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
       RowBox[{"-", "4"}], ",", "13", ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "15"}], ",", "16", ",", 
       RowBox[{"-", "9"}], ",", "10", ",", "11", ",", 
       RowBox[{"-", "12"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", "7", ",", 
       RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
       RowBox[{"-", "3"}], ",", "14", ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "16"}], ",", "15", ",", 
       RowBox[{"-", "10"}], ",", "9", ",", "12", ",", 
       RowBox[{"-", "11"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "8", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}], ",", "1", ",", "2", ",", "15", ",", "16", ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "11"}], ",", 
       RowBox[{"-", "12"}], ",", "9", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "7", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}], ",", "2", ",", "1", ",", "16", ",", "15", ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "12"}], ",", 
       RowBox[{"-", "11"}], ",", "10", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "11"}], ",", "12", ",", 
       RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
       RowBox[{"-", "4"}], ",", "5", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "12"}], ",", "11", ",", 
       RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
       RowBox[{"-", "3"}], ",", "6", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "12", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "16"}], ",", "13", ",", "14", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}], ",", "1", ",", "2", ",", "7", ",", "8", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "11", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "15"}], ",", "14", ",", "13", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}], ",", "2", ",", "1", ",", "8", ",", "7", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", ",", "11", 
       ",", "12", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "8"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "14", ",", "13", ",", "16", ",", "15", ",", "10", ",", "9", ",", "12", 
       ",", "11", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", 
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", 
       RowBox[{"-", "16"}], ",", "13", ",", 
       RowBox[{"-", "14"}], ",", "11", ",", 
       RowBox[{"-", "12"}], ",", "9", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "7"}], ",", "8", ",", 
       RowBox[{"-", "5"}], ",", "6", ",", 
       RowBox[{"-", "3"}], ",", "4", ",", 
       RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", 
       RowBox[{"-", "15"}], ",", "14", ",", 
       RowBox[{"-", "13"}], ",", "12", ",", 
       RowBox[{"-", "11"}], ",", "10", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "8"}], ",", "7", ",", 
       RowBox[{"-", "6"}], ",", "5", ",", 
       RowBox[{"-", "4"}], ",", "3", ",", 
       RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CL31", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
       ",", "15", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", 
       "7", ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", 
       ",", "16", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}], ",", "1", ",", 
       RowBox[{"-", "2"}], ",", "7", ",", 
       RowBox[{"-", "8"}], ",", "5", ",", 
       RowBox[{"-", "6"}], ",", "11", ",", 
       RowBox[{"-", "12"}], ",", "9", ",", 
       RowBox[{"-", "10"}], ",", "15", ",", 
       RowBox[{"-", "16"}], ",", "13", ",", 
       RowBox[{"-", "14"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "3"}], ",", "2", ",", 
       RowBox[{"-", "1"}], ",", "8", ",", 
       RowBox[{"-", "7"}], ",", "6", ",", 
       RowBox[{"-", "5"}], ",", "12", ",", 
       RowBox[{"-", "11"}], ",", "10", ",", 
       RowBox[{"-", "9"}], ",", "16", ",", 
       RowBox[{"-", "15"}], ",", "14", ",", 
       RowBox[{"-", "13"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", "8", ",", "1", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}], ",", "4", ",", "13", ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "15"}], ",", "16", ",", "9", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "11"}], ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", "7", ",", "2", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "4"}], ",", "3", ",", "14", ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "16"}], ",", "15", ",", "10", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "12"}], ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "8", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "6"}], ",", "3", ",", "4", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}], ",", "15", ",", "16", ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "14"}], ",", "11", ",", "12", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "7", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "5"}], ",", "4", ",", "3", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "1"}], ",", "16", ",", "15", ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "13"}], ",", "12", ",", "11", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "11"}], ",", "12", ",", 
       RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
       RowBox[{"-", "4"}], ",", "5", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "12"}], ",", "11", ",", 
       RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
       RowBox[{"-", "3"}], ",", "6", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "12", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "15"}], ",", 
       RowBox[{"-", "16"}], ",", "13", ",", "14", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}], ",", "1", ",", "2", ",", "7", ",", "8", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "11", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "16"}], ",", 
       RowBox[{"-", "15"}], ",", "14", ",", "13", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}], ",", "2", ",", "1", ",", "8", ",", "7", ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "14", ",", "15", ",", "16", ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "11"}], ",", 
       RowBox[{"-", "12"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "7"}], ",", 
       RowBox[{"-", "8"}], ",", "1", ",", "2", ",", "3", ",", "4"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "13", ",", "16", ",", "15", ",", 
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "9"}], ",", 
       RowBox[{"-", "12"}], ",", 
       RowBox[{"-", "11"}], ",", 
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "8"}], ",", 
       RowBox[{"-", "7"}], ",", "2", ",", "1", ",", "4", ",", "3"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", 
       RowBox[{"-", "16"}], ",", "13", ",", 
       RowBox[{"-", "14"}], ",", 
       RowBox[{"-", "11"}], ",", "12", ",", 
       RowBox[{"-", "9"}], ",", "10", ",", 
       RowBox[{"-", "7"}], ",", "8", ",", 
       RowBox[{"-", "5"}], ",", "6", ",", "3", ",", 
       RowBox[{"-", "4"}], ",", "1", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", 
       RowBox[{"-", "15"}], ",", "14", ",", 
       RowBox[{"-", "13"}], ",", 
       RowBox[{"-", "12"}], ",", "11", ",", 
       RowBox[{"-", "10"}], ",", "9", ",", 
       RowBox[{"-", "8"}], ",", "7", ",", 
       RowBox[{"-", "6"}], ",", "5", ",", "4", ",", 
       RowBox[{"-", "3"}], ",", "2", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{"OctC2", "=", 
   RowBox[{"co", "[", 
    RowBox[{"Oct", ",", "C2"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SL23", "=", 
   RowBox[{"mg", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"9", ",", "14"}], "}"}], ",", "u4"}], "]"}]}], ";", 
  RowBox[{"P27", "=", 
   RowBox[{"ge", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}]}], "]"}]}], ";",
   
  RowBox[{"g2704", "=", 
   RowBox[{"ge", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"9", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], ",", 
       RowBox[{"\"\<baa\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"r31u", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
      "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
      ",", "15", ",", "16"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", 
      "7", ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", 
      ",", "16", ",", "15"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "1"}], ",", "2", ",", "7", ",", 
      RowBox[{"-", "8"}], ",", 
      RowBox[{"-", "5"}], ",", "6", ",", "11", ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "9"}], ",", "10", ",", "15", ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "13"}], ",", "14"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "2"}], ",", "1", ",", "8", ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "6"}], ",", "5", ",", "12", ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "10"}], ",", "9", ",", "16", ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "14"}], ",", "13"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "7"}], ",", "8", ",", "1", ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "3"}], ",", "4", ",", "13", ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "15"}], ",", "16", ",", "9", ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "11"}], ",", "12"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6", ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "8"}], ",", "7", ",", "2", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "4"}], ",", "3", ",", "14", ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "16"}], ",", "15", ",", "10", ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "12"}], ",", "11"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "7", ",", "8", ",", "5", ",", "6", ",", "3", ",", "4", ",", "1", ",", 
      "2", ",", "15", ",", "16", ",", "13", ",", "14", ",", "11", ",", "12", 
      ",", "9", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "8", ",", "7", ",", "6", ",", "5", ",", "4", ",", "3", ",", "2", ",", 
      "1", ",", "16", ",", "15", ",", "14", ",", "13", ",", "12", ",", "11", 
      ",", "10", ",", "9"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "11"}], ",", "12", ",", 
      RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
      RowBox[{"-", "4"}], ",", "5", ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "7"}], ",", "8"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "12"}], ",", "11", ",", 
      RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
      RowBox[{"-", "3"}], ",", "6", ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "8"}], ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"11", ",", "12", ",", "9", ",", "10", ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "2"}], ",", "7", ",", "8", ",", "5", ",", "6"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"12", ",", "11", ",", "10", ",", "9", ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "1"}], ",", "8", ",", "7", ",", "6", ",", "5"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"13", ",", "14", ",", "15", ",", "16", ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "8"}], ",", "1", ",", "2", ",", "3", ",", "4"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"14", ",", "13", ",", "16", ",", "15", ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "8"}], ",", 
      RowBox[{"-", "7"}], ",", "2", ",", "1", ",", "4", ",", "3"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "13"}], ",", "14", ",", 
      RowBox[{"-", "11"}], ",", "12", ",", "9", ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "7"}], ",", "8", ",", "5", ",", 
      RowBox[{"-", "6"}], ",", "3", ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"16", ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "14"}], ",", "13", ",", 
      RowBox[{"-", "12"}], ",", "11", ",", "10", ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "8"}], ",", "7", ",", "6", ",", 
      RowBox[{"-", "5"}], ",", "4", ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "}"}]}], "\n", 
 RowBox[{"r31t", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
      "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
      ",", "15", ",", "16"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}], ",", "4", ",", 
      RowBox[{"-", "3"}], ",", "6", ",", 
      RowBox[{"-", "5"}], ",", "8", ",", 
      RowBox[{"-", "7"}], ",", "10", ",", 
      RowBox[{"-", "9"}], ",", "12", ",", 
      RowBox[{"-", "11"}], ",", "14", ",", 
      RowBox[{"-", "13"}], ",", "16", ",", 
      RowBox[{"-", "15"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"-", "4"}], ",", "1", ",", 
      RowBox[{"-", "2"}], ",", "7", ",", 
      RowBox[{"-", "8"}], ",", "5", ",", 
      RowBox[{"-", "6"}], ",", "11", ",", 
      RowBox[{"-", "12"}], ",", "9", ",", 
      RowBox[{"-", "10"}], ",", "15", ",", 
      RowBox[{"-", "16"}], ",", "13", ",", 
      RowBox[{"-", "14"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "4", ",", "3", ",", "2", ",", "1", ",", "8", ",", "7", ",", "6", ",", 
      "5", ",", "12", ",", "11", ",", "10", ",", "9", ",", "16", ",", "15", 
      ",", "14", ",", "13"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "7"}], ",", "8", ",", 
      RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
      RowBox[{"-", "4"}], ",", "13", ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "15"}], ",", "16", ",", 
      RowBox[{"-", "9"}], ",", "10", ",", "11", ",", 
      RowBox[{"-", "12"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6", ",", "5", ",", 
      RowBox[{"-", "8"}], ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "1"}], ",", "4", ",", "3", ",", "14", ",", "13", ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "9"}], ",", "12", ",", "11"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "8", ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "4"}], ",", "1", ",", "2", ",", "15", ",", "16", ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "12"}], ",", "9", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"8", ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "6"}], ",", "5", ",", 
      RowBox[{"-", "4"}], ",", "3", ",", "2", ",", 
      RowBox[{"-", "1"}], ",", "16", ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "14"}], ",", "13", ",", 
      RowBox[{"-", "12"}], ",", "11", ",", "10", ",", 
      RowBox[{"-", "9"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "11"}], ",", "12", ",", 
      RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
      RowBox[{"-", "16"}], ",", "1", ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "3"}], ",", "4", ",", 
      RowBox[{"-", "5"}], ",", "6", ",", "7", ",", 
      RowBox[{"-", "8"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", "9", ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "13"}], ",", "16", ",", "15", ",", "2", ",", "1", ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "5"}], ",", "8", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"11", ",", "12", ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "16"}], ",", "13", ",", "14", ",", "3", ",", "4", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "8"}], ",", "5", ",", "6"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12", ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "10"}], ",", "9", ",", 
      RowBox[{"-", "16"}], ",", "15", ",", "14", ",", 
      RowBox[{"-", "13"}], ",", "4", ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "2"}], ",", "1", ",", 
      RowBox[{"-", "8"}], ",", "7", ",", "6", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", ",", "11", 
      ",", "12", ",", "5", ",", "6", ",", "7", ",", "8", ",", "1", ",", "2", 
      ",", "3", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"14", ",", 
      RowBox[{"-", "13"}], ",", "16", ",", 
      RowBox[{"-", "15"}], ",", "10", ",", 
      RowBox[{"-", "9"}], ",", "12", ",", 
      RowBox[{"-", "11"}], ",", "6", ",", 
      RowBox[{"-", "5"}], ",", "8", ",", 
      RowBox[{"-", "7"}], ",", "2", ",", 
      RowBox[{"-", "1"}], ",", "4", ",", 
      RowBox[{"-", "3"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", 
      RowBox[{"-", "16"}], ",", "13", ",", 
      RowBox[{"-", "14"}], ",", "11", ",", 
      RowBox[{"-", "12"}], ",", "9", ",", 
      RowBox[{"-", "10"}], ",", "7", ",", 
      RowBox[{"-", "8"}], ",", "5", ",", 
      RowBox[{"-", "6"}], ",", "3", ",", 
      RowBox[{"-", "4"}], ",", "1", ",", 
      RowBox[{"-", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "16", ",", "15", ",", "14", ",", "13", ",", "12", ",", "11", ",", "10", 
      ",", "9", ",", "8", ",", "7", ",", "6", ",", "5", ",", "4", ",", "3", 
      ",", "2", ",", "1"}], "}"}]}], "}"}]}], "\n", 
 RowBox[{"r31s", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
      "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
      ",", "15", ",", "16"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", 
      "7", ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", 
      ",", "16", ",", "15"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "1"}], ",", "2", ",", "7", ",", 
      RowBox[{"-", "8"}], ",", 
      RowBox[{"-", "5"}], ",", "6", ",", "11", ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "9"}], ",", "10", ",", "15", ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "13"}], ",", "14"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "2"}], ",", "1", ",", "8", ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "6"}], ",", "5", ",", "12", ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "10"}], ",", "9", ",", "16", ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "14"}], ",", "13"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "7"}], ",", "8", ",", 
      RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
      RowBox[{"-", "4"}], ",", "13", ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "15"}], ",", "16", ",", 
      RowBox[{"-", "9"}], ",", "10", ",", "11", ",", 
      RowBox[{"-", "12"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6", ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "8"}], ",", "7", ",", 
      RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
      RowBox[{"-", "3"}], ",", "14", ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "16"}], ",", "15", ",", 
      RowBox[{"-", "10"}], ",", "9", ",", "12", ",", 
      RowBox[{"-", "11"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "8", ",", "5", ",", "6", ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "2"}], ",", "15", ",", "16", ",", "13", ",", "14", ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "10"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"8", ",", "7", ",", "6", ",", "5", ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "1"}], ",", "16", ",", "15", ",", "14", ",", "13", ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "9"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "11"}], ",", "12", ",", 
      RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
      RowBox[{"-", "16"}], ",", "1", ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "3"}], ",", "4", ",", 
      RowBox[{"-", "5"}], ",", "6", ",", "7", ",", 
      RowBox[{"-", "8"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "12"}], ",", "11", ",", 
      RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
      RowBox[{"-", "15"}], ",", "2", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "4"}], ",", "3", ",", 
      RowBox[{"-", "6"}], ",", "5", ",", "8", ",", 
      RowBox[{"-", "7"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"11", ",", "12", ",", "9", ",", "10", ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "14"}], ",", "3", ",", "4", ",", "1", ",", "2", ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "8"}], ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "6"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12", ",", "11", ",", "10", ",", "9", ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "13"}], ",", "4", ",", "3", ",", "2", ",", "1", ",", 
      RowBox[{"-", "8"}], ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", ",", "11", 
      ",", "12", ",", "5", ",", "6", ",", "7", ",", "8", ",", "1", ",", "2", 
      ",", "3", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "14", ",", "13", ",", "16", ",", "15", ",", "10", ",", "9", ",", "12", 
      ",", "11", ",", "6", ",", "5", ",", "8", ",", "7", ",", "2", ",", "1", 
      ",", "4", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "13"}], ",", "14", ",", "11", ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "9"}], ",", "10", ",", "7", ",", 
      RowBox[{"-", "8"}], ",", 
      RowBox[{"-", "5"}], ",", "6", ",", "3", ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"16", ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "14"}], ",", "13", ",", "12", ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "10"}], ",", "9", ",", "8", ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "6"}], ",", "5", ",", "4", ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "}"}]}], "\n", 
 RowBox[{"r31r", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
      "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
      ",", "15", ",", "16"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", 
      "7", ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", 
      ",", "16", ",", "15"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"-", "4"}], ",", "1", ",", 
      RowBox[{"-", "2"}], ",", "7", ",", 
      RowBox[{"-", "8"}], ",", "5", ",", 
      RowBox[{"-", "6"}], ",", "11", ",", 
      RowBox[{"-", "12"}], ",", "9", ",", 
      RowBox[{"-", "10"}], ",", "15", ",", 
      RowBox[{"-", "16"}], ",", "13", ",", 
      RowBox[{"-", "14"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"-", "3"}], ",", "2", ",", 
      RowBox[{"-", "1"}], ",", "8", ",", 
      RowBox[{"-", "7"}], ",", "6", ",", 
      RowBox[{"-", "5"}], ",", "12", ",", 
      RowBox[{"-", "11"}], ",", "10", ",", 
      RowBox[{"-", "9"}], ",", "16", ",", 
      RowBox[{"-", "15"}], ",", "14", ",", 
      RowBox[{"-", "13"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "7"}], ",", "8", ",", 
      RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
      RowBox[{"-", "4"}], ",", "13", ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "15"}], ",", "16", ",", 
      RowBox[{"-", "9"}], ",", "10", ",", "11", ",", 
      RowBox[{"-", "12"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6", ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "8"}], ",", "7", ",", 
      RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
      RowBox[{"-", "3"}], ",", "14", ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "16"}], ",", "15", ",", 
      RowBox[{"-", "10"}], ",", "9", ",", "12", ",", 
      RowBox[{"-", "11"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "8", ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "4"}], ",", "1", ",", "2", ",", "15", ",", "16", ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "11"}], ",", 
      RowBox[{"-", "12"}], ",", "9", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"8", ",", "7", ",", 
      RowBox[{"-", "6"}], ",", 
      RowBox[{"-", "5"}], ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "3"}], ",", "2", ",", "1", ",", "16", ",", "15", ",", 
      RowBox[{"-", "14"}], ",", 
      RowBox[{"-", "13"}], ",", 
      RowBox[{"-", "12"}], ",", 
      RowBox[{"-", "11"}], ",", "10", ",", "9"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "11"}], ",", "12", ",", 
      RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
      RowBox[{"-", "16"}], ",", "1", ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "3"}], ",", "4", ",", 
      RowBox[{"-", "5"}], ",", "6", ",", "7", ",", 
      RowBox[{"-", "8"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "12"}], ",", "11", ",", 
      RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
      RowBox[{"-", "15"}], ",", "2", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "4"}], ",", "3", ",", 
      RowBox[{"-", "6"}], ",", "5", ",", "8", ",", 
      RowBox[{"-", "7"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"11", ",", "12", ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "15"}], ",", 
      RowBox[{"-", "16"}], ",", "13", ",", "14", ",", "3", ",", "4", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "7"}], ",", 
      RowBox[{"-", "8"}], ",", "5", ",", "6"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12", ",", "11", ",", 
      RowBox[{"-", "10"}], ",", 
      RowBox[{"-", "9"}], ",", 
      RowBox[{"-", "16"}], ",", 
      RowBox[{"-", "15"}], ",", "14", ",", "13", ",", "4", ",", "3", ",", 
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "8"}], ",", 
      RowBox[{"-", "7"}], ",", "6", ",", "5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", ",", "11", 
      ",", "12", ",", "5", ",", "6", ",", "7", ",", "8", ",", "1", ",", "2", 
      ",", "3", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "14", ",", "13", ",", "16", ",", "15", ",", "10", ",", "9", ",", "12", 
      ",", "11", ",", "6", ",", "5", ",", "8", ",", "7", ",", "2", ",", "1", 
      ",", "4", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", 
      RowBox[{"-", "16"}], ",", "13", ",", 
      RowBox[{"-", "14"}], ",", "11", ",", 
      RowBox[{"-", "12"}], ",", "9", ",", 
      RowBox[{"-", "10"}], ",", "7", ",", 
      RowBox[{"-", "8"}], ",", "5", ",", 
      RowBox[{"-", "6"}], ",", "3", ",", 
      RowBox[{"-", "4"}], ",", "1", ",", 
      RowBox[{"-", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"16", ",", 
      RowBox[{"-", "15"}], ",", "14", ",", 
      RowBox[{"-", "13"}], ",", "12", ",", 
      RowBox[{"-", "11"}], ",", "10", ",", 
      RowBox[{"-", "9"}], ",", "8", ",", 
      RowBox[{"-", "7"}], ",", "6", ",", 
      RowBox[{"-", "5"}], ",", "4", ",", 
      RowBox[{"-", "3"}], ",", "2", ",", 
      RowBox[{"-", "1"}]}], "}"}]}], "}"}]}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8",
      ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", 
     "15", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", "7",
      ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", ",", 
     "16", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "7", ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "5"}], ",", "6", ",", "11", ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "9"}], ",", "10", ",", "15", ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "13"}], ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "1", ",", "8", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", "5", ",", "12", ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "10"}], ",", "9", ",", "16", ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "14"}], ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "7"}], ",", "8", ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", "4", ",", "13", ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "15"}], ",", "16", ",", "9", ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "11"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "8"}], ",", "7", ",", "2", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", "3", ",", "14", ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "16"}], ",", "15", ",", "10", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "12"}], ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "7", ",", "8", ",", "5", ",", "6", ",", "3", ",", "4", ",", "1", ",", "2",
      ",", "15", ",", "16", ",", "13", ",", "14", ",", "11", ",", "12", ",", 
     "9", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "8", ",", "7", ",", "6", ",", "5", ",", "4", ",", "3", ",", "2", ",", "1",
      ",", "16", ",", "15", ",", "14", ",", "13", ",", "12", ",", "11", ",", 
     "10", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "11"}], ",", "12", ",", 
     RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
     RowBox[{"-", "4"}], ",", "5", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "7"}], ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "12"}], ",", "11", ",", 
     RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
     RowBox[{"-", "3"}], ",", "6", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "8"}], ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "12", ",", "9", ",", "10", ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", "7", ",", "8", ",", "5", ",", "6"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"12", ",", "11", ",", "10", ",", "9", ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", "8", ",", "7", ",", "6", ",", "5"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"13", ",", "14", ",", "15", ",", "16", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "8"}], ",", "1", ",", "2", ",", "3", ",", "4"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"14", ",", "13", ",", "16", ",", "15", ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "7"}], ",", "2", ",", "1", ",", "4", ",", "3"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"15", ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "13"}], ",", "14", ",", 
     RowBox[{"-", "11"}], ",", "12", ",", "9", ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "7"}], ",", "8", ",", "5", ",", 
     RowBox[{"-", "6"}], ",", "3", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16", ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "14"}], ",", "13", ",", 
     RowBox[{"-", "12"}], ",", "11", ",", "10", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "8"}], ",", "7", ",", "6", ",", 
     RowBox[{"-", "5"}], ",", "4", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8",
      ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", 
     "15", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}], ",", "4", ",", 
     RowBox[{"-", "3"}], ",", "6", ",", 
     RowBox[{"-", "5"}], ",", "8", ",", 
     RowBox[{"-", "7"}], ",", "10", ",", 
     RowBox[{"-", "9"}], ",", "12", ",", 
     RowBox[{"-", "11"}], ",", "14", ",", 
     RowBox[{"-", "13"}], ",", "16", ",", 
     RowBox[{"-", "15"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "4"}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", "7", ",", 
     RowBox[{"-", "8"}], ",", "5", ",", 
     RowBox[{"-", "6"}], ",", "11", ",", 
     RowBox[{"-", "12"}], ",", "9", ",", 
     RowBox[{"-", "10"}], ",", "15", ",", 
     RowBox[{"-", "16"}], ",", "13", ",", 
     RowBox[{"-", "14"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "4", ",", "3", ",", "2", ",", "1", ",", "8", ",", "7", ",", "6", ",", "5",
      ",", "12", ",", "11", ",", "10", ",", "9", ",", "16", ",", "15", ",", 
     "14", ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "7"}], ",", "8", ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
     RowBox[{"-", "4"}], ",", "13", ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "15"}], ",", "16", ",", 
     RowBox[{"-", "9"}], ",", "10", ",", "11", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "5", ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", "4", ",", "3", ",", "14", ",", "13", ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "9"}], ",", "12", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", "1", ",", "2", ",", "15", ",", "16", ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "12"}], ",", "9", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", "5", ",", 
     RowBox[{"-", "4"}], ",", "3", ",", "2", ",", 
     RowBox[{"-", "1"}], ",", "16", ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "14"}], ",", "13", ",", 
     RowBox[{"-", "12"}], ",", "11", ",", "10", ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "11"}], ",", "12", ",", 
     RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
     RowBox[{"-", "16"}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", "4", ",", 
     RowBox[{"-", "5"}], ",", "6", ",", "7", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "9", ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "13"}], ",", "16", ",", "15", ",", "2", ",", "1", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "5"}], ",", "8", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "12", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "16"}], ",", "13", ",", "14", ",", "3", ",", "4", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "8"}], ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "10"}], ",", "9", ",", 
     RowBox[{"-", "16"}], ",", "15", ",", "14", ",", 
     RowBox[{"-", "13"}], ",", "4", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "1", ",", 
     RowBox[{"-", "8"}], ",", "7", ",", "6", ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", ",", "11", 
     ",", "12", ",", "5", ",", "6", ",", "7", ",", "8", ",", "1", ",", "2", 
     ",", "3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"14", ",", 
     RowBox[{"-", "13"}], ",", "16", ",", 
     RowBox[{"-", "15"}], ",", "10", ",", 
     RowBox[{"-", "9"}], ",", "12", ",", 
     RowBox[{"-", "11"}], ",", "6", ",", 
     RowBox[{"-", "5"}], ",", "8", ",", 
     RowBox[{"-", "7"}], ",", "2", ",", 
     RowBox[{"-", "1"}], ",", "4", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     RowBox[{"-", "16"}], ",", "13", ",", 
     RowBox[{"-", "14"}], ",", "11", ",", 
     RowBox[{"-", "12"}], ",", "9", ",", 
     RowBox[{"-", "10"}], ",", "7", ",", 
     RowBox[{"-", "8"}], ",", "5", ",", 
     RowBox[{"-", "6"}], ",", "3", ",", 
     RowBox[{"-", "4"}], ",", "1", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "16", ",", "15", ",", "14", ",", "13", ",", "12", ",", "11", ",", "10", 
     ",", "9", ",", "8", ",", "7", ",", "6", ",", "5", ",", "4", ",", "3", 
     ",", "2", ",", "1"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8",
      ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", 
     "15", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", "7",
      ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", ",", 
     "16", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "7", ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "5"}], ",", "6", ",", "11", ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "9"}], ",", "10", ",", "15", ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "13"}], ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "1", ",", "8", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", "5", ",", "12", ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "10"}], ",", "9", ",", "16", ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "14"}], ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "7"}], ",", "8", ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
     RowBox[{"-", "4"}], ",", "13", ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "15"}], ",", "16", ",", 
     RowBox[{"-", "9"}], ",", "10", ",", "11", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "8"}], ",", "7", ",", 
     RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
     RowBox[{"-", "3"}], ",", "14", ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "16"}], ",", "15", ",", 
     RowBox[{"-", "10"}], ",", "9", ",", "12", ",", 
     RowBox[{"-", "11"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8", ",", "5", ",", "6", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", "15", ",", "16", ",", "13", ",", "14", ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "10"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "7", ",", "6", ",", "5", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", "16", ",", "15", ",", "14", ",", "13", ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "11"}], ",", "12", ",", 
     RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
     RowBox[{"-", "16"}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", "4", ",", 
     RowBox[{"-", "5"}], ",", "6", ",", "7", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "12"}], ",", "11", ",", 
     RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
     RowBox[{"-", "15"}], ",", "2", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", "3", ",", 
     RowBox[{"-", "6"}], ",", "5", ",", "8", ",", 
     RowBox[{"-", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "12", ",", "9", ",", "10", ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "14"}], ",", "3", ",", "4", ",", "1", ",", "2", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "11", ",", "10", ",", "9", ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "13"}], ",", "4", ",", "3", ",", "2", ",", "1", ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", ",", "11", 
     ",", "12", ",", "5", ",", "6", ",", "7", ",", "8", ",", "1", ",", "2", 
     ",", "3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "14", ",", "13", ",", "16", ",", "15", ",", "10", ",", "9", ",", "12", 
     ",", "11", ",", "6", ",", "5", ",", "8", ",", "7", ",", "2", ",", "1", 
     ",", "4", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "13"}], ",", "14", ",", "11", ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "9"}], ",", "10", ",", "7", ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "5"}], ",", "6", ",", "3", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16", ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "14"}], ",", "13", ",", "12", ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "10"}], ",", "9", ",", "8", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", "5", ",", "4", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8",
      ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", 
     "15", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "1", ",", "4", ",", "3", ",", "6", ",", "5", ",", "8", ",", "7",
      ",", "10", ",", "9", ",", "12", ",", "11", ",", "14", ",", "13", ",", 
     "16", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "4"}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", "7", ",", 
     RowBox[{"-", "8"}], ",", "5", ",", 
     RowBox[{"-", "6"}], ",", "11", ",", 
     RowBox[{"-", "12"}], ",", "9", ",", 
     RowBox[{"-", "10"}], ",", "15", ",", 
     RowBox[{"-", "16"}], ",", "13", ",", 
     RowBox[{"-", "14"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "3"}], ",", "2", ",", 
     RowBox[{"-", "1"}], ",", "8", ",", 
     RowBox[{"-", "7"}], ",", "6", ",", 
     RowBox[{"-", "5"}], ",", "12", ",", 
     RowBox[{"-", "11"}], ",", "10", ",", 
     RowBox[{"-", "9"}], ",", "16", ",", 
     RowBox[{"-", "15"}], ",", "14", ",", 
     RowBox[{"-", "13"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "7"}], ",", "8", ",", 
     RowBox[{"-", "1"}], ",", "2", ",", "3", ",", 
     RowBox[{"-", "4"}], ",", "13", ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "15"}], ",", "16", ",", 
     RowBox[{"-", "9"}], ",", "10", ",", "11", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "8"}], ",", "7", ",", 
     RowBox[{"-", "2"}], ",", "1", ",", "4", ",", 
     RowBox[{"-", "3"}], ",", "14", ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "16"}], ",", "15", ",", 
     RowBox[{"-", "10"}], ",", "9", ",", "12", ",", 
     RowBox[{"-", "11"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", "1", ",", "2", ",", "15", ",", "16", ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "12"}], ",", "9", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "7", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", "2", ",", "1", ",", "16", ",", "15", ",", 
     RowBox[{"-", "14"}], ",", 
     RowBox[{"-", "13"}], ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "11"}], ",", "10", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "11"}], ",", "12", ",", 
     RowBox[{"-", "13"}], ",", "14", ",", "15", ",", 
     RowBox[{"-", "16"}], ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", "4", ",", 
     RowBox[{"-", "5"}], ",", "6", ",", "7", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "12"}], ",", "11", ",", 
     RowBox[{"-", "14"}], ",", "13", ",", "16", ",", 
     RowBox[{"-", "15"}], ",", "2", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", "3", ",", 
     RowBox[{"-", "6"}], ",", "5", ",", "8", ",", 
     RowBox[{"-", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "12", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "15"}], ",", 
     RowBox[{"-", "16"}], ",", "13", ",", "14", ",", "3", ",", "4", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "8"}], ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "11", ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "16"}], ",", 
     RowBox[{"-", "15"}], ",", "14", ",", "13", ",", "4", ",", "3", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "7"}], ",", "6", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", ",", "11", 
     ",", "12", ",", "5", ",", "6", ",", "7", ",", "8", ",", "1", ",", "2", 
     ",", "3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "14", ",", "13", ",", "16", ",", "15", ",", "10", ",", "9", ",", "12", 
     ",", "11", ",", "6", ",", "5", ",", "8", ",", "7", ",", "2", ",", "1", 
     ",", "4", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     RowBox[{"-", "16"}], ",", "13", ",", 
     RowBox[{"-", "14"}], ",", "11", ",", 
     RowBox[{"-", "12"}], ",", "9", ",", 
     RowBox[{"-", "10"}], ",", "7", ",", 
     RowBox[{"-", "8"}], ",", "5", ",", 
     RowBox[{"-", "6"}], ",", "3", ",", 
     RowBox[{"-", "4"}], ",", "1", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16", ",", 
     RowBox[{"-", "15"}], ",", "14", ",", 
     RowBox[{"-", "13"}], ",", "12", ",", 
     RowBox[{"-", "11"}], ",", "10", ",", 
     RowBox[{"-", "9"}], ",", "8", ",", 
     RowBox[{"-", "7"}], ",", "6", ",", 
     RowBox[{"-", "5"}], ",", "4", ",", 
     RowBox[{"-", "3"}], ",", "2", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Q12M5n", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
       ",", "15", ",", "16", ",", "17", ",", "18", ",", "19", ",", "20", ",", 
       "21", ",", "22", ",", "23", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "3", ",", "5", ",", "6", ",", "1", ",", "7", ",", "9", ",", 
       "10", ",", "4", ",", "11", ",", "12", ",", "8", ",", "14", ",", "15", 
       ",", "17", ",", "22", ",", "13", ",", "23", ",", "24", ",", "18", ",", 
       "20", ",", "19", ",", "21", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "5", ",", "1", ",", "7", ",", "2", ",", "9", ",", "4", ",", 
       "11", ",", "6", ",", "12", ",", "8", ",", "10", ",", "15", ",", "17", 
       ",", "13", ",", "19", ",", "14", ",", "21", ",", "16", ",", "23", ",", 
       "18", ",", "24", ",", "20", ",", "22"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "4", ",", "10", ",", "7", ",", "8", ",", "12", ",", "2", ",", "11", ",",
        "1", ",", "5", ",", "6", ",", "3", ",", "9", ",", "16", ",", "18", 
       ",", "19", ",", "20", ",", "21", ",", "22", ",", "23", ",", "13", ",", 
       "24", ",", "14", ",", "15", ",", "17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "1", ",", "2", ",", "9", ",", "3", ",", "4", ",", "6", ",", 
       "12", ",", "7", ",", "8", ",", "10", ",", "11", ",", "17", ",", "13", 
       ",", "14", ",", "24", ",", "15", ",", "20", ",", "22", ",", "21", ",", 
       "23", ",", "16", ",", "18", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "6", ",", "11", ",", "9", ",", "10", ",", "8", ",", "3", ",", "12", ",",
        "2", ",", "1", ",", "7", ",", "5", ",", "4", ",", "18", ",", "19", 
       ",", "21", ",", "14", ",", "16", ",", "15", ",", "17", ",", "22", ",", 
       "13", ",", "23", ",", "24", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "7", ",", "12", ",", "4", ",", "11", ",", "10", ",", "5", ",", "8", ",",
        "3", ",", "2", ",", "9", ",", "1", ",", "6", ",", "19", ",", "21", 
       ",", "16", ",", "23", ",", "18", ",", "24", ",", "20", ",", "15", ",", 
       "22", ",", "17", ",", "13", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "8", ",", "6", ",", "11", ",", "1", ",", "9", ",", "10", ",", "3", ",", 
       "4", ",", "12", ",", "2", ",", "7", ",", "5", ",", "20", ",", "22", 
       ",", "23", ",", "13", ",", "24", ",", "14", ",", "15", ",", "16", ",", 
       "17", ",", "18", ",", "19", ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "9", ",", "8", ",", "6", ",", "12", ",", "11", ",", "1", ",", "10", ",",
        "5", ",", "3", ",", "4", ",", "2", ",", "7", ",", "21", ",", "16", 
       ",", "18", ",", "17", ",", "19", ",", "13", ",", "14", ",", "24", ",", 
       "15", ",", "20", ",", "22", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "10", ",", "7", ",", "12", ",", "2", ",", "4", ",", "11", ",", "5", ",",
        "6", ",", "8", ",", "3", ",", "9", ",", "1", ",", "22", ",", "23", 
       ",", "24", ",", "18", ",", "20", ",", "19", ",", "21", ",", "14", ",", 
       "16", ",", "15", ",", "17", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "11", ",", "9", ",", "8", ",", "3", ",", "6", ",", "12", ",", "1", ",", 
       "7", ",", "10", ",", "5", ",", "4", ",", "2", ",", "23", ",", "24", 
       ",", "20", ",", "15", ",", "22", ",", "17", ",", "13", ",", "19", ",", 
       "14", ",", "21", ",", "16", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "12", ",", "4", ",", "10", ",", "5", ",", "7", ",", "8", ",", "2", ",", 
       "9", ",", "11", ",", "1", ",", "6", ",", "3", ",", "24", ",", "20", 
       ",", "22", ",", "21", ",", "23", ",", "16", ",", "18", ",", "17", ",", 
       "19", ",", "13", ",", "14", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "13", ",", "17", ",", "15", ",", "20", ",", "14", ",", "21", ",", "23", 
       ",", "16", ",", "18", ",", "24", ",", "19", ",", "22", ",", "3", ",", 
       "2", ",", "1", ",", "11", ",", "5", ",", "6", ",", "8", ",", "7", ",", 
       "9", ",", "10", ",", "4", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "14", ",", "13", ",", "17", ",", "22", ",", "15", ",", "16", ",", "24", 
       ",", "18", ",", "19", ",", "20", ",", "21", ",", "23", ",", "5", ",", 
       "3", ",", "2", ",", "9", ",", "1", ",", "11", ",", "6", ",", "12", ",",
        "8", ",", "7", ",", "10", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "15", ",", "14", ",", "13", ",", "23", ",", "17", ",", "18", ",", "20", 
       ",", "19", ",", "21", ",", "22", ",", "16", ",", "24", ",", "1", ",", 
       "5", ",", "3", ",", "8", ",", "2", ",", "9", ",", "11", ",", "4", ",", 
       "6", ",", "12", ",", "7", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "16", ",", "24", ",", "19", ",", "13", ",", "22", ",", "17", ",", "15", 
       ",", "20", ",", "14", ",", "21", ",", "23", ",", "18", ",", "7", ",", 
       "6", ",", "4", ",", "3", ",", "9", ",", "10", ",", "1", ",", "11", ",",
        "12", ",", "2", ",", "8", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "17", ",", "15", ",", "14", ",", "24", ",", "13", ",", "19", ",", "22", 
       ",", "21", ",", "16", ",", "23", ",", "18", ",", "20", ",", "2", ",", 
       "1", ",", "5", ",", "6", ",", "3", ",", "8", ",", "9", ",", "10", ",", 
       "11", ",", "4", ",", "12", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "18", ",", "20", ",", "21", ",", "14", ",", "23", ",", "13", ",", "17", 
       ",", "22", ",", "15", ",", "16", ",", "24", ",", "19", ",", "9", ",", 
       "7", ",", "6", ",", "12", ",", "4", ",", "3", ",", "10", ",", "5", ",",
        "1", ",", "11", ",", "2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "19", ",", "22", ",", "16", ",", "15", ",", "24", ",", "14", ",", "13", 
       ",", "23", ",", "17", ",", "18", ",", "20", ",", "21", ",", "4", ",", 
       "9", ",", "7", ",", "1", ",", "6", ",", "12", ",", "3", ",", "8", ",", 
       "10", ",", "5", ",", "11", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "20", ",", "21", ",", "23", ",", "16", ",", "18", ",", "24", ",", "19", 
       ",", "13", ",", "22", ",", "17", ",", "15", ",", "14", ",", "11", ",", 
       "10", ",", "8", ",", "7", ",", "12", ",", "2", ",", "4", ",", "3", ",",
        "5", ",", "6", ",", "1", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "21", ",", "23", ",", "18", ",", "17", ",", "20", ",", "15", ",", "14", 
       ",", "24", ",", "13", ",", "19", ",", "22", ",", "16", ",", "6", ",", 
       "4", ",", "9", ",", "10", ",", "7", ",", "1", ",", "12", ",", "2", ",",
        "3", ",", "8", ",", "5", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "22", ",", "16", ",", "24", ",", "18", ",", "19", ",", "20", ",", "21", 
       ",", "14", ",", "23", ",", "13", ",", "17", ",", "15", ",", "12", ",", 
       "11", ",", "10", ",", "5", ",", "8", ",", "7", ",", "2", ",", "9", ",",
        "4", ",", "3", ",", "6", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "23", ",", "18", ",", "20", ",", "19", ",", "21", ",", "22", ",", "16", 
       ",", "15", ",", "24", ",", "14", ",", "13", ",", "17", ",", "8", ",", 
       "12", ",", "11", ",", "4", ",", "10", ",", "5", ",", "7", ",", "1", 
       ",", "2", ",", "9", ",", "3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "24", ",", "19", ",", "22", ",", "21", ",", "16", ",", "23", ",", "18", 
       ",", "17", ",", "20", ",", "15", ",", "14", ",", "13", ",", "10", ",", 
       "8", ",", "12", ",", "2", ",", "11", ",", "4", ",", "5", ",", "6", ",",
        "7", ",", "1", ",", "9", ",", "3"}], "}"}]}], "}"}]}], ";", 
  RowBox[{"Alt12nC2", "=", 
   RowBox[{"co", "[", 
    RowBox[{"Alt12n", ",", "C2"}], "]"}]}], ";", 
  RowBox[{"OctrC3", "=", 
   RowBox[{"co", "[", 
    RowBox[{"Oct", ",", "C3"}], "]"}]}], ";", 
  RowBox[{"Alt12nC3", "=", 
   RowBox[{"co", "[", 
    RowBox[{"Alt12n", ",", "C3"}], "]"}]}], ";", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"C4iC4M", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14",
          ",", "15", ",", "16", ",", "17", ",", "18", ",", "19", ",", "20", 
         ",", "21", ",", "22", ",", "23", ",", "24", ",", "25", ",", "26", 
         ",", "27", ",", "28", ",", "29", ",", "30", ",", "31", ",", "32"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "2", ",", "5", ",", "6", ",", "7", ",", "8", ",", "10", ",", "11", 
         ",", "1", ",", "12", ",", "13", ",", "14", ",", "15", ",", "3", ",", 
         "4", ",", "16", ",", "9", ",", "18", ",", "21", ",", "28", ",", "23",
          ",", "24", ",", "31", ",", "27", ",", "17", ",", "22", ",", "32", 
         ",", "30", ",", "26", ",", "25", ",", "20", ",", "29", ",", "19"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3", ",", "12", ",", "4", ",", "9", ",", "10", ",", "2", ",", "6", 
         ",", "16", ",", "1", ",", "11", ",", "15", ",", "7", ",", "8", ",", 
         "13", ",", "5", ",", "14", ",", "25", ",", "28", ",", "17", ",", 
         "19", ",", "31", ",", "18", ",", "22", ",", "32", ",", "20", ",", 
         "21", ",", "26", ",", "23", ",", "24", ",", "29", ",", "27", ",", 
         "30"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "4", ",", "7", ",", "9", ",", "1", ",", "11", ",", "12", ",", "2", 
         ",", "14", ",", "3", ",", "15", ",", "5", ",", "6", ",", "16", ",", 
         "8", ",", "10", ",", "13", ",", "20", ",", "23", ",", "25", ",", 
         "17", ",", "27", ",", "28", ",", "18", ",", "30", ",", "19", ",", 
         "31", ",", "21", ",", "22", ",", "32", ",", "24", ",", "26", ",", 
         "29"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "5", ",", "8", ",", "10", ",", "11", ",", "1", ",", "13", ",", "14", 
         ",", "2", ",", "15", ",", "3", ",", "4", ",", "16", ",", "6", ",", 
         "7", ",", "9", ",", "12", ",", "21", ",", "24", ",", "26", ",", "27",
          ",", "17", ",", "29", ",", "30", ",", "18", ",", "31", ",", "19", 
         ",", "20", ",", "32", ",", "22", ",", "23", ",", "25", ",", "28"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "6", ",", "15", ",", "7", ",", "12", ",", "13", ",", "5", ",", "10", 
         ",", "9", ",", "2", ",", "14", ",", "16", ",", "11", ",", "1", ",", 
         "3", ",", "8", ",", "4", ",", "28", ",", "31", ",", "23", ",", "22", 
         ",", "32", ",", "27", ",", "26", ",", "25", ",", "18", ",", "30", 
         ",", "29", ",", "21", ",", "20", ",", "19", ",", "24", ",", "17"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "7", ",", "11", ",", "12", ",", "2", ",", "14", ",", "15", ",", "5", 
         ",", "4", ",", "6", ",", "16", ",", "8", ",", "10", ",", "9", ",", 
         "1", ",", "13", ",", "3", ",", "23", ",", "27", ",", "22", ",", "18",
          ",", "30", ",", "26", ",", "21", ",", "20", ",", "28", ",", "29", 
         ",", "24", ",", "31", ",", "19", ",", "17", ",", "32", ",", "25"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "8", ",", "1", ",", "13", ",", "14", ",", "2", ",", "3", ",", "4", 
         ",", "5", ",", "16", ",", "6", ",", "7", ",", "9", ",", "10", ",", 
         "11", ",", "12", ",", "15", ",", "24", ",", "17", ",", "32", ",", 
         "30", ",", "18", ",", "25", ",", "20", ",", "21", ",", "29", ",", 
         "28", ",", "23", ",", "19", ",", "31", ",", "27", ",", "22", ",", 
         "26"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "9", ",", "6", ",", "1", ",", "3", ",", "15", ",", "7", ",", "12", 
         ",", "13", ",", "4", ",", "5", ",", "10", ",", "2", ",", "14", ",", 
         "16", ",", "11", ",", "8", ",", "19", ",", "22", ",", "20", ",", 
         "25", ",", "26", ",", "23", ",", "28", ",", "29", ",", "17", ",", 
         "27", ",", "31", ",", "18", ",", "30", ",", "32", ",", "21", ",", 
         "24"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "10", ",", "16", ",", "11", ",", "15", ",", "3", ",", "8", ",", "13", 
         ",", "12", ",", "5", ",", "4", ",", "9", ",", "14", ",", "2", ",", 
         "6", ",", "1", ",", "7", ",", "31", ",", "32", ",", "21", ",", "26", 
         ",", "25", ",", "24", ",", "29", ",", "28", ",", "27", ",", "17", 
         ",", "19", ",", "30", ",", "18", ",", "22", ",", "20", ",", "23"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "11", ",", "14", ",", "15", ",", "5", ",", "4", ",", "16", ",", "8", 
         ",", "7", ",", "10", ",", "9", ",", "1", ",", "13", ",", "12", ",", 
         "2", ",", "3", ",", "6", ",", "27", ",", "30", ",", "31", ",", "21", 
         ",", "20", ",", "32", ",", "24", ",", "23", ",", "26", ",", "25", 
         ",", "17", ",", "29", ",", "28", ",", "18", ",", "19", ",", "22"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "12", ",", "10", ",", "2", ",", "6", ",", "16", ",", "11", ",", "15", 
         ",", "3", ",", "7", ",", "8", ",", "13", ",", "5", ",", "4", ",", 
         "9", ",", "14", ",", "1", ",", "22", ",", "26", ",", "18", ",", "28",
          ",", "29", ",", "21", ",", "31", ",", "19", ",", "23", ",", "24", 
         ",", "32", ",", "27", ",", "17", ",", "25", ",", "30", ",", "20"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "13", ",", "9", ",", "14", ",", "16", ",", "6", ",", "1", ",", "3", 
         ",", "15", ",", "8", ",", "7", ",", "12", ",", "4", ",", "5", ",", 
         "10", ",", "2", ",", "11", ",", "32", ",", "25", ",", "30", ",", 
         "29", ",", "28", ",", "20", ",", "19", ",", "31", ",", "24", ",", 
         "23", ",", "22", ",", "17", ",", "27", ",", "26", ",", "18", ",", 
         "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "14", ",", "4", ",", "16", ",", "8", ",", "7", ",", "9", ",", "1", 
         ",", "11", ",", "13", ",", "12", ",", "2", ",", "3", ",", "15", ",", 
         "5", ",", "6", ",", "10", ",", "30", ",", "20", ",", "29", ",", "24",
          ",", "23", ",", "19", ",", "17", ",", "27", ",", "32", ",", "22", 
         ",", "18", ",", "25", ",", "26", ",", "21", ",", "28", ",", "31"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "15", ",", "13", ",", "5", ",", "10", ",", "9", ",", "14", ",", "16", 
         ",", "6", ",", "11", ",", "1", ",", "3", ",", "8", ",", "7", ",", 
         "12", ",", "4", ",", "2", ",", "26", ",", "29", ",", "27", ",", "31",
          ",", "19", ",", "30", ",", "32", ",", "22", ",", "21", ",", "20", 
         ",", "25", ",", "24", ",", "23", ",", "28", ",", "17", ",", "18"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "16", ",", "3", ",", "8", ",", "13", ",", "12", ",", "4", ",", "9", 
         ",", "10", ",", "14", ",", "2", ",", "6", ",", "1", ",", "11", ",", 
         "15", ",", "7", ",", "5", ",", "29", ",", "19", ",", "24", ",", "32",
          ",", "22", ",", "17", ",", "25", ",", "26", ",", "30", ",", "18", 
         ",", "28", ",", "20", ",", "21", ",", "31", ",", "23", ",", "27"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "17", ",", "23", ",", "19", ",", "20", ",", "21", ",", "22", ",", 
         "18", ",", "30", ",", "25", ",", "26", ",", "27", ",", "28", ",", 
         "29", ",", "24", ",", "31", ",", "32", ",", "5", ",", "14", ",", 
         "10", ",", "11", ",", "1", ",", "13", ",", "8", ",", "7", ",", "15", 
         ",", "3", ",", "4", ",", "16", ",", "6", ",", "2", ",", "9", ",", 
         "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "18", ",", "27", ",", "22", ",", "23", ",", "24", ",", "26", ",", 
         "21", ",", "20", ",", "28", ",", "29", ",", "30", ",", "31", ",", 
         "19", ",", "17", ",", "32", ",", "25", ",", "8", ",", "4", ",", "16",
          ",", "14", ",", "2", ",", "9", ",", "1", ",", "11", ",", "13", ",", 
         "12", ",", "7", ",", "3", ",", "15", ",", "5", ",", "6", ",", "10"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "19", ",", "22", ",", "20", ",", "25", ",", "26", ",", "18", ",", 
         "28", ",", "29", ",", "17", ",", "27", ",", "31", ",", "23", ",", 
         "24", ",", "32", ",", "21", ",", "30", ",", "15", ",", "13", ",", 
         "5", ",", "10", ",", "9", ",", "8", ",", "16", ",", "6", ",", "11", 
         ",", "1", ",", "3", ",", "14", ",", "2", ",", "12", ",", "4", ",", 
         "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "20", ",", "18", ",", "25", ",", "17", ",", "27", ",", "28", ",", 
         "23", ",", "24", ",", "19", ",", "31", ",", "21", ",", "22", ",", 
         "32", ",", "30", ",", "26", ",", "29", ",", "11", ",", "8", ",", 
         "15", ",", "5", ",", "4", ",", "16", ",", "14", ",", "2", ",", "10", 
         ",", "9", ",", "1", ",", "13", ",", "12", ",", "7", ",", "3", ",", 
         "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "21", ",", "30", ",", "26", ",", "27", ",", "17", ",", "29", ",", 
         "24", ",", "23", ",", "31", ",", "19", ",", "20", ",", "32", ",", 
         "22", ",", "18", ",", "25", ",", "28", ",", "1", ",", "7", ",", "3", 
         ",", "4", ",", "5", ",", "6", ",", "2", ",", "14", ",", "9", ",", 
         "10", ",", "11", ",", "12", ",", "13", ",", "8", ",", "15", ",", 
         "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "22", ",", "26", ",", "23", ",", "28", ",", "29", ",", "21", ",", 
         "31", ",", "19", ",", "18", ",", "30", ",", "32", ",", "27", ",", 
         "17", ",", "25", ",", "24", ",", "20", ",", "16", ",", "3", ",", 
         "14", ",", "13", ",", "12", ",", "4", ",", "9", ",", "10", ",", "8", 
         ",", "7", ",", "6", ",", "1", ",", "11", ",", "15", ",", "2", ",", 
         "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "23", ",", "21", ",", "28", ",", "18", ",", "30", ",", "31", ",", 
         "27", ",", "17", ",", "22", ",", "32", ",", "24", ",", "26", ",", 
         "25", ",", "20", ",", "29", ",", "19", ",", "14", ",", "1", ",", 
         "13", ",", "8", ",", "7", ",", "3", ",", "4", ",", "5", ",", "16", 
         ",", "6", ",", "2", ",", "9", ",", "10", ",", "11", ",", "12", ",", 
         "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "24", ",", "20", ",", "29", ",", "30", ",", "18", ",", "19", ",", 
         "17", ",", "27", ",", "32", ",", "22", ",", "23", ",", "25", ",", 
         "26", ",", "21", ",", "28", ",", "31", ",", "2", ",", "11", ",", 
         "12", ",", "7", ",", "8", ",", "15", ",", "5", ",", "4", ",", "6", 
         ",", "16", ",", "14", ",", "10", ",", "9", ",", "1", ",", "13", ",", 
         "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "25", ",", "28", ",", "17", ",", "19", ",", "31", ",", "23", ",", 
         "22", ",", "32", ",", "20", ",", "21", ",", "26", ",", "18", ",", 
         "30", ",", "29", ",", "27", ",", "24", ",", "10", ",", "16", ",", 
         "11", ",", "15", ",", "3", ",", "14", ",", "13", ",", "12", ",", "5",
          ",", "4", ",", "9", ",", "8", ",", "7", ",", "6", ",", "1", ",", 
         "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "26", ",", "29", ",", "27", ",", "31", ",", "19", ",", "24", ",", 
         "32", ",", "22", ",", "21", ",", "20", ",", "25", ",", "30", ",", 
         "18", ",", "28", ",", "17", ",", "23", ",", "9", ",", "6", ",", "1", 
         ",", "3", ",", "15", ",", "2", ",", "12", ",", "13", ",", "4", ",", 
         "5", ",", "10", ",", "7", ",", "8", ",", "16", ",", "11", ",", 
         "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "27", ",", "24", ",", "31", ",", "21", ",", "20", ",", "32", ",", 
         "30", ",", "18", ",", "26", ",", "25", ",", "17", ",", "29", ",", 
         "28", ",", "23", ",", "19", ",", "22", ",", "4", ",", "2", ",", "9", 
         ",", "1", ",", "11", ",", "12", ",", "7", ",", "8", ",", "3", ",", 
         "15", ",", "5", ",", "6", ",", "16", ",", "14", ",", "10", ",", 
         "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "28", ",", "31", ",", "18", ",", "22", ",", "32", ",", "27", ",", 
         "26", ",", "25", ",", "23", ",", "24", ",", "29", ",", "21", ",", 
         "20", ",", "19", ",", "30", ",", "17", ",", "13", ",", "9", ",", "8",
          ",", "16", ",", "6", ",", "1", ",", "3", ",", "15", ",", "14", ",", 
         "2", ",", "12", ",", "4", ",", "5", ",", "10", ",", "7", ",", "11"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "29", ",", "19", ",", "30", ",", "32", ",", "22", ",", "17", ",", 
         "25", ",", "26", ",", "24", ",", "23", ",", "28", ",", "20", ",", 
         "21", ",", "31", ",", "18", ",", "27", ",", "12", ",", "10", ",", 
         "7", ",", "6", ",", "16", ",", "11", ",", "15", ",", "3", ",", "2", 
         ",", "14", ",", "13", ",", "5", ",", "4", ",", "9", ",", "8", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "30", ",", "17", ",", "32", ",", "24", ",", "23", ",", "25", ",", 
         "20", ",", "21", ",", "29", ",", "28", ",", "18", ",", "19", ",", 
         "31", ",", "27", ",", "22", ",", "26", ",", "7", ",", "5", ",", "6", 
         ",", "2", ",", "14", ",", "10", ",", "11", ",", "1", ",", "12", ",", 
         "13", ",", "8", ",", "15", ",", "3", ",", "4", ",", "16", ",", "9"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "31", ",", "32", ",", "21", ",", "26", ",", "25", ",", "30", ",", 
         "29", ",", "28", ",", "27", ",", "17", ",", "19", ",", "24", ",", 
         "23", ",", "22", ",", "20", ",", "18", ",", "3", ",", "12", ",", "4",
          ",", "9", ",", "10", ",", "7", ",", "6", ",", "16", ",", "1", ",", 
         "11", ",", "15", ",", "2", ",", "14", ",", "13", ",", "5", ",", 
         "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "32", ",", "25", ",", "24", ",", "29", ",", "28", ",", "20", ",", 
         "19", ",", "31", ",", "30", ",", "18", ",", "22", ",", "17", ",", 
         "27", ",", "26", ",", "23", ",", "21", ",", "6", ",", "15", ",", "2",
          ",", "12", ",", "13", ",", "5", ",", "10", ",", "9", ",", "7", ",", 
         "8", ",", "16", ",", "11", ",", "1", ",", "3", ",", "14", ",", "4"}],
         "}"}]}], "}"}]}], ";"}], ")"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "5 Main Groupoid Data File,",
 StyleBox[" ",
  FontWeight->"Plain"],
 StyleBox["loop[[mm,nn]]",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "loop", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "loop", "]"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"to", " ", "allow", " ", "revisions"}], "*)"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"loop", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "257"}], "}"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C1\>\"", ",", 
      RowBox[{"{", "1.", "}"}], ",", "0", ",", "\"\<ca[1]\>\"", ",", 
      RowBox[{"{", "1", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C2\>\"", ",", 
       RowBox[{"{", "2.", "}"}], ",", "0", ",", "\"\<ca[2]\>\"", ",", 
       RowBox[{"{", "2", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "1", "}"}], ",", 
       RowBox[{"{", "1", "}"}], ",", 
       RowBox[{"{", "1", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", "1", ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "30", "}"}], ",", "\"\<clf[0,1]\>\""}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "2"]}], "}"}], ",", "0", ",", "\"\<ca[3]\>\"", ",",
        
       RowBox[{"{", "3", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "10", "}"}], ",", 
       RowBox[{"{", "8", "}"}], ",", 
       RowBox[{"{", "8", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C2c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "2"], ",", "3"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "45", "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "2"], ",", "2"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-3}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4C3c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1."}], " ", "\[ImaginaryI]"}], ",", 
         SubscriptBox["1", "2"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<C4C3c\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C3j\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1."}], " ", "\[DoubleStruckCapitalJ]"}], ",", 
         SubscriptBox["1", "2"], ",", "8"}], "}"}], ",", "0", ",", 
       "\"\<C3C3j\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C9j\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1."}], "\[DoubleStruckCapitalJ]"}], ",", 
         SubscriptBox["1", "2"], ",", "5"}], "}"}], ",", "0", ",", 
       "\"\<C9j\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C9J\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1."}], " ", "\[DoubleStruckCapitalJ]"}], ",", 
         SubscriptBox["1", "2"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[9],3]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C12c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1."}], "\[ImaginaryI]"}], ",", 
         SubscriptBox["1", "2"], ",", "3"}], "}"}], ",", "22", ",", 
       "\"\<C12c\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3i\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1."}], " ", "\[ImaginaryI]"}], ",", 
         SubscriptBox["1", "2"], ",", "3"}], "}"}], ",", "22", ",", 
       "\"\<C3i\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         SubscriptBox["1", "2"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<C3n\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<K\>\"", ",", 
       RowBox[{"{", "4.", "}"}], ",", "0", ",", "\"\<co[C2,C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", "2"}], "}"}], ",", "0", ",", "\"\<ca[4]\>\"", ",", 
       
       RowBox[{"{", "4", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "12", "}"}], ",", 
       RowBox[{"{", "13", "}"}], ",", 
       RowBox[{"{", "12", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Qr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "1", ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-1,-1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"30", ",", "31"}], "*)"}], "}"}], ",", "\"\<clf[0,2]\>\""}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Kr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<cd[{4.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<O2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", "2", ",", "4"}], "}"}], ",", "7", ",", 
       "\"\<cd[{-1,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"3", ",", "30"}], "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Dav\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", "2", ",", "6"}], "}"}], ",", "2", ",", 
       "\"\<cd[{-1,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"30", ",", "41"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL11\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "3", ",", "4"}], "}"}], ",", "101", ",", 
       "\"\<clf[1,1]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"4", ",", "43"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "3", ",", "4"}], "}"}], ",", "101", ",", 
       "\"\<clf[2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"4", ",", "5"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<P4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], "\[ImaginaryI]"}], ",", "6"}], "}"}], ",", "0", 
       ",", "\"\<P4\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", "\"\<msi[{2,3,4}]\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4C2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", "2", ",", "6"}], "}"}], ",", "2", ",", 
       "\"\<cd[{-4}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C4j\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", "2", ",", "4"}], "}"}], ",", "7", ",", 
       "\"\<cd[{-2,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"4", ",", "13"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C8c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "3"], ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-4.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "37", "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C8r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "3"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[8,5]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<P16c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "\[ImaginaryI]"}], ",", "2", ",", "8"}], "}"}], 
       ",", "0", ",", "\"\<P16c\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", "\"\<msi[{13,2,14}]\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q4n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "3"}], "}"}], ",", "0", ",", "\"\<Q4n\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "4"]}], "}"}], ",", "0", ",", "\"\<ca[5]\>\"", ",",
        
       RowBox[{"{", "5", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "18", "}"}], ",", 
       RowBox[{"{", "16", "}"}], ",", 
       RowBox[{"{", "17", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C10c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "4"], ",", "10"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[10]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "25", "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C10r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "4"], ",", "9"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[10],2,{1,3,5,7,4,6,8,10,2,9}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C10s\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "4"], ",", "7"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[10],2,{1,7,8,4,10,6,2,3,9,5}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C10t\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "4"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[10],2,{1,2,8,4,10,6,7,3,9,5}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C5n\>\"", ",", 
       RowBox[{"{", "5", "}"}], ",", "0", ",", "\"\<C5n\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<L5n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", "0", ",", 
       "\"\<L5n\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<D3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "2"]}], "}"}], ",", "0", ",", "\"\<ca[6,5]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "9"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "2"]}], "}"}], ",", "72", ",", "\"\<co[C3,C2]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "19", " ", "}"}], ",", 
       RowBox[{"{", "17", "}"}], ",", 
       RowBox[{"{", "18", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         SubscriptBox["1", "3"], ",", "9"}], "}"}], ",", "0", ",", 
       "\"\<ts[Q12]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"8", ",", "43"}], "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         SubscriptBox["1", "2"], ",", "3", ",", "15"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[12,5]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D6r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "4", ",", "12"}], "}"}], ",", "0",
        ",", "\"\<ts[ca[12,11]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"4", ",", 
          RowBox[{"-", "8"}]}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KC3c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "2"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3.,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3Kr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "2"], ",", "8"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-3,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C4c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "5"], ",", "9"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D3C2c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "4", ",", "8"}], "}"}], ",", "0", 
       ",", "\"\<ms[{6,7},u3]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Clm3r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "5"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-3,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Cl3r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "5"], ",", "15"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3.,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "26", "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g2401c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], "\[ImaginaryI]"}], ",", 
         SubscriptBox["1", "3"], ",", "9"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[{24,1}],-4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C6n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"]}], "}"}], ",", "0", ",", "\"\<C6n\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C6an\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "2"]}], "}"}], ",", "72", ",", 
       "\"\<co[C9j,C2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Alt6n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1."}], " ", "\[ImaginaryI]"}], ",", 
         SubscriptBox["1", "5"], ",", "15"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[{24,2}],-4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "7", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C7\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "6"]}], "}"}], ",", "0", ",", "\"\<ca[7]\>\"", ",",
        
       RowBox[{"{", "7", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "21", "}"}], ",", 
       RowBox[{"{", "24", "}"}], ",", 
       RowBox[{"{", "20", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C14c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "6"], ",", "21"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[14]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "8", "]"}], "]"}], "=", 
   RowBox[{"{", "  ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "3"]}], "}"}], ",", "0", ",", "\"\<ca[8]\>\"", ",",
        
       RowBox[{"{", "8", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "22", "}"}], ",", 
       RowBox[{"{", "25", "}"}], ",", 
       RowBox[{"{", "21", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", "4"}], "}"}], ",", "0", ",", "\"\<co[C4,C2]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "16"}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<D4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2"}], "}"}], ",", "0", ",", "\"\<ca[8,7]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "6"}], "}"}], ",", "0", ",", "\"\<ca[8,3]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "16"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<KC2\>\"", ",", 
       RowBox[{"{", "8.", "}"}], ",", "0", ",", "\"\<co[K,C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "4"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C16c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "7"], ",", "28"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[16]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C16r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "7"], ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[16,9]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4C4c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "3"], ",", "16"}], "}"}], ",", "0", ",", 
       "\"\<cd[{2,1.,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<KiC4c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2", ",", "4", ",", "16"}], "}"}], ",", "0",
        ",", "\"\<ts[co[K,C4,2]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"12", ",", "16"}], "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C4iC4c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", 
         SubscriptBox["2", "2"], ",", "16"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[C4,C4,2]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<QC2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "2", ",", "24"}], "}"}], ",", "20", ",", 
       "\"\<ts[co[C2,Q8]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"7", ",", "30", ",", "44"}], "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "2", ",", "26"}], "}"}], ",", "0", ",", 
       "\"\<Q8C2r\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"29", ",", "30", ",", "31"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<O4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", "4", ",", "16"}], "}"}], ",", "97", ",", 
       "\"\<cd[{1,1,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<O4a\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", "4", ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-1,1.,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<O4b\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", "4", ",", "28"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-1,-1.,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<P8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], "\[ImaginaryI]"}], ",", "24"}], "}"}], ",", "0",
        ",", "\"\<P8\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KKr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8."}], ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<cd[{4.,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C2D4r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "6", ",", "16"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[C2,D4]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "4", ",", "5"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4", ",", "24"}], "}"}], ",", "100", ",", 
       "\"\<clf[3]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"4", ",", "29", ",", "30"}], "*)"}], "}"}], ",", 
       "\"\<ts[P16i]\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4", ",", "24"}], "}"}], ",", "100", ",", 
       "\"\<clf[1,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Octr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7"}], ",", "1", ",", "28"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-1,-1,-1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KiC4r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2", ",", "4", ",", "24"}], "}"}], ",", "0",
        ",", "\"\<ts[co[K,C4,2],2,{1,10,13,14,3,12,15,16,9,2,5,6,11,4,7,8}]\>\
\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"3", ",", "43"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C8pC2c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", 
         SubscriptBox["2", "3"], ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[{16,6}],{1,14,3,4,9,6,11,12,5,10,7,8,13,2,15,16}]\>\"", ",",
        
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D8c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         SubscriptBox["1", "2"], ",", "5", ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[16,15]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8iC2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", 
         SubscriptBox["3", "2"], ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[Q8,C2,2],{1,4,3,2,9,14,15,16,   5,8,7,6,13,10,11,12}]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q16r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         SubscriptBox["1", "2"], ",", "5", ",", "28"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[16,7]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL21\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "6", ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<clf[2,1]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"4", ",", "5", ",", "7", ",", "16"}], "*)"}], "}"}]}], "}"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL03\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "2", ",", "28"}], "}"}], ",", "0", ",", 
       "\"\<clf[0,3]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"16", ",", "30", ",", "44"}], "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C4C4r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "3"], ",", "24"}], "}"}], ",", "12", ",", 
       "\"\<cd[{-2,1,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Octs\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "5", ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<cd[{1,-1,-1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<O4k\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", "4", ",", "16"}], "}"}], ",", "97", ",", 
       "\"\<cd[{-2,1,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C8pr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", 
         SubscriptBox["2", "3"], ",", "26"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[ca[8],C2,4],{1,13,16,4,3,11,10,6,5,9,12,8,7,15,14,2}]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C8n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "1", ",", "2", ",", "3", ",", "24"}], "}"}],
        ",", "0", ",", "\"\<cd[{2,-1.,-1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8n\>\"", ",", 
       RowBox[{"{", "8", "}"}], ",", "0", ",", "\"\<Q8n\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "9", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C9\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "8"]}], "}"}], ",", "1", ",", "\"\<ca[9]\>\"", ",",
        
       RowBox[{"{", "9", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "23", "}"}], ",", 
       RowBox[{"{", "28", "}"}], ",", 
       RowBox[{"{", "23", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "8"]}], "}"}], ",", "1", ",", "\"\<co[C3,C3]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "11"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C6C3c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "8"], ",", "38"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[18,5],2,{1,15,8,5,13,9,14,7,6,4,18,11,2,16,12,17,10,3}]\>\"\
", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C6c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "8"], ",", "27"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[C3,ca[6]]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"10", ",", 
          RowBox[{"-", "12"}]}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C18c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "8"], ",", "36"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[18]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"-", "28"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "10", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<D5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["1", "4"]}], "}"}], ",", "0", ",", "\"\<ca[10,9]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C10\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "4"]}], "}"}], ",", "0", ",", "\"\<ca[10]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "18"}], "}"}], ",", 
       RowBox[{"{", "29", "}"}], ",", 
       RowBox[{"{", "24", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q20c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5"}], ",", 
         SubscriptBox["1", "5"], ",", "25"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "11", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C11\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "10"]}], "}"}], ",", "0", ",", "\"\<ca[11]\>\"", 
      ",", 
      RowBox[{"{", "11", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "12", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<Q12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<co[C3,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "36"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "16"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "5"]}], "}"}], ",", "0", ",", "\"\<co[C3,C4]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "15"}], "}"}], ",", 
       RowBox[{"{", "26", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<A4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "8"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "10"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<D3C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "2"]}], "}"}], ",", "0", ",", "\"\<co[C3,K,2]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], " ", "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "2"]}], "}"}], ",", "0", ",", "\"\<co[C3,K]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "19"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Alt12n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"]}], "}"}], ",", "0", ",", 
       "\"\<cd[{-1,-1,{3}}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", "\"\<ge[{2,2,3},{ ba->abc }]\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3Qr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         SubscriptBox["1", "3"], ",", 
         SubscriptBox["3", "2"], ",", "54"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[C3,Q8]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3P4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], "\[ImaginaryI]"}], ",", 
         SubscriptBox["4", "2"], ",", "54"}], "}"}], ",", "0", ",", 
       "\"\<C3P4\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3Dav\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "5"], ",", "54"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3,-1.,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<SL23r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         SubscriptBox["1", "8"], ",", "3", ",", "54"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[{24,3},4],2,{1,2,4,3,5,6,10,9,22,20,21,7,8,12,14,13,15,16,\
19,18,24,11,23,17}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3iC8c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         SubscriptBox["1", "6"], ",", "3", ",", "54"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[{24,1},1]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D3C4c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         SubscriptBox["1", "3"], ",", 
         SubscriptBox["4", "2"], ",", "36"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[{24,5},1]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D12r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         SubscriptBox["1", "4"], ",", "7", ",", "60"}], "}"}], ",", "0", ",", 
       "\"\<ts[ca[24,23]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12C2c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", 
         SubscriptBox["2", "3"], ",", "36"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[{24,7},1]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12C2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", 
         SubscriptBox["2", "2"], ",", "6", ",", "60"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[C2,ca[12,5]]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3iC4iC2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         SubscriptBox["2", "2"], ",", "5", ",", "36"}], "}"}], ",", "0", ",", 
       "\"\<ts[mp[{24,8},1]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", "\"\<msi[{11,2,14}]\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3r8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "5"], ",", "36"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3,-1.,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"12", ",", "19"}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"\[ImaginaryI]", ",", 
          RowBox[{"2", "\[DoubleStruckCapitalJ]"}]}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"\[ImaginaryI]", ",", "\[DoubleStruckCapitalJ]"}], "*)"}], 
        "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C6Kc\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", 
         SubscriptBox["4", "2"], ",", "48"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3.,1,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3KC2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", 
         SubscriptBox["4", "2"], ",", "30"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[C2,C3K],2,{1,3, 5,20,22,24,7,21,23,2,4, \
6,13,15,17,8,10,12,19,9,11,14,16,18}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C6Kr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", 
         SubscriptBox["4", "2"], ",", "32"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-3,1,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C8c\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", 
         SubscriptBox["1", "11"], ",", "54"}], "}"}], ",", "0", ",", 
       "\"\<ts[co[C3,ca[8],1]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C24r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "5"], ",", "52"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-3,-1.,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C24ra\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "5"], ",", "60"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3.,-1.,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"19", ",", "44"}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"2", ",", 
          RowBox[{"8", "\[ImaginaryI]"}]}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Cm311\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "5"], ",", "62"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-3,-1.,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C24rb\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2."}], ",", 
         SubscriptBox["2", "5"], ",", "66"}], "}"}], ",", "0", ",", 
       "\"\<cd[{3.,-1.,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<A4C2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         SubscriptBox["1", "7"], ",", "4", ",", "46"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"4", ",", "11"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C12n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "1", ",", "3", ",", "4", ",", "52"}], "}"}],
        ",", "0", ",", "\"\<cd[{-3,1.,-1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D3Mn\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "2"]}], "}"}], ",", "0", ",", "\"\<md[D3]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "13", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C13\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "12"]}], "}"}], ",", "0", ",", "\"\<ca[13]\>\"", 
      ",", 
      RowBox[{"{", "13", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "14", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C14\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "6"]}], "}"}], ",", "0", ",", "\"\<ca[14]\>\"", 
       ",", 
       RowBox[{"{", "14", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "21"}], "}"}], ",", 
       RowBox[{"{", "30", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "20"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D7\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["1", "6"]}], "}"}], ",", "0", ",", "\"\<ca[14,13]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a6b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "24"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "15", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C15\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "14"]}], "}"}], ",", "0", ",", "\"\<ca[15]\>\"", 
      ",", 
      RowBox[{"{", "15", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "18"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "16"}], "}"}], ",", 
      RowBox[{"{", "28", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "16", "]"}], "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C16\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "7"]}], "}"}], ",", "0", ",", "\"\<ca[16]\>\"", 
       ",", 
       RowBox[{"{", "16", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"\"\<C4C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "3"]}], "}"}], ",", "3", ",", "\"\<co[C4,C4]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "43"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"\"\<KiC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "2"]}], "}"}], ",", "0", ",", "\"\<co[K,C4,2]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "13"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C4iC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "8"}], "}"}], ",", "0", ",", 
       "\"\<co[C4,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C8C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "3"]}], "}"}], ",", "3", ",", "\"\<co[C8,C2]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "22"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C8pC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "3"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[8],C2,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"29", ",", "34"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "26"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "21"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["2", "3"]}], "}"}], ",", "0", ",", "\"\<ca[16,15]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "22"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "22"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8iC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "2"], ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<co[Q8,C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "37"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q16\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", "10"}], "}"}], ",", "0", ",", 
       "\"\<ca[16,7]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", "8"}], "}"}], ",", "0", ",", "\"\<co[C4,K]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "6", ",", "12"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "4"}], "}"}], ",", "0", ",", "\"\<co[D4,C2]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "5"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "12"}], "}"}], ",", "0", ",", "\"\<co[Q8,C2]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "14", ",", "30"}], " ", "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<P16\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8"}], "}"}], ",", "0", ",", "\"\<co[P4,C4]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "4"}], " ", "}"}], ",", 
       RowBox[{"{", " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "7", ",", "16"}], "}"}], ",", "\"\<co[Q8,C2,4]\>\"",
        ",", "\"\<co[clf[3],C2]\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KK\>\"", ",", 
       RowBox[{"{", "16.", "}"}], ",", "0", ",", "\"\<co[K,K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "6", ",", "8"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Oct\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "14"}], "}"}], ",", "0", ",", "\"\<Oct\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Sed\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15"}], ",", "1", ",", "120"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-1,-1,-1,-1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<r31r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "10", ",", "96"}], "}"}], ",", "16", ",", 
       "\"\<r31r\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<r31s\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "10", ",", "96"}], "}"}], ",", "16", ",", 
       "\"\<r31s\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<r31t\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "10", ",", "96"}], "}"}], ",", "16", ",", 
       "\"\<r31t\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<r31u\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "10", ",", "96"}], "}"}], ",", "16", ",", 
       "\"\<r31u\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10"}], ",", "6", ",", "112"}], "}"}], ",", "15", ",", 
       "\"\<clf[4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL31\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "10", ",", "112"}], "}"}], ",", "13", ",", 
       "\"\<clf[3,1]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL22\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "10", ",", "112"}], "}"}], ",", "13", ",", 
       "\"\<clf[2,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<CL13\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10"}], ",", "6", ",", "112"}], "}"}], ",", "15", ",", 
       "\"\<clf[1,3]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL04\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10"}], ",", "6", ",", "120"}], "}"}], ",", "0", ",", 
       "\"\<clf[0,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<PD16\>\"", ",", 
       RowBox[{"(*", 
        RowBox[{"Variation", " ", "on", " ", "CL04", "??"}], "*)"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10"}], ",", "6", ",", "118"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", 
          RowBox[{"-", "29"}], ",", 
          RowBox[{"-", "30"}], ",", "15"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<O8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8."}], ",", "8", ",", "64"}], "}"}], ",", "0", ",", 
       "\"\<cd[{1,1,1,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SuperscriptBox[\(C2\), \(5\)]\)r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "16."}], ",", "96"}], "}"}], ",", "0", ",", 
       "\"\<cd[{4.,1,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4KC2r\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8."}], ",", "8", ",", "112"}], "}"}], ",", "0", ",", 
       "\"\<cd[{4.,1,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C8Kr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", 
         SubscriptBox["4", "3"], ",", "96"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-4.,1,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D4Kr\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "12", ",", "70"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<O8a\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4."}], ",", 
         SubscriptBox["4", "3"], ",", "64"}], "}"}], ",", "0", ",", 
       "\"\<cd[{4,1,-1.}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D4M1n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "2"}], "}"}], ",", "0", ",", "\"\<md[D4]\>\"", ",",
        
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8M2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "6"}], "}"}], ",", "98", ",", "\"\<md[Q8]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", "\"\<cd[{1,-1,-1,{2}}]\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D4M4n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "6"}], "}"}], ",", "98", ",", 
       "\"\<md[D4,{1,2,3,8,5,6,7,4}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D4M5n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "10"}], "}"}], ",", "0", ",", 
       "\"\<md[Q8,{1,2,3,8,5,6,7,4}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "17", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C17\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "16"]}], "}"}], ",", "0", ",", "\"\<ca[17]\>\"", 
      ",", 
      RowBox[{"{", "17", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "18", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<D9\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "8"]}], "}"}], ",", "6", ",", "\"\<ca[18,17]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a8b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "28"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C18\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "8"]}], "}"}], ",", "5", ",", "\"\<ca[18]\>\"", 
       ",", 
       RowBox[{"{", "18", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "23"}], "}"}], ",", 
       RowBox[{"{", "31", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "23"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D3C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "6"], ",", 
         SubscriptBox["4", "2"]}], "}"}], ",", "0", ",", "\"\<co[D3,C3]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "11"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<E18\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "8"]}], "}"}], ",", "6", ",", 
       "\"\<co[C3,ca[6,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10", ",", "11"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "32"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C6C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "8"]}], "}"}], ",", "5", ",", 
       "\"\<co[C3C2,C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "17"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "19"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "19", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C19\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "18"]}], "}"}], ",", "0", ",", "\"\<ca[19]\>\"", 
      ",", 
      RowBox[{"{", "19", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "20", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<Q20\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "4"], ",", "10"}], "}"}], ",", "0", ",", 
       "\"\<ca[20,9]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "18"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C20\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "9"]}], "}"}], ",", "0", ",", "\"\<ca[20]\>\"", 
       ",", 
       RowBox[{"{", "20", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "17"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<g2003\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["1", "4"], ",", 
         SubscriptBox["2", "5"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       
       RowBox[{"{", 
        RowBox[{"5", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", "\"\<pe[{{1,6,5,4,2,3},{1,3,4,5,2,6}}]\>\""}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D10\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["2", "4"]}], "}"}], ",", "0", ",", "\"\<ca[20,19]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a9b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"-", "18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "29"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C10C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "4"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[10],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"-", "18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "29"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "25"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D5Mn\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["1", "4"]}], "}"}], ",", "0", ",", 
       "\"\<md[ca[10,9]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "21", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<g2101\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         SubscriptBox["1", "20"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[7],C3,7]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C21\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "20"]}], "}"}], ",", "0", ",", "\"\<ca[21]\>\"", 
       ",", 
       RowBox[{"{", "21", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "24"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "20"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "22", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<D11\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["1", "10"]}], "}"}], ",", "0", ",", "\"\<ca[22,21]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"11", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a10b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C22\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "10"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[11],C2]\>\"", ",", 
       RowBox[{"{", "22", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "23", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C23\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "22"]}], "}"}], ",", "0", ",", "\"\<ca[23]\>\"", 
      ",", 
      RowBox[{"{", "23", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "24", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C3iC8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "5"], ",", 
         SubscriptBox["6", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[C3,C8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "35"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "26"}], " ", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C24\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "11"]}], "}"}], ",", "0", ",", "\"\<ca[24]\>\"", 
       ",", 
       RowBox[{"{", "24", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "27"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "22"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<SL23\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abcd\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "14"}], "}"}], ",", 
       "\"\<pe[{{{3,7,5},{4,8,6}},{{1,5,2,6},{3,8,4,7}},{{1,3,2,4},{5,7,6,8}},\
{{1,2},{3,4},{5,6},{7,8}}}]\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q24\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "4"], ",", "14"}], "}"}], ",", "0", ",", 
       "\"\<ca[24,11]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "15"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "27"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D3C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "4"], ",", "8"}], "}"}], ",", "0", ",", 
       "\"\<co[D3,C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "46"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"27", ",", "29"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["2", "5"]}], "}"}], ",", "0", ",", "\"\<ca[24,23]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a11b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"34", ",", "39", ",", "40"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12,5],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "19"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "8", ",", "16"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3iC4iC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["4", "2"], ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<co[C3,C4,C2,2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5bc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "20"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "19"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<C3C4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "5"]}], "}"}], ",", "0", ",", 
       "\"\<co[C3C4,C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "17"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "27"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D4C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "3"], ",", 
         SubscriptBox["6", "2"]}], "}"}], ",", "0", ",", "\"\<co[D4,C3]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "27"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "3"]}], "}"}], ",", "0", ",", "\"\<co[Q8,C3]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<S4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "8"], ",", 
         SubscriptBox["2", "3"]}], "}"}], ",", "0", ",", "\"\<sgroup[4]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<a2d\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<cd\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<bd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "11"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "9"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<A4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "8"]}], "}"}], ",", "0", ",", "\"\<co[A4a,C2]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "20"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "9"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D6C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12,11],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"-", "9"}], ",", "18"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3KC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "2"]}], "}"}], ",", "0", ",", "\"\<co[C3K,C2]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "19"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Alt12nC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[cd[{-1,-1,{3}}],C2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D3C2Mn\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "2"]}], "}"}], ",", "0", ",", "\"\<md[D3C2]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<A4Mn\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["1", "8"]}], "}"}], ",", "0", ",", "\"\<md[A4]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12M3n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["2", "2"], ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<md[Q12]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12M4n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "2"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<md[Q12,{1,3,2,4,5,6,7,9,8,10,11,12}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12M5n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", "18"}], "}"}], ",", "0", ",", 
       "\"\<Q12M5n\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "25", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C25\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "24"]}], "}"}], ",", "9", ",", "\"\<ca[25]\>\"", 
       ",", 
       RowBox[{"{", "25", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C5C5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "24"]}], "}"}], ",", "9", ",", 
       "\"\<co[ca[5],ca[5]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "5"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "26", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<D13\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["1", "12"]}], "}"}], ",", "0", ",", "\"\<ca[26,25]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a12b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C26\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "12"]}], "}"}], ",", "0", ",", "\"\<ca[26]\>\"", 
       ",", 
       RowBox[{"{", "26", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "27", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C27\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "26"]}], "}"}], ",", "8", ",", "\"\<ca[27]\>\"", 
       ",", 
       RowBox[{"{", "27", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C9C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "26"]}], "}"}], ",", "8", ",", 
       "\"\<co[ca[9],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "28"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "23"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<P27\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         SubscriptBox["1", "26"]}], "}"}], ",", "10", ",", "\"\<ca[]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "9"}], " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "10"}], " ", "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g2704\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         SubscriptBox["1", "26"]}], "}"}], ",", "10", ",", "\"\<ca[]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3^3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "26"]}], "}"}], ",", "8", ",", 
       "\"\<co[C3C3,C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "12", ",", "32"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "28", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<Q28\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "6"], ",", "14"}], "}"}], ",", "0", ",", 
       "\"\<ca[28,13]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a6b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "21"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C28\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "13"]}], "}"}], ",", "0", ",", "\"\<ca[28]\>\"", 
       ",", 
       RowBox[{"{", "28", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "24"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "20"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D14\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["2", "6"]}], "}"}], ",", "0", ",", "\"\<ca[28,27]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a13b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"-", "21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "30"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C14C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "6"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[14],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"-", "21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "30"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "20"}]}], "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "29", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C29\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "28"]}], "}"}], ",", "0", ",", "\"\<ca[29]\>\"", 
      ",", 
      RowBox[{"{", "29", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "30", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<D3C5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "10"], ",", 
         SubscriptBox["4", "4"]}], "}"}], ",", "0", ",", "\"\<ca[30,11]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "28"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D5C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["1", "12"], ",", 
         SubscriptBox["6", "2"]}], "}"}], ",", "0", ",", "\"\<ca[30,19]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "19"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D15\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["1", "14"]}], "}"}], ",", "0", ",", "\"\<ca[30,29]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a14b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C30\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "14"]}], "}"}], ",", "0", ",", "\"\<ca[30]\>\"", 
       ",", 
       RowBox[{"{", "30", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "29"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "25"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "31", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C31\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "30"]}], "}"}], ",", "0", ",", "\"\<ca[31]\>\"", 
      ",", 
      RowBox[{"{", "31", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "32", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C32\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "15"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[32]\>\"", ",", 
       RowBox[{"{", "32", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3202\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "19"}], "}"}], ",", "11", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C8C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "7"], ",", "7"}], "}"}], ",", "0", ",", 
       "\"\<co[C8,C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "27"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "22"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C8pC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", "7"}], "}"}], ",", "0", ",", 
       "\"\<co[C8,C4,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KiC8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", "11"}], "}"}], ",", "14", 
       ",", "\"\<co[K,C8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "35"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "25"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g3206\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "5"], ",", "23"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "13"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<g3207\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "5"], ",", "15"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "37"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<g3208\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "4"], ",", "12", ",", "7"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<ace\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "->", "\"\<bde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D4iC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "3"], ",", "8", ",", "19"}], "}"}], ",", "0", ",", 
       "\"\<co[D4,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a3bc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "17"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8iC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"], ",", "8", ",", "12", ",", "11"}], "}"}], ",",
        "0", ",", "\"\<co[Q8,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "->", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<ace\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "->", "\"\<bce\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3211\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", "11"}], "}"}], ",", "14", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "29"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "26"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "12"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<C4iC8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "3"], ",", 
         SubscriptBox["8", "2"], ",", "7"}], "}"}], ",", "0", ",", 
       "\"\<co[C4,C8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"34", ",", "35"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8pC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "3"], ",", 
         SubscriptBox["8", "2"], ",", "11"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[8,5],C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C8iC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "3"], ",", "16", ",", "11"}], "}"}], ",", "0", 
       ",", "\"\<co[C8,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "17"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "27"}], " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "22"}], " ", "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3215\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "3"], ",", 
         SubscriptBox["8", "2"], ",", "3"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "->", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C16C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "7"], ",", "3"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[16],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3217\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", "3"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a9b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D16\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", 
         SubscriptBox["2", "7"], ",", "9"}], "}"}], ",", "0", ",", 
       "\"\<ca[32,31]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a15b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q16iC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["2", "6"], ",", "10", ",", "9"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[16,7],C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q32\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "6"], ",", "18", ",", "9"}], "}"}], ",", "0", ",", 
       "\"\<ca[32,15]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<de\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<acd\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "->", "\"\<ade\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "->", "\"\<bde\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "->", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4C4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "3"], ",", "19"}], "}"}], ",", "0", ",", 
       "\"\<co[C4,C4,C2,1]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "12", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<KiC4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "2"], ",", "43"}], "}"}], ",", "0", ",", 
       "\"\<co[K,C4C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "9", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "4", ",", "12"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4iC4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8", ",", "16", ",", "19"}], "}"}], ",", "17", ",", 
       "\"\<co[C4,C4,C2,1,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C2C4pC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "19"}], "}"}], ",", "11", ",", 
       "\"\<co[co[C2,C4],C4,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<abcc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D4C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "2"], ",", "12", ",", "23"}], "}"}], ",", "18", 
       ",", "\"\<co[ca[8,7],C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "9", ",", "12"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "5", ",", "12"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", 
         SubscriptBox["12", "2"], ",", "15"}], "}"}], ",", "19", ",", 
       "\"\<co[Q8,C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<P32\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "3"], ",", "47"}], "}"}], ",", "0", ",", 
       "\"\<co[K,K,C2,2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5", ",", "34"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "7"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KiD4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "2"], ",", "27"}], "}"}], ",", "0", ",", 
       "\"\<co[K,D4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ac3\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "9"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5", ",", "12"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KiQ8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8", ",", "16", ",", "19"}], "}"}], ",", "17", " ", 
       ",", "\"\<co[K,Q8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ade\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "14", ",", "30"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g3230\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "2"], ",", "12", ",", "23"}], "}"}], ",", "18", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3231\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "2"], ",", "12", ",", "23"}], "}"}], ",", "18", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C4a\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", 
         SubscriptBox["12", "2"], ",", "15"}], "}"}], ",", "19", " ", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3233\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "19"}], "}"}], ",", "11", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "->", "\"\<de\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4iD4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "3"], ",", "31"}], "}"}], ",", "0", " ", ",", 
       "\"\<co[C4,D4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<b3c\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a3c\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "9"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4iQ8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"], ",", "20", ",", "15"}], "}"}], ",", "0", 
       ",", "\"\<co[C4,Q8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "14", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C8K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "3"], ",", "11"}], "}"}], ",", "0", ",", 
       "\"\<co[C8,K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "26"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "22"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C2C8pC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "11"}], "}"}], ",", "0", ",", 
       "\"\<co[C2,ca[8],C2,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "15", ",", "26"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "21"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3238\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "7"}], "}"}], ",", "99", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D4iK\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "3"], ",", "27"}], "}"}], ",", "0", " ", ",", 
       "\"\<co[D4,K,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "3", ",", "22"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4", ",", "22"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8iK\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "2"], ",", "12", ",", "19"}], "}"}], ",", "0", 
       ",", "\"\<co[Q8,K,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q16C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"], ",", "20", ",", "11"}], "}"}], ",", "0", " ",
        ",", "\"\<co[ca[16,7],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3242\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "2"], ",", "12", ",", "11"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abe\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3243\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "2"], ",", "8", ",", "19"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a5c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g3244\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "2"], ",", "16", ",", "11"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abe\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4KC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16.", ",", "16", ",", "43"}], "}"}], ",", "0", ",", 
       "\"\<co[C4,K,C2,1]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "6", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D4K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "8", ",", "67"}], "}"}], ",", "0", ",", 
       "\"\<co[D4,K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "6", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "15"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "24", ",", "19"}], "}"}], ",", "0", ",", 
       "\"\<co[Q8,K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "8", ",", "13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "4", ",", "15", ",", "36"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<PC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "16", ",", "27"}], "}"}], ",", "0", " ", ",", 
       "\"\<co[co[Q8,C2,4],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "4", ",", "6"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "7", ",", "29", ",", "30"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL31C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "12", ",", "39"}], "}"}], ",", "0", ",", 
       "\"\<co[clf[3,1],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ed\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4", ",", "5", ",", "7"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "20", ",", "15"}], "}"}], ",", "0", ",", 
       "\"\<co[clf[4],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abe\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ade\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bde\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "29", ",", "30", ",", "31"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KKC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32.", ",", "155"}], "}"}], ",", "0", ",", 
       "\"\<co[K,co[K,C2]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL5?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20"}], ",", "12", ",", "3"}], "}"}], ",", "0", ",", 
       "\"\<clf[5]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<CL32\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12"}], ",", "20", ",", "17"}], "}"}], ",", "0", ",", 
       "\"\<clf[3,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL41?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "16"}], ",", "16", ",", "7"}], "}"}], ",", "0", ",", 
       "\"\<clf[4,1]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"4", ",", "28", ",", "15"}], "}"}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,C2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctsC2n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["4", "2"], ",", "14", ",", "9"}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,C2,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<P16M\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "16", ",", "15"}], "}"}], ",", "0", ",", 
       "\"\<md[co[P4,C4],{1,10,11,12,5,14,15,16,9,2,3,4,13,6,7,8}]\>\"", ",", 
       
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C8pC2M\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "7"}], "}"}], ",", "99", ",", 
       "\"\<md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KiC4M\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", "23"}], "}"}], ",", "0", ",", 
       "\"\<md[co[K,C4,2],{1,4,3,2,7,8,5,6,9,12,11,10,15,16,13,14}]\>\"", ",",
        
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C2M\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "12", ",", "31"}], "}"}], ",", "0", ",", 
       "\"\<md[co[Q8,C2]]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4iC4M\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "12", ",", "16", ",", "15"}], "}"}], ",", "0", ",", 
       "\"\<C4iC4M\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<O16\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "16."}], ",", "16", ",", "35"}], "}"}], ",", "0", ",", 
       "\"\<cd[{-1,1,1,1,1}]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "33", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C33\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "32"]}], "}"}], ",", "0", ",", "\"\<ca[33]\>\"", 
      ",", 
      RowBox[{"{", 
       RowBox[{"11", ",", "3"}], "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "34", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C34\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "16"]}], "}"}], ",", "0", ",", "\"\<ca[34]\>\"", 
       ",", 
       RowBox[{"{", "34", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D17\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", 
         SubscriptBox["1", "16"]}], "}"}], ",", "0", ",", "\"\<ca[34,33]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a16b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "35", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C35\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "34"]}], "}"}], ",", "0", ",", "\"\<ca[35]\>\"", 
      ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "5"}], "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"18", ",", "21"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"16", ",", "24"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"17", ",", "20"}], "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "36", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<Q36\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", "18"}], "}"}], ",", "26", ",", 
       "\"\<ca[36,17]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a8b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "23"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C36\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "17"]}], "}"}], ",", "23", ",", "\"\<ca[36]\>\"", 
       ",", 
       RowBox[{"{", "36", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "28"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "23"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<g3603\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["4", "2"]}], "}"}], ",", "27", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aaa\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<acd\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ac\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D18\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "8"]}], "}"}], ",", "25", ",", "\"\<ca[36,35]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a17b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"-", "23"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "31"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C18C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "8"]}], "}"}], ",", "24", ",", 
       "\"\<co[ca[18],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "31"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "23"}]}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["6", "3"]}], "}"}], ",", "0", ",", "\"\<co[Q12,C3]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "3"}], "}"}], "\[InvisibleSpace]", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "14"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3iQ12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", "18"}], "}"}], ",", "26", ",", 
       "\"\<co[C3,ca[12,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11", ",", "13"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C12C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "17"]}], "}"}], ",", "23", ",", 
       "\"\<co[ca[12],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11", ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "12", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "11", ",", "12"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3609\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "8"], ",", 
         SubscriptBox["2", "9"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<ac\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abb\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "13"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<D3D3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["1", "4"], ",", 
         SubscriptBox["4", "4"]}], "}"}], ",", "0", ",", "\"\<co[D3,D3]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", " ", ",", "2", " ", ",", "3", ",", " ", "2"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<c2d\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", "33"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<A4C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["4", "2"]}], "}"}], ",", "27", ",", 
       "\"\<co[A4a,C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "10", ",", "11"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D6C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "6"], ",", 
         SubscriptBox["8", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[D3C2,C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "19"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<E18C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "8"]}], "}"}], ",", "25", ",", 
       "\"\<co[ca[6],ca[6,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "18", ",", "32"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C6C6\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "8"]}], "}"}], ",", "24", ",", 
       "\"\<co[ca[6],ca[6]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "6"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "20"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8"}], ",", "19"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "37", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C37\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "36"]}], "}"}], ",", "0", ",", "\"\<ca[37]\>\"", 
      ",", 
      RowBox[{"{", "37", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "38", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C38\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "18"]}], "}"}], ",", "0", ",", "\"\<ca[38]\>\"", 
       ",", 
       RowBox[{"{", "38", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D19\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["1", "18"]}], "}"}], ",", "0", ",", "\"\<ca[38,37]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a18b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "39", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C39n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         SubscriptBox["1", "38"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"13", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C39\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "38"]}], "}"}], ",", "0", ",", "\"\<ca[39]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "40", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C40g9\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "9"], ",", 
         SubscriptBox["10", "2"]}], "}"}], ",", "0", ",", "\"\<ca[40,9]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "35"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "26"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C40\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "19"]}], "}"}], ",", "0", ",", "\"\<ca[40]\>\"", 
       ",", 
       RowBox[{"{", "40", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "27"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "22"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C40d\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "14"], ",", "10"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q40\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", "22"}], "}"}], ",", "0", ",", 
       "\"\<ca[40,19]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "14", ",", "18"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D5C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["2", "8"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[10,9],C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a9b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "12", ",", "18"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D20\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", 
         SubscriptBox["2", "9"]}], "}"}], ",", "0", ",", "\"\<ca[40,39]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a19b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "15", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C10iC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "4"], ",", "20"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[10],C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13", ",", "18"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KiD5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["4", "4"], ",", "10"}], "}"}], ",", "0", ",", 
       "\"\<co[K,ca[10,9],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<b3c\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "18"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C20C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "9"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[20],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         RowBox[{"-", "18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "29"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "25"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C40g31\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "5"], ",", 
         SubscriptBox["6", "4"]}], "}"}], ",", "0", ",", "\"\<ca[40,31]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"37", ",", "40"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "24"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "4"], ",", 
         SubscriptBox["6", "5"]}], "}"}], ",", "0", ",", "\"\<ca[40,11]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C40b\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["2", "4"], ",", 
         SubscriptBox["4", "5"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       
       RowBox[{"{", 
        RowBox[{"5", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D5K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["4", "4"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[10,9],K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6", ",", 
         RowBox[{"-", "18"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "29"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C10K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "4"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[10],K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "6", ",", 
         RowBox[{"-", "18"}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "25"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "41", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C41\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "40"]}], "}"}], ",", "0", ",", "\"\<ca[41]\>\"", 
      ",", 
      RowBox[{"{", "41", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "42", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C42\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "20"]}], "}"}], ",", "0", ",", "\"\<ca[42]\>\"", 
       ",", 
       RowBox[{"{", "42", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "30"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "20"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C42g13\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["1", "18"], ",", 
         SubscriptBox["8", "2"]}], "}"}], ",", "0", ",", "\"\<ca[42,13]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"21", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a13b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"21", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "24"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C42g29\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "14"], ",", 
         SubscriptBox["4", "6"]}], "}"}], ",", "0", ",", "\"\<ca[42,29]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D21\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", 
         SubscriptBox["1", "20"]}], "}"}], ",", "0", ",", "\"\<ca[42,41]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"21", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a20b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "24"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C42a\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["1", "6"], ",", 
         SubscriptBox["2", "14"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"7", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g2101C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "20"]}], "}"}], ",", "0", ",", 
       "\"\<co[co[ca[7],C3,7],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<baa\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "43", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C43\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "42"]}], "}"}], ",", "0", ",", "\"\<ca[43]\>\"", 
      ",", 
      RowBox[{"{", "43", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "44", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<Q44\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "10"], ",", "22"}], "}"}], ",", "0", ",", 
       "\"\<ca[44,21]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"11", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a10b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C44\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "21"]}], "}"}], ",", "0", ",", "\"\<ca[44]\>\"", 
       ",", 
       RowBox[{"{", "44", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D22\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["2", "10"]}], "}"}], ",", "0", ",", "\"\<ca[44,43]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a21b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C11K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "10"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[11],K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"11", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "45", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C45\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "44"]}], "}"}], ",", "30", ",", "\"\<ca[45]\>\"", 
       ",", 
       RowBox[{"{", "45", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "28"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "23"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C15C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "44"]}], "}"}], ",", "30", ",", 
       "\"\<co[ca[5],C3C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "12", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "11", ",", "17"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "46", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C46\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "22"]}], "}"}], ",", "0", ",", "\"\<ca[46]\>\"", 
       ",", 
       RowBox[{"{", "46", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D23\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["1", "22"]}], "}"}], ",", "0", ",", "\"\<ca[46,45]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"23", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a22b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "47", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C47\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "46"]}], "}"}], ",", "0", ",", "\"\<ca[47]\>\"", 
      ",", 
      RowBox[{"{", "47", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "48", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C3iC16\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "11"], ",", 
         SubscriptBox["6", "4"]}], "}"}], ",", "0", ",", "\"\<ca[48,41]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C48\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "23"]}], "}"}], ",", "0", ",", "\"\<ca[48]\>\"", 
       ",", 
       RowBox[{"{", "48", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g4803\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "32"], ",", 
         SubscriptBox["4", "3"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "->", "\"\<de\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "->", "\"\<abcd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<abe\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "->", "\"\<ade\>\""}], ",", 
         RowBox[{"\"\<ea\>\"", "->", "\"\<ad\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "12"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C8D3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["8", "3"]}], "}"}], ",", "33", ",", "\"\<co[C8,D3]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a17b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g4805\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["8", "3"]}], "}"}], ",", "33", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "->", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "->", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ea\>\"", "->", "\"\<aee\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], " ", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C24iC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["2", "10"], ",", "14"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[24,13],C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a11b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D24\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"26", ",", 
         SubscriptBox["2", "11"]}], "}"}], ",", "0", ",", "\"\<ca[48,47]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a23b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10", ",", "22"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "8", ",", "22"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q48\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "10"], ",", "26"}], "}"}], ",", "0", ",", 
       "\"\<ca[48,23]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "->", "\"\<cd\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "->", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<acd\>\""}], ",", 
         RowBox[{"\"\<ea\>\"", "->", "\"\<aee\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3iC8C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["12", "2"]}], "}"}], ",", "36", ",", 
       "\"\<co[ca[24,17],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "11"}], ",", "35"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "26"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C8pC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["12", "2"]}], "}"}], ",", "36", ",", 
       "\"\<co[C3,C8pC2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<b5c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "15", ",", "26"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["12", "2"]}], "}"}], ",", "36", ",", 
       "\"\<co[Q12,C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12iC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "4"], ",", "12", ",", "16"}], "}"}], ",", "0", 
       ",", "\"\<co[ca[12,5],C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bbbc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C4iQ12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[4],ca[12,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a11b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "13", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D6iC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "5"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12,11],C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a11bc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "15"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "8", ",", "12"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3iC8iC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", 
         SubscriptBox["2", "3"], ",", 
         SubscriptBox["6", "4"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[24,17],C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a7c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C3iQ8iC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "4"], ",", "14"}], "}"}], ",", "0", ",", 
       "\"\<co[C3,co[Q8,C2,2],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bbbc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8iD3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "5"]}], "}"}], ",", "0", ",", 
       "\"\<co[Q8,ca[6,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "->", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<acd\>\""}], ",", 
         RowBox[{"\"\<ea\>\"", "->", "\"\<aee\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "->", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g4818\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "4"], ",", "18"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}], ",", 
         RowBox[{"\"\<ea\>\"", "->", "\"\<aee\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "->", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KiQ12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", 
         SubscriptBox["12", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[K,ca[12,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5bc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "19"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C3C4C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "11"]}], "}"}], ",", "32", " ", ",", 
       "\"\<co[C3C4,C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "12", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KiC4C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "6"], ",", 
         SubscriptBox["8", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[C3,K,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "12", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "12"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4iC4iC3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["8", "3"]}], "}"}], ",", "0", ",", 
       "\"\<co[co[C4,C4,2],C3,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C24C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "11"]}], "}"}], ",", "32", ",", 
       "\"\<co[ca[24],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "22"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C8pC2C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "11"]}], "}"}], ",", "0", ",", 
       "\"\<co[C8pC2,C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[DoubleStruckCapitalJ]", " ", "2"}], ",", "29"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", "25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "11", ",", "21"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D8C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["2", "9"], ",", 
         SubscriptBox["10", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[16,15],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", "32"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", "33"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<Q8iC6\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "6"], ",", 
         SubscriptBox["6", "5"]}], "}"}], ",", "0", ",", 
       "\"\<co[Q8,C3C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q16C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["10", "3"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[16,7],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g4828\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "14"], ",", "18"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g4829\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["2", "14"], ",", "6"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "37"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<g4830\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["4", "3"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "->", "\"\<b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "->", "\"\<ae\>\""}], ",", 
         RowBox[{"\"\<ea\>\"", "\[Rule]", "\"\<ad\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<ce\>\""}], ",", 
         RowBox[{"\"\<ec\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<A4C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "16"], ",", "8"}], "}"}], ",", "37", ",", 
       "\"\<co[A4a,C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "46"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "26"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<SL23C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "8"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<co[SL23,C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abcd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g4833\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "16"], ",", "8"}], "}"}], ",", "37", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcde\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q24C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "4"], ",", "28"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[24,11],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13", ",", "15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "8", ",", "15", ",", "18", ",", "36"}], "}"}], ",", 
       
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C4D6\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "4"], ",", "16"}], "}"}], ",", "35", ",", 
       "\"\<co[C4,D3C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6", ",", "15"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D12C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["4", "5"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[24,23],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a11b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "15", ",", "18"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<P48\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "4"], ",", "16"}], "}"}], ",", "35", ",", 
       "\"\<co[C3,P16a,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<aac\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bde\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "5"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "14", ",", "27"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D4D3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "2"], ",", "8"}], "}"}], ",", "0", ",", 
       "\"\<co[D4,D3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ac3\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "27", ",", "29"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3iP16\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "2"], ",", "20"}], "}"}], ",", "0", ",", 
       "\"\<co[C3,P16i,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bde\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "14", ",", "27"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8D3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "2"], ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<co[Q8,D3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<abab\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ed\>\"", "\[Rule]", "\"\<dde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "27", ",", "30"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8pD3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "2"], ",", "12"}], "}"}], ",", "0", ",", 
       "\"\<co[Q8,D3,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "->", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}], ",", 
         RowBox[{"\"\<ea\>\"", "\[Rule]", "\"\<aee\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", "24"}], "}"}], ",", "0", ",", 
       "\"\<co[Q12,K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "4", ",", "8", ",", "36"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<KpD12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["8", "2"], ",", "12"}], "}"}], ",", "0", "  ", ",", 
       "\"\<co[K,ca[12,11],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5bc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6", ",", "19"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3C4K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "5"]}], "}"}], ",", "0", ",", "\"\<co[C3C4,K]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "16", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "15", ",", "17"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "12", ",", "19"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C4pC12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "3"], ",", 
         SubscriptBox["12", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[C4,ca[12,7],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "27"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C6\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["12", "3"]}], "}"}], ",", "0", ",", 
       "\"\<co[Q8,C3C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "12", ",", "13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<PC3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "5"]}], "}"}], ",", "0", ",", 
       "\"\<co[P16i,C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "6", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "12", ",", "15", ",", "19", ",", "36"}], "}"}], ",",
        
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<S4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["4", "3"]}], "}"}], ",", "0", " ", ",", 
       "\"\<co[pe[s4],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<a2d\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<cd\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<bd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "18"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<A4K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "8"]}], "}"}], ",", "0", ",", "\"\<co[A4a,K]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "18"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<g4850\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["1", "32"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ade\>\""}], ",", 
         RowBox[{"\"\<ea\>\"", "\[Rule]", "\"\<ad\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10", ",", "35"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D3KC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["8", "2"]}], "}"}], ",", "0", ",", "\"\<co[D3,KC2]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "6", ",", "19"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C6KC2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16.", ",", 
         SubscriptBox["16", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[6],K,C2,1]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "6", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "6", ",", "19"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctC3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["14", "3"]}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,C3]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<OctsC3n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "3"], ",", 
         SubscriptBox["4", "3"], ",", 
         SubscriptBox["14", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,C3,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<OctpC3n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "2"], ",", "30"}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,C3,3]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "49", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C49\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "48"]}], "}"}], ",", "38", ",", "\"\<ca[49]\>\"", 
       ",", 
       RowBox[{"{", "49", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C7C7\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "48"]}], "}"}], ",", "38", ",", 
       "\"\<co[ca[7],ca[7]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "7"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "50", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C50\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "24"]}], "}"}], ",", "39", ",", "\"\<ca[50]\>\"", 
       ",", 
       RowBox[{"{", "50", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C10C5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "24"]}], "}"}], ",", "39", ",", 
       "\"\<co[ca[10],ca[5]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "5"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D25\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"26", ",", 
         SubscriptBox["1", "24"]}], "}"}], ",", "40", ",", 
       "\"\<ca[50,49]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"25", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a24b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C5nD5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"26", ",", 
         SubscriptBox["1", "24"]}], "}"}], ",", "40", ",", 
       "\"\<co[ca[5],ca[10,9],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "5", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<b4c\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a4c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C5nC10\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["1", "20"], ",", 
         SubscriptBox["6", "4"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[5],ca[10],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "17"}], "}"}]}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "51", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C51\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "50"]}], "}"}], ",", "0", ",", "\"\<ca[51]\>\"", 
      ",", 
      RowBox[{"{", "51", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "52", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C52\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "25"]}], "}"}], ",", "0", ",", "\"\<ca[52]\>\"", 
       ",", 
       RowBox[{"{", "52", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D26\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["2", "12"]}], "}"}], ",", "0", ",", "\"\<ca[52,51]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"26", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a25b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q52\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "12"], ",", "26"}], "}"}], ",", "0", ",", 
       "\"\<ca[52,25]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a12b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C26C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "12"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[26],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"26", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C52a\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["1", "12"], ",", 
         SubscriptBox["2", "13"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"13", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "53", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C53\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "52"]}], "}"}], ",", "0", ",", "\"\<ca[53]\>\"", 
      ",", 
      RowBox[{"{", "53", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "54", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<D27\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["1", "26"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[54,53]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"27", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a26b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C54\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "26"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[54]\>\"", ",", 
       RowBox[{"{", " ", "54", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D9C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["10", "2"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[18,17],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a8b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"23", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "28"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C9D3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "18"], ",", 
         SubscriptBox["4", "8"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[9],D3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "33"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "23"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<D9C3a\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "20"], ",", 
         SubscriptBox["4", "6"], ",", "4"}], "}"}], ",", "42", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g5406\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "20"], ",", 
         SubscriptBox["4", "6"], ",", "4"}], "}"}], ",", "42", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ccc\>\"", "->", "\"\<dd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<accd\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<add\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D9nC3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["1", "26"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[C3,ca[18,17],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bbb\>\"", "\[Rule]", "\"\<dd\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abbd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<add\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "28"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<P54\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["10", "2"], ",", "13"}], "}"}], ",", "41", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "5", ",", "7"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C18C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "26"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[18],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "3"}], " ", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "31"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "23"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<Q54\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "26"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<co[P27,C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "20"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8"}], ",", "10"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g2704C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "26"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D3C3C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "18"], ",", 
         SubscriptBox["4", "8"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<co[D3,C3,C3,0]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "12", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "11"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<E18C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["10", "2"], ",", "13"}], "}"}], ",", "41", ",", 
       "\"\<co[co[C3,ca[6,5],2],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "7", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "8", ",", "11"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D27b\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["1", "26"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<aad\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bbd\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<ccd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C3^3C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "26"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<co[C3C3,C3,C2,1]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "17", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "11", ",", "19"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "55", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C55\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "54"]}], "}"}], ",", "0", ",", "\"\<ca[55]\>\"", 
       ",", 
       RowBox[{"{", "55", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g5502\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         SubscriptBox["1", "54"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"11", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a9b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "56", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C7nC8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "13"], ",", 
         SubscriptBox["14", "2"]}], "}"}], ",", "0", ",", "\"\<ca[56,13]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a6b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"21", ",", "35"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "26"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C56\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "27"]}], "}"}], ",", "0", ",", "\"\<ca[56]\>\"", 
       ",", 
       RowBox[{"{", "56", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"21", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "27"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "22"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C7nQ8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "12"], ",", "30"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[7],Q8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a6b\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "14", ",", "21"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q56\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["2", "12"], ",", "16"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[14,13],C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a13b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "12", ",", "21"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D28\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"30", ",", 
         SubscriptBox["2", "13"]}], "}"}], ",", "0", ",", "\"\<ca[56,55]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a27b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "15", ",", "24"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C14nC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "6"], ",", "28"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[14],C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a13b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13", ",", "21"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<KnD7\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", 
         SubscriptBox["4", "6"], ",", "14"}], "}"}], ",", "0", ",", 
       "\"\<co[K,ca[14,13],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a6b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "->", "\"\<bbbc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "21"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C2nC28\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "13"]}], "}"}], ",", "0", ",", 
       "\"\<co[C4,ca[14],4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "7", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         RowBox[{"-", "21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "30"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         RowBox[{"-", "20"}]}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<KnC14\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "7"], ",", 
         SubscriptBox["6", "6"]}], "}"}], ",", "0", ",", "\"\<ca[56,15]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "5", ",", "20"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C7\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "6"], ",", 
         SubscriptBox["6", "7"]}], "}"}], ",", "0", ",", "\"\<ca[56,43]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g5611\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["1", "48"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"7", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<adc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C14nK\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["4", "6"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[14],K,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a13b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6", ",", 
         RowBox[{"-", "21"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "30"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C14K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "6"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[14],K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "6", ",", 
         RowBox[{"-", "21"}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "6", ",", "20"}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "57", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<g5701\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         SubscriptBox["1", "56"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", 
        RowBox[{"19", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C57\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "56"]}], "}"}], ",", "0", ",", "\"\<ca[57]\>\"", 
       ",", 
       RowBox[{"{", "57", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "58", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C58\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "28"]}], "}"}], ",", "0", ",", "\"\<ca[58]\>\"", 
       ",", 
       RowBox[{"{", "58", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D29\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"30", ",", 
         SubscriptBox["1", "28"]}], "}"}], ",", "0", ",", "\"\<ca[58,57]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"29", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a28b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "59", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C59\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "58"]}], "}"}], ",", "0", ",", "\"\<ca[59]\>\"", 
      ",", 
      RowBox[{"{", "59", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "60", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C3iC20\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "14"], ",", 
         SubscriptBox["6", "5"]}], "}"}], ",", "0", ",", 
       "\"\<co[C3,ca[20],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q20C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "14"], ",", 
         SubscriptBox["10", "3"]}], "}"}], ",", "0", ",", "\"\<ca[60,49]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "4", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q60\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "14"], ",", "30"}], "}"}], ",", "0", ",", 
       "\"\<ca[60,29]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a14b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "13", ",", "18"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C60\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "29"]}], "}"}], ",", "0", ",", "\"\<ca[60]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "4", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "12", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "15", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "12", ",", "17"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<A5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["1", "44"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", "\"\<pe[{{1,4,2,6,3,5},{1,2,5,6,3,4}}]\>\""}],
       "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g6006\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["1", "12"], ",", 
         SubscriptBox["2", "15"], ",", 
         SubscriptBox["6", "2"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       
       RowBox[{"{", 
        RowBox[{"5", ",", "4", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g6007\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["1", "12"], ",", 
         SubscriptBox["6", "7"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       
       RowBox[{"{", 
        RowBox[{"15", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a8b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D10iC3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["1", "8"], ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["6", "2"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[30,19],C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a14b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a4c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<A4C5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "40"], ",", 
         SubscriptBox["4", "4"]}], "}"}], ",", "0", ",", 
       "\"\<co[A4a,ca[5]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "28"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C60g19\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["2", "12"], ",", 
         SubscriptBox["12", "2"]}], "}"}], ",", "0", ",", "\"\<ca[60,19]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "6", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "29"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C6iC10\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "10"], ",", 
         SubscriptBox["8", "4"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[6],ca[10],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"-", "28"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D30\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["2", "14"]}], "}"}], ",", "0", ",", "\"\<ca[60,59]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"30", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a29b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "18", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "29"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C30C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "14"]}], "}"}], ",", "0", ",", 
       "\"\<co[ca[30],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "18"}], ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", "29"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "25"}], "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",\

 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "61", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C61\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "60"]}], "}"}], ",", "0", ",", "\"\<ca[61]\>\"", 
      ",", 
      RowBox[{"{", "61", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "62", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C62\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "30"]}], "}"}], ",", "0", ",", "\"\<ca[62]\>\"", 
       ",", 
       RowBox[{"{", "62", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D31\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["1", "30"]}], "}"}], ",", "0", ",", "\"\<ca[62,61]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"31", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a30b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "63", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C63\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "62"]}], "}"}], ",", "29", ",", "\"\<ca[63]\>\"", 
       ",", 
       RowBox[{"{", "63", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"21", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "28"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "23"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<C7C3C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "62"]}], "}"}], ",", "29", ",", 
       "\"\<co[ca[7],C3C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "12", ",", "24"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "11", ",", "20"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g2101C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         SubscriptBox["1", "62"]}], "}"}], ",", "31", ",", 
       "\"\<co[co[ca[7],C3,7],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g6304\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         SubscriptBox["1", "62"]}], "}"}], ",", "31", ",", "\"\<ca[]\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "64", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C64\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "31"], ",", "32", ",", "0"}], "}"}], ",", "0", 
       ",", "\"\<ca[64]\>\"", ",", 
       RowBox[{"{", "64", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64002\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "15"], ",", "48", ",", "0"}], "}"}], ",", "0", 
       ",", "\"\<co[C8,C8]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64003\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "15"], ",", "48", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[C8,C8,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64004\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "8"], ",", 
         SubscriptBox["8", "2"], ",", "32", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "->", "\"\<adb\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64005\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "8"], ",", "8", ",", "16", ",", "32", ",", 
         "2688"}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64006\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "6"], ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "32", ",", "2304"}], "}"}], 
       ",", "0", ",", "\"\<co[D4,ca[8,5],2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"29", ",", "17"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8pC8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["8", "2"], ",", 
         SubscriptBox["12", "2"], ",", "32", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<co[Q8,C8,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64008\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["8", "4"], ",", "32", ",", "2880"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64009\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["8", "3"], ",", "16", ",", "40", ",", "2880"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64010\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "10"], ",", "12", ",", "32", ",", "2880"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64011\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "9"], ",", 
         SubscriptBox["12", "2"], ",", "32", ",", "2880"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64012\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "3"], ",", 
         SubscriptBox["8", "4"], ",", "32", ",", "2880"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64013\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["8", "4"], ",", "20", ",", "32", ",", "2880"}], "}"}], 
       ",", "47", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64014\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["8", "4"], ",", "20", ",", "32", ",", "2880"}], "}"}], 
       ",", "47", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64015\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", 
         SubscriptBox["8", "4"], ",", "48", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<co[ca[8,5],C8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64016\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", 
         SubscriptBox["16", "2"], ",", "48", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<co[C8,C8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"29", ",", "22"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64017\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "1536"}], "}"}], ",", "60", 
       ",", "\"\<co[C4C2,C8,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "16", ",", "22"}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "15", ",", "27"}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"5", ",", "12", ",", "22"}], "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64018\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "40", ",", "2688"}], "}"}], ",", "51", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64019\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "48", ",", "2688"}], "}"}], ",", "46", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64020\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "40", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<bc\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<ac\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "35"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64021\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "2304"}], "}"}], ",", "52", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3bc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64022\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "48", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64023\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "6"], ",", "48", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64024\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "5"], ",", "16", ",", "32", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64025\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64026\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "15"], ",", "32", ",", "0"}], "}"}], ",", "49", 
       ",", "\"\<co[C4,ca[16,9],4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64027\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "15"], ",", "32", ",", "1536"}], "}"}], ",", "50", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a9b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64028\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "15"], ",", "32", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64029\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "8"], ",", 
         SubscriptBox["8", "3"], ",", "32", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[K,ca[16],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64030\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "8"], ",", 
         SubscriptBox["8", "3"], ",", "32", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64031\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "8"], ",", 
         SubscriptBox["8", "3"], ",", "32", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64032\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "11"], ",", "28", ",", "3264"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64033\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "10"], ",", "12", ",", "36", ",", "3264"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64034\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "11"], ",", "44", ",", "3264"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64035\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "10"], ",", "12", ",", "52", ",", "3264"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "13"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64036\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "10"], ",", "12", ",", "32", ",", "3264"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64037\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "10"], ",", "20", ",", "32", ",", "3264"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64038\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "7"], ",", "16", ",", "20", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<co[ca[16,15],C4,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64039\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "6"], ",", "16", ",", "20", ",", "36", ",", 
         "2688"}], "}"}], ",", "0", ",", "\"\<co[ca[16,7],C4,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64040\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "6"], ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "24", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64041\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "6"], ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "28", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64042\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "7"], ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "3072"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64043\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "6"], ",", 
         SubscriptBox["8", "2"], ",", "20", ",", "24", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64044\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", 
         SubscriptBox["8", "4"], ",", "32", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[C4,ca[16],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64045\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", 
         SubscriptBox["8", "4"], ",", "32", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64046\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", 
         SubscriptBox["8", "4"], ",", "24", ",", "3072"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64047\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", "32", ",", "36", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<co[ca[16],C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a15b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64048\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", 
         SubscriptBox["16", "2"], ",", "36", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64049\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "7"], ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64050\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "15"], ",", "32", ",", "0"}], "}"}], ",", "49", 
       ",", "\"\<co[ca[32],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64051\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "15"], ",", "32", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a17b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64052\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"34", ",", 
         SubscriptBox["2", "15"], ",", "33", ",", "2880"}], "}"}], ",", "0", 
       ",", "\"\<ca[64,63]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a31b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64053\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", 
         SubscriptBox["2", "14"], ",", "18", ",", "18", ",", "2880"}], "}"}], 
       ",", "0", ",", "\"\<co[ca[32,15],C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a15b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64054\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "14"], ",", "34", ",", "34", ",", "2880"}], "}"}], 
       ",", "0", ",", "\"\<ca[64,31]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64055\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "7"], ",", "56", ",", "0"}], "}"}], ",", "0", ",", 
       "\"\<co[C4,C4,C4,1]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<f\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64056\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "48", ",", "1536"}], "}"}], ",", "69", 
       ",", "\"\<co[C4C2,C4C2,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64057\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "56", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<abcc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64058\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "48", ",", "1536"}], "}"}], 
       ",", "0", ",", "\"\<co[C4,K,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"7", ",", "13", ",", "30"}], "*)"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64059\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "56", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[C4,C4,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64060\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["8", "4"], ",", "32", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64061\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "48", ",", "2304"}], "}"}], ",", "68", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "->", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64062\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "48", ",", "2304"}], "}"}], 
       ",", "67", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64063\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "56", ",", "2304"}], "}"}], ",", "66", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64064\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "56", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64065\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "32", ",", "56", ",", "2304"}], "}"}], 
       ",", "62", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64066\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "3"], ",", "24", ",", "48", ",", "2304"}], "}"}], 
       ",", "0", ",", "\"\<co[K,C4,C4,2,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64067\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "3"], ",", "16", ",", "40", ",", "2304"}], "}"}], 
       ",", "64", ",", "\"\<co[K,K,C4,2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "->", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "->", "\"\<a3d\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64068\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "56", ",", "2304"}], "}"}], ",", "66", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64069\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "48", ",", "2304"}], "}"}], 
       ",", "67", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64070\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "24", ",", "56", ",", 
         "2304"}], "}"}], ",", "65", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<accc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64071\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "3"], ",", "16", ",", "40", ",", "2304"}], "}"}], 
       ",", "64", ",", "\"\<co[C4C2,D4,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64072\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "24", ",", "56", ",", 
         "2304"}], "}"}], ",", "65", ",", "\"\<co[C4C2,Q8,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64073\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["8", "4"], ",", "32", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64074\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "3"], ",", "24", ",", "48", ",", "2688"}], "}"}], 
       ",", "63", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64075\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "3"], ",", "16", ",", "40", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64076\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "32", ",", "56", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64077\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "48", ",", "2688"}], "}"}], ",", "68", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64078\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "48", ",", "2688"}], "}"}], 
       ",", "21", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64079\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "24", ",", "56", ",", 
         "2688"}], "}"}], ",", "65", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64080\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "3"], ",", "24", ",", "48", ",", "2688"}], "}"}], 
       ",", "63", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64081\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "56", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64082\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "56", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64083\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "0"}], "}"}], ",", "61", 
       ",", "\"\<co[C8,C4C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "12", ",", "22"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64084\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "1536"}], "}"}], ",", "60", 
       ",", "\"\<co[C8,C4C2,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64085\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "1536"}], "}"}], ",", "60", 
       ",", "\"\<co[C4,C8,C2,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64086\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "1536"}], "}"}], ",", "60", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "4", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<abcccc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64087\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "1536"}], "}"}], 
       ",", "0", ",", "\"\<co[K,C8,C2,1,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "3", ",", "4", ",", 
          RowBox[{"-", "14"}]}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "2", ",", "15", ",", "26"}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"5", ",", "7", ",", "12"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64088\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "2304"}], "}"}], 
       ",", "59", ",", "\"\<co[K,C8,C2,4,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64089\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "2304"}], "}"}], 
       ",", "59", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64090\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "5"], ",", "40", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64091\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "48", ",", "2688"}], "}"}], 
       ",", "21", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64092\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "5"], ",", "32", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "->", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64093\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "4"], ",", "24", ",", "32", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64094?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ac3\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64095\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "3"], ",", "16", ",", "24", ",", "2304"}], "}"}], 
       ",", "0", ",", "\"\<co[D4,C4,C2,1,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3bc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"2", ",", "13", ",", "22"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64096\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "24", ",", "40", ",", 
         "2304"}], "}"}], ",", "0", ",", "\"\<co[Q8,C4C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64097\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "2304"}], "}"}], 
       ",", "59", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64098\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "2"], ",", 
         SubscriptBox["16", "2"], ",", "32", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64099\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "5"], ",", "24", ",", "2688"}], "}"}], ",", "72", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64100\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "4"], ",", "24", ",", "40", ",", "2688"}], "}"}], 
       ",", "58", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64101\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "2304"}], "}"}], 
       ",", "59", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ad3\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ac3\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "26", ",", "29"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64102?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "2688"}], "}"}], 
       ",", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64103\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "32", ",", "1536"}], "}"}], ",", "28", 
       ",", "\"\<co[C2,C4,C8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64104\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "32", ",", "2304"}], "}"}], ",", "28", 
       ",", "\"\<co[C4,C8,C2,4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ac3\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64105\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "32", ",", "2304"}], "}"}], ",", "28", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64106\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "2304"}], "}"}], ",", "52", 
       ",", "\"\<co[ca[8,5],C4C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64107\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", "32", ",", "40", ",", "2304"}], "}"}], 
       ",", "0", ",", "\"\<co[C8,C4C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13", ",", "17"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "13", ",", "27"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "16", ",", "22"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64108\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "2304"}], "}"}], ",", "52", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64109\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "4"], ",", "24", ",", "40", ",", "2688"}], "}"}], 
       ",", "58", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a5c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64110\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "48", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64111\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "3"], ",", 
         SubscriptBox["16", "2"], ",", "48", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64112\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[co[C2,C4],C8,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64113\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "2304"}], "}"}], ",", "62", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64114\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "2304"}], "}"}], ",", "62", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64115\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "3"], ",", "32", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[D4,C8]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"2", ",", "5", ",", "22"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64116?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "3"], ",", "32", ",", "2304"}], "}"}], ",", "34", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64117?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "3"], ",", "32", ",", "2304"}], "}"}], ",", "34", 
       ",", "\"\<co[C8,D4,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64118\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "28", ",", "2304"}], "}"}], 
       ",", "0", ",", "\"\<co[C4,C8,C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "12", ",", "22"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64119\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "3"], ",", "36", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<co[C4,Q8,C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64120\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["20", "2"], ",", "44", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<co[ca[16,7],C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64121\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "5"], ",", "12", ",", "20", ",", "36", ",", 
         "2688"}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a5c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64122\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "2"], ",", "20", ",", "44", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64123\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["12", "2"], ",", "28", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a3c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64124\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "3"], ",", "32", ",", "2304"}], "}"}], ",", "34", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64125\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "3"], ",", "32", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "3"], ",", 
         SubscriptBox["12", "4"], ",", "32", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[Q8,C8]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8pC8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "3"], ",", 
         SubscriptBox["12", "4"], ",", "32", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<co[C8,Q8,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64128\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["8", "2"], ",", "31", ",", "2880"}], "}"}], ",", "0", 
       ",", "\"\<co[K,C8,C2,2,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64129\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", "24", ",", "32", ",", 
         "2880"}], "}"}], ",", "70", ",", "\"\<co[Q8,K,C2,2,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64130\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", "16", ",", "24", ",", 
         "2880"}], "}"}], ",", "71", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64131\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", "16", ",", "24", ",", 
         "2880"}], "}"}], ",", "71", ",", "\"\<co[K,Q8,C2,2,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64132\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", "32", ",", "40", ",", 
         "2880"}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64133\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", "24", ",", "32", ",", 
         "2880"}], "}"}], ",", "70", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64134\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["4", "6"], ",", "12", ",", "27", ",", "3072"}], "}"}], 
       ",", "54", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64135\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "28", ",", "3072"}], "}"}], 
       ",", "53", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"3", ",", "12", ",", "17"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"4", ",", "7", ",", "12"}], "*)"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64136\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "28", ",", "3072"}], "}"}], 
       ",", "53", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64137\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "6"], ",", "28", ",", "36", ",", "3072"}], "}"}], 
       ",", "73", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64138\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["4", "6"], ",", "12", ",", "36", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "4"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64139\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "44", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "13", ",", "30"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64140\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "27", ",", "2880"}], "}"}], 
       ",", "0", ",", "\"\<co[D4,D4,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8pD4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", 
         SubscriptBox["12", "2"], ",", "28", ",", "2880"}], "}"}], ",", "0", 
       ",", "\"\<co[Q8,D4,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64142\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "20", ",", "36", ",", 
         "2880"}], "}"}], ",", "74", ",", "\"\<co[C4,Q8,C2,2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ac3\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64143?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "28", ",", "44", ",", 
         "2880"}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64144\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", 
         SubscriptBox["12", "2"], ",", "28", ",", "56"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64145\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "20", ",", "36", ",", 
         "2880"}], "}"}], ",", "74", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64146?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64147\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "3"], ",", "16", ",", "24", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<co[C8,C4,C2,2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ac7\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "22"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64148\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "24", ",", "40", ",", 
         "2688"}], "}"}], ",", "0", ",", "\"\<co[K,ca[16,7],2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64149\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "2"], ",", 
         SubscriptBox["16", "2"], ",", "32", ",", "3072"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64150\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "5"], ",", "24", ",", "3072"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64151\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "4"], ",", "24", ",", "40", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64152\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "4"], ",", "16", ",", "32", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64153\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "5"], ",", "32", ",", "3072"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64154\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "4"], ",", "24", ",", "32", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D4nQ8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["8", "2"], ",", "28", ",", "36", ",", "2880"}], "}"}], 
       ",", "0", ",", "\"\<co[D4,Q8,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8pQ8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["8", "2"], ",", 
         SubscriptBox["12", "2"], ",", "20", ",", "44", ",", "2880"}], "}"}], 
       ",", "75", ",", "\"\<co[Q8,Q8,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64157\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "20", ",", "36", ",", 
         "2880"}], "}"}], ",", "74", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64158?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "28", ",", "44", ",", 
         "2880"}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64159\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "4", ",", 
         SubscriptBox["8", "2"], ",", "12", ",", "20", ",", "36", ",", 
         "2880"}], "}"}], ",", "74", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64160\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["8", "2"], ",", 
         SubscriptBox["12", "2"], ",", "20", ",", "44", ",", "2880"}], "}"}], 
       ",", "75", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64161\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", "24", ",", "32", ",", 
         "2880"}], "}"}], ",", "70", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64162\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "32", ",", "2880"}], "}"}], 
       ",", "76", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64163\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "32", ",", "2880"}], "}"}], 
       ",", "76", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64164\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "2880"}], "}"}], ",", "77", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64165\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "4"], ",", "16", ",", "24", ",", "40", ",", 
         "2880"}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64166\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["4", "4"], ",", "8", ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "2880"}], "}"}], ",", "77", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64167\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "28", ",", "2688"}], "}"}], 
       ",", "57", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64168\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["20", "2"], ",", "44", ",", "2688"}], "}"}], ",", "78", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64169\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "3"], ",", "36", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64170\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "5"], ",", "12", ",", "20", ",", "36", ",", 
         "3072"}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64171\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["12", "2"], ",", "28", ",", "3072"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64172\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "4"], ",", 
         SubscriptBox["12", "2"], ",", "20", ",", "44", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64173\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "28", ",", "2688"}], "}"}], 
       ",", "57", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a3c\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<b3c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64174\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"36", ",", 
         SubscriptBox["4", "7"], ",", "35", ",", "2688"}], "}"}], ",", "79", 
       ",", "\"\<co[C4,ca[16,15],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "8", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a3c\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<b7c\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "16", ",", "22"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64175\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "6"], ",", "36", ",", "44", ",", "2688"}], "}"}], 
       ",", "80", ",", "\"\<co[C4,ca[16,7],2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"13", ",", "14", ",", "17"}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"13", ",", "14", ",", "27"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64176\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "28", ",", "2688"}], "}"}], 
       ",", "57", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64177\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["4", "6"], ",", "12", ",", "27", ",", "3072"}], "}"}], 
       ",", "54", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64178\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "6"], ",", "28", ",", "36", ",", "3072"}], "}"}], 
       ",", "73", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64179\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["20", "2"], ",", "44", ",", "2688"}], "}"}], ",", "78", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64180\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", 
         SubscriptBox["20", "2"], ",", "44", ",", "2688"}], "}"}], ",", "78", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64181\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "6"], ",", "36", ",", "44", ",", "2688"}], "}"}], 
       ",", "80", ",", "\"\<co[C8,Q8,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "14", ",", "17"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64182\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "5"], ",", "12", ",", "28", ",", "44", ",", 
         "3072"}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64183\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "0"}], "}"}], ",", "61", 
       ",", "\"\<co[K,ca[16],4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64184\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "1536"}], "}"}], ",", "60", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a9b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64185\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "7"], ",", "32", ",", "1536"}], "}"}], ",", "60", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64186\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"36", ",", 
         SubscriptBox["4", "7"], ",", "35", ",", "2688"}], "}"}], ",", "79", 
       ",", "\"\<co[ca[32,31],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a15b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64187\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "20", ",", "2688"}], "}"}], 
       ",", "81", ",", "\"\<co[ca[16,9],K,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64188\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "6"], ",", "36", ",", "36", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<co[ca[32,15],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<de\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ade\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bde\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64189\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["4", "6"], ",", "20", ",", "20", ",", "2688"}], "}"}], 
       ",", "81", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64190\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["4", "6"], ",", "12", ",", "27", ",", "3072"}], "}"}], 
       ",", "54", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a15b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a7c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64191\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "6"], ",", "28", ",", "28", ",", "3072"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<de\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ade\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bde\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}], ",", 
         RowBox[{"\"\<ff\>\"", "->", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<fa\>\"", "->", "\"\<afe\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64192\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16.", ",", 
         SubscriptBox["16", "3"], ",", "48", ",", "0"}], "}"}], ",", "0", 
       ",", "\"\<co[C4C2,C4C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "4", ",", "4"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64193\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["16", "2"], ",", "32", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[K,K,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abce\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "2", ",", "3", ",", "6", ",", "9"}], "*)"}], "}"}],
        ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64194\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "16", ",", "32", ",", "48", ",", "1536"}], "}"}], 
       ",", "0", ",", "\"\<co[K,C4,C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "8", ",", "13", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "3", ",", "4", ",", "13", ",", "14"}], "*)"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "3", ",", "4", ",", "13", ",", "14"}], "*)"}], 
        "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64195\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "48", ",", "1536"}], "}"}], ",", "69", 
       ",", "\"\<co[C2,co[C2,C4],C4,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abcc\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64196\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "40", ",", "1536"}], "}"}], 
       ",", "0", ",", "\"\<co[C4C2,D4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"2", ",", "13", ",", "14", ",", "16"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"1", ",", "2", ",", "7", ",", "30"}], "*)"}], "}"}]}], "}"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8", ",", 
         SubscriptBox["24", "2"], ",", "56", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[Q8,C4C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64198\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "48", ",", "1536"}], "}"}], ",", "69", 
       ",", "\"\<co[co[P4,C4],C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<acd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64199\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "8", ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "1920"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64200\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["16", "2"], ",", "24", ",", "56", ",", "1920"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ed\>\"", "->", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64201\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "16", ",", "8", ",", "16", ",", "24", ",", "48", ",", "1920"}], "}"}],
        ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<adc\>\""}], ",", 
         RowBox[{"\"\<ed\>\"", "->", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64202\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"40", ",", 
         SubscriptBox["8", "3"], ",", "39", ",", "2304"}], "}"}], ",", "82", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acd\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"6", ",", "8", ",", "9", ",", "22"}], "*)"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "4", ",", "5", ",", "34"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64203\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["16", "2"], ",", "32", ",", "2304"}], "}"}], ",", "0", 
       ",", "\"\<co[C2,K,D4,2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ac3\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64204\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "16", ",", "32", ",", "48", ",", "2304"}], "}"}], 
       ",", "0", ",", "\"\<co[K,co[Q8,C2],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ade\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64205\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "40", ",", "2304"}], "}"}], 
       ",", "83", ",", "\"\<co[K,Q8,C2,4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64206\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "40", ",", "2304"}], "}"}], 
       ",", "83", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64207\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "40", ",", "2304"}], "}"}], 
       ",", "83", ",", "\"\<co[C4,co[P4,C4],2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64208\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8", ",", 
         SubscriptBox["24", "2"], ",", "56", ",", "2304"}], "}"}], ",", "84", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64209\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "48", ",", "2304"}], "}"}], ",", "68", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<de\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64210\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "48", ",", "2304"}], "}"}], ",", "68", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64211\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"40", ",", 
         SubscriptBox["8", "3"], ",", "39", ",", "2304"}], "}"}], ",", "82", 
       ",", "\"\<co[C2,C4,D4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<b3c\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a3c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64212\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", "40", ",", "56", ",", "2304"}], "}"}], 
       ",", "0", ",", "\"\<co[C2,C4,Q8,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "13", ",", "14", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64213\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "40", ",", "2304"}], "}"}], 
       ",", "83", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64214\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8", ",", 
         SubscriptBox["24", "2"], ",", "56", ",", "2304"}], "}"}], ",", "84", 
       ",", "\"\<co[co[C2,C4],Q8,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64215\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "32", ",", "2688"}], "}"}], 
       ",", "85", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64216\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "32", ",", "2688"}], "}"}], 
       ",", "85", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64217\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "2"], ",", "32", ",", "48", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64218\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "16", ",", "24", ",", "40", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64219\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "8", ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "2688"}], "}"}], ",", "87", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64220?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "16", ",", "8", ",", "16", ",", "24", ",", "48", ",", "2688"}], "}"}],
        ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64221\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "8", ",", 
         SubscriptBox["16", "2"], ",", "40", ",", "2688"}], "}"}], ",", "87", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64222\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["16", "2"], ",", "24", ",", "56", ",", "2688"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64223?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "16", ",", "8", ",", "16", ",", "24", ",", "48", ",", "2688"}], "}"}],
        ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64224\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["24", "2"], ",", "48", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64225\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8", ",", "16", ",", "32", ",", "56", ",", "2688"}],
         "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64226\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"36", ",", "4", ",", 
         SubscriptBox["12", "2"], ",", "35", ",", "2496"}], "}"}], ",", "0", 
       ",", "\"\<co[D4,D4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<c3d\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64227\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "28", ",", "4", ",", "12", ",", "20", ",", "36", ",", "2496"}], "}"}],
        ",", "86", ",", "\"\<co[K,P16i,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64228\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "20", ",", "4", ",", "12", ",", "28", ",", "44", ",", "2496"}], "}"}],
        ",", "88", ",", "\"\<co[C4,P16i,-2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64229\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "20", ",", "4", ",", "12", ",", "28", ",", "44", ",", "2496"}], "}"}],
        ",", "88", ",", "\"\<co[D4,D4,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8D4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "12", ",", "4", ",", "12", ",", "36", ",", "52", ",", "2496"}], "}"}],
        ",", "0", ",", "\"\<co[Q8,D4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ed\>\"", "\[Rule]", "\"\<d3e\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64231\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "28", ",", "4", ",", "12", ",", "20", ",", "36", ",", "2496"}], "}"}],
        ",", "86", ",", "\"\<co[Q8,D4,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64232\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["12", "2"], ",", "20", ",", "44", ",", "2496"}], "}"}], 
       ",", "89", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64233?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "12", ",", 
         SubscriptBox["20", "2"], ",", "52", ",", "2496"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64234?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["12", "2"], ",", "20", ",", "44", ",", "2496"}], "}"}], 
       ",", "89", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64235\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "12", ",", "4", ",", "20", ",", "28", ",", "52", ",", "2496"}], "}"}],
        ",", "0", ",", "\"\<co[D4,Q8,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"2", ",", "4", ",", "5", ",", "11"}], "*)"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64236?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["12", "2"], ",", "20", ",", "44", ",", "2496"}], "}"}], 
       ",", "89", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64237?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "12", ",", 
         SubscriptBox["20", "2"], ",", "52", ",", "2496"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8pQ8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "4", ",", "12", ",", "20", ",", "28", ",", "60", ",", "2496"}], "}"}],
        ",", "0", ",", "\"\<co[Q8,Q8,4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8Q8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["12", "2"], ",", "36", ",", "60", ",", "2496"}], "}"}], 
       ",", "0", ",", "\"\<co[Q8,Q8]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<f\>\""}], ",", 
         RowBox[{"\"\<ee\>\"", "\[Rule]", "\"\<f\>\""}], ",", 
         RowBox[{"\"\<ed\>\"", "\[Rule]", "\"\<def\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64240\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["12", "2"], ",", "20", ",", "44", ",", "2496"}], "}"}], 
       ",", "89", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64241\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["12", "3"], ",", "36", ",", "2880"}], "}"}], ",", "90", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64242\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"28", ",", 
         SubscriptBox["12", "3"], ",", "36", ",", "2880"}], "}"}], ",", "90", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64243\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "4", ",", 
         SubscriptBox["20", "2"], ",", "44", ",", "2880"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64244\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["12", "2"], ",", "28", ",", "52", ",", "2880"}], "}"}], 
       ",", "0", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64245\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["20", "3"], ",", "60", ",", "2880"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64246\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16.", ",", 
         SubscriptBox["16", "3"], ",", "32", ",", "0"}], "}"}], ",", "0", 
       ",", "\"\<co[C8,K,C2,1]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "8"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "6", ",", "8", ",", "22"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64247\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "32", ",", "1536"}], "}"}], ",", "91", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64248\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "32", ",", "1536"}], "}"}], ",", "91", 
       ",", "\"\<co[C2,C8,K,4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64249\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["16", "3"], ",", "32", ",", "1920"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64250?\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"40", ",", 
         SubscriptBox["8", "3"], ",", "39", ",", "2304"}], "}"}], ",", "82", 
       ",", "\"\<co[C2,D4,K,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64251\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "24", ",", "2304"}], "}"}], 
       ",", "92", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64252\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["8", "2"], ",", "40", ",", "40", ",", "2304"}], "}"}], 
       ",", "0", ",", "\"\<co[ca[16,7],K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64253\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "24", ",", "2304"}], "}"}], 
       ",", "92", ",", "\"\<co[C2,Q8,K,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64254\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "31", ",", "2688"}], "}"}], 
       ",", "93", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a5c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64255\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "2"], ",", "32", ",", "32", ",", "2688"}], "}"}], 
       ",", "95", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abe\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64256\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "24", ",", "2688"}], "}"}], 
       ",", "94", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64257\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["8", "2"], ",", "16", ",", "31", ",", "2688"}], "}"}], 
       ",", "93", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64258\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "24", ",", "2688"}], "}"}], 
       ",", "94", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64259\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["8", "2"], ",", "32", ",", "32", ",", "2688"}], "}"}], 
       ",", "95", ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g64260\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32.", ",", "32", ",", "32", ",", "0"}], "}"}], ",", "0", 
       ",", "\"\<co[C4C2,KC2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "6", ",", "8", ",", "16"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64261\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"48", ",", "16", ",", "47", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[D4,KC2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "6", ",", "8", ",", "9"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64262\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "48", ",", "48", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[Q8,KC2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g64263\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", "32", ",", "32", ",", "1536"}], "}"}], ",", "0", 
       ",", "\"\<co[co[P4,C4],K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<fd\>\"", "\[Rule]", "\"\<def\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "4", ",", "6", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "15", ",", "36"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL32C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"40", ",", "24", ",", "39", ",", "1920"}], "}"}], ",", "0", 
       ",", "\"\<co[clf[3,2],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ed\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL5C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "40", ",", "40", ",", "1920"}], "}"}], ",", "0", 
       ",", "\"\<co[clf[5],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abe\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ace\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<ade\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bde\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<CL41C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", "32", ",", "32", ",", "1920"}], "}"}], ",", "0", 
       ",", "\"\<co[clf[4,1],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
         RowBox[{"\"\<fd\>\"", "\[Rule]", "\"\<def\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<KKK\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"64.", ",", "63", ",", "0"}], "}"}], ",", "0", ",", 
       "\"\<co[K,K,K,1]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<CL6\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "36"}], ",", "28", ",", "36", ",", "2016"}], "}"}], ",",
        "0", ",", "\"\<clf[6]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctC4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", 
         SubscriptBox["28", "2"], ",", "60", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<co[Oct,C4]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctsC4n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["8", "3"], ",", "28", ",", "36", ",", "3008"}], "}"}], 
       ",", "0", ",", "\"\<co[Oct,C4,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctK\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "56", ",", "56", ",", "2688"}], "}"}], ",", "0", 
       ",", "\"\<co[Oct,K]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctsKn\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["8", "2"], ",", "28", ",", "28", ",", "3008"}], "}"}], 
       ",", "0", ",", "\"\<co[Oct,K,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "65", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<g6501\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "64"]}], "}"}], ",", "0", ",", "\"\<ca[65]\>\"", 
      ",", 
      RowBox[{"{", 
       RowBox[{"13", ",", "5"}], "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "66", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<g6601\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["1", "22"], ",", 
         SubscriptBox["4", "10"]}], "}"}], ",", "0", ",", "\"\<ca[66,23]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "11"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g6602\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         SubscriptBox["1", "30"], ",", 
         SubscriptBox["12", "2"]}], "}"}], ",", "0", ",", "\"\<ca[66,43]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"11", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a10b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D33\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"34", ",", 
         SubscriptBox["1", "32"]}], "}"}], ",", "0", ",", "\"\<ca[66,65]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"33", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a32b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g6604\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "32"]}], "}"}], ",", "0", ",", "\"\<ca[66]\>\"", 
       ",", 
       RowBox[{"{", "66", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "67", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C67\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "66"]}], "}"}], ",", "0", ",", "\"\<ca[67]\>\"", 
      ",", 
      RowBox[{"{", "67", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "68", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<Q68\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "16"], ",", "34"}], "}"}], ",", "0", ",", 
       "\"\<ca[68,33]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a16b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C68\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "33"]}], "}"}], ",", "0", ",", "\"\<ca[68]\>\"", 
       ",", 
       RowBox[{"{", "68", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g6803\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", 
         SubscriptBox["1", "16"], ",", 
         SubscriptBox["2", "17"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",",
        
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<D34\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"36", ",", 
         SubscriptBox["2", "16"]}], "}"}], ",", "0", ",", "\"\<ca[68,67]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"34", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a33b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C17K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "16"]}], "}"}], ",", "0", ",", "\"\<ca[68,35]\>\"",
        ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "69", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<g6901\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "68"]}], "}"}], ",", "0", ",", "\"\<ca[69]\>\"", 
      ",", 
      RowBox[{"{", "69", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "70", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<g7001\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["1", "28"], ",", 
         SubscriptBox["6", "6"]}], "}"}], ",", "0", ",", "\"\<ca[70,29]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g7002\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["1", "30"], ",", 
         SubscriptBox["8", "4"]}], "}"}], ",", "0", ",", "\"\<ca[70,41]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D35\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"36", ",", 
         SubscriptBox["1", "34"]}], "}"}], ",", "0", ",", "\"\<ca[70,69]\>\"",
        ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "18", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "16", ",", "24"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C70\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "34"]}], "}"}], ",", "0", ",", "\"\<ca[70]\>\"", 
       ",", 
       RowBox[{"{", "70", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "18"}], ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "30"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "25"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "71", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C71\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "70"]}], "}"}], ",", "0", ",", "\"\<ca[71]\>\"", 
      ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "72", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<g7201\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "17"], ",", 
         SubscriptBox["18", "2"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[72,53]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"23", ",", "35"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"26", ",", "28"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C72\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "35"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[72]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "8"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"25", ",", "33"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", "23"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<g7203\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "26"], ",", 
         SubscriptBox["6", "3"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q72\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "16"], ",", "38", ",", "1"}], "}"}], ",", "0", 
       ",", "\"\<ca[72,35]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "14", ",", "23"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D9C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "16"], ",", "20", ",", "1"}], "}"}], ",", "0", 
       ",", "\"\<co[ca[18,17],C4,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a8b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "12", ",", "23"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D36\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"38", ",", 
         SubscriptBox["2", "17"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[72,71]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"36", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a35b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "15", ",", "28"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q36C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "8"], ",", "36", ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[36,17],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a8b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13", ",", "23"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<KnD9\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", 
         SubscriptBox["4", "8"], ",", "18", ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[36,17],C2,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"18", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a17bc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "23"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C9C4C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "17"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[36],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "4", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "31"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", 
         RowBox[{"-", "23"}]}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D4C9\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "9"], ",", 
         SubscriptBox["6", "8"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[72,7]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5", ",", "33"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C9\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["6", "9"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[72,19]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g7212\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "17"], ",", 
         SubscriptBox["6", "6"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[3],ca[8],ca[3],3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "24"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"29", ",", "33"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "21"}], "}"}]}], "}"}], "\[InvisibleSpace]", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SuperscriptBox[\(C3\), \(2\)]\)nC8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "17"], ",", 
         SubscriptBox["18", "2"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[C3,ca[24,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", " ", ",", "3", ",", " ", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bbc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<aac\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "26", ",", "32"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SuperscriptBox[\(C8C3\), \(2\)]\)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.", ",", 
         SubscriptBox["2", "35"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[24],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "12", ",", "27"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "11", ",", "22"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g7215\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["6", "3"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g3603C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "24"], ",", 
         SubscriptBox["8", "2"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D9K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"40", ",", 
         SubscriptBox["4", "8"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[18,17],K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a8b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6", ",", 
         RowBox[{"-", "23"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "31"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C9\!\(\*FormBox[SuperscriptBox[\"C2\", \"3\"],
TraditionalForm]\)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "8"], ",", "1"}], "}"}], ",", "0", ",", 
       "\"\<co[C2,ca[36,19]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "6", ",", 
         RowBox[{"-", "23"}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "5", ",", "6", ",", "23"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g7219\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "26"], ",", "18", ",", "4"}], "}"}], ",", "0", 
       ",", "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "->", "\"\<acc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12D3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "6"], ",", 
         SubscriptBox["6", "2"], ",", 
         SubscriptBox["8", "2"], ",", "24", ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12,5],D3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "->", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<ccd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "27"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g7221\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["6", "4"], ",", "12", ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[C3,co[ca[6,5],C4,2],2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "27"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<g7222\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["2", "4"], ",", 
         SubscriptBox["8", "4"], ",", "18", ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "8", ",", "16"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12nD3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"26", ",", 
         SubscriptBox["2", "6"], ",", 
         SubscriptBox["6", "3"], ",", 
         SubscriptBox["8", "2"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12,5],D3,2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "3", ",", "2"}], "}"}], "\[InvisibleSpace]", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<a11c\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "7", ",", "8"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g7224\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["6", "4"], ",", "30", ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "15", ",", "16"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<SL23C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "26"], ",", 
         SubscriptBox["6", "3"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<co[SL23,C3]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q24C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "14"], ",", 
         SubscriptBox["14", "3"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[24,11],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "13", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "14", ",", "30"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D3C3C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "12"], ",", 
         SubscriptBox["8", "5"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[D3,C3,C4,1]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "6", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "46"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C4nD3C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["2", "15"], ",", 
         SubscriptBox["14", "2"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[co[C4,D3,2],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a11b\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "15", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "39", ",", "40"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<Q12C3C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "8"], ",", 
         SubscriptBox["12", "3"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12,5],C3C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "4", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "->", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"13", ",", "18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "19"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"\"\<g7230\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["4", "6"], ",", 
         SubscriptBox["6", "3"], ",", 
         SubscriptBox["10", "2"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12,7],ca[6],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5bc\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "32"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "19"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<C3nQ24\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "16"], ",", "38", ",", "4"}], "}"}], ",", "0", 
       ",", "\"\<co[C3,ca[24,11],2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"11", ",", "13", ",", "15"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<E18C4\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "16"], ",", "20", ",", "4"}], "}"}], ",", "0", 
       ",", "\"\<co[co[C3,ca[6,5],2],C4]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "11", ",", "15"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C12nD3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"38", ",", 
         SubscriptBox["2", "17"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12],ca[6,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "12", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<b11c\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<aac\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "5", ",", "11"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "8", ",", "15", ",", "32"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<C6nQ12\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["4", "8"], ",", "36", ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[6],ca[12,5],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "13", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "8", ",", "18", ",", "32", ",", "36"}], "}"}], ",", 
       
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g7235\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", 
         SubscriptBox["4", "8"], ",", "18", ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[12,7],ca[6,5],2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "11", ",", "20"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g7236\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4.", ",", 
         SubscriptBox["4", "17"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "12", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "15", ",", "17"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "12", ",", "19"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<D4C3C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", 
         SubscriptBox["2", "9"], ",", 
         SubscriptBox["6", "8"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[C3,ca[24,7]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "2", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Q8C3C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["6", "9"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[24,19],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g7239\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "8"], ",", 
         SubscriptBox["2", "27"], ",", "a_"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<P72\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", 
         SubscriptBox["2", "9"], ",", 
         SubscriptBox["4", "8"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "7", ",", "8"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<g7241\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "8"], ",", 
         SubscriptBox["6", "9"], ",", "a_"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<S4C3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["2", "9"], ",", 
         SubscriptBox["10", "2"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<co[sgroup[4],C3]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}], ",", 
         RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<a2d\>\""}], ",", 
         RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<cd\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<bd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"\"\<g7243\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"22", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["4", "2"], ",", 
         SubscriptBox["6", "3"], ",", "a_"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<A4D3\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["1", "16"], ",", 
         SubscriptBox["4", "10"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<co[A4a,ca[6,5]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}], ",", 
         RowBox[{"\"\<ed\>\"", "\[Rule]", "\"\<dde\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g7245\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "8"], ",", 
         SubscriptBox["4", "9"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<ca[]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "3", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "->", "\"\<acc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "8"}], ",", "13"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SuperscriptBox[\(D3\), \(2\)]\)C2\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"32", ",", 
         SubscriptBox["2", "4"], ",", 
         SubscriptBox["8", "4"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[co[ca[6,5],ca[6,5]],C2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "->", "\"\<a2b\>\""}], ",", 
         RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<ccd\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<A4C6\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "24"], ",", 
         SubscriptBox["8", "2"], ",", "13"}], "}"}], ",", "0", ",", 
       "\"\<co[A4a,ca[6]]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}], ",", 
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", "21"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "10", ",", "11"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<g7248\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", 
         SubscriptBox["4", "6"], ",", 
         SubscriptBox["16", "2"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[ca[6],ca[12,7],2]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "18", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "7", ",", "19"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<E18K\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"40", ",", 
         SubscriptBox["4", "8"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[co[C3,ca[6,5],2],K]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "5", ",", "19"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "18", ",", "32"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SuperscriptBox[\(C3\), \(2\)]\)\!\(\*SuperscriptBox[\(C2\), \
\(3\)]\)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"8.", ",", 
         SubscriptBox["8", "8"], ",", "4"}], "}"}], ",", "0", ",", 
       "\"\<co[C3C3,K,C2,1]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "19", ",", "20"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "18", ",", "22"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "8"}], ",", "19"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "73", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<C73\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", 
        SubscriptBox["1", "72"]}], "}"}], ",", "0", ",", "\"\<ca[73]\>\"", 
      ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "74", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<D34\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"38", ",", 
        SubscriptBox["1", "36"]}], "}"}], ",", "0", ",", "\"\<ca[74,73]\>\"", 
      ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\"\<C74\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"2.", ",", 
      SubscriptBox["2", "36"]}], "}"}], ",", "0", ",", "\"\<ca[74]\>\"", ",", 
    
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", "}"}]}], "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "75", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<C3C25\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "74"]}], "}"}], ",", "4", ",", 
       "\"\<co[ca[5],ca[5],C3,1]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<C75\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", 
         SubscriptBox["1", "74"]}], "}"}], ",", "4", ",", "\"\<ca[75]\>\"", 
       ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "80", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<OctC5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "4"], ",", 
         SubscriptBox["14", "5"]}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,C5]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctC5n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "70"}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,C5n]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<OctsC5n\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "6"], ",", 
         SubscriptBox["4", "6"], ",", 
         SubscriptBox["14", "3"]}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,C5,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "96", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<P48C2?\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"32", ",", 
        SubscriptBox["8", "4"], ",", "32"}], "}"}], ",", "0", ",", 
      "\"\<co[co[C3,P16a,2],C2]\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
        RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<aac\>\""}], ",", 
        RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bce\>\""}], ",", 
        RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bde\>\""}], ",", 
        RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<cde\>\""}]}], "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "104", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<g104003\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        SubscriptBox["2", "38"], ",", "26"}], "}"}], ",", "0", ",", 
      "\"\<ca[]\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"13", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "120", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<S5\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"26", ",", 
         SubscriptBox["1", "24"], ",", 
         SubscriptBox["2", "35"]}], "}"}], ",", "0", ",", "\"\<sgroup[5]\>\"",
        ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<SL25\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "44"], ",", "30"}], "}"}], ",", "0", ",", 
       "\"\<pe[{{1,3,5,7,9,6,12,14,15,17,19,8,11,4,2,13,23,18,22,24,21,16,20,\
10},\n{2,4,6,8,10,11,13,3,16,18,20,21,22,23,5,9,19,7,1,17,24,12,14,15}},120]\>\
\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "144", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<P144?\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"52", ",", 
        SubscriptBox["4", "4"], ",", 
        SubscriptBox["6", "4"], ",", 
        SubscriptBox["10", "4"], ",", "12"}], "}"}], ",", "0", ",", 
      "\"\<ca[]\>\"", ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "168", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<SL32?\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"22", ",", 
        SubscriptBox["1", "104"], ",", 
        SubscriptBox["2", "21"]}], "}"}], ",", "0", ",", "\"\<ca[]\>\"", ",", 
      
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "256", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<CL8\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "120"}], ",", "136", ",", "32512"}], "}"}], ",", "0", 
       ",", "\"\<clf[8]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<OctOctn\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["28", "2"], ",", "196"}], "}"}], ",", "0", ",", 
       "\"\<co[Oct,Oct]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<OctsOctn\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         SubscriptBox["16", "2"], ",", "28", ",", 
         SubscriptBox["32", "2"], ",", "44", ",", "84"}], "}"}], ",", "0", 
       ",", "\"\<co[Oct,Oct,2]\>\"", ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"loop", "[", 
    RowBox[{"[", "257", "]"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\"\<Unrecognised\>\"", ",", 
      RowBox[{"{", "}"}], ",", "0", ",", "\"\<Unrecognised\>\"", ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "6 Creating Polar-Vector & Hyperbolic functions."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[TextData[{
 "Standard Rules for ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"toPol", ",", " ", "toVec", ",", " ", "toHyPol"}],
    FontSlant->"Italic"], TraditionalForm]]],
 " & ",
 StyleBox["toHyVec",
  FontSlant->"Italic"],
 " synthesis.\n1. Sum of 2 squares  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a1", "2"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a1", "\[PlusMinus]", "a2"}], "+"}], ".."}], ")"}], "2"], 
   TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b1", "2"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"b1", "\[PlusMinus]", "b2"}], "+"}], ".."}], ")"}], "2"], 
   TraditionalForm]]],
 "; s2=",
 Cell[BoxData[
  FormBox["a1", TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox["b1", TraditionalForm]]],
 ",\nInclude s2 in the toPol output, followed by \[Theta]=If[b1==0,If[a1==0,\
\[Pi],0],ArcTan[a1,b1]]\nIn toVec, calculate s= m",
 Cell[BoxData[
  FormBox[
   SqrtBox["s2"], TraditionalForm]]],
 ", where m is the required weighting.\nSet up the result list, with an entry \
for each of {a1,a2,..b1,b2,..}, divided by ",
 StyleBox["mm",
  FontSlant->"Italic"],
 ", the number of elements. Add \[PlusMinus]s Cos[\[Theta]] wherever \
\[PlusMinus]ai occurs, \[PlusMinus]s Sin[\[Theta]] wherever \[PlusMinus]bi \
occurs.\n2. Sum of 3 squares ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a1", "2"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "\[PlusMinus]", "b"}], "+"}], ".."}], ")"}], "2"], 
   TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b1", "2"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"h", "\[PlusMinus]", "i"}], "+"}], ".."}], ")"}], "2"], 
   TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["c1", "2"], "=", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "\[PlusMinus]", "q"}], "+"}], ".."}], ")"}], "2"]}], 
   TraditionalForm]]],
 ",s3=(a1+b1+c1)/2.\n They all have the 2 divisor. Include s3, followed by \
\[Theta] =If[b1=0, 0, ArcTan[a1-c1, -",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 " b1]]. Start toVec in the same way, but add \[PlusMinus]s Cos[\[Theta]] \
wherever \[PlusMinus]ai occurs, \[PlusMinus]s Cos[\[Theta]+2\[Pi]/3] wherever \
\[PlusMinus]bi occurs, \[PlusMinus]s Cos[\[Theta]-2\[Pi]/3] wherever \
\[PlusMinus]ci occurs.\n3. Difference of 2 squares  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a1", "2"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a1", "\[PlusMinus]", "a2"}], "+"}], ".."}], ")"}], "2"], 
   TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b1", "2"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"b1", "\[PlusMinus]", "b2"}], "+"}], ".."}], ")"}], "2"], 
   TraditionalForm]]],
 "; s2=",
 Cell[BoxData[
  FormBox["a1", TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox["b1", TraditionalForm]]],
 ",\n Include s2 in the toHyPol output, followed by \
\[Theta]=If[b1==0,If[a1==0,\[Pi],0], arcTanh[a1,b1]]. Note that this must be \
my 2-argument version, NOT ArcTanh[a1/b1].\n In toVec, calculate s= m",
 Cell[BoxData[
  FormBox[
   SqrtBox["s2"], TraditionalForm]]],
 ", where m is the required ?? weighting.\n Set up the result list, with an \
entry for each of {a1,a2,..b1,b2,..}, divided by ",
 StyleBox["mm",
  FontSlant->"Italic"],
 ", the number of elements. Add \[PlusMinus]s Cosh[\[Theta]] wherever \
\[PlusMinus]ai occurs, \[PlusMinus]s Sinh[\[Theta]] wherever \[PlusMinus]bi \
occurs."
}], "Text",
 PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "7 Shapes, Polar-Vector, Hyperbolics, ",
 StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
  FontSlant->"Italic"],
 "for 2, 3, & 4 element loops."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C2\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "-", "b"}], ",", 
        RowBox[{"a", "+", "b"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "-", "y"}], ",", 
     RowBox[{"x", "+", "y"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "+", "y"}], ",", 
      RowBox[{"y", "-", "x"}]}], "}"}], "/", "2"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}], ",", 
      RowBox[{"arcTanh", "[", 
       RowBox[{"a", ",", "b"}], "]"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"uu_", ",", "\[Phi]_"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ":=",
    
   RowBox[{"Chop", "[", 
    RowBox[{
     SqrtBox["uu"], " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
       RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}], ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_"}], "}"}], ",", "\"\<C4c\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_"}], "}"}], ",", "\"\<C4c\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox["x"], " ", 
      RowBox[{"Cos", "[", "y", "]"}]}], ",", 
     RowBox[{
      SqrtBox["x"], " ", 
      RowBox[{"Sin", "[", "y", "]"}]}]}], "}"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "2", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "c", ",", "b"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"strictly", ",", " ", 
        RowBox[{"shape", " ", "should", " ", "be", " ", 
         RowBox[{"symdiff", "^", "2"}]}], ",", " ", 
        RowBox[{"not", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], "^", "2"}], " ", 
         RowBox[{"etc", "."}]}]}], "*)"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", "b", "+", "c"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b"}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "c"}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"c", "-", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
         "2"}]}], "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], ",", "\"\<C3\>\""}], "]"}],
    ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "^", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "^", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}]}], ")"}], "/", "2"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", "*", "a"}], "-", "b", "-", "c"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], "*", 
        RowBox[{"(", 
         RowBox[{"b", "-", "c"}], ")"}]}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]_", ",", "rr_", ",", "\[Theta]_"}], "}"}], ",", 
     "\"\<C3\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "-", 
           RowBox[{"2", "*", 
            RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}]}], "}"}], "/", "3"}], 
    "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3C2c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "2"}], ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "b"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "-", "b", "+", "c"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b"}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "+", "c"}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"c", "-", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
         "2"}]}], "}"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], ",", "\"\<C3C2c\>\""}], 
    "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", "b", "+", "c"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], "^", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}], "^", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}]}], ")"}], "/", "2"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", "*", "a"}], "+", "b", "-", "c"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], "*", 
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}]}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]_", ",", "rr_", ",", "\[Theta]_"}], "}"}], ",", 
     "\"\<C3C2c\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], "-", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "-", 
           RowBox[{"2", "*", 
            RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}]}], "}"}], "/", "3"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C12c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"3", " ", "\[ImaginaryI]"}], ",", 
         RowBox[{"2", " ", "\[ImaginaryI]"}], ",", "1", ",", "1"}], "}"}]}], 
      ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", 
         RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ",", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", 
              RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[ImaginaryI]", " ", "b"}], "+", "c"}], ")"}], "2"]}], 
          ")"}], "/", "2"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], ",", "\"\<C12c\>\""}], 
    "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", 
      RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", 
           RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "b"}], "+", "c"}], ")"}], "2"]}], 
       ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", "*", "a"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "b"}], "+", "c"}], ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "3", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "b"}], "+", "c"}], ")"}]}]}], "]"}]}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]_", ",", "rr_", ",", "\[Theta]_"}], "}"}], ",", 
     "\"\<C12c\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "-", 
             RowBox[{"2", "*", 
              RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], ")"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], ")"}]}]}], "}"}], "/", 
     "3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3i\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], ",", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}], ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "-", 
         RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ",", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", 
              RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ")"}], "2"], 
           "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"c", "+", "a"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], ",", "\"\<C3i\>\""}], 
    "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", 
      RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", 
           RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ")"}], "2"], "+", 
        
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "+", "a"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", "*", "a"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "b"}], "+", "c"}], ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "3", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "b"}], "+", "c"}], ")"}]}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]_", ",", "rr_", ",", "\[Theta]_"}], "}"}], ",", 
     "\"\<C3i\>\""}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "-", 
             RowBox[{"2", "*", 
              RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], ")"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], ")"}]}]}], "}"}], "/", 
     "3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4C3c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "2"}], ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "==", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", 
         RowBox[{"\[ImaginaryI]", " ", "b"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "c"}]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", 
              RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", 
              RowBox[{"\[ImaginaryI]", " ", "c"}]}], ")"}], "^", "2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "c"}], ")"}], "^", "2"}]}], ")"}], "/", 
         "2"}]}], "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], ",", "\"\<C4C3c\>\""}], 
    "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", 
      RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", 
           RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ")"}], "2"], "+", 
        
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "+", "a"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", "*", "a"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "b"}], "+", "c"}], ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "3", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "b"}], "+", "c"}], ")"}]}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]_", ",", "rr_", ",", "\[Theta]_"}], "}"}], ",", 
     "\"\<C4C3c\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "-", 
             RowBox[{"2", "*", 
              RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], ")"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "rr", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], ")"}]}]}], "}"}], "/", 
     "3"}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C9j\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "2", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}], " ", "-",
         
        RowBox[{"3", " ", "a", " ", "b", " ", "c"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3C3j\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"3", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", 
         RowBox[{"2", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", "1", ",", 
         "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", 
          RowBox[{"b", " ", 
           SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "+", 
          RowBox[{"c", " ", 
           SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], ")"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", 
              RowBox[{"b", "  ", 
               SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], ")"}], "^",
             "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"b", " ", 
               SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "-", 
              RowBox[{"c", " ", 
               SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], ")"}], "^",
             "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"c", " ", 
               SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "-", "a"}], 
             ")"}], "^", "2"}]}], ")"}], "/", "2"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C9J\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"3", 
          RowBox[{"\[DoubleStruckCapitalJ]", "^", "2"}]}], ",", 
         RowBox[{"2", 
          RowBox[{"\[DoubleStruckCapitalJ]", "^", "2"}]}], ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{
         SuperscriptBox["c", "3"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "-", 
        RowBox[{
        "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}]}],
        "}"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "4", ",", "3", ",", "2", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1", ",", "0."}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", " ", 
         RowBox[{"-", "b"}], ",", " ", "c", ",", 
         RowBox[{"-", " ", "d"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ",", 
        RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d"}], ")"}], "2"]}]}], "}"}]}]}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "d"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["d", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "c"}]}], ")"}], "2"]}], "*)"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
     "\"\<C4\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ",", 
     RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "d"}], ")"}], "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "c"}], ",", 
       RowBox[{"b", "-", "d"}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Beta]_", ",", "\[Epsilon]\[Epsilon]_", ",", 
       "\[Sigma]_"}], "}"}], ",", "\"\<C4\>\""}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", "\[IndentingNewLine]",
       
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}]}], "}"}], "/", "4"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
     "\"\<C4\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "+", "d"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{"arcTanh", "[", 
       RowBox[{
        RowBox[{"a", "+", "c"}], ",", 
        RowBox[{"b", "+", "d"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "-", "d"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"a", "-", "c"}], ",", 
        RowBox[{"b", "-", "d"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tohyVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"uu_", ",", "\[Phi]_", ",", "rr_", ",", "\[Theta]_"}], "}"}], 
    ",", "\"\<C4\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r", "=", 
       RowBox[{"Sqrt", "[", "rr", "]"}]}], ",", 
      RowBox[{"u", "=", 
       RowBox[{"Sqrt", "[", "uu", "]"}]}]}], "}"}], ",", 
    RowBox[{"Chop", "[", 
     RowBox[{
      RowBox[{"r", "*", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "}"}], "/", "2"}]}], 
      "+", 
      RowBox[{"u", "*", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}], ",", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "}"}], "/", "2"}]}]}], 
     "]"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sh", "[", "\"\<K\>\"", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "4", ",", "1", ",", "1", ",", "1", ",", 
        "1"}], "}"}]}], ";", 
     RowBox[{"gp", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
     RowBox[{"plex", "=", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", " ", "b"}], ",", " ", 
        RowBox[{"-", "c"}], ",", "d"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ",", 
       RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
       RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ",", 
       RowBox[{"a", "+", "b", "+", "c", "+", "d"}]}], "}"}]}]}], 
   RowBox[{"(*", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["d", "2"]}], ")"}], "2"], "-", 
     RowBox[{"4", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "d"}], "-", 
         RowBox[{"b", " ", "c"}]}], ")"}], "2"]}]}], "*)"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
     "\"\<K\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ",", 
     RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
     RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ",", 
     RowBox[{"a", "+", "b", "+", "c", "+", "d"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"o1_", ",", "o2_", ",", "o3_", ",", "o4_"}], "}"}], ",", 
    "\"\<K\>\""}], "]"}], ":=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"o1", "+", "o2", "+", "o3", "+", "o4"}], ",", 
     RowBox[{"o1", "-", "o2", "-", "o3", "+", "o4"}], ",", 
     RowBox[{
      RowBox[{"-", "o1"}], "+", "o2", "-", "o3", "+", "o4"}], ",", 
     RowBox[{
      RowBox[{"-", "o1"}], "-", "o2", "+", "o3", "+", "o4"}]}], "}"}], "/", 
   "4"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
     "\"\<K\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "+", "d"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{"arcTanh", "[", 
       RowBox[{
        RowBox[{"a", "+", "c"}], ",", 
        RowBox[{"b", "+", "d"}]}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "-", "d"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{"arcTanh", "[", 
       RowBox[{
        RowBox[{"a", "-", "c"}], ",", 
        RowBox[{"b", "-", "d"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"uu_", ",", "\[Phi]_", ",", "vv_", ",", "\[Psi]_"}], "}"}], 
     ",", "\"\<K\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"v", "=", 
        RowBox[{"Sqrt", "[", "vv", "]"}]}], ",", 
       RowBox[{"u", "=", 
        RowBox[{"Sqrt", "[", "uu", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"v", "*", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cosh", "[", "\[Psi]", "]"}], ",", 
           RowBox[{"Sinh", "[", "\[Psi]", "]"}], ",", 
           RowBox[{"-", 
            RowBox[{"Cosh", "[", "\[Psi]", "]"}]}], ",", 
           RowBox[{"-", 
            RowBox[{"Sinh", "[", "\[Psi]", "]"}]}]}], "}"}], "/", "2"}]}], 
       "+", 
       RowBox[{"u", "*", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
           RowBox[{"Sinh", "[", "\[Phi]", "]"}], ",", 
           RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
           RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "}"}], "/", "2"}]}]}], 
      "]"}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"sh", "[", "\"\<Qr\>\"", "]"}], 
    RowBox[{"(*", 
     RowBox[{"Signature", " ", 
      RowBox[{"(", 
       RowBox[{"4", ",", "0"}], ")"}]}], "*)"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{"gi", "=", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}], ",", 
          RowBox[{"-", "3"}], ",", 
          RowBox[{"-", "4"}], ",", "2"}], "}"}]}], ";", 
       RowBox[{"gp", "=", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
       RowBox[{"plex", "=", 
        RowBox[{"{", 
         RowBox[{"a", ",", 
          RowBox[{"-", " ", "b"}], ",", " ", 
          RowBox[{"-", "c"}], ",", 
          RowBox[{"-", "d"}]}], "}"}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"]}], "}"}]}]}], "]"}]}], ";"}],
  FormatType->StandardForm], "\n", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"toPol", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
      "\"\<Qr\>\""}], "]"}],
    FormatType->StandardForm], 
   StyleBox[":=",
    FormatType->StandardForm], 
   RowBox[{
    StyleBox["{",
     FormatType->StandardForm], 
    RowBox[{
     StyleBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}],
      FormatType->StandardForm], 
     StyleBox[",",
      FormatType->StandardForm], 
     RowBox[{
      StyleBox[
       RowBox[{"A", 
        StyleBox["rcTan",
         FormatType->StandardForm]}]], 
      StyleBox["[",
       FormatType->StandardForm], 
      RowBox[{"a", ",", "b"}], "]"}], ",", 
     StyleBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}],
      FormatType->StandardForm], ",", 
     RowBox[{
      StyleBox[
       RowBox[{"A", 
        StyleBox["rcTan",
         FormatType->StandardForm]}]], "[", 
      RowBox[{"c", ",", "d"}], "]"}]}], 
    StyleBox["}",
     FormatType->StandardForm]}]}], 
  StyleBox[" ",
   FormatType->StandardForm], 
  StyleBox[";",
   FormatType->StandardForm]}], "\n", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"toVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rr_", ",", "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], 
      ",", "\"\<Qr\>\""}], "]"}], ":=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{"rr", "-", "ss"}]], " ", 
       RowBox[{"Cos", "[", "\[Rho]", "]"}]}], ",", 
      RowBox[{
       SqrtBox[
        RowBox[{"rr", "-", "ss"}]], " ", 
       RowBox[{"Sin", "[", "\[Rho]", "]"}]}], ",", 
      RowBox[{
       SqrtBox["ss"], " ", 
       RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], ",", 
      RowBox[{
       SqrtBox["ss"], " ", 
       RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], "}"}]}],
   FormatType->StandardForm], ";"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"sh", "[", "\"\<C8c\>\"", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{"gi", "=", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "4"}], ",", 
          RowBox[{"-", "3"}], ",", 
          RowBox[{"-", "2"}], ",", "1", ",", "1"}], "}"}]}], ";", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["d", "2"], "+", 
          RowBox[{
           SqrtBox["2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", " ", "b"}], "+", 
             RowBox[{"b", " ", "c"}], "-", 
             RowBox[{"a", " ", "d"}], "+", 
             RowBox[{"c", " ", "d"}]}], ")"}]}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["d", "2"], "-", 
          RowBox[{
           SqrtBox["2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", " ", "b"}], "+", 
             RowBox[{"b", " ", "c"}], "-", 
             RowBox[{"a", " ", "d"}], "+", 
             RowBox[{"c", " ", "d"}]}], ")"}]}]}]}], "}"}]}]}], 
     RowBox[{"(*", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"], "+", 
           SuperscriptBox["d", "2"]}], ")"}], "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "+", 
            RowBox[{"b", " ", "c"}], "-", 
            RowBox[{"a", " ", "d"}], "+", 
            RowBox[{"c", " ", "d"}]}], ")"}], "2"]}]}], "}"}], "*)"}], 
     "]"}]}], ";"}],
  FormatType->StandardForm]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"sh", "[", "\"\<P4\>\"", "]"}],
    FormatType->StandardForm], 
   RowBox[{"(*", 
    RowBox[{"Signature", " ", 
     RowBox[{"(", 
      RowBox[{"1", ",", "3"}], ")"}]}], "*)"}], 
   StyleBox[":=",
    FormatType->StandardForm], 
   StyleBox[" ",
    FormatType->StandardForm], 
   RowBox[{
    StyleBox["Module",
     FormatType->StandardForm], 
    StyleBox["[",
     FormatType->StandardForm], 
    StyleBox[
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{"gi", "=", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "2"}], "}"}]}], ";", 
       
       RowBox[{"gp", "=", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
       RowBox[{"plex", "=", 
        RowBox[{"{", 
         RowBox[{"a", ",", 
          RowBox[{"-", " ", "b"}], ",", " ", 
          RowBox[{"-", "c"}], ",", 
          RowBox[{"-", "d"}]}], "}"}]}], ";", 
       RowBox[{"{", " ", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"], "-", 
         SuperscriptBox["d", "2"]}], "}"}]}]}],
     FormatType->StandardForm], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"toPol", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
      "\"\<P4\>\""}], "]"}],
    FormatType->StandardForm], 
   StyleBox[":=",
    FormatType->StandardForm], 
   RowBox[{
    StyleBox["Module",
     FormatType->StandardForm], 
    StyleBox["[",
     FormatType->StandardForm], 
    RowBox[{
     StyleBox[
      RowBox[{"{", 
       RowBox[{"r", "=", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"c", "-", "d"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"d", "-", "b"}], ")"}], "2"]}], ")"}], "/", "2"}], 
          ")"}]}]}], "}"}],
      FormatType->StandardForm], 
     StyleBox[",",
      FormatType->StandardForm], 
     RowBox[{
      StyleBox["{",
       FormatType->StandardForm], 
      RowBox[{
       StyleBox["r",
        FormatType->StandardForm], 
       StyleBox[",",
        FormatType->StandardForm], 
       RowBox[{
        StyleBox[
         RowBox[{"A", 
          StyleBox["rcTan",
           FormatType->StandardForm]}]], 
        StyleBox["[",
         FormatType->StandardForm], 
        RowBox[{"a", "/", 
         StyleBox["r",
          FormatType->StandardForm]}], "]"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "+", "c", "+", "d"}], ")"}], "/", "3"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"c", "\[Equal]", "d"}], ",", "0", ",", 
         RowBox[{
          StyleBox[
           RowBox[{"A", 
            StyleBox["rcTan",
             FormatType->StandardForm]}]], "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "b"}], "-", "c", "-", "d"}], ",", 
           RowBox[{
            RowBox[{"-", 
             SqrtBox["3"]}], 
            RowBox[{"(", 
             RowBox[{"c", "-", "d"}], ")"}]}]}], "]"}]}], "]"}]}], 
      StyleBox["}",
       FormatType->StandardForm]}]}], 
    StyleBox[" ",
     FormatType->StandardForm], 
    StyleBox["]",
     FormatType->StandardForm]}]}], 
  StyleBox[";",
   FormatType->StandardForm]}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"toVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r_", ",", "\[Sigma]_", ",", "s_", ",", "\[Theta]_"}], "}"}], 
      ",", "\"\<P4\>\""}], "]"}], ":=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r", " ", 
       RowBox[{"Tan", "[", "\[Sigma]", "]"}]}], ",", 
      RowBox[{"s", "+", 
       RowBox[{"2", "*", "r", "*", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Theta]", "]"}], "/", "3"}]}]}], ",", 
      RowBox[{"s", "+", 
       RowBox[{"2", "*", "r", "*", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Pi", "/", "3"}]}]}], "]"}], "/", "3"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"s", "+", 
       RowBox[{"2", "*", "r", "*", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"4", "*", 
            RowBox[{"Pi", "/", "3"}]}]}], "]"}], "/", "3"}]}]}]}], "}"}]}], 
   ";"}],
  FormatType->StandardForm], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
     "\"\<P4\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}], ",", 
      RowBox[{"arcTanh", "[", 
       RowBox[{"a", ",", "b"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"c", ",", "d"}], "]"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"uu_", ",", "\[Phi]_", ",", "vv_", ",", "\[Psi]_"}], "}"}], 
     ",", "\"\<P4\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"v", "=", 
        SqrtBox["vv"]}], ",", 
       RowBox[{"u", "=", 
        SqrtBox["uu"]}]}], "}"}], ",", 
     RowBox[{"Chop", "[", " ", 
      RowBox[{
       RowBox[{"v", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}], ",", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "}"}]}], "+", 
       RowBox[{"u", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}], ",", "0", ",", "0"}], 
         "}"}]}]}], "]"}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"sh", "[", "\"\<Dav\>\"", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{"gi", "=", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}], ",", 
          RowBox[{"-", "3"}], ",", "4", ",", "1", ",", "1"}], "}"}]}], ";", 
       RowBox[{"gp", "=", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
       RowBox[{"plex", "=", 
        RowBox[{"{", 
         RowBox[{"a", ",", 
          RowBox[{"-", " ", "b"}], ",", " ", 
          RowBox[{"-", "c"}], ",", "d"}], "}"}]}], ";", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            StyleBox["(",
             FormatType->StandardForm], 
            RowBox[{"a", "-", "d"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            StyleBox["(",
             FormatType->StandardForm], 
            RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            StyleBox["(",
             FormatType->StandardForm], 
            RowBox[{"a", 
             StyleBox["+",
              FormatType->StandardForm], "d"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            StyleBox["(",
             FormatType->StandardForm], 
            RowBox[{"b", 
             StyleBox["-",
              FormatType->StandardForm], "c"}], ")"}], "2"]}]}], "}"}]}]}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"L4", " ", "equivalent", " ", "is", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"], "+", 
           SuperscriptBox["d", "2"]}], ")"}], "2"]}], "+", 
       RowBox[{"4", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", "d"}], "-", 
           RowBox[{"b", " ", "c"}]}], ")"}], "2"]}]}], "*)"}], "]"}]}], ";"}],
  
  FormatType->StandardForm], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"toPol", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
      "\"\<Dav\>\""}], "]"}],
    FormatType->StandardForm], 
   StyleBox[":=",
    FormatType->StandardForm], 
   RowBox[{
    StyleBox["{",
     FormatType->StandardForm], 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{
        StyleBox["(",
         FormatType->StandardForm], 
        RowBox[{"a", "-", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        StyleBox["(",
         FormatType->StandardForm], 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], 
     StyleBox[",",
      FormatType->StandardForm], 
     RowBox[{
      StyleBox[
       RowBox[{"A", 
        StyleBox["rcTan",
         FormatType->StandardForm]}]], 
      StyleBox["[",
       FormatType->StandardForm], 
      RowBox[{
       RowBox[{"a", "-", "d"}], ",", 
       RowBox[{"b", "+", "c"}]}], "]"}], ",", "\[IndentingNewLine]", 
     StyleBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", 
          StyleBox["+",
           FormatType->StandardForm], "d"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         StyleBox["(",
          FormatType->StandardForm], 
         RowBox[{"b", 
          StyleBox["-",
           FormatType->StandardForm], "c"}], ")"}], "2"]}],
      FormatType->StandardForm], ",", 
     RowBox[{
      StyleBox[
       RowBox[{"A", 
        StyleBox["rcTan",
         FormatType->StandardForm]}]], "[", 
      RowBox[{
       RowBox[{"a", "+", "d"}], ",", 
       RowBox[{"b", "-", "c"}]}], "]"}]}], 
    StyleBox["}",
     FormatType->StandardForm]}]}], 
  StyleBox[" ",
   FormatType->StandardForm], 
  StyleBox[";",
   FormatType->StandardForm]}], "\n", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"toVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rr_", ",", "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], 
      ",", "\"\<Dav\>\""}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox["rr"], " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{
         SqrtBox["ss"], " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{
         SqrtBox["rr"], " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{
         SqrtBox["ss"], " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{
         SqrtBox["rr"], " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "-", 
        RowBox[{
         SqrtBox["ss"], " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox["rr"]}], " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{
         SqrtBox["ss"], " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}]}], "}"}], "/", "2"}]}], 
   ";"}],
  FormatType->StandardForm]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<O2\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}], ",", "3", ",", 
         RowBox[{"-", "4"}], ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", " ", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}]}], "}"}]}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "d"}], ")"}], "2"]}]}], "}"}]}]}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"]}], ")"}], "2"], "-", 
      RowBox[{"4", 
       SuperscriptBox[
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           RowBox[{"a", " ", "c"}], "+", 
           RowBox[{"b", " ", "d"}]}],
          FormatType->StandardForm], ")"}], "2"]}]}], "*)"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"toPol", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
      "\"\<O2\>\""}], "]"}],
    FormatType->StandardForm], 
   StyleBox[":=",
    FormatType->StandardForm], 
   StyleBox[" ",
    FormatType->StandardForm], 
   RowBox[{
    StyleBox["{",
     FormatType->StandardForm], 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{
        StyleBox["(",
         FormatType->StandardForm], 
        RowBox[{"a", "-", 
         StyleBox["c",
          FormatType->StandardForm]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        StyleBox["(",
         FormatType->StandardForm], 
        RowBox[{"b", 
         StyleBox["-",
          FormatType->StandardForm], 
         StyleBox["d",
          FormatType->StandardForm]}], ")"}], "2"]}], 
     StyleBox[",",
      FormatType->StandardForm], 
     RowBox[{
      StyleBox["ArcTan",
       FormatType->StandardForm], 
      StyleBox["[",
       FormatType->StandardForm], 
      RowBox[{
       RowBox[{"a", "-", "c"}], ",", 
       RowBox[{"b", "-", "d"}]}], "]"}], ",", "\[IndentingNewLine]", 
     StyleBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "+", "d"}], ")"}], "2"]}],
      FormatType->StandardForm], ",", 
     RowBox[{
      StyleBox["ArcTan",
       FormatType->StandardForm], "[", 
      RowBox[{
       RowBox[{"a", "+", "c"}], ",", 
       RowBox[{"b", "+", "d"}]}], "]"}]}], 
    StyleBox["}",
     FormatType->StandardForm]}]}], 
  StyleBox[" ",
   FormatType->StandardForm], 
  StyleBox[";",
   FormatType->StandardForm], 
  StyleBox[
   RowBox[{
    RowBox[{"toVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rr_", ",", "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], 
      ",", "\"\<O2\>\""}], "]"}], ":=", 
    RowBox[{
     RowBox[{"{", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox["rr"], " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{
         SqrtBox["ss"], " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{
         SqrtBox["rr"], " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{
         SqrtBox["ss"], " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox["rr"]}], " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{
         SqrtBox["ss"], 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox["rr"]}], " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{
         SqrtBox["ss"], " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}]}], "}"}], "/", "2"}]}],
   FormatType->StandardForm], 
  StyleBox[";",
   FormatType->StandardForm]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C8r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4", ",", 
         RowBox[{"-", "3"}], ",", "2", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", " ", "b"}], ",", "c", ",", 
         RowBox[{"-", "d"}]}], "}"}]}], ";", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"]}], ")"}], "2"], "-", 
           RowBox[{"2", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", "b"}], "-", 
               RowBox[{"b", " ", "c"}], "+", 
               RowBox[{"a", " ", "d"}], "+", 
               RowBox[{"c", " ", "d"}]}], ")"}], "2"]}]}], "}"}], 
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"], "-", 
              SuperscriptBox["d", "2"]}], ")"}], "2"], "+", 
           RowBox[{"2", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", "b"}], "+", 
               RowBox[{"b", " ", "c"}], "-", 
               RowBox[{"a", " ", "d"}], "+", 
               RowBox[{"c", " ", "d"}]}], ")"}], "2"]}]}], "}"}]}], ","}], 
       "*)"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"], "+", 
         RowBox[{
          SqrtBox["2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            RowBox[{"a", " ", "d"}], "+", 
            RowBox[{"c", " ", "d"}]}], ")"}]}]}], ",", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"], "-", 
         RowBox[{
          SqrtBox["2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            RowBox[{"a", " ", "d"}], "+", 
            RowBox[{"c", " ", "d"}]}], ")"}]}]}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3C4j\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "4"}], ",", "3", ",", 
         RowBox[{"-", "2"}], ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", " ", 
         RowBox[{"-", "b"}], ",", " ", "c", ",", 
         RowBox[{"-", "d"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ",", 
        RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "d"}], ")"}], "2"]}]}], "}"}]}]}], 
    RowBox[{"(*", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         RowBox[{"2", "b", " ", "d"}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"2", " ", "ac"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}], "2"]}], "*)"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
     "\"\<C3C4j\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ",", 
     RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "d"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "+", "c"}], ",", 
       RowBox[{"b", "+", "d"}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Beta]_", ",", "\[Epsilon]\[Epsilon]_", ",", 
       "\[Sigma]_"}], "}"}], ",", "\"\<C3C4j\>\""}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", "\[IndentingNewLine]",
       
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", "\[IndentingNewLine]",
       
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", "\[IndentingNewLine]",
       
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}]}], "}"}], "/", "4"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL11\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", 
         RowBox[{"-", "3"}], ",", "4", ",", "2"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", " ", "b"}], ",", " ", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}]}], "}"}]}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "-", 
        SuperscriptBox["d", "2"]}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL2\>\"", "]"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Signature", " ", 
      RowBox[{"(", 
       RowBox[{"2", ",", "2"}], ")"}]}], ",", " ", 
     RowBox[{"matching", " ", 
      RowBox[{"Twistors", "!"}]}]}], " ", "*)"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", 
         RowBox[{"-", "4"}], ",", "2"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", " ", "b"}], ",", " ", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}]}], "}"}]}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["d", "2"]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"toPol", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
      "\"\<CL2\>\""}], "]"}],
    FormatType->StandardForm], 
   StyleBox[":=",
    FormatType->StandardForm], 
   StyleBox[" ",
    FormatType->StandardForm], 
   RowBox[{
    StyleBox["{",
     FormatType->StandardForm], 
    RowBox[{
     RowBox[{
      StyleBox[
       SuperscriptBox["a", "2"],
       FormatType->StandardForm], 
      StyleBox["+",
       FormatType->StandardForm], 
      StyleBox[
       SuperscriptBox["c", "2"],
       FormatType->StandardForm], 
      StyleBox["-",
       FormatType->StandardForm], 
      StyleBox[
       SuperscriptBox["b", "2"],
       FormatType->StandardForm], 
      StyleBox["-",
       FormatType->StandardForm], 
      SuperscriptBox["d", "2"]}], 
     StyleBox[",",
      FormatType->StandardForm], 
     StyleBox[
      RowBox[{"ArcTan", "[", 
       RowBox[{"a", ",", "c"}], "]"}],
      FormatType->StandardForm], 
     StyleBox[",",
      FormatType->StandardForm], 
     RowBox[{
      StyleBox[
       SuperscriptBox["b", "2"],
       FormatType->StandardForm], 
      RowBox[{
       StyleBox["+",
        FormatType->StandardForm], 
       SuperscriptBox["d", "2"]}]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"b", ",", "d"}], "]"}]}], 
    StyleBox["}",
     FormatType->StandardForm]}]}], 
  StyleBox[";",
   FormatType->StandardForm]}], "\n", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"toVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rr_", ",", "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], 
      ",", "\"\<CL2\>\""}], "]"}], ":=", 
    RowBox[{"{", "  ", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{"rr", "+", "ss"}]], " ", 
       RowBox[{"Cos", "[", "\[Rho]", "]"}]}], ",", " ", 
      RowBox[{
       SqrtBox["ss"], " ", 
       RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], ",", 
      RowBox[{
       SqrtBox[
        RowBox[{"rr", "+", "ss"}]], " ", 
       RowBox[{"Sin", "[", "\[Rho]", "]"}]}], ",", 
      RowBox[{
       SqrtBox["ss"], " ", 
       RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], "}"}]}],
   FormatType->StandardForm], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4C2r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "4"}], ",", "3", ",", 
         RowBox[{"-", "2"}], ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", "c", ",", 
         RowBox[{"-", "d"}]}], "}"}]}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", "b", "+", "c", "-", "d"}], ",", 
        RowBox[{"a", "-", "b", "+", "c", "+", "d"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "d"}], ")"}], "2"]}]}], "}"}]}]}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         RowBox[{"2", " ", "b", " ", "d"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "c"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}], "2"]}], "*)"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"toPol", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
      "\"\<C4C2r\>\""}], "]"}],
    FormatType->StandardForm], 
   StyleBox[":=",
    FormatType->StandardForm], 
   StyleBox[" ",
    FormatType->StandardForm], 
   RowBox[{
    StyleBox["{",
     FormatType->StandardForm], 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c", "-", "d"}], ",", 
     RowBox[{"a", "-", "b", "+", "c", "+", "d"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "d"}], ")"}], "2"]}], 
     StyleBox[",",
      FormatType->StandardForm], 
     RowBox[{
      StyleBox[
       RowBox[{"A", 
        StyleBox["rcTan",
         FormatType->StandardForm]}]], 
      StyleBox["[",
       FormatType->StandardForm], 
      RowBox[{
       RowBox[{"a", "-", "c"}], ",", 
       RowBox[{"b", "+", "d"}]}], "]"}]}], 
    StyleBox["}",
     FormatType->StandardForm]}]}], 
  StyleBox[" ",
   FormatType->StandardForm]}], "\n", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"toVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\[Alpha]_", ",", "\[Beta]_", ",", "\[Epsilon]\[Epsilon]_", ",", 
        "\[Sigma]_"}], "}"}], ",", "\"\<C4C2r\>\""}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "\[Epsilon]\[Epsilon]", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}]}], "}"}], "/", "4"}]}], 
   ";"}],
  FormatType->StandardForm], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
     "\"\<C4C2r\>\""}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "-", "d"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{"arcTanh", "[", 
       RowBox[{
        RowBox[{"a", "+", "c"}], ",", 
        RowBox[{"b", "-", "d"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "+", "d"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"a", "-", "c"}], ",", 
        RowBox[{"b", "+", "d"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"uu_", ",", "\[Phi]_", ",", "rr_", ",", "\[Theta]_"}], "}"}], 
     ",", "\"\<C4C2r\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "=", 
        RowBox[{"Sqrt", "[", "rr", "]"}]}], ",", 
       RowBox[{"u", "=", 
        RowBox[{"Sqrt", "[", "uu", "]"}]}]}], "}"}], ",", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"r", "*", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}], ",", 
           RowBox[{"-", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}], "/", "2"}]}], "+", 
       
       RowBox[{"u", "*", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
           RowBox[{"Sinh", "[", "\[Phi]", "]"}], ",", 
           RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
           RowBox[{"-", 
            RowBox[{"Sinh", "[", "\[Phi]", "]"}]}]}], "}"}], "/", "2"}]}]}], 
      "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<P16c\>\"", "]"}], 
   RowBox[{"(*", 
    RowBox[{"Signature", " ", 
     RowBox[{"(", 
      RowBox[{"3", ",", "1"}], ")"}]}], "*)"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "3"}], ",", "4", ",", "2"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", " ", "b"}], ",", " ", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}]}], "}"}]}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "-", 
        SuperscriptBox["d", "2"]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"toPol", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
      "\"\<P16c\>\""}], "]"}],
    FormatType->StandardForm], 
   StyleBox[":=",
    FormatType->StandardForm], 
   StyleBox[" ",
    FormatType->StandardForm], 
   RowBox[{
    StyleBox["{",
     FormatType->StandardForm], 
    RowBox[{
     StyleBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"]}],
      FormatType->StandardForm], 
     StyleBox[",",
      FormatType->StandardForm], 
     StyleBox[
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"b", "\[NotEqual]", "0"}], ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"a", ",", "b"}], "]"}], ",", "0"}], "]"}],
      FormatType->StandardForm], 
     StyleBox[",",
      FormatType->StandardForm], 
     RowBox[{
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["d", "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"d", "\[NotEqual]", "0"}], ",", 
       RowBox[{
        StyleBox[
         RowBox[{"a", 
          StyleBox["rcTanh",
           FormatType->StandardForm]}]], "[", 
        RowBox[{"c", ",", "d"}], "]"}], ",", "0"}], "]"}]}], 
    StyleBox["}",
     FormatType->StandardForm]}]}], 
  StyleBox[" ",
   FormatType->StandardForm], 
  StyleBox[";",
   FormatType->StandardForm]}], "\n", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"toVec", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rr_", ",", "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], 
      ",", "\"\<P16c\>\""}], "]"}], ":=", 
    RowBox[{"{", "  ", 
     RowBox[{
      RowBox[{
       SqrtBox["rr"], " ", 
       RowBox[{"Cos", "[", "\[Rho]", "]"}]}], ",", " ", 
      RowBox[{
       SqrtBox["rr"], " ", 
       RowBox[{"Sin", "[", "\[Rho]", "]"}]}], ",", 
      RowBox[{
       SqrtBox["ss"], " ", 
       RowBox[{"Cosh", "[", "\[Sigma]", "]"}]}], ",", 
      RowBox[{
       SqrtBox["ss"], " ", 
       RowBox[{"Sinh", "[", "\[Sigma]", "]"}]}]}], "}"}]}],
   FormatType->StandardForm], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q4n\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"plex", "=."}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"], "-", 
         SuperscriptBox["d", "2"]}], ",", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"]}]}], "}"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "8 Shapes, Polar-Vector, Hyperbolics, ",
 StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
  FontSlant->"Italic"],
 "for 5 & 6 element loops."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C5\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "5", ",", "4", ",", "3", ",", "2", ",", "1", ",", "1", ",", 
         "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e"}], ",", 
        RowBox[{"(", " ", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", " ", 
          SuperscriptBox["b", "2"], "+", " ", 
          SuperscriptBox["c", "2"], "+", " ", 
          SuperscriptBox["d", "2"], "+", " ", 
          SuperscriptBox["e", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox["5"]}], ")"}], 
           RowBox[{
            RowBox[{"(", " ", 
             RowBox[{
              RowBox[{"a", " ", "b"}], "+", 
              RowBox[{"b", " ", "c"}], "+", 
              RowBox[{"c", " ", "d"}], "+", 
              RowBox[{"a", " ", "e"}], "+", 
              RowBox[{"d", " ", "e"}]}], ")"}], "/", "2"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SqrtBox["5"]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "c"}], "+", 
              RowBox[{"a", " ", "d"}], "+", 
              RowBox[{"b", " ", "d"}], "+", 
              RowBox[{"b", " ", "e"}], "+", 
              RowBox[{"c", " ", "e"}]}], ")"}], "/", "2"}]}]}], ")"}], ",", 
        " ", 
        RowBox[{"(", " ", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", " ", 
          SuperscriptBox["b", "2"], "+", " ", 
          SuperscriptBox["c", "2"], "+", " ", 
          SuperscriptBox["d", "2"], "+", " ", 
          SuperscriptBox["e", "2"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SqrtBox["5"]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", " ", 
             RowBox[{
              RowBox[{"a", " ", "b"}], "+", 
              RowBox[{"b", " ", "c"}], "+", 
              RowBox[{"c", " ", "d"}], "+", 
              RowBox[{"a", " ", "e"}], "+", 
              RowBox[{"d", " ", "e"}]}], ")"}], "/", "2"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox["5"]}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "c"}], "+", 
              RowBox[{"a", " ", "d"}], "+", 
              RowBox[{"b", " ", "d"}], "+", 
              RowBox[{"b", " ", "e"}], "+", 
              RowBox[{"c", " ", "e"}]}], ")"}], "/", "2"}]}]}], ")"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]_", ",", "\[Epsilon]_", ",", "\[Sigma]_"}], "}"}], 
     ",", "\"\<C5\>\""}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Sigma]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "5"}]}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Sigma]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "5"}]}]}], "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Sigma]", "+", 
          RowBox[{"6", 
           RowBox[{"\[Pi]", "/", "5"}]}]}], "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Sigma]", "+", 
          RowBox[{"8", 
           RowBox[{"\[Pi]", "/", "5"}]}]}], "]"}]}]}]}], "}"}], "/", "5"}]}], 
  " ", ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3C2\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "4", ",", "6", ",", "5", ",", "1", ",", 
         "1", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "c", ",", "b", ",", "d", ",", "f", ",", "e"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
        
        RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], ",", 
        
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "d", "-", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "+", "d", "-", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}], "2"]}], 
          ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "-", "d", "+", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "-", "d", "+", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "-", "e", "+", "f"}], ")"}], "2"]}], 
          ")"}], "/", "2"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Delta]_", ",", "\[Eta]\[Eta]_", ",", "\[Chi]_", 
       ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
     "\"\<C3C2\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Eta]", "=", 
        RowBox[{"2", 
         SqrtBox["\[Eta]\[Eta]"]}]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        RowBox[{"2", 
         SqrtBox["\[Kappa]\[Kappa]"]}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"{", "  ", 
       RowBox[{
        RowBox[{"\[Alpha]", "+", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
        RowBox[{"\[Alpha]", "+", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{"\[Alpha]", "+", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
        RowBox[{"\[Alpha]", "-", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{"\[Alpha]", "-", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}]}], "}"}], "/", 
      "6"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"toPol", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}], 
     "}"}], ",", "\"\<C3C2\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "=", 
       RowBox[{"Chop", "[", 
        RowBox[{
         RowBox[{"2", "a"}], "-", "b", "-", "c", "+", 
         RowBox[{"2", "d"}], "-", "e", "-", "f"}], "]"}]}], ",", 
      RowBox[{"a2", "=", 
       RowBox[{"Chop", "[", 
        RowBox[{
         RowBox[{"2", "a"}], "-", "b", "-", "c", "-", 
         RowBox[{"2", "d"}], "+", "e", "+", "f"}], "]"}]}], ",", 
      RowBox[{"b1", "=", 
       RowBox[{"Chop", "[", 
        RowBox[{"Simplify", "[", 
         RowBox[{"c", "-", "b", "-", "e", "+", "f"}], "]"}], "]"}]}], ",", 
      RowBox[{"b2", "=", 
       RowBox[{"Chop", "[", 
        RowBox[{"Simplify", "[", 
         RowBox[{"c", "-", "b", "+", "e", "-", "f"}], "]"}], "]"}]}]}], "}"}],
     ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
      RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "d", "-", "e"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "a", "+", "f", "-", "d"}], ")"}], "2"]}], ")"}], 
       "/", "2"}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"a1", ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "b1"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "d", "+", "e"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "c", "-", "e", "+", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "a", "-", "f", "+", "d"}], ")"}], "2"]}], ")"}], 
       "/", "2"}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"a2", ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "b2"}]}], "]"}]}], "}"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}], 
      "}"}], ",", "\"\<C3C2\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a1", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"2", "a"}], "-", "b", "-", "c", "+", 
          RowBox[{"2", "d"}], "-", "e", "-", "f"}], "]"}]}], ",", 
       RowBox[{"a2", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"2", "a"}], "-", "b", "-", "c", "-", 
          RowBox[{"2", "d"}], "+", "e", "+", "f"}], "]"}]}], ",", 
       RowBox[{"b1", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"c", "-", "b", "-", "e", "+", "f"}], "]"}], "]"}]}], ",", 
       RowBox[{"b2", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"c", "-", "b", "+", "e", "-", "f"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"]}], ",", 
       RowBox[{"arcTanh", "[", 
        RowBox[{
         RowBox[{"a", "+", "b", "+", "c"}], ",", 
         RowBox[{"d", "+", "e", "+", "f"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "d", "-", "e"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "a", "+", "f", "-", "d"}], ")"}], "2"]}], ")"}],
         "/", "2"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"a1", ",", 
         RowBox[{
          RowBox[{"Sqrt", "[", "3", "]"}], "b1"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "-", "d", "+", "e"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "c", "-", "e", "+", "f"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "a", "-", "f", "+", "d"}], ")"}], "2"]}], ")"}],
         "/", "2"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"a2", ",", 
         RowBox[{
          RowBox[{"Sqrt", "[", "3", "]"}], "b2"}]}], "]"}]}], "}"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Gamma]\[Gamma]_", ",", "\[Delta]_", ",", "\[Eta]\[Eta]_", ",", 
       "\[Chi]_", ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
     "\"\<C3C2\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Gamma]", "=", 
        SqrtBox["\[Gamma]\[Gamma]"]}], ",", 
       RowBox[{"\[Eta]", "=", 
        SqrtBox["\[Eta]\[Eta]"]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        SqrtBox["\[Kappa]\[Kappa]"]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Delta]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Delta]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Delta]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Delta]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Delta]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Delta]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}]}], "}"}], "/", 
      "3"}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<D3\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "5", ",", "4", ",", "3", ",", "6", ",", "1", ",", 
         "1", ",", "2"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
        
        RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
        
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"e", "-", "a"}], ")"}], "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "d"}], ")"}], "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "f"}], ")"}], "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"f", "-", "b"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}], 
      "}"}], ",", "\"\<D3\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ace", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"e", "-", "a"}], ")"}], "2"]}], ")"}], "/", "2"}]}], ",",
        
       RowBox[{"\[Chi]", "=", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "a"}], "-", "c", "-", "e"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{"e", "-", "c"}], ")"}]}]}], "]"}]}], ",", 
       RowBox[{"bdf", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"f", "-", "b"}], ")"}], "2"]}], ")"}], "/", "2"}]}], ",",
        
       RowBox[{"\[Psi]", "=", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "b"}], "-", "d", "-", "f"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{"f", "-", "d"}], ")"}]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
       RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
       RowBox[{"ace", "-", "bdf"}], ",", "\[Chi]", ",", "ace", ",", 
       "\[Psi]"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Gamma]_", ",", "\[Delta]_", ",", "\[Eta]\[Eta]_", ",", "\[Chi]_", 
       ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", "\"\<D3\>\""}],
     "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Eta]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Kappa]\[Kappa]"]}]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        RowBox[{"4", 
         SqrtBox[
          RowBox[{"\[Kappa]\[Kappa]", "-", "\[Eta]\[Eta]"}]]}]}]}], "}"}], 
     ",", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], " ", ",", 
        RowBox[{"\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Kappa]", "  ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
        RowBox[{"\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{"\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Kappa]", "  ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{"\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{"\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Kappa]", "  ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}]}], "}"}], "/", 
      "6"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}], 
      "}"}], ",", "\"\<D3\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[Chi]", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "c", "+", "e"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "+", "d", "+", "f"}], ")"}], "2"]}], ",", 
       RowBox[{"arcTanh", "[", 
        RowBox[{
         RowBox[{"a", "+", "c", "+", "e"}], ",", 
         RowBox[{"b", "+", "d", "+", "f"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"e", "-", "a"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Chi]", "=", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "a"}], "-", "c", "-", "e"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{"e", "-", "c"}], ")"}]}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "-", "f"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"f", "-", "b"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "b"}], "-", "d", "-", "f"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{"f", "-", "d"}], ")"}]}]}], "]"}], "-", "\[Chi]"}]}], 
      "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Gamma]\[Gamma]_", ",", "\[Phi]_", ",", "\[Eta]\[Eta]_", ",", 
       "\[Chi]_", ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
     "\"\<D3\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Gamma]", "=", 
        RowBox[{"2", 
         SqrtBox["\[Gamma]\[Gamma]"]}]}], ",", 
       RowBox[{"\[Eta]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Eta]\[Eta]"]}]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Kappa]\[Kappa]"]}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Kappa]", "  ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Psi]"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Kappa]", "  ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Psi]", "+", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Kappa]", "  ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Psi]", "-", 
            RowBox[{"2", " ", 
             RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}]}], "}"}], "/", 
      "6"}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C6n\>\"", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", " ", 
     RowBox[{
      RowBox[{"gi", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", " ", "3", ",", " ", "2", ",", " ", "5", ",", " ", "4", ",", 
         " ", "6", ",", " ", "1", ",", " ", "1", ",", " ", "1", ",", " ", 
         "1"}], "}"}]}], ";", " ", "\n", "    ", 
      RowBox[{"gp", " ", "=."}], " ", ";", " ", 
      RowBox[{"plex", " ", "=."}], " ", ";", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", " ", "+", " ", "b", " ", "+", " ", "c", " ", "-", " ", "d", " ", 
         "-", " ", "e", " ", "-", " ", "f"}], ",", " ", "\n", "     ", 
        RowBox[{
        "a", " ", "+", " ", "b", " ", "+", " ", "c", " ", "+", " ", "d", " ", 
         "+", " ", "e", " ", "+", " ", "f"}], ",", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", " ", "-", " ", "b"}], ")"}], "^", "2"}], " ", "+", 
           " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", " ", "-", " ", "c"}], ")"}], "^", "2"}], " ", "+", 
           " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"c", " ", "-", " ", "a"}], ")"}], "^", "2"}], " ", "-", 
           " ", "\n", "       ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"d", " ", "-", " ", "e"}], ")"}], "^", "2"}], " ", "-", 
           " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"e", " ", "-", " ", "f"}], ")"}], "^", "2"}], " ", "-", 
           " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"f", " ", "-", " ", "d"}], ")"}], "^", "2"}]}], ")"}], 
         "/", "2"}], ",", " ", "\n", "     ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", " ", "-", " ", "b"}], ")"}], "^", "2"}], " ", "+", 
           " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", " ", "-", " ", "c"}], ")"}], "^", "2"}], " ", "+", 
           " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"c", " ", "-", " ", "a"}], ")"}], "^", "2"}], " ", "+", 
           " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"d", " ", "-", " ", "e"}], ")"}], "^", "2"}], " ", "+", 
           " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"e", " ", "-", " ", "f"}], ")"}], "^", "2"}], " ", "+", 
           " ", "\n", "       ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"f", " ", "-", " ", "d"}], ")"}], "^", "2"}]}], ")"}], 
         "/", "2"}]}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontFamily->"Courier New"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3C4c\>\"", "]"}], ":=", 
   RowBox[{"(*", 
    RowBox[{"Revised", " ", 
     RowBox[{
      RowBox[{"8", "/", "1"}], "/", "6"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "2", ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "6"}], ",", 
         RowBox[{"-", "5"}], ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"]}], ",", 
        RowBox[{"3", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "b", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"d", "+", "e", "-", 
                  RowBox[{"2", "f"}]}], ")"}], "r3"}]}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"a", "+", "b", "-", 
                  RowBox[{"2", "c"}]}], ")"}], "r3"}], "-", "d", "+", "e"}], 
              ")"}], "2"]}], ")"}], "/", "4"}]}], ",", 
        RowBox[{"3", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "b", "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"d", "+", "e", "-", 
                  RowBox[{"2", "f"}]}], ")"}], "r3"}]}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"a", "+", "b", "-", 
                  RowBox[{"2", "c"}]}], ")"}], "r3"}], "+", "d", "-", "e"}], 
              ")"}], "2"]}], ")"}], "/", "4"}]}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}], 
      "}"}], ",", "\"\<C3C4c\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f1", "=", 
        RowBox[{"a", "-", "b", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", "f"}]}], ")"}], "/", 
          SqrtBox["3"]}]}]}], ",", 
       RowBox[{"f2", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}]}], ")"}], "/", 
          SqrtBox["3"]}], "-", "d", "+", "e"}]}], ",", 
       RowBox[{"f3", "=", 
        RowBox[{"a", "-", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", "f"}]}], ")"}], "/", 
          SqrtBox["3"]}]}]}], ",", 
       RowBox[{"f4", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}]}], ")"}], "/", 
          SqrtBox["3"]}], "+", "d", "-", "e"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"]}], 
       RowBox[{"(*", "\[Epsilon]\[Epsilon]", "*)"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "+", "e", "+", "f"}], "\[Equal]", "0"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"a", "+", "b", "+", "c"}], "<", "0"}], ",", "\[Pi]", ",", 
           "0"}], "]"}], ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"a", "+", "b", "+", "c"}], ",", 
           RowBox[{"d", "+", "e", "+", "f"}]}], "]"}]}], "]"}], 
       RowBox[{"(*", "\[Sigma]", "*)"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Expand", "[", 
        RowBox[{"3", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["f1", "2"], "+", 
            SuperscriptBox["f2", "2"]}], ")"}], "/", "4"}]}], "]"}], 
       RowBox[{"(*", "\[Eta]\[Eta]", "*)"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"f2", "\[Equal]", "0"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"f1", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"f1", ",", "f2"}], "]"}]}], "]"}], "-", 
        RowBox[{"\[Pi]", "/", "6"}]}], 
       RowBox[{"(*", "\[CurlyKappa]", "*)"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Expand", "[", 
        RowBox[{"3", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["f3", "2"], "+", 
            SuperscriptBox["f4", "2"]}], ")"}], "/", "4"}]}], "]"}], 
       RowBox[{"(*", "\[Kappa]\[Kappa]", "*)"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"f4", "\[Equal]", "0"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"f3", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"f3", ",", "f4"}], "]"}]}], "]"}], "-", 
        RowBox[{"\[Pi]", "/", "6"}]}]}], 
      RowBox[{"(*", "\[Psi]", "*)"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Eta]\[Eta]_", ",", 
       "\[Chi]_", ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
     "\"\<C3C4c\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "=", 
        RowBox[{
         SqrtBox["\[Epsilon]\[Epsilon]"], "/", "3"}]}], ",", 
       RowBox[{"\[Eta]", "=", 
        SqrtBox[
         RowBox[{"\[Eta]\[Eta]", "/", "12"}]]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        SqrtBox[
         RowBox[{"\[Kappa]\[Kappa]", "/", "12"}]]}], ",", 
       RowBox[{"x", "=", 
        RowBox[{"\[Chi]", "+", 
         RowBox[{"\[Pi]", "/", "6"}]}]}], ",", 
       RowBox[{"y", "=", 
        RowBox[{"\[Psi]", "+", 
         RowBox[{"\[Pi]", "/", "6"}]}]}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{"(*", "a", "*)"}], 
      RowBox[{
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "x", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", "r3", " ", 
         RowBox[{"Sin", "[", "x", "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "y", "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", "r3", " ", 
         RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "b", "*)"}], 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "x", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", "r3", " ", 
         RowBox[{"Sin", "[", "x", "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "y", "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", "r3", " ", 
         RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "c", "*)"}], 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", "2", "r3", " ", 
         RowBox[{"Sin", "[", "x", "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", "2", "r3", " ", 
         RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "d", "*)"}], 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", "r3", " ", 
         RowBox[{"Cos", "[", "x", "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Sin", "[", "x", "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", "r3", " ", 
         RowBox[{"Cos", "[", "y", "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "e", "*)"}], 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", "r3", " ", 
         RowBox[{"Cos", "[", "x", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Sin", "[", "x", "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", "r3", " ", 
         RowBox[{"Cos", "[", "y", "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "f", "*)"}], 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", "2", "r3", " ", 
         RowBox[{"Cos", "[", "x", "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", "2", "r3", " ", 
         RowBox[{"Cos", "[", "y", "]"}]}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q12c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "2", ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "6"}], ",", "1", ",", "2"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "c", ",", "b", ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"e", "-", "f"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}], 
      "}"}], ",", "\"\<Q12c\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"abc", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"c", "-", "a"}], ")"}], "2"]}], ")"}], "/", "2"}]}], ",",
        
       RowBox[{"def", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"e", "-", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"f", "-", "d"}], ")"}], "2"]}], ")"}], "/", "2"}]}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "+", "e", "+", "f"}], "===", "0"}], ",", "0", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"a", "+", "b", "+", "c"}], ",", 
           RowBox[{"d", "+", "e", "+", "f"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"abc", "+", "def"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"c", "==", "b"}], ",", "0", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ",", 
           RowBox[{
            RowBox[{"Sqrt", "[", "3", "]"}], 
            RowBox[{"(", 
             RowBox[{"c", "-", "b"}], ")"}]}]}], "]"}]}], "]"}], ",", "def", 
       ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"e", "==", "f"}], ",", "0", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", " ", "d"}], "-", "e", "-", "f"}], ",", 
           RowBox[{
            RowBox[{"Sqrt", "[", "3", "]"}], 
            RowBox[{"(", 
             RowBox[{"f", "-", "e"}], ")"}]}]}], "]"}]}], "]"}]}], "}"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Eta]\[Eta]_", ",", 
       "\[Chi]_", ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
     "\"\<Q12c\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "=", 
        RowBox[{
         SqrtBox["\[Epsilon]\[Epsilon]"], "/", "3"}]}], ",", 
       RowBox[{"\[Eta]", "=", 
        RowBox[{"2", 
         RowBox[{
          SqrtBox[
           RowBox[{"\[Eta]\[Eta]", "-", "\[Kappa]\[Kappa]"}]], "/", "3"}]}]}],
        ",", 
       RowBox[{"\[Kappa]", "=", 
        RowBox[{"2", 
         RowBox[{
          SqrtBox["\[Kappa]\[Kappa]"], "/", "3"}]}]}]}], "}"}], ",", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Kappa]", "  ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Kappa]", "  ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Kappa]", "  ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sh", "[", "\"\<Q12r\>\"", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "6"}], ",", "1", ",", "2"}], "}"}]}], ";", 
     RowBox[{"gp", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
       "}"}]}], ";", 
     RowBox[{"plex", "=", 
      RowBox[{"{", 
       RowBox[{"a", ",", "c", ",", "b", ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}]}], "}"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "c", "+", "e"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "d", "+", "f"}], ")"}], "2"]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"c", "+", "e"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "e"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "+", "d"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "f"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "f"}], ")"}], "^", "2"}]}], ")"}], "/", "2"}]}],
       "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"toPol", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}], 
     "}"}], ",", "\"\<Q12r\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ace", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "e"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"c", "+", "e"}], ")"}], "^", "2"}]}], ")"}], "/", "2"}]}],
       ",", 
      RowBox[{"bdf", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "+", "d"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "f"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "f"}], ")"}], "^", "2"}]}], ")"}], "/", 
        "2"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "c", "+", "e"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "d", "+", "f"}], ")"}], "2"]}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"b", "+", "f"}], "===", "d"}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"a", "-", "c", "+", "e"}], ",", 
          RowBox[{"b", "-", "d", "+", "f"}]}], "]"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ace", "+", "bdf"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"-", "e"}]}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "a"}], "-", "e", "+", "c"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "c"}], "-", "e"}], ")"}]}]}], "]"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "bdf", ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"d", "\[Equal]", 
         RowBox[{"-", "f"}]}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "b"}], "+", "d", "-", "f"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "d"}], "-", "f"}], ")"}]}]}], "]"}]}], "]"}]}], 
     "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Eta]\[Eta]_", ",", 
       "\[Chi]_", ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
     "\"\<Q12r\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "=", 
        RowBox[{
         SqrtBox["\[Epsilon]\[Epsilon]"], "/", "3"}]}], ",", 
       RowBox[{"\[Eta]", "=", 
        RowBox[{"2", 
         RowBox[{
          SqrtBox[
           RowBox[{"\[Eta]\[Eta]", "-", "\[Kappa]\[Kappa]"}]], "/", "3"}]}]}],
        ",", 
       RowBox[{"\[Kappa]", "=", 
        RowBox[{"2", 
         RowBox[{
          SqrtBox["\[Kappa]\[Kappa]"], "/", "3"}]}]}]}], "}"}], ",", 
     RowBox[{"{", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell["\<\
sh[\"g2401c\"]:=Module[{},gi={1,3,2,-4*I,-5*I,-6*I,2,1};gp={1,1,1,0.,1,0.};\
plex={a,c,b,-d,-e,-f}; 
{((a-b)^2+(a-c)^2+(b-c)^2-I*((d-e)^2+(d-f)^2+(e-f)^2))/2,(a+b+c)^2-I*(d+e+f)^\
2}];
sh[\"D6r\"]:=Module[{},gi={1,2,-5,4,-3,6,1,1,2};
gp={1,1,1,0.,1,0.};plex=.;{a-b-c+d+e-f,a+b-c-d+e+f,
((a+c)^2+(c+e)^2+(a-e)^2-(b+d)^2-(d+f)^2-(b-f)^2)/2}];
sh[\"D3C2c\"]:=Module[{},gi={1,2,3,5,4,6,1,1,2};plex={a,c,b,-d,-e,-f};
gp={1,1,1,0.,1,0.};{(a-b+c-d-e-f),(a+b-c-d-e+f), \
((a+d)^2+(a+e)^2+(d-e)^2-(b+c)^2-(b-f)^2-(c+f)^2)/2}];   \
\>", "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell["\<\
(*Two relabellings of C3C2*)
sh[\"KC3c\"]:=Module[{},gi={1,-3,-2,4,-6,-5,1,1,1,1};gp={1,1,1,0.,1,0.};plex={\
a,b,c,-d,-e,-f};{a-b+c-d+e-f,a-b+c+d-e+f,((a+b-d-e)^2+(a-c-d+f)^2+(b+c-e-f)^2)\
/2,((a+b+d+e)^2+(a-c+d-f)^2+(b+c+e+f)^2)/2}];
sh[\"C3Kr\"]:=Module[{},gi={1,3,2,4,6,5,1,1,1,1};gp={1,1,1,0.,1,0.};{a-b-c-d+\
e+f,a-b-c+d-e-f,((a+b-d-e)^2+(a+c-d-f)^2+(b-c-e+f)^2)/2,((a+b+d+e)^2+(a+c+d+f)\
^2+(b-c+e-f)^2)/2}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"sh", "[", "\"\<Cl3r\>\"", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"gp", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
       "}"}]}], ";", 
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "4"}], ",", "6", ",", "5", ",", "1", ",", "1"}], "}"}]}],
      ";", 
     RowBox[{"plex", "=", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c", ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}]}], "}"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "-", "e", "+", "f"}], ")"}], "2"]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", "b"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", " ", 
              RowBox[{"b", "+", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", " ", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"d", "+", "e"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"e", "+", "f"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", " ", 
              RowBox[{"f", "-", "d"}], ")"}], "2"]}], ")"}], "2"], "/", "4"}],
         "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "d"}], "-", 
            RowBox[{"c", " ", "d"}], "+", 
            RowBox[{"a", " ", "e"}], "-", 
            RowBox[{"c", " ", "e"}], "+", 
            RowBox[{"a", " ", "f"}], "+", 
            RowBox[{"b", " ", "f"}]}], ")"}], "2"]}]}]}], "}"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sh", "[", "\"\<Clm3r\>\"", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"gp", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
       "}"}]}], ";", 
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "2", ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "5"}], ",", "1", ",", "1"}], "}"}]}], ";", 
     RowBox[{"plex", "=", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c", ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "-", "c"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "-", "e", "-", "f"}], ")"}], "2"]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"a", "+", "b"}], ")"}], "^", "2"}], "+", 
              RowBox[{
               RowBox[{"(", " ", 
                RowBox[{"b", "-", "c"}], ")"}], "^", "2"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"a", "+", " ", "c"}], ")"}], "^", "2"}]}], ")"}], "+",
             
            RowBox[{
             RowBox[{"(", 
              RowBox[{"d", "+", "e"}], ")"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"e", "-", "f"}], ")"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"(", " ", 
              RowBox[{"f", "+", "d"}], ")"}], "^", "2"}]}], ")"}], "^", "2"}],
          "/", "4"}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "d"}], "+", 
            RowBox[{"c", " ", "d"}], "+", 
            RowBox[{"a", " ", "e"}], "+", 
            RowBox[{"c", " ", "e"}], "-", 
            RowBox[{"a", " ", "f"}], "-", 
            RowBox[{"b", " ", "f"}]}], ")"}], "2"]}]}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8",
  FontFamily->"Arial"],
 ".9 Shapes, Polar-Vector, Hyperbolics, ",
 StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
  FontSlant->"Italic"],
 "for 8 & 9 element loops."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sh", "[", "\"\<QC2r\>\"", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", 
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "7"}], ",", 
        RowBox[{"-", "8"}], ",", "2", ",", "2"}], "}"}]}], ";", 
     RowBox[{"plex", "=", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", 
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "g"}], ",", 
        RowBox[{"-", "h"}]}], "}"}]}], ";", 
     RowBox[{"gp", "=", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
       "}"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "-", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "-", "f"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"g", "-", "h"}], ")"}], "2"]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "+", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "+", "f"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"g", "+", "h"}], ")"}], "2"]}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<KiC4r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", 
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "8"}], ",", "5", ",", "6", ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "4"}], ",", "2", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", "e", ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"]}], 
        RowBox[{"(*", "repeated", "*)"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "e", "+", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "d", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "e", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "+", "d", "+", "g", "+", "h"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL21\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "5"}], ",", "6", ",", "7", ",", "8", ",", "2", ",", 
         "2"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", "h"}], "}"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "h"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "g"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "+", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "e"}], ")"}], "2"]}], 
        RowBox[{"(*", "repeated", "*)"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "h"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "g"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "e"}], ")"}], "2"]}]}], 
       RowBox[{"(*", "repeated", "*)"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<CL21\>\""}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"(*", 
     RowBox[{"p", ",", "\[Phi]"}], "*)"}], 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "g"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "h"}], ",", 
       RowBox[{"b", "+", "g"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"q", ",", "\[Psi]"}], "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "e"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"c", "+", "f"}], ",", 
       RowBox[{"d", "-", "e"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"r", ",", "\[Rho]"}], "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "g"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "+", "h"}], ",", 
       RowBox[{"b", "-", "g"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"s", ",", "\[Sigma]"}], "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "+", "e"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"c", "-", "f"}], ",", 
       RowBox[{"d", "+", "e"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "pp_", ",", "\[Phi]_", ",", "qq_", ",", "\[Psi]_", ",", "rr_", ",", 
       "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], ",", 
     "\"\<CL21\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Sqrt", "[", "pp", "]"}]}], ",", 
       RowBox[{"q", "=", 
        RowBox[{"Sqrt", "[", "qq", "]"}]}], ",", 
       RowBox[{"r", "=", 
        RowBox[{"Sqrt", "[", "rr", "]"}]}], ",", 
       RowBox[{"s", "=", 
        RowBox[{"Sqrt", "[", "ss", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"(*", "a", "*)"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"p", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], " ", "+", 
         RowBox[{"r", " ", 
          RowBox[{"Cos", "[", "\[Rho]", "]"}]}]}], ",", 
        RowBox[{"(*", "b", "*)"}], " ", 
        RowBox[{
         RowBox[{"p", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}], " ", "+", 
         RowBox[{"r", " ", 
          RowBox[{"Sin", "[", "\[Rho]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{"(*", "c", "*)"}], 
        RowBox[{
         RowBox[{"q", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "+", 
         RowBox[{"s", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{"(*", "d", "*)"}], 
        RowBox[{
         RowBox[{"q", " ", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "+", 
         RowBox[{"s", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "e", "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "q"}], " ", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "+", 
         RowBox[{"s", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{"(*", "f", "*)"}], " ", 
        RowBox[{
         RowBox[{"q", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
         RowBox[{"s", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "g", "*)"}], " ", 
        RowBox[{
         RowBox[{"p", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}], " ", "-", 
         RowBox[{"r", " ", 
          RowBox[{"Sin", "[", "\[Rho]", "]"}]}]}], ",", 
        RowBox[{"(*", "h", "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", " ", "p"}], " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"r", " ", 
          RowBox[{"Cos", "[", "\[Rho]", "]"}]}]}]}], "}"}], "/", "2"}]}], 
    "]"}]}], ";", 
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL03\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "6"}], ",", 
         RowBox[{"-", "7"}], ",", "8", ",", "2", ",", "2"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", "h"}], "}"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "e"}], ")"}], "2"]}], 
        RowBox[{"(*", "repeated", "*)"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "+", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "e"}], ")"}], "2"]}]}], 
       RowBox[{"(*", "repeated", "*)"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<CL03\>\""}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"(*", 
     RowBox[{"p", ",", "\[Phi]"}], "*)"}], 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "g"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "h"}], ",", 
       RowBox[{"b", "+", "g"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"q", ",", "\[Psi]"}], "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "+", "e"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"c", "-", "f"}], ",", 
       RowBox[{"d", "+", "e"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"r", ",", "\[Rho]"}], "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "g"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "+", "h"}], ",", 
       RowBox[{"b", "-", "g"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"s", ",", "\[Sigma]"}], "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "e"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"c", "+", "f"}], ",", 
       RowBox[{"d", "-", "e"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "pp_", ",", "\[Phi]_", ",", "qq_", ",", "\[Psi]_", ",", "rr_", ",", 
       "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], ",", 
     "\"\<CL03\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Sqrt", "[", "pp", "]"}]}], ",", 
       RowBox[{"q", "=", 
        RowBox[{"Sqrt", "[", "qq", "]"}]}], ",", 
       RowBox[{"r", "=", 
        RowBox[{"Sqrt", "[", "rr", "]"}]}], ",", 
       RowBox[{"s", "=", 
        RowBox[{"Sqrt", "[", "ss", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"(*", "a", "*)"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"p", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], " ", "+", 
         RowBox[{"r", " ", 
          RowBox[{"Cos", "[", "\[Rho]", "]"}]}]}], ",", 
        RowBox[{"(*", "b", "*)"}], " ", 
        RowBox[{
         RowBox[{"p", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}], " ", "+", 
         RowBox[{"r", " ", 
          RowBox[{"Sin", "[", "\[Rho]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{"(*", "c", "*)"}], 
        RowBox[{
         RowBox[{"q", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "+", 
         RowBox[{"s", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{"(*", "d", "*)"}], 
        RowBox[{
         RowBox[{"q", " ", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "+", 
         RowBox[{"s", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "e", "*)"}], 
        RowBox[{
         RowBox[{"q", " ", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
         RowBox[{"s", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{"(*", "f", "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "q"}], " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "+", 
         RowBox[{"s", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "g", "*)"}], " ", 
        RowBox[{
         RowBox[{"p", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}], " ", "-", 
         RowBox[{"r", " ", 
          RowBox[{"Sin", "[", "\[Rho]", "]"}]}]}], ",", 
        RowBox[{"(*", "h", "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", " ", "p"}], " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"r", " ", 
          RowBox[{"Cos", "[", "\[Rho]", "]"}]}]}]}], "}"}], "/", "2"}]}], 
    "]"}]}], ";", 
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL3\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";",
       
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", 
         RowBox[{"-", "4"}], ",", "5", ",", 
         RowBox[{"-", "6"}], ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "8"}], ",", "2", ",", "2"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", "h"}], "}"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "h"}], "-", 
              RowBox[{"b", " ", "g"}], "+", 
              RowBox[{"c", " ", "f"}], "-", 
              RowBox[{"d", " ", "e"}]}], ")"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"], "+", 
             SuperscriptBox["d", "2"], "-", 
             SuperscriptBox["e", "2"], "+", 
             SuperscriptBox["f", "2"], "+", 
             SuperscriptBox["g", "2"], "-", 
             SuperscriptBox["h", "2"]}], ")"}], "2"]}], "}"}], "]"}], "*)"}], 
      "\n", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", 
            RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "+", 
            RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"c", "-", 
            RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "^", "2"}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", 
            RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", 
            RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", 
            RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"c", "+", 
            RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "^", "2"}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", 
            RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"]}]}], "}"}]}]}],
     "]"}]}], ";", 
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL12\>\"", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", 
        RowBox[{"-", "3"}], ",", "4", ",", 
        RowBox[{"-", "5"}], ",", "6", ",", 
        RowBox[{"-", "7"}], ",", 
        RowBox[{"-", "8"}], ",", "2", ",", "2"}], "}"}]}], ";", 
     RowBox[{"plex", "=", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "g"}], ",", "h"}], "}"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", 
           RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", 
           RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "-", 
           RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "-", 
           RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", 
           RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "+", 
           RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "+", 
           RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "+", 
           RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"]}]}], "}"}]}], 
    ")"}]}], ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sh", "[", "\"\<QC2r\>\"", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", 
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "7"}], ",", 
        RowBox[{"-", "8"}], ",", "2", ",", "2"}], "}"}]}], ";", 
     RowBox[{"plex", "=", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", 
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "g"}], ",", 
        RowBox[{"-", "h"}]}], "}"}]}], ";", 
     RowBox[{"gp", "=", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
       "}"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "-", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "-", "f"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"g", "-", "h"}], ")"}], "2"]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "+", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "+", "f"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"g", "+", "h"}], ")"}], "2"]}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<KiC4r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", 
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "8"}], ",", "5", ",", "6", ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "4"}], ",", "2", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", "e", ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"]}], 
        RowBox[{"(*", "repeated", "*)"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "e", "+", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "d", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "e", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "+", "d", "+", "g", "+", "h"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4iC4c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4", ",", "3", ",", "2", ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "6"}], ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "8"}], ",", "2", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "2", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", "c", ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"f", "-", "h"}], ")"}], "2"]}], 
        RowBox[{"(*", "repeated", "*)"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C8\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "8", ",", "7", ",", "6", ",", "5", ",", "4", ",", "3", ",", 
         "2", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", "c", ",", 
         RowBox[{"-", "d"}], ",", "e", ",", 
         RowBox[{"-", "f"}], ",", "g", ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-",
           "h"}], ")"}], " ", ",", 
        RowBox[{"(", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+",
           "h"}], ")"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "+", "e", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "+", "f", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"c", "-", "g"}], ")"}], "2"]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"d", "-", "h"}], ")"}], "2"]}], ")"}], "2"], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"a", "-", "e"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"d", "-", "h"}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"f", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"c", "-", "g"}], ")"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"a", "-", "e"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"b", "-", "f"}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"c", "-", "g"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"d", "-", "h"}], ")"}]}]}], ")"}]}]}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<KC2\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "1"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h"}]}], "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<KC2\>\""}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
      "h"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
      "h"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Alpha]_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
      "\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Zeta]_", ",", "\[Theta]_"}], 
     "}"}], ",", "\"\<KC2\>\""}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
     "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
      "\[Epsilon]", " ", "+", "\[Sigma]", "+", "\[Zeta]", " ", "+", 
      "\[Theta]"}], ",", 
     RowBox[{
     "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "-", 
      "\[Epsilon]", " ", "-", "\[Sigma]", "+", "\[Zeta]", " ", "+", 
      "\[Theta]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
      "\[Epsilon]", "+", "\[Sigma]", "-", "\[Zeta]", "+", "\[Theta]"}], ",", 
     RowBox[{
     "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
      "\[Epsilon]", "-", "\[Sigma]", "-", "\[Zeta]", "+", "\[Theta]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", "\[Gamma]", "-", 
      "\[Delta]", "+", "\[Epsilon]", " ", "-", "\[Sigma]", "-", "\[Zeta]", 
      " ", "+", "\[Theta]"}], ",", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "-", "\[Gamma]", "+", 
      "\[Delta]", "-", "\[Epsilon]", " ", "+", "\[Sigma]", "-", "\[Zeta]", 
      " ", "+", "\[Theta]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]", "+", 
      "\[Delta]", "-", "\[Epsilon]", " ", "-", "\[Sigma]", "+", "\[Zeta]", 
      " ", "+", "\[Theta]"}], ",", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "-", "\[Gamma]", "-", 
      "\[Delta]", "+", "\[Epsilon]", " ", "+", "\[Sigma]", "+", "\[Zeta]", 
      " ", "+", "\[Theta]"}]}], "}"}], "/", "8"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4C2\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "4", ",", "3", ",", "2", ",", "5", ",", "8", ",", "7", ",", 
         "6", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", "c", ",", 
         RowBox[{"-", "d"}], ",", "e", ",", 
         RowBox[{"-", "f"}], ",", "g", ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "-", "e", "+", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "-", "f", "+", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "+", "e", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "+", "f", "-", "h"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<C4C2\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
      "h"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c", "-", "e", "+", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "d", "-", "f", "+", "h"}], ")"}], "2"]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "c", "-", "e", "+", "g"}], ",", 
       RowBox[{"b", "-", "d", "-", "f", "+", "h"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c", "+", "e", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "d", "+", "f", "-", "h"}], ")"}], "2"]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "c", "+", "e", "-", "g"}], ",", 
       RowBox[{"b", "-", "d", "+", "f", "-", "h"}]}], "]"}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Alpha]_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
      "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Zeta]\[Zeta]_", ",", 
      "\[Theta]_"}], "}"}], ",", "\"\<C4C2\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Epsilon]", "=", 
       RowBox[{"2", 
        SqrtBox["\[Epsilon]\[Epsilon]"]}]}], ",", 
      RowBox[{"\[Zeta]", "=", 
       RowBox[{"2", 
        SqrtBox["\[Zeta]\[Zeta]"]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "  ", 
      RowBox[{
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "-", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "-", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "-", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}], "/", "8"}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<D4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "7", ",", "4", ",", "5", ",", "6", ",", "3", ",", 
         "8", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2"}], "}"}]}], 
      ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"]}]}], 
       RowBox[{"(*", "repeated", "*)"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<D4\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "g"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "e"}], ",", 
       RowBox[{"c", "-", "g"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"b", "-", "f"}], ",", 
       RowBox[{"d", "-", "h"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
       "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Zeta]\[Zeta]_", ",",
        "\[Theta]_"}], "}"}], ",", "\"\<D4\>\""}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Epsilon]", "=", 
         RowBox[{"4", 
          SqrtBox[
           RowBox[{"\[Epsilon]\[Epsilon]", "+", "\[Zeta]\[Zeta]"}]]}]}], ",", 
        
        RowBox[{"\[Zeta]", "=", 
         RowBox[{"4", 
          SqrtBox["\[Zeta]\[Zeta]"]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "-", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]}], "]"}], "/", 
    "8"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<D4\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "e", "+", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "d", "+", "g", "+", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"arcTanh", "[", 
      RowBox[{
       RowBox[{"a", "+", "b", "+", "e", "+", "f"}], ",", 
       RowBox[{"c", "+", "d", "+", "g", "+", "h"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "e", "-", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "d", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"arcTanh", "[", 
      RowBox[{
       RowBox[{"a", "-", "b", "+", "e", "-", "f"}], ",", 
       RowBox[{"c", "-", "d", "+", "g", "-", "h"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "g"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "e"}], ",", 
       RowBox[{"c", "-", "g"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"b", "-", "f"}], ",", 
       RowBox[{"d", "-", "h"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]\[Alpha]_", ",", "\[Phi]_", ",", "\[Gamma]\[Gamma]_", ",", 
       "\[Rho]_", ",", "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", 
       "\[Zeta]\[Zeta]_", ",", "\[Theta]_"}], "}"}], ",", "\"\<D4\>\""}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "=", 
         SqrtBox["\[Alpha]\[Alpha]"]}], ",", 
        RowBox[{"\[Gamma]", "=", 
         SqrtBox["\[Gamma]\[Gamma]"]}], ",", 
        RowBox[{"\[Epsilon]", "=", 
         RowBox[{"2", 
          SqrtBox["\[Epsilon]\[Epsilon]"]}]}], ",", 
        RowBox[{"\[Zeta]", "=", 
         RowBox[{"2", 
          SqrtBox["\[Zeta]\[Zeta]"]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Rho]", "]"}]}], "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Rho]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Rho]", "]"}]}], "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Rho]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]}], "]"}], "/", 
    "4"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q8\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "6", ",", "7", ",", "8", ",", "5", ",", "2", ",", "3", ",", 
         "4", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2"}], "}"}]}], 
      ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", "e", ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"]}]}], 
       RowBox[{"(*", "repeated", "*)"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<Q8\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "e"}], ",", 
       RowBox[{"b", "-", "f"}]}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"c", "-", "g"}], ",", 
       RowBox[{"d", "-", "h"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
       "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Zeta]\[Zeta]_", ",",
        "\[Theta]_"}], "}"}], ",", "\"\<Q8\>\""}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", "  ", 
     RowBox[{
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"4", 
        SqrtBox["\[Epsilon]\[Epsilon]"], " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"4", 
        SqrtBox["\[Epsilon]\[Epsilon]"], " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"4", 
        SqrtBox["\[Zeta]\[Zeta]"], " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"4", 
        SqrtBox["\[Zeta]\[Zeta]"], " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "-", 
       RowBox[{"4", 
        SqrtBox["\[Epsilon]\[Epsilon]"], " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
       RowBox[{"4", 
        SqrtBox["\[Epsilon]\[Epsilon]"], " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "-", 
       RowBox[{"4", 
        SqrtBox["\[Zeta]\[Zeta]"], " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
       RowBox[{"4", 
        SqrtBox["\[Zeta]\[Zeta]"], " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}], "/", "8"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<Q8\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "e", "+", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "d", "+", "g", "+", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"arcTanh", "[", 
      RowBox[{
       RowBox[{"a", "+", "b", "+", "e", "+", "f"}], ",", 
       RowBox[{"c", "+", "d", "+", "g", "+", "h"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "e", "-", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "d", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"arcTanh", "[", 
      RowBox[{
       RowBox[{"a", "-", "b", "+", "e", "-", "f"}], ",", 
       RowBox[{"c", "-", "d", "+", "g", "-", "h"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "e"}], ",", 
       RowBox[{"b", "-", "f"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"c", "-", "g"}], ",", 
       RowBox[{"d", "-", "h"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tohyVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]\[Alpha]_", ",", "\[Phi]_", ",", "\[Gamma]\[Gamma]_", ",", 
       "\[Rho]_", ",", "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", 
       "\[Zeta]\[Zeta]_", ",", "\[Theta]_"}], "}"}], ",", "\"\<Q8\>\""}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "=", 
         SqrtBox["\[Alpha]\[Alpha]"]}], ",", 
        RowBox[{"\[Gamma]", "=", 
         SqrtBox["\[Gamma]\[Gamma]"]}], ",", 
        RowBox[{"\[Epsilon]", "=", 
         RowBox[{"2", 
          SqrtBox["\[Epsilon]\[Epsilon]"]}]}], ",", 
        RowBox[{"\[Zeta]", "=", 
         RowBox[{"2", 
          SqrtBox["\[Zeta]\[Zeta]"]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Rho]", "]"}]}], "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Rho]", "]"}]}], "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Rho]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Rho]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Cosh", "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Gamma]", " ", 
          RowBox[{"Sinh", "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]}], "]"}], "/", 
    "4"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Octr\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "6"}], ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "8"}], ",", "4"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["d", "2"], "+", 
        SuperscriptBox["e", "2"], "+", 
        SuperscriptBox["f", "2"], "+", 
        SuperscriptBox["g", "2"], "+", 
        SuperscriptBox["h", "2"]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"toPol", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
      ",", "h_"}], "}"}], ",", "\"\<Octr\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"], "+", 
       SuperscriptBox["e", "2"], "+", 
       SuperscriptBox["f", "2"], "+", 
       SuperscriptBox["g", "2"], "+", 
       SuperscriptBox["h", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"a", ",", "b"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"c", ",", "d"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["e", "2"], "+", 
       SuperscriptBox["f", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"e", ",", "f"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["g", "2"], "+", 
       SuperscriptBox["h", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"g", ",", "h"}], "]"}]}], "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "pp_", ",", "\[Phi]_", ",", "qq_", ",", "\[Psi]_", ",", "rr_", ",", 
       "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], ",", 
     "\"\<Octr\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        SqrtBox[
         RowBox[{"pp", "-", "qq", "-", "rr", "-", "ss"}]]}], ",", 
       RowBox[{"q", "=", 
        SqrtBox["qq"]}], ",", 
       RowBox[{"r", "=", 
        SqrtBox["rr"]}], ",", 
       RowBox[{"s", "=", 
        SqrtBox["ss"]}]}], "}"}], ",", 
     RowBox[{"{", "  ", 
      RowBox[{
       RowBox[{"p", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], " ", ",", 
       RowBox[{"p", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}], ",", 
       RowBox[{"q", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}], " ", ",", 
       RowBox[{"q", " ", 
        RowBox[{"Sin", "[", "\[Psi]", "]"}]}], " ", ",", 
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "\[Rho]", "]"}]}], " ", ",", 
       RowBox[{"r", " ", 
        RowBox[{"Sin", "[", "\[Rho]", "]"}]}], ",", 
       RowBox[{"s", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], ",", 
       RowBox[{"s", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sh", "[", "\"\<KiC4c\>\"", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "8"}], ",", 
        RowBox[{"-", "7"}], ",", 
        RowBox[{"-", "6"}], ",", "1", ",", "1", ",", "2"}], "}"}]}], ";", 
     RowBox[{"gp", "=", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0", ",", "1", ",",
         "0."}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "c"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "-", "g"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"f", "-", "h"}], ")"}], "2"]}]}], 
      RowBox[{"(*", "repeated", "*)"}], "}"}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"toPol", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
      ",", "h_"}], "}"}], ",", "\"\<KiC4c\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"(*", "pp", "*)"}], 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"e", "-", "g"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"f", "-", "h"}], ")"}], "2"]}], ",", 
      RowBox[{"(*", "\[Phi]", "*)"}], 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"e", "==", "g"}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"a", "-", "c"}], ",", 
          RowBox[{"e", "-", "g"}]}], "]"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "qq", "*)"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"f", "-", "h"}], ")"}], "2"]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", "\[Psi]", "*)"}], 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"f", "==", "h"}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"b", "-", "d"}], ",", 
          RowBox[{"f", "-", "h"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"(*", "rr", "*)"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
      RowBox[{"(*", "\[Rho]", "*)"}], 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"e", "+", "g"}], "\[Equal]", 
         RowBox[{"f", "+", "h"}]}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
          RowBox[{"e", "-", "f", "+", "g", "-", "h"}]}], "]"}]}], "]"}], ",", 
      
      RowBox[{"(*", "ss", "*)"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}], ",", 
      RowBox[{"(*", "\[Sigma]", "*)"}], 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"e", "+", "f"}], "\[Equal]", 
         RowBox[{"g", "+", "h"}]}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ",", 
          RowBox[{"e", "+", "f", "+", "g", "+", "h"}]}], "]"}]}], "]"}]}], 
     "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "pp_", ",", "\[Phi]_", ",", "qq_", ",", "\[Psi]_", ",", "rr_", ",", 
       "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], ",", 
     "\"\<KiC4c\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{
         SqrtBox[
          RowBox[{"pp", "+", "qq"}]], "/", "2"}]}], ",", 
       RowBox[{"q", "=", 
        RowBox[{
         SqrtBox["qq"], "/", "2"}]}], ",", 
       RowBox[{"r", "=", 
        RowBox[{
         SqrtBox["rr"], "/", "4"}]}], ",", 
       RowBox[{"s", "=", 
        RowBox[{
         SqrtBox["ss"], "/", "4"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"(*", "a", "*)"}], "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], " ", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", "   ", 
       RowBox[{"(*", "b", "*)"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"+", "q"}], " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", "c", "*)"}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", "   ", 
       RowBox[{"(*", "d", "*)"}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "q"}], " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", "e", "*)"}], "  ", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", "   ", 
       RowBox[{"(*", "f", "*)"}], 
       RowBox[{
        RowBox[{
         RowBox[{"+", "q"}], " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", "g", "*)"}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", "   ", 
       RowBox[{"(*", "h", "*)"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "q"}], " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<O4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "6"}], ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "8"}], ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "f", "-", "g", "+", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "+", "f", "-", "g", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"toPol", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
      ",", "h_"}], "}"}], ",", "\"\<O4\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"gp", "=", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
        ",", "0."}], "}"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "-", "f", "-", "g", "+", "h"}], ")"}], "2"]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"e", "+", "h"}], "\[Equal]", 
          RowBox[{"f", "+", "g"}]}], ",", "0", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ",", 
           RowBox[{"e", "-", "f", "-", "g", "+", "h"}]}], "]"}]}], "]"}], ",",
        
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"e", "+", "g"}], "\[Equal]", 
          RowBox[{"f", "+", "h"}]}], ",", "0", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
           RowBox[{"e", "-", "f", "+", "g", "-", "h"}]}], "]"}]}], "]"}], ",",
        
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "+", "f", "-", "g", "-", "h"}], ")"}], "2"]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"e", "+", "f"}], "\[Equal]", 
          RowBox[{"g", "+", "h"}]}], ",", "0", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ",", 
           RowBox[{"e", "+", "f", "-", "g", "-", "h"}]}], "]"}]}], "]"}], ",",
        
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"e", "+", "f", "+", "g", "+", "h"}], "\[Equal]", "0"}], ",",
          "0", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ",", 
           RowBox[{"e", "+", "f", "+", "g", "+", "h"}]}], "]"}]}], "]"}]}], 
      "}"}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pp_", ",", "\[Phi]_", ",", "qq_", ",", "\[Psi]_", ",", "rr_", ",", 
      "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], ",", "\"\<O4\>\""}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Sqrt", "[", "pp", "]"}]}], ",", 
       RowBox[{"q", "=", 
        RowBox[{"Sqrt", "[", "qq", "]"}]}], ",", 
       RowBox[{"r", "=", 
        RowBox[{"Sqrt", "[", "rr", "]"}]}], ",", 
       RowBox[{"s", "=", 
        RowBox[{"Sqrt", "[", "ss", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], " ", "+", 
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], " ", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], " ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", " ", "p"}], " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], " ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], " ", "+", 
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], " ", "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], " ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], " ", "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], " ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], " ", "+", 
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], " ", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], " ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], " ", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], " ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], " ", "+", 
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], " ", "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], " ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], " ", "-", 
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}]}], "}"}]}], "]"}], "/", 
   "4"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<O4a\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}], ",", "3", ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "5"}], ",", "6", ",", 
         RowBox[{"-", "7"}], ",", "8", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", "c", ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", "f", ",", 
         RowBox[{"-", "g"}], ",", "h"}], "}"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "-", "f", "+", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "+", "e", "-", "g"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "+", "f", "-", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "-", "e", "+", "g"}], ")"}], "2"]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "c", "-", "f", "-", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "d", "+", "e", "+", "g"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "c", "+", "f", "+", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "d", "-", "e", "-", "g"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<O4b\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "3"}], ",", "4", ",", 
         RowBox[{"-", "5"}], ",", "6", ",", "7", ",", 
         RowBox[{"-", "8"}], ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", "d", ",", 
         RowBox[{"-", "e"}], ",", "f", ",", "g", ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "d", "+", "f", "+", "g"}], ")"}], "2"], 
         "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "c", "+", "e", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "d", "+", "f", "+", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "c", "-", "e", "+", "h"}], ")"}], "2"]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "d", "-", "f", "+", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "c", "+", "e", "+", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "d", "+", "f", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "b"}], "+", "c", "+", "e", "+", "h"}], ")"}], 
          "2"]}]}], "}"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4C4c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4", ",", "3", ",", "2", ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "8"}], ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "6"}], ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", "c", ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", "f", ",", 
         RowBox[{"-", "g"}], ",", "h"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "+", "e", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "-", "f", "+", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "-", "e", "+", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "+", "f", "-", "h"}], ")"}], "2"]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<C4C4c\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aa", ",", "bb", ",", "ss", ",", "w"}], "}"}], ",", 
     RowBox[{
      RowBox[{"ss", ":=", 
       RowBox[{
        RowBox[{"aa", "^", "2"}], "+", 
        RowBox[{"bb", "^", "2"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"w", ":=", 
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"bb", "===", "0"}], "&&", 
          RowBox[{"aa", "<", "0"}]}], ",", "\[Pi]", ",", 
         RowBox[{"bb", "\[Equal]", "0"}], ",", "0", ",", 
         RowBox[{"aa", "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"\[Pi]", "/", "2"}], " ", 
          RowBox[{"Sign", "[", "bb", "]"}]}], ",", "True", ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{"aa", ",", "bb"}], "]"}]}], "]"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"aa", "=", 
          RowBox[{"a", "-", "c", "-", "f", "+", "h"}]}], ";", 
         RowBox[{"bb", "=", 
          RowBox[{"b", "-", "d", "+", "e", "-", "g"}]}], ";", "ss"}], ",", 
        "w", ",", 
        RowBox[{
         RowBox[{"aa", "=", 
          RowBox[{"a", "-", "c", "+", "f", "-", "h"}]}], ";", 
         RowBox[{"bb", "=", 
          RowBox[{"b", "-", "d", "-", "e", "+", "g"}]}], ";", "ss"}], ",", 
        "w", ",", 
        RowBox[{
         RowBox[{"aa", "=", 
          RowBox[{"a", "-", "b", "+", "c", "-", "d"}]}], ";", 
         RowBox[{"bb", "=", 
          RowBox[{"e", "-", "f", "+", "g", "-", "h"}]}], ";", "ss"}], ",", 
        "w", ",", 
        RowBox[{
         RowBox[{"aa", "=", 
          RowBox[{"a", "+", "b", "+", "c", "+", "d"}]}], ";", 
         RowBox[{"bb", "=", 
          RowBox[{"e", "+", "f", "+", "g", "+", "h"}]}], ";", "ss"}], ",", 
        "w"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pp_", ",", "\[Phi]_", ",", "qq_", ",", "\[Psi]_", ",", "rr_", ",", 
      "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], ",", 
    "\"\<C4C4c\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "=", 
       RowBox[{"Sqrt", "[", "pp", "]"}]}], ",", 
      RowBox[{"q", "=", 
       RowBox[{"Sqrt", "[", "qq", "]"}]}], ",", 
      RowBox[{"r", "=", 
       RowBox[{"Sqrt", "[", "rr", "]"}]}], ",", 
      RowBox[{"s", "=", 
       RowBox[{"Sqrt", "[", "ss", "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"{", "    ", 
      RowBox[{
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p"}], " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", "  ", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Rho]", "]"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}]}], "}"}], "/", "4"}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4C4r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "4"}], ",", "3", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "5"}], ",", "8", ",", 
         RowBox[{"-", "7"}], ",", "6", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", "c", ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", "f", ",", 
         RowBox[{"-", "g"}], ",", "h"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "d", "+", "e", "+", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "c", "-", "f", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "+", "f", "-", "g", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "f", "-", "g", "+", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "d", "-", "e", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "c", "+", "f", "+", "h"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q8C2r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "2", ",", 
         RowBox[{"-", "7"}], ",", "5", ",", 
         RowBox[{"-", "8"}], ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "6"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "2"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", "e", ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "-", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "+", "f", "+", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "-", "g", "-", 
         "h"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "e"}], ")"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "g"}], ")"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"f", "+", "h"}], ")"}], "^", "2"}]}]}], 
       RowBox[{"(*", "repeated", "*)"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<Q8C2r\>\""}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "-", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "-", "d", "-", "e", "+", "f", "+", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "-", "g", "-", 
      "h"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "e"}], ")"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "^", "2"}]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "+", "e"}], ",", 
       RowBox[{"b", "-", "c"}]}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "+", "g"}], ")"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"f", "+", "h"}], ")"}], "^", "2"}]}], " ", ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"d", "+", "g"}], ",", 
       RowBox[{"f", "+", "h"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
       "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Zeta]\[Zeta]_", ",",
        "\[Theta]_"}], "}"}], ",", "\"\<Q8C2r\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Epsilon]\[Epsilon]"]}]}], ",", 
       RowBox[{"\[Zeta]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Zeta]\[Zeta]"]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "     ", 
       RowBox[{
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", "\[Gamma]", "-", 
         "\[Delta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", "\[Gamma]", "-", 
         "\[Delta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]", "+", 
         "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "-", "\[Gamma]", "-", 
         "\[Delta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "-", "\[Gamma]", "+", 
         "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", "  ", 
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", "   ", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}], "/", "8"}]}], 
    "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C2D4r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "6"}], ",", "7", ",", "8", ",", "2", ",", "2"}], 
        "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "+", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "+", "f"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"g", "+", "h"}], ")"}], "2"]}], 
        RowBox[{"(*", "repeated", "*)"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "f"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"g", "-", "h"}], ")"}], "2"]}]}], 
       RowBox[{"(*", "repeated", "*)"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<C2D4r\>\""}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "+", "f"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"e", "\[Equal]", 
        RowBox[{"-", "f"}]}], ",", "0", ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"a", "+", "b"}], ",", 
         RowBox[{"e", "+", "f"}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"g", "+", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"g", "\[Equal]", 
        RowBox[{"-", "h"}]}], ",", "0", ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"c", "+", "d"}], ",", 
         RowBox[{"g", "+", "h"}]}], "]"}]}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "f"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"e", "\[Equal]", "f"}], ",", "0", ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"a", "-", "b"}], ",", 
         RowBox[{"e", "-", "f"}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"g", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"g", "\[Equal]", "h"}], ",", "0", ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"c", "-", "d"}], ",", 
         RowBox[{"g", "-", "h"}]}], "]"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Zeta]\[Zeta]_", ",", 
       "\[Theta]_", ",", "\[Eta]\[Eta]_", ",", "\[Phi]_", ",", 
       "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", "\"\<C2D4r\>\""}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "=", 
        SqrtBox["\[Epsilon]\[Epsilon]"]}], ",", 
       RowBox[{"\[Zeta]", "=", 
        SqrtBox["\[Zeta]\[Zeta]"]}], ",", 
       RowBox[{"\[Eta]", "=", 
        SqrtBox["\[Eta]\[Eta]"]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        SqrtBox["\[Kappa]\[Kappa]"]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}]}], "}"}], "/", "2"}]}], 
    "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<P8\>\"", "]"}], 
   RowBox[{"(*", 
    RowBox[{"Signature", " ", 
     RowBox[{"(", 
      RowBox[{"1", ",", "3"}], ")"}], " ", "repeated"}], "*)"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", "2", ",", "2"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", "e", ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "e"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "f"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "+", "g"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "h"}], ")"}], "2"]}], 
        RowBox[{"(*", "repeated", "*)"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"]}]}], 
       RowBox[{"(*", "repeated", "*)"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_"}], "}"}], ",", "\"\<P8\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "e"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "f"}], ")"}], "2"]}], ",", 
        RowBox[{"arcTanh", "[", 
         RowBox[{
          RowBox[{"a", "+", "e"}], ",", 
          RowBox[{"b", "+", "f"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "+", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "h"}], ")"}], "2"]}], ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"c", "+", "g"}], ",", 
          RowBox[{"d", "+", "h"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"]}], ",", 
        RowBox[{"arcTanh", "[", 
         RowBox[{
          RowBox[{"a", "-", "e"}], ",", 
          RowBox[{"b", "-", "f"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"c", "-", "g"}], ",", 
          RowBox[{"d", "-", "h"}]}], "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pp_", ",", "\[Phi]_", ",", "qq_", ",", "\[Psi]_", ",", "rr_", ",", 
      "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], ",", "\"\<P8\>\""}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Sqrt", "[", "pp", "]"}]}], ",", 
       RowBox[{"q", "=", 
        RowBox[{"Sqrt", "[", "qq", "]"}]}], ",", 
       RowBox[{"r", "=", 
        RowBox[{"Sqrt", "[", "rr", "]"}]}], ",", 
       RowBox[{"s", "=", 
        RowBox[{"Sqrt", "[", "ss", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cosh", "[", "\[Rho]", "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sinh", "[", "\[Rho]", "]"}]}]}], " ", ",", 
       RowBox[{
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "  ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "  ", "+", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Cosh", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cosh", "[", "\[Rho]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"p", " ", 
         RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sinh", "[", "\[Rho]", "]"}]}]}], " ", ",", 
       RowBox[{
        RowBox[{"q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"s", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"q", " ", 
         RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
        RowBox[{"s", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}]}], "}"}]}], "]"}], "/", 
   "2"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Octs\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", 
         RowBox[{"-", "3"}], ",", "4", ",", 
         RowBox[{"-", "5"}], ",", "6", ",", 
         RowBox[{"-", "7"}], ",", "8", ",", "4"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "-", 
        SuperscriptBox["d", "2"], "+", 
        SuperscriptBox["e", "2"], "-", 
        SuperscriptBox["f", "2"], "+", 
        SuperscriptBox["g", "2"], "-", 
        SuperscriptBox["h", "2"]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"toPol", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
      ",", "h_"}], "}"}], ",", "\"\<Octs\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["c", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"a", ",", "c"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["d", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"b", ",", "d"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["e", "2"], "+", 
       SuperscriptBox["g", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"e", ",", "g"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["f", "2"], "+", 
       SuperscriptBox["h", "2"]}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"f", ",", "h"}], "]"}]}], "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "pp_", ",", "\[Phi]_", ",", "qq_", ",", "\[Psi]_", ",", "rr_", ",", 
       "\[Rho]_", ",", "ss_", ",", "\[Sigma]_"}], "}"}], ",", 
     "\"\<Octs\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Sqrt", "[", "pp", "]"}]}], ",", 
       RowBox[{"q", "=", 
        RowBox[{"Sqrt", "[", "qq", "]"}]}], ",", 
       RowBox[{"r", "=", 
        RowBox[{"Sqrt", "[", "rr", "]"}]}], ",", 
       RowBox[{"s", "=", 
        RowBox[{"Sqrt", "[", "ss", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], " ", ",", 
       RowBox[{"q", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ",", 
       RowBox[{"p", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}], " ", ",", 
       RowBox[{"q", " ", 
        RowBox[{"Sin", "[", "\[Psi]", "]"}]}], " ", ",", 
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "\[Rho]", "]"}]}], " ", ",", 
       RowBox[{"s", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], ",", 
       RowBox[{"r", " ", 
        RowBox[{"Sin", "[", "\[Rho]", "]"}]}], ",", 
       RowBox[{"s", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q8n\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"(*", 
      RowBox[{"L2", " ", "shapes", " ", "not", " ", "conserved"}], "*)"}], 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h"}], ",", "\[IndentingNewLine]", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"]}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3C3\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "7", ",", "9", ",", "8", ",", "4", ",", 
         "6", ",", "5", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", 
         ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{
        "a", ",", "c", ",", "b", ",", "g", ",", "i", ",", "h", ",", "d", ",", 
         "f", ",", "e"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+",
           "h", "+", "i"}], ")"}], " ", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "-", "d", "+", "f", "+", "h", "-", "i"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "+", "d", "-", "e", "+", "i", "-", "g"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "+", "e", "-", "f", "+", "g", "-",
               "h"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "e", "-", "f", "-", "g", "+", "i"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "-", "d", "+", "f", "+", "g", "-", "h"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "-", "d", "+", "e", "-", "h", "+", "i"}], 
             ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"c", "-", "a", "+", "f", "-", "d", "+", "i", "-", "g"}], 
             ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "+", "e", "+", "f", "-", "g", "-", "h", "-", "i"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], 
             ")"}], "2"]}], ")"}], "/", "2"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_"}], "}"}], ",", "\"\<C3C3\>\""}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "+", "i"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "-", "d", "+", "f", "+", "h", "-", "i"}], 
          ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c", "+", "d", "-", "e", "+", "i", "-", "g"}], 
          ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "c", "+", "e", "-", "f", "+", "g", "-", 
           "h"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", "d", "-", "e", "+", 
        
        RowBox[{"2", " ", "f"}], "-", "g", "+", 
        RowBox[{"2", " ", "h"}], "-", "i"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], 
        RowBox[{"(", 
         RowBox[{"b", "-", "c", "+", "d", "-", "e", "+", "i", "-", "g"}], 
         ")"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "e", "-", "f", "-", "g", "+", "i"}], 
          ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c", "-", "d", "+", "f", "+", "g", "-", "h"}], 
          ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "c", "-", "d", "+", "e", "-", "h", "+", "i"}], 
          ")"}], "2"]}], ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", "d", "+", 
        RowBox[{"2", " ", "e"}], "-", "f", "-", "g", "-", "h", "+", 
        RowBox[{"2", " ", "i"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], 
        RowBox[{"(", 
         RowBox[{"b", "-", "c", "-", "d", "+", "f", "+", "g", "-", "h"}], 
         ")"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h"}], 
          ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i"}], 
          ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "-", "a", "+", "f", "-", "d", "+", "i", "-", "g"}], 
          ")"}], "2"]}], ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
        RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "+", 
        RowBox[{"2", " ", "g"}], "-", "h", "-", "i"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], 
        RowBox[{"(", 
         RowBox[{"b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i"}], 
         ")"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], 
          ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "+", "e", "+", "f", "-", "g", "-", "h", "-", "i"}], 
          ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], 
          ")"}], "2"]}], ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "+", 
        RowBox[{"2", " ", "c"}], "-", "d", "-", "e", "-", "f", "-", "g", "-", 
        "h", "-", "i"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "e", "+", "f", "-", "g", "-", "h", "-", "i"}], 
         ")"}]}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Alpha]_", ",", "\[Zeta]2_", ",", "\[Theta]_", ",", "\[Eta]2_", ",", 
      "\[CurlyTheta]_", ",", "\[Kappa]2_", ",", "\[CurlyKappa]_", ",", 
      "\[Lambda]2_", ",", "\[Phi]_"}], "}"}], ",", "\"\<C3C3\>\""}], "]"}], ":=",
   
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Zeta]", "=", 
       SqrtBox["\[Zeta]2"]}], ",", 
      RowBox[{"\[Eta]", "=", 
       SqrtBox["\[Eta]2"]}], ",", 
      RowBox[{"\[Kappa]", "=", 
       SqrtBox["\[Kappa]2"]}], ",", 
      RowBox[{"\[Lambda]", "=", 
       SqrtBox["\[Lambda]2"]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "  ", 
      RowBox[{
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "               ", "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}]}], "                ", 
        "+", 
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[CurlyKappa]", "]"}]}], "               ", "+",
         
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ",", " ", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyTheta]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyKappa]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyTheta]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyKappa]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ",", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyTheta]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[CurlyKappa]", "]"}]}], "               ", "+",
         
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}]}], "               ", "+",
         
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyKappa]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", " ", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "               ", "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyTheta]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyKappa]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyTheta]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[CurlyKappa]", "]"}]}], "               ", "+",
         
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", " ", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "               ", "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyTheta]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyKappa]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", " ", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"2", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "+", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}]}], "               ", "+",
         
        RowBox[{"2", "\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[CurlyKappa]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
        RowBox[{"2", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", 
           RowBox[{"4", 
            RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}]}], "}"}], "/", "9"}]}],
    "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C6C3c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "9", ",", "8", ",", "7", ",", "6", ",", 
         "5", ",", "4", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",",
          "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}],
       ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "-", "i"}], ",", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "+", "i"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "d"}], "+", "e", "+", "f", "-", "g", "-", "h", "+",
               "i"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "+", "d", "+", "e", "-", "g", "+", "h"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "+", "d", "+", "f", "-", "g", "-", "i"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "e", "-", "f", "+", "h", "+", "i"}], 
             ")"}], "2"]}], ")"}], "/", "2"}], ",", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "d", "+", "f", "+", "g", "-", "h"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "-", "e", "+", "f", "+", "g", "+", "i"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "-", "d", "-", "e", "+", "h", "+", "i"}], 
             ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "+", "e", "-", "f", "+", "g", "-", "h"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "-", "d", "-", "e", "-", "g", "-", "i"}], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "-", "d", "-", "f", "-", "h", "-", "i"}], 
             ")"}], "2"]}], ")"}], "/", "2"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"sh", "[", "\"\<C9C3j\>\"", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{
        RowBox[{"gi", "=", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", 
           RowBox[{"-", "7"}], ",", 
           RowBox[{"-", "9"}], ",", 
           RowBox[{"-", "8"}], ",", 
           RowBox[{"-", "4"}], ",", 
           RowBox[{"-", "6"}], ",", 
           RowBox[{"-", "5"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", 
           "1"}], "}"}]}], ";", 
        RowBox[{"gp", "=", 
         RowBox[{"{", 
          RowBox[{
          "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", 
           ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
          "}"}]}], ";", 
        RowBox[{"plex", "=."}], ";", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", 
           "+", "h", "+", "i"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h"}], ")"}],
               "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "a", "-", "c", "-", "d", "+", "f", "+", "g", "-", "i"}], ")"}],
               "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i"}], ")"}],
               "2"]}], ")"}], "/", "2"}], ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "b", "-", "c", "+", "d", "-", "f", "+", "g", "-", "h"}], ")"}],
               "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "a", "-", "b", "-", "e", "+", "f", "-", "g", "+", "i"}], ")"}],
               "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "a", "-", "c", "+", "d", "-", "e", "-", "h", "+", "i"}], ")"}],
               "2"]}], ")"}], "/", "2"}], ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "a", "-", "c", "+", "e", "-", "f", "-", "g", "+", "h"}], ")"}],
               "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "b", "-", "c", "-", "d", "+", "e", "-", "g", "+", "i"}], ")"}],
               "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "a", "-", "b", "+", "d", "-", "f", "+", "h", "-", "i"}], ")"}],
               "2"]}], ")"}], "/", "2"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ")"}],
               "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "d", "+", "e", "+", "f", "+", "g", "+", "h", "+", "i"}], ")"}],
               "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], ")"}],
               "2"]}], ")"}], "/", "2"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "*)"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8",
  FontFamily->"Arial"],
 ".10 Shapes, Polar-Vector, Hyperbolics, ",
 StyleBox["sh, toPol, toVec, tohyPol, tohyVec ",
  FontSlant->"Italic"],
 "for 10 & 12 element loops."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3C4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "10", ",", "12", ",", "11", ",", "7", 
         ",", "9", ",", "8", ",", "4", ",", "6", ",", "5", ",", "1", ",", "1",
          ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{
        "a", ",", "c", ",", "b", ",", "d", ",", "f", ",", "e", ",", "g", ",", 
         "i", ",", "h", ",", "j", ",", "l", ",", "k"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], 
           ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}], 
           ")"}], "2"]}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", 
              "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
              "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "+",
               "i", "-", "j", "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", 
              "+", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", 
              "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "-", "g", "+",
               "i", "+", "j", "-", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"a", "+", "b", "-", 
                 RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
                 RowBox[{"2", "i"}]}], ")"}], "r3"}], "-", "d", "+", "e", "+",
               "j", "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "-", "g", "+", "h", "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"d", "+", "e", "-", 
                 RowBox[{"2", "f"}], "-", "j", "-", "k", "+", 
                 RowBox[{"2", "l"}]}], ")"}], "r3"}]}], ")"}], "2"]}], ")"}], 
         
         RowBox[{"3", "/", "4"}]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"a", "+", "b", "-", 
                 RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
                 RowBox[{"2", "i"}]}], ")"}], "r3"}], "+", "d", "-", "e", "-",
               "j", "+", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "-", "g", "+", "h", "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"d", "+", "e", "-", 
                 RowBox[{"2", "f"}], "-", "j", "-", "k", "+", 
                 RowBox[{"2", "l"}]}], ")"}], "r3"}]}], ")"}], "2"]}], ")"}], 
         
         RowBox[{"3", "/", "4"}]}]}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Beta]_", ",", "\[Epsilon]\[Epsilon]_", ",", 
       "\[Sigma]_", ",", "\[Zeta]\[Zeta]_", ",", "\[Tau]_", ",", 
       "\[Lambda]\[Lambda]_", ",", "\[Phi]_", ",", "\[Eta]\[Eta]_", ",", 
       "\[Chi]_", ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
     "\"\<C3C4\>\""}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "=", 
        RowBox[{"2", 
         SqrtBox["\[Epsilon]\[Epsilon]"]}]}], ",", 
       RowBox[{"\[Zeta]", "=", 
        RowBox[{"2", 
         SqrtBox["\[Zeta]\[Zeta]"]}]}], ",", 
       RowBox[{"\[Lambda]", "=", 
        RowBox[{"2", 
         SqrtBox["\[Lambda]\[Lambda]"]}]}], ",", 
       RowBox[{"\[Eta]", "=", 
        SqrtBox[
         RowBox[{"3", "\[Eta]\[Eta]"}]]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        SqrtBox[
         RowBox[{"3", "\[Kappa]\[Kappa]"}]]}], ",", 
       RowBox[{"x", "=", 
        RowBox[{"\[Chi]", "+", 
         RowBox[{"\[Pi]", "/", "6"}]}]}], ",", 
       RowBox[{"y", "=", 
        RowBox[{"\[Psi]", "+", 
         RowBox[{"\[Pi]", "/", "6"}]}]}]}], "}"}], ",", "\[IndentingNewLine]",
      
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"2", "\[Eta]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "-", 
         RowBox[{"2", "\[Kappa]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"2", "\[Eta]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "+", 
         RowBox[{"2", "\[Kappa]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"2", "\[Eta]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "+", 
         RowBox[{"2", "\[Kappa]", " ", "r3", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Sin", "[", "x", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Sin", "[", "y", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"2", "\[Eta]", "  ", "r3", " ", 
          RowBox[{"Cos", "[", "x", "]"}]}], "-", 
         RowBox[{"2", "\[Kappa]", " ", "r3", " ", 
          RowBox[{"Cos", "[", "y", "]"}]}]}]}], "}"}], "/", "12"}]}], "]"}]}],
   ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9],

Cell["\<\
Note that {\[Epsilon],\[Sigma]} defines 4-phases, {\[Zeta],\[Tau]} 3 phases, \
{\[Lambda],\[Phi]} 6 phases and both {\[Eta],\[Chi]} and {\[Kappa],\[Psi]} 12 \
phases. The {\[Eta],\[Chi]} and {\[Kappa],\[Psi]} systems are shown by the \
following plots:-\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vv", ":=", 
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "36", ",", "\[Chi]", ",", "0", ",", "0"}], "}"}], ",", 
     "\"\<C3C4\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "10", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "11", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"vv", "\[LeftDoubleBracket]", "12", "\[RightDoubleBracket]"}]}],
      "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Chi]", ",", "0", ",", 
      RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ";", 
  RowBox[{"vv", ":=", 
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "0", ",", "0", ",", "36", ",", "\[Psi]"}], "}"}], ",", 
     "\"\<C3C4\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vv", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "10", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "11", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "12", "\[RightDoubleBracket]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], "Input",
 FontSize->9],

Cell["\<\
Six of the 12 phases cancel if {\[Eta],\[Chi]} = {\[Kappa],\[Psi]} \
(displacement introduced to separate phases):-\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vv", ":=", 
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "1", ",", "\[Chi]", ",", "1", ",", "\[Chi]"}], "}"}], ",", 
     "\"\<C3C4\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vv", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "+", "0.01`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "+", "0.02`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
      "+", "0.03`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
      "+", "0.04`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
      "+", "0.05`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
      "+", "0.06`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
      "+", "0.07`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
      "+", "0.08`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "10", "\[RightDoubleBracket]"}], 
      "+", "0.09`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "11", "\[RightDoubleBracket]"}], 
      "+", "0.1`"}], ",", 
     RowBox[{
      RowBox[{"vv", "\[LeftDoubleBracket]", "12", "\[RightDoubleBracket]"}], 
      "+", "0.11`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Chi]", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], "Input",
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_"}], "}"}], ",", 
     "\"\<C3C4\>\""}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", 
       RowBox[{"r", "=", 
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}]}], ",", 
       RowBox[{"e1", "=", 
        RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}]}], 
       ",", 
       RowBox[{"e2", "=", 
        RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"a1", "=", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-", 
         "k"}]}], ",", 
       RowBox[{"a2", "=", 
        RowBox[{
        "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", "+", 
         "k"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"b1", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
          "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
           "-", "l"}], "]"}], "]"}]}], ",", 
       RowBox[{"b2", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
          "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", 
           "+", "l"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"c1", "=", 
        RowBox[{
        "c", "-", "a", "+", "f", "-", "d", "+", "i", "-", "g", "+", "l", "-", 
         "j"}]}], ",", 
       RowBox[{"c2", "=", 
        RowBox[{
        "c", "-", "a", "-", "f", "+", "d", "+", "i", "-", "g", "-", "l", "+", 
         "j"}]}], ",", 
       RowBox[{"f1", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
            RowBox[{"2", "l"}]}], ")"}], "r3"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"f2", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
            RowBox[{"2", "i"}]}], ")"}], "r3"}], "-", "d", "+", "e", "+", "j",
          "-", "k"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"f3", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
            RowBox[{"2", "l"}]}], ")"}], "r3"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"f4", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
            RowBox[{"2", "i"}]}], ")"}], "r3"}], "+", "d", "-", "e", "-", "j",
          "+", "k"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Chop", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Epsilon]", "=", 
         RowBox[{
          SuperscriptBox["e1", "2"], "+", 
          SuperscriptBox["e2", "2"]}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Epsilon]", "==", "0"}], "&&", 
           RowBox[{"e2", "\[Equal]", "0"}]}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"e1", ",", "e2"}], "]"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"e1", ",", "e2"}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a1", "2"], "+", 
           SuperscriptBox["b1", "2"], "+", 
           SuperscriptBox["c1", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b1", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a1", "-", "c1"}], ",", 
            RowBox[{"r", " ", "b1"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a2", "2"], "+", 
           SuperscriptBox["b2", "2"], "+", 
           SuperscriptBox["c2", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b2", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a2", "-", "c2"}], ",", 
            RowBox[{"r", " ", "b2"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["f1", "2"], "+", 
           SuperscriptBox["f2", "2"]}], ")"}], 
         RowBox[{"3", "/", "4"}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"f2", "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "6"}], ",", 
          RowBox[{
           RowBox[{"ArcTan", "[", 
            RowBox[{"f1", ",", "f2"}], "]"}], "-", 
           RowBox[{"\[Pi]", "/", "6"}]}]}], "]"}], ",", "\[IndentingNewLine]",
         
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["f3", "2"], "+", 
           SuperscriptBox["f4", "2"]}], ")"}], 
         RowBox[{"3", "/", "4"}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"f4", "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "6"}], ",", 
          RowBox[{
           RowBox[{"ArcTan", "[", 
            RowBox[{"f3", ",", "f4"}], "]"}], "-", 
           RowBox[{"\[Pi]", "/", "6"}]}]}], "]"}]}], "}"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3K\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "4", ",", "6", ",", "5", ",", "7", ",", 
         "9", ",", "8", ",", "10", ",", "12", ",", "11", ",", "1", ",", "1", 
         ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
         RowBox[{"-", "d"}], ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", "g", ",", "h", ",", "i", ",", 
         RowBox[{"-", "j"}], ",", 
         RowBox[{"-", "k"}], ",", 
         RowBox[{"-", "l"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "-", "i", "+", "j", "+", "k", "+", "l"}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", 
              "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
              "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "c", "-", "a", "+", "f", "-", "d", "+", "i", "-", "g", "+", "l", 
              "-", "j"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", 
              "+", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", 
              "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "c", "-", "a", "-", "f", "+", "d", "+", "i", "-", "g", "-", "l", 
              "+", "j"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "+", "d", "-", "e", "-", "g", "+", "h", "-", "j", 
              "+", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "+", "e", "-", "f", "-", "h", "+", "i", "-", "k", 
              "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "c", "-", "a", "+", "f", "-", "d", "-", "i", "+", "g", "-", "l", 
              "+", "j"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "-", "d", "+", "e", "-", "g", "+", "h", "+", "j", 
              "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "-", "e", "+", "f", "-", "h", "+", "i", "+", "k", 
              "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "c", "-", "a", "-", "f", "+", "d", "-", "i", "+", "g", "+", "l", 
              "-", "j"}], ")"}], "2"]}], ")"}], "/", "2"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_"}], "}"}], ",", 
     "\"\<C3K\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "=", 
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}]}], ",", 
       RowBox[{"a1", "=", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-", 
         "k"}]}], ",", 
       RowBox[{"a2", "=", 
        RowBox[{
        "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", "+", 
         "k"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"a3", "=", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "-", "g", "+", "h", "-", "j", "+", 
         "k"}]}], ",", 
       RowBox[{"a4", "=", 
        RowBox[{
        "a", "-", "b", "-", "d", "+", "e", "-", "g", "+", "h", "+", "j", "-", 
         "k"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"b1", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
          "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
           "-", "l"}], "]"}], "]"}]}], ",", 
       RowBox[{"b2", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
          "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", 
           "+", "l"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"b3", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
          "b", "-", "c", "+", "e", "-", "f", "-", "h", "+", "i", "-", "k", 
           "+", "l"}], "]"}], "]"}]}], ",", 
       RowBox[{"b4", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
          "b", "-", "c", "-", "e", "+", "f", "-", "h", "+", "i", "+", "k", 
           "-", "l"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"c1", "=", 
        RowBox[{
        "c", "-", "a", "+", "f", "-", "d", "+", "i", "-", "g", "+", "l", "-", 
         "j"}]}], ",", 
       RowBox[{"c2", "=", 
        RowBox[{
        "c", "-", "a", "-", "f", "+", "d", "+", "i", "-", "g", "-", "l", "+", 
         "j"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"c3", "=", 
        RowBox[{
        "c", "-", "a", "+", "f", "-", "d", "-", "i", "+", "g", "-", "l", "+", 
         "j"}]}], ",", 
       RowBox[{"c4", "=", 
        RowBox[{
        "c", "-", "a", "-", "f", "+", "d", "-", "i", "+", "g", "+", "l", "-", 
         "j"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Chop", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "-", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a1", "2"], "+", 
           SuperscriptBox["b1", "2"], "+", 
           SuperscriptBox["c1", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b1", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a1", "-", "c1"}], ",", 
            RowBox[{"r", " ", "b1"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a2", "2"], "+", 
           SuperscriptBox["b2", "2"], "+", 
           SuperscriptBox["c2", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b2", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a2", "-", "c2"}], ",", 
            RowBox[{"r", " ", "b2"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a3", "2"], "+", 
           SuperscriptBox["b3", "2"], "+", 
           SuperscriptBox["c3", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b3", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a3", "-", "c3"}], ",", 
            RowBox[{"r", " ", "b3"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a4", "2"], "+", 
           SuperscriptBox["b4", "2"], "+", 
           SuperscriptBox["c4", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b4", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a4", "-", "c4"}], ",", 
            RowBox[{"r", " ", "b4"}]}], "]"}]}], "]"}]}], "}"}], "]"}]}], 
    "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Alpha]_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
      "\[Zeta]\[Zeta]_", ",", "\[Tau]_", ",", "\[Lambda]\[Lambda]_", ",", 
      "\[Phi]_", ",", "\[Eta]\[Eta]_", ",", "\[Chi]_", ",", 
      "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", "\"\<C3K\>\""}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Zeta]", "=", 
       RowBox[{"2", 
        SqrtBox["\[Zeta]\[Zeta]"]}]}], ",", 
      RowBox[{"\[Lambda]", "=", 
       RowBox[{"2", 
        SqrtBox["\[Lambda]\[Lambda]"]}]}], ",", 
      RowBox[{"\[Eta]", "=", 
       RowBox[{"2", 
        SqrtBox["\[Eta]\[Eta]"]}]}], ",", 
      RowBox[{"\[Kappa]", "=", 
       RowBox[{"2", 
        SqrtBox["\[Kappa]\[Kappa]"]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"{", "  ", 
      RowBox[{
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}]}], "}"}], "/", 
     "12"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9],

Cell["\<\
Note that in C3K,  {\[Zeta],\[Tau]} defines 3 phases, {\[Lambda],\[Phi]} {\
\[Eta],\[Chi]} and {\[Kappa],\[Psi]} 6 phases in different sequences. 12 \
equal phases arise if {\[Eta],\[Chi]} = {\[Kappa],\[Psi]+\[Pi]/2}. These \
systems are shown by the following plots:-\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vv", ":=", 
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "\[Tau]", ",", "0", 
       ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     "\"\<C3K\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vv", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "10", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "11", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "12", "\[RightDoubleBracket]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"vv", ":=", 
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
       "\[Phi]", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     "\"\<C3K\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vv", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "10", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "11", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "12", "\[RightDoubleBracket]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"vv", ":=", 
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "1", ",", "\[Eta]", ",", "0", ",", "0"}], "}"}], ",", 
     "\"\<C3K\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vv", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "10", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "11", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "12", "\[RightDoubleBracket]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Eta]", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"vv", ":=", 
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       "0", ",", "1", ",", "\[Psi]", ",", "1", ",", 
       RowBox[{"\[Psi]", "+", 
        FractionBox["\[Pi]", "2"]}]}], "}"}], ",", "\"\<C3K\>\""}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vv", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "10", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "11", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"vv", "\[LeftDoubleBracket]", "12", "\[RightDoubleBracket]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], "Input",
 FontSize->9],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q12\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "10", ",", "11", ",", "12", ",", "7", 
         ",", "9", ",", "8", ",", "4", ",", "5", ",", "6", ",", "1", ",", "1",
          ",", "1", ",", "2", ",", "2"}], "}"}]}], ";", "\[IndentingNewLine]",
       
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      
      RowBox[{"plex", "=."}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], 
           ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}], 
           ")"}], "2"]}], ",", "\n", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "b"}], "+", "c", "-", "h", "+", "i"}], ")"}], "2"],
            "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "+", "g", "-", "i"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "g", "-", "h"}], ")"}], "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "e"}], "+", "f", "-", "k", "+", "l"}], ")"}], "2"],
            "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "f", "+", "j", "-", "l"}], ")"}], "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "e", "+", "j", "-", "k"}], ")"}], "2"]}], 
          ")"}], "/", "2"}], ",", "\n", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "b"}], "+", "c", "+", "h", "-", "i"}], ")"}], "2"],
            "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "-", "g", "+", "i"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "-", "g", "+", "h"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "e"}], "+", "f", "+", "k", "-", "l"}], ")"}], "2"],
            "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "f", "-", "j", "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "e", "-", "j", "+", "k"}], ")"}], "2"]}], 
          ")"}], "/", "2"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_"}], "}"}], ",", 
     "\"\<Q12\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", 
       RowBox[{"r", "=", 
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}]}], ",", 
       RowBox[{"g1", "=", 
        RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}]}], 
       ",", 
       RowBox[{"g2", "=", 
        RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"a1", "=", 
        RowBox[{"a", "-", "b", "+", "g", "-", "h"}]}], ",", 
       RowBox[{"a2", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"b1", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{"b", "-", "c", "+", "h", "-", "i"}], "]"}], "]"}]}], ",", 
       RowBox[{"b2", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{"b", "-", "c", "-", "h", "+", "i"}], "]"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"c1", "=", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "g", "+", "i"}]}], ",", 
       RowBox[{"c2", "=", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "g", "-", "i"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"d1", "=", 
        RowBox[{"d", "-", "e", "+", "j", "-", "k"}]}], ",", 
       RowBox[{"d2", "=", 
        RowBox[{"d", "-", "e", "-", "j", "+", "k"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"e1", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{"e", "-", "f", "+", "k", "-", "l"}], "]"}], "]"}]}], ",", 
       RowBox[{"e2", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{"e", "-", "f", "-", "k", "+", "l"}], "]"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"f1", "=", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "f", "-", "j", "+", "l"}]}], ",", 
       RowBox[{"f2", "=", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "f", "+", "j", "-", "l"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Chop", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Epsilon]", "=", 
         RowBox[{
          SuperscriptBox["g1", "2"], "+", 
          SuperscriptBox["g2", "2"]}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Epsilon]", "==", "0"}], "&&", 
           RowBox[{"g2", "\[Equal]", "0"}]}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"g1", ",", "g2"}], "]"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"g1", ",", "g2"}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a1", "2"], "+", 
           SuperscriptBox["b1", "2"], "+", 
           SuperscriptBox["c1", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b1", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a1", "-", "c1"}], ",", 
            RowBox[{"r", " ", "b1"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["d1", "2"], "+", 
           SuperscriptBox["e1", "2"], "+", 
           SuperscriptBox["f1", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"e1", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"d1", "-", "f1"}], ",", 
            RowBox[{"r", " ", "e1"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a2", "2"], "+", 
           SuperscriptBox["b2", "2"], "+", 
           SuperscriptBox["c2", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b2", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a2", "-", "c2"}], ",", 
            RowBox[{"r", " ", "b2"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["d2", "2"], "+", 
           SuperscriptBox["e2", "2"], "+", 
           SuperscriptBox["f2", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"e2", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"d2", "-", "f2"}], ",", 
            RowBox[{"r", " ", "e2"}]}], "]"}]}], "]"}]}], "}"}], "]"}]}], 
    "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Beta]_", ",", "\[Epsilon]\[Epsilon]_", ",", 
       "\[Sigma]_", ",", "\[Zeta]\[Zeta]_", ",", "\[Tau]_", ",", 
       "\[Lambda]\[Lambda]_", ",", "\[Phi]_", ",", "\[Eta]\[Eta]_", ",", 
       "\[Chi]_", ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
     "\"\<Q12\>\""}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "=", 
        RowBox[{"2", 
         SqrtBox["\[Epsilon]\[Epsilon]"]}]}], ",", 
       RowBox[{"\[Zeta]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Zeta]\[Zeta]"]}]}], ",", 
       RowBox[{"\[Lambda]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Lambda]\[Lambda]"]}]}], ",", 
       RowBox[{"\[Eta]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Eta]\[Eta]"]}]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Kappa]\[Kappa]"]}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"{", "  ", 
       RowBox[{
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "  ", "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "        ", "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "  ", "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "  ", "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "  ", "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "  ", "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], "  ", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "  ", "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "        ", "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "  ", "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "  ", "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"\[Epsilon]", "  ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "  ", "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "  ", "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}]}], "}"}], "/", 
      "12"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<D3C2\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "9", ",", "8", ",", "10", ",", "11", ",", "12", ",", "1", ",", "1", 
         ",", "1", ",", "1", ",", "2", ",", "2"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=."}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "-", "i", "+", "j", "+", "k", "+", "l"}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "g", "-", "h"}], ")"}], "^", "2"}], 
           "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "+", "h", "-", "i"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "-", "g", "+", "i"}], ")"}], "2"],
            "-", "\n", "\t ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "d"}], "+", "e", "-", "j", "+", "k"}], ")"}], "2"],
            "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "e"}], "+", "f", "-", "k", "+", "l"}], ")"}], "2"],
            "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "f", "+", "j", "-", "l"}], ")"}], "2"]}], 
          ")"}], "/", "2"}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "-", "g", "+", "h"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "-", "h", "+", "i"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "+", "g", "-", "i"}], ")"}], "2"],
            "-", "\n", "\t   ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "d"}], "+", "e", "+", "j", "-", "k"}], ")"}], "2"],
            "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "e"}], "+", "f", "+", "k", "-", "l"}], ")"}], "2"],
            "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "-", "f", "-", "j", "+", "l"}], ")"}], "2"]}], 
          ")"}], "/", "2"}]}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_"}], "}"}], ",", 
     "\"\<D3C2\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "=", 
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}]}], ",", 
       RowBox[{"a1", "=", 
        RowBox[{"a", "-", "b", "+", "g", "-", "h"}]}], ",", 
       RowBox[{"a2", "=", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "e", "-", "j", "+", "k"}]}], ",", 
       RowBox[{"a3", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h"}]}], ",", 
       RowBox[{"a4", "=", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "e", "+", "j", "-", "k"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"b1", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{"b", "-", "c", "+", "h", "-", "i"}], "]"}], "]"}]}], ",", 
       RowBox[{"b2", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
           RowBox[{"-", "e"}], "+", "f", "-", "k", "+", "l"}], "]"}], "]"}]}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"b3", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{"b", "-", "c", "-", "h", "+", "i"}], "]"}], "]"}]}], ",", 
       RowBox[{"b4", "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
           RowBox[{"-", "e"}], "+", "f", "+", "k", "-", "l"}], "]"}], "]"}]}],
        ",", "\[IndentingNewLine]", 
       RowBox[{"c1", "=", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "g", "+", "i"}]}], ",", 
       RowBox[{"c2", "=", 
        RowBox[{"d", "-", "f", "+", "j", "-", "l"}]}], ",", 
       RowBox[{"c3", "=", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "g", "-", "i"}]}], ",", 
       RowBox[{"c4", "=", 
        RowBox[{"d", "-", "f", "-", "j", "+", "l"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Chop", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "-", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a1", "2"], "+", 
           SuperscriptBox["b1", "2"], "+", 
           SuperscriptBox["c1", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b1", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a1", "-", "c1"}], ",", 
            RowBox[{"r", " ", "b1"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a2", "2"], "+", 
           SuperscriptBox["b2", "2"], "+", 
           SuperscriptBox["c2", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b2", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a2", "-", "c2"}], ",", 
            RowBox[{"r", " ", "b2"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a3", "2"], "+", 
           SuperscriptBox["b3", "2"], "+", 
           SuperscriptBox["c3", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b3", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a3", "-", "c3"}], ",", 
            RowBox[{"r", " ", "b3"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a4", "2"], "+", 
           SuperscriptBox["b4", "2"], "+", 
           SuperscriptBox["c4", "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b4", "\[Equal]", "0"}], ",", "0", ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"a4", "-", "c4"}], ",", 
            RowBox[{"r", " ", "b4"}]}], "]"}]}], "]"}]}], "}"}], "]"}]}], 
    "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
       "\[Zeta]\[Zeta]_", ",", "\[Tau]_", ",", "\[Lambda]\[Lambda]_", ",", 
       "\[Phi]_", ",", "\[Eta]\[Eta]_", ",", "\[Chi]_", ",", 
       "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", "\"\<D3C2\>\""}], 
    "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Zeta]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Zeta]\[Zeta]"]}]}], ",", 
       RowBox[{"\[Lambda]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Lambda]\[Lambda]"]}]}], ",", 
       RowBox[{"\[Eta]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Eta]\[Eta]"]}]}], ",", 
       RowBox[{"\[Kappa]", "=", 
        RowBox[{"4", 
         SqrtBox["\[Kappa]\[Kappa]"]}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"{", "      ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], " ", ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
         RowBox[{"\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"\[Kappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}]}], "}"}], "/", 
      "12"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<A4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "4", ",", "9", ",", "11", ",", "7", ",",
          "12", ",", "5", ",", "10", ",", "6", ",", "8", ",", "1", ",", "1", 
         ",", "3"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "+",
               "i", "-", "j", "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", 
              "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
              "-", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "d", "-", "g", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "d", "+", "g", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "d", "-", "g", "+", "j"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "+", "e", "-", "h", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "e", "+", "h", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "e", "-", "h", "+", "k"}], ")"}]}], "-", "\n", 
         "             \t", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "d", "+", "g", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "e", "-", "h", "+", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "+", "f", "-", "i", "-", "l"}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "d", "-", "g", "+", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "e", "-", "h", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "f", "+", "i", "-", "l"}], ")"}]}], "-", 
         "\[IndentingNewLine]", "   ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "d", "-", "g", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "e", "+", "h", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "f", "-", "i", "+", "l"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"c", "+", "f", "-", "i", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "f", "+", "i", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "f", "-", "i", "+", "l"}], ")"}]}]}]}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3Qr\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "2", ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "6"}], ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "9"}], ",", 
         RowBox[{"-", "8"}], ",", 
         RowBox[{"-", "10"}], ",", 
         RowBox[{"-", "12"}], ",", 
         RowBox[{"-", "11"}], ",", "2", ",", "2"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{"a", ",", "c", ",", "b", ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "g"}], ",", 
        RowBox[{"-", "i"}], ",", 
        RowBox[{"-", "h"}], ",", 
        RowBox[{"-", "j"}], ",", 
        RowBox[{"-", "l"}], ",", 
        RowBox[{"-", "k"}]}], "}"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"g", "+", "h", "+", "i"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"j", "+", "k", "+", "l"}], ")"}], "2"]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"c", "-", "a"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"d", "-", "e"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"e", "-", "f"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"f", "-", "d"}], ")"}], "2"], "+", "\n", "\t    ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"g", "-", "h"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"h", "-", "i"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"i", "-", "g"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"j", "-", "k"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"k", "-", "l"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"l", "-", "j"}], ")"}], "2"]}], ")"}], "^", "2"}], "/",
           "4"}], "-", 
         RowBox[{"3", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"b", " ", "d"}], "-", 
               RowBox[{"c", " ", "d"}], "-", 
               RowBox[{"a", " ", "e"}], "+", 
               RowBox[{"c", " ", "e"}], "+", 
               RowBox[{"a", " ", "f"}], "-", 
               RowBox[{"b", " ", "f"}]}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"h", " ", "j"}], "-", 
               RowBox[{"i", " ", "j"}], "-", 
               RowBox[{"g", " ", "k"}], "+", 
               RowBox[{"i", " ", "k"}], "+", 
               RowBox[{"g", " ", "l"}], "-", 
               RowBox[{"h", " ", "l"}]}], ")"}], "2"], "+", "\n", "\t", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"b", " ", "j"}], "-", 
               RowBox[{"c", " ", "j"}], "-", 
               RowBox[{"a", " ", "k"}], "+", 
               RowBox[{"c", " ", "k"}], "+", 
               RowBox[{"a", " ", "l"}], "-", 
               RowBox[{"b", " ", "l"}]}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"b", " ", "g"}], "-", 
               RowBox[{"c", " ", "g"}], "-", 
               RowBox[{"a", " ", "h"}], "+", 
               RowBox[{"c", " ", "h"}], "+", 
               RowBox[{"a", " ", "i"}], "-", 
               RowBox[{"b", " ", "i"}]}], ")"}], "2"], "+", "\n", "\t", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"e", " ", "g"}], "-", 
               RowBox[{"f", " ", "g"}], "-", 
               RowBox[{"d", " ", "h"}], "+", 
               RowBox[{"f", " ", "h"}], "+", 
               RowBox[{"d", " ", "i"}], "-", 
               RowBox[{"e", " ", "i"}]}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "e"}], " ", "j"}], "+", 
               RowBox[{"f", " ", "j"}], "+", 
               RowBox[{"d", " ", "k"}], "-", 
               RowBox[{"f", " ", "k"}], "-", 
               RowBox[{"d", " ", "l"}], "+", 
               RowBox[{"e", " ", "l"}]}], ")"}], "2"]}], ")"}]}]}]}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3P4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"(*", "?", "*)"}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "4", ",", "6", ",", "5", ",", "7", ",", 
         "9", ",", "8", ",", "10", ",", "12", ",", "11", ",", "2", ",", "2"}],
         "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{"a", ",", "c", ",", "b", ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "g"}], ",", 
        RowBox[{"-", "i"}], ",", 
        RowBox[{"-", "h"}], ",", 
        RowBox[{"-", "j"}], ",", 
        RowBox[{"-", "l"}], ",", 
        RowBox[{"-", "k"}]}], "}"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"g", "+", "h", "+", "i"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"j", "+", "k", "+", "l"}], ")"}], "2"]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"a", "-", "c"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"d", "-", "e"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"e", "-", "f"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"d", "-", "f"}], ")"}], "2"], "-", "\n", "\t    ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"g", "-", "h"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"h", "-", "i"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"g", "-", "i"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"j", "-", "k"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"k", "-", "l"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"j", "-", "l"}], ")"}], "2"]}], ")"}], "^", "2"}], "/",
           "4"}], "+", 
         RowBox[{"3", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"b", " ", "d"}], "-", 
               RowBox[{"c", " ", "d"}], "-", 
               RowBox[{"a", " ", "e"}], "+", 
               RowBox[{"c", " ", "e"}], "+", 
               RowBox[{"a", " ", "f"}], "-", 
               RowBox[{"b", " ", "f"}]}], ")"}], "2"], "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"h", " ", "j"}], "-", 
               RowBox[{"i", " ", "j"}], "-", 
               RowBox[{"g", " ", "k"}], "+", 
               RowBox[{"i", " ", "k"}], "+", 
               RowBox[{"g", " ", "l"}], "-", 
               RowBox[{"h", " ", "l"}]}], ")"}], "2"], "+", "\n", "\t", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"b", " ", "j"}], "-", 
               RowBox[{"c", " ", "j"}], "-", 
               RowBox[{"a", " ", "k"}], "+", 
               RowBox[{"c", " ", "k"}], "+", 
               RowBox[{"a", " ", "l"}], "-", 
               RowBox[{"b", " ", "l"}]}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"b", " ", "g"}], "-", 
               RowBox[{"c", " ", "g"}], "-", 
               RowBox[{"a", " ", "h"}], "+", 
               RowBox[{"c", " ", "h"}], "+", 
               RowBox[{"a", " ", "i"}], "-", 
               RowBox[{"b", " ", "i"}]}], ")"}], "2"], "-", "\n", "\t", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"e", " ", "g"}], "-", 
               RowBox[{"f", " ", "g"}], "-", 
               RowBox[{"d", " ", "h"}], "+", 
               RowBox[{"f", " ", "h"}], "+", 
               RowBox[{"d", " ", "i"}], "-", 
               RowBox[{"e", " ", "i"}]}], ")"}], "2"], "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "e"}], " ", "j"}], "+", 
               RowBox[{"f", " ", "j"}], "+", 
               RowBox[{"d", " ", "k"}], "-", 
               RowBox[{"f", " ", "k"}], "-", 
               RowBox[{"d", " ", "l"}], "+", 
               RowBox[{"e", " ", "l"}]}], ")"}], "2"]}], ")"}]}]}]}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C6Kr\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "4", ",", "6", ",", "5", ",", "7", ",", 
         "9", ",", "8", ",", "10", ",", "12", ",", "11", ",", "1", ",", "1", 
         ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{
        "a", ",", "c", ",", "b", ",", "d", ",", "f", ",", "e", ",", "g", ",", 
         "i", ",", "h", ",", "j", ",", "l", ",", "k"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "-", "f", "+", "g", "-", 
         "h", "-", "i", "+", "j", "-", "k", "-", "l"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "+", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "-", "b", "-", "c", "-", "d", "+", "e", "+", "f", "+", "g", "-", 
         "h", "-", "i", "-", "j", "+", "k", "+", "l"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "+", "k", "+", "l"}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "+", "b", "-", "d", "-", "e", "-", "g", "-", "h", "+", "j", 
              "+", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "-", "e", "+", "f", "-", "h", "+", "i", "+", "k", 
              "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "+", "c", "-", "d", "-", "f", "-", "g", "-", "i", "+", "j", 
              "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "+", "b", "-", "d", "-", "e", "+", "g", "+", "h", "-", "j", 
              "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", 
              "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "+", "c", "-", "d", "-", "f", "+", "g", "+", "i", "-", "j", 
              "-", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "+", "b", "+", "d", "+", "e", "+", "g", "+", "h", "+", "j", 
              "+", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
              "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "+", "c", "+", "d", "+", "f", "+", "g", "+", "i", "+", "j", 
              "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "+", "b", "+", "d", "+", "e", "-", "g", "-", "h", "-", "j", 
              "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "+", "e", "-", "f", "-", "h", "+", "i", "-", "k", 
              "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "+", "c", "+", "d", "+", "f", "-", "g", "-", "i", "-", "j", 
              "-", "l"}], ")"}], "2"]}], ")"}], "/", "2"}]}], "}"}]}]}], 
    "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C3KC2r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "3", ",", "2", ",", "4", ",", "6", ",", "5", ",", "7", ",", 
         "9", ",", "8", ",", "10", ",", "12", ",", "11", ",", "1", ",", "1", 
         ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.", ",", "1", ",",
          "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"plex", "=", 
       RowBox[{"{", 
        RowBox[{
        "a", ",", "c", ",", "b", ",", "d", ",", "f", ",", "e", ",", "g", ",", 
         "i", ",", "h", ",", "j", ",", "l", ",", "k"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "-", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "-", 
         "h", "-", "i", "+", "j", "+", "k", "+", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "+", "d", "-", "e", "-", "g", "-", "h", "+", "j", 
              "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
              "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "+", "g", "+",
               "i", "-", "j", "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], 
        ",", "\n", "\t", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "-", "d", "+", "e", "+", "g", "+", "h", "+", "j", 
              "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "-", "e", "+", "f", "-", "h", "+", "i", "+", "k", 
              "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "-", "g", "-",
               "i", "-", "j", "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "-", "d", "+", "e", "-", "g", "-", "h", "-", "j", 
              "+", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", 
              "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "+", "g", "+",
               "i", "+", "j", "-", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "a", "-", "b", "+", "d", "-", "e", "+", "g", "+", "h", "-", "j", 
              "+", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
             "b", "-", "c", "+", "e", "-", "f", "-", "h", "+", "i", "-", "k", 
              "+", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "-",
               "i", "+", "j", "-", "l"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q12C2c\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"plex", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "6", ",", "5", ",", "4", ",", "3", ",", "2", ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "8"}], ",", 
         RowBox[{"-", "9"}], ",", 
         RowBox[{"-", "10"}], ",", 
         RowBox[{"-", "11"}], ",", 
         RowBox[{"-", "12"}], ",", "1", ",", "2", ",", "2", ",", "1"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0."}], "}"}]}], ";", "\n", "\t", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], 
           ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"g", "-", "h", "+", "i", "-", "j", "+", "k", "-", "l"}], 
           ")"}], "2"]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "d", "-", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "+", "d", "-", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"g", "-", "h", "+", "j", "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"g", "-", "i", "+", "j", "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"h", "-", "i", "+", "k", "-", "l"}], ")"}], "2"]}], 
          ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "d", "-", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "+", "c", "-", "e", "-", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c", "-", "d", "+", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"g", "+", "h", "-", "j", "-", "k"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"h", "+", "i", "-", "k", "-", "l"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"g", "-", "i", "-", "j", "+", "l"}], ")"}], "2"]}], 
          ")"}], "/", "2"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], 
           ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"g", "+", "h", "+", "i", "+", "j", "+", "k", "+", "l"}], 
           ")"}], "2"]}]}], "}"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<D3Mn\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "5", ",", "4", ",", "3", ",", "7", ",", 
         "\[IndentingNewLine]", "8", ",", "9", ",", "10", ",", "11", ",", 
         "12", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2", 
         ",", "2", ",", "2"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "-", "i", "+", "j", "-", "k", "+", "l"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", "Unknown"}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 Evaluatable->False,
 InitializationCell->True,
 TextJustification->0,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh12", "[", 
    RowBox[{"{", 
     RowBox[{
     "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
      ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_"}], "}"}], "]"}], ":=",
    
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ab", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h"}]}], ",", 
       RowBox[{"ag", "=", 
        RowBox[{"a", "-", "b", "+", "g", "-", "h"}]}], ",", 
       RowBox[{"bc", "=", 
        RowBox[{"b", "-", "c", "-", "h", "+", "i"}]}], ",", 
       RowBox[{"bh", "=", 
        RowBox[{"b", "-", "c", "+", "h", "-", "i"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ca", "=", 
        RowBox[{"a", "-", "c", "-", "g", "+", "i"}]}], ",", 
       RowBox[{"ci", "=", 
        RowBox[{"a", "-", "c", "+", "g", "-", "i"}]}], ",", 
       RowBox[{"de", "=", 
        RowBox[{"d", "-", "e", "-", "j", "+", "k"}]}], ",", 
       RowBox[{"dj", "=", 
        RowBox[{"d", "-", "e", "+", "j", "-", "k"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ef", "=", 
        RowBox[{"e", "-", "f", "-", "k", "+", "l"}]}], ",", 
       RowBox[{"ek", "=", 
        RowBox[{"e", "-", "f", "+", "k", "-", "l"}]}], ",", 
       RowBox[{"fd", "=", 
        RowBox[{"d", "-", "f", "-", "j", "+", "l"}]}], ",", 
       RowBox[{"fl", "=", 
        RowBox[{"d", "-", "f", "+", "j", "-", "l"}]}], ",", 
       RowBox[{"f1", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
            RowBox[{"2", "l"}]}], ")"}], "/", 
          SqrtBox["3"]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"f2", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
            RowBox[{"2", "i"}]}], ")"}], "/", 
          SqrtBox["3"]}], "-", "d", "+", "e", "+", "j", "-", "k"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"f3", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
            RowBox[{"2", "l"}]}], ")"}], "/", 
          SqrtBox["3"]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"f4", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
            RowBox[{"2", "i"}]}], ")"}], "/", 
          SqrtBox["3"]}], "+", "d", "-", "e", "-", "j", "+", "k"}]}], ",", 
       "abef", ",", "agek"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"abef", "=", 
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ab", " ", "ef"}], "-", 
           RowBox[{"bc", " ", "de"}]}], ")"}], "2"]}]}], ";", 
      RowBox[{"agek", "=", 
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ag", " ", "ek"}], "-", 
           RowBox[{"bh", " ", "dj"}]}], ")"}], "2"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"o1", "=", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+",
           "h", "+", "i", "+", "j", "+", "k", "+", "l"}]}], ",", 
        RowBox[{"o2", "=", 
         RowBox[{
         "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+",
           "h", "+", "i", "-", "j", "-", "k", "-", "l"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"o3", "=", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-",
           "h", "-", "i", "-", "j", "-", "k", "-", "l"}]}], ",", 
        RowBox[{"o4", "=", 
         RowBox[{
         "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "-",
           "h", "-", "i", "+", "j", "+", "k", "+", "l"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "5", "*)"}], 
        RowBox[{"l22a", "=", 
         RowBox[{"3", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["f1", "2"], "+", 
             SuperscriptBox["f2", "2"]}], ")"}], "/", "4"}]}]}], ",", 
        RowBox[{"(*", "6", "*)"}], 
        RowBox[{"l22b", "=", 
         RowBox[{"3", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["f3", "2"], "+", 
             SuperscriptBox["f4", "2"]}], ")"}], "/", "4"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "7", "*)"}], 
        RowBox[{"p22", "=", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c", "+", "g", "+", "h", "+", "i"}], 
            ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "+", "e", "+", "f", "+", "j", "+", "k", "+", "l"}], 
            ")"}], "2"]}]}], ",", 
        RowBox[{"(*", "8", "*)"}], 
        RowBox[{"q22", "=", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], 
            ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}], 
            ")"}], "2"]}]}], ",", 
        RowBox[{"(*", "9", "*)"}], 
        RowBox[{"r22", "=", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c", "+", "g", "+", "h", "+", "i"}], 
            ")"}], "2"], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "+", "e", "+", "f", "+", "j", "+", "k", "+", "l"}], 
            ")"}], "2"]}]}], ",", 
        RowBox[{"(*", "10", "*)"}], 
        RowBox[{"s22", "=", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], 
            ")"}], "2"], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}], 
            ")"}], "2"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "11", "*)"}], 
        RowBox[{"p23", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"ag", "+", "dj"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"bh", "+", "ek"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"ci", "+", "fl"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
        ",", 
        RowBox[{"(*", "12", "*)"}], 
        RowBox[{"q23", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"ag", "-", "dj"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"bh", "-", "ek"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"ci", "-", "fl"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "13", "*)"}], 
        RowBox[{"r23", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"ab", "+", "de"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"bc", "+", "ef"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"ca", "+", "fd"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
        ",", 
        RowBox[{"(*", "14", "*)"}], 
        RowBox[{"s23", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"ab", "-", "de"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"bc", "-", "ef"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"ca", "-", "fd"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "15", "*)"}], 
        RowBox[{"q24", "=", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"g", "+", "h", "+", "i"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"j", "+", "k", "+", "l"}], ")"}], "2"]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "16", "*)"}], 
        RowBox[{"s24", "=", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "2"], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "+", "e", "+", "f"}], ")"}], "2"], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"g", "+", "h", "+", "i"}], ")"}], "2"], "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"j", "+", "k", "+", "l"}], ")"}], "2"]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "17", "*)"}], 
        RowBox[{"p26", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["ag", "2"], "+", 
            SuperscriptBox["bh", "2"], "+", 
            SuperscriptBox["ci", "2"], "-", 
            SuperscriptBox["dj", "2"], "-", 
            SuperscriptBox["fl", "2"], "-", 
            SuperscriptBox["ek", "2"]}], ")"}], "/", "2"}]}], ",", 
        RowBox[{"(*", "18", "*)"}], 
        RowBox[{"q26", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["ab", "2"], "+", 
            SuperscriptBox["bc", "2"], "+", 
            SuperscriptBox["ca", "2"], "-", 
            SuperscriptBox["de", "2"], "-", 
            SuperscriptBox["ef", "2"], "-", 
            SuperscriptBox["fd", "2"]}], ")"}], "/", "2"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "19", "*)"}], 
        RowBox[{"r26", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["ag", "2"], "+", 
            SuperscriptBox["bh", "2"], "+", 
            SuperscriptBox["ci", "2"], "+", 
            SuperscriptBox["dj", "2"], "+", 
            SuperscriptBox["fl", "2"], "+", 
            SuperscriptBox["ek", "2"]}], ")"}], "/", "2"}]}], ",", 
        RowBox[{"(*", "20", "*)"}], 
        RowBox[{"s26", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["ab", "2"], "+", 
            SuperscriptBox["bc", "2"], "+", 
            SuperscriptBox["ca", "2"], "+", 
            SuperscriptBox["de", "2"], "+", 
            SuperscriptBox["ef", "2"], "+", 
            SuperscriptBox["fd", "2"]}], ")"}], "/", "2"}]}], ",", "\n", 
        "        ", 
        RowBox[{"(*", "21", "*)"}], " ", 
        RowBox[{"l3", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "d", "-", "g", "-", "j"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "d", "+", "g", "-", "j"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "d", "-", "g", "+", "j"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "+", "e", "-", "h", "-", "k"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"b", "-", "e", "+", "h", "-", "k"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"b", "-", "e", "-", "h", "+", "k"}], ")"}]}], "+", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"c", "+", "f", "-", " ", "i", " ", "-", "l"}], ")"}], " ",
            
           RowBox[{"(", 
            RowBox[{"c", "-", "f", "+", " ", "i", " ", "-", "l"}], ")"}], " ",
            
           RowBox[{"(", 
            RowBox[{"c", "-", "f", "-", " ", "i", " ", "+", "l"}], ")"}]}], 
          "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "d", "+", "g", "-", "j"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"b", "-", "e", "-", "h", "+", "k"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"c", "+", "f", "-", " ", "i", " ", "-", "l"}], ")"}]}], 
          "-", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "d", "-", "g", "+", "j"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"b", "+", "e", "-", "h", "-", "k"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"c", "-", "f", "+", "i", "-", "l"}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "d", "-", "g", "-", "j"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"b", "-", "e", "+", "h", "-", "k"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"c", "-", "f", "-", " ", "i", " ", "+", "l"}], 
            ")"}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "22", "*)"}], 
        RowBox[{"l4p", "=", 
         RowBox[{
          SuperscriptBox["p26", "2"], "+", "agek"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "23", "*)"}], 
        RowBox[{"l4q", "=", 
         RowBox[{
          SuperscriptBox["q26", "2"], "+", "abef"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "24", "*)"}], 
        RowBox[{"l4r", "=", 
         RowBox[{
          SuperscriptBox["r26", "2"], "-", 
          RowBox[{"3", "agek"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "25", "*)"}], 
        RowBox[{"l4s", "=", 
         RowBox[{"l22a", " ", "l22b"}]}], 
        RowBox[{"(*", 
         RowBox[{
          SuperscriptBox["s26", "2"], "-", "abef"}], "*)"}], ",", 
        RowBox[{"(*", "26", "*)"}], 
        RowBox[{"L4Q", "=", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"d", "-", "e"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"e", "-", "f"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"d", "-", "f"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"g", "-", "h"}], ")"}], "2"], "+", 
              "\[IndentingNewLine]", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"h", "-", "i"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"g", "-", "i"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"j", "-", "k"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"k", "-", "l"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"j", "-", "l"}], ")"}], "2"]}], ")"}], "^", "2"}], 
           "/", "4"}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"(", 
                  RowBox[{"f", "-", "e"}], ")"}]}], "+", 
                RowBox[{"b", " ", 
                 RowBox[{"(", 
                  RowBox[{"d", "-", "f"}], ")"}]}], "+", 
                RowBox[{"c", " ", 
                 RowBox[{"(", 
                  RowBox[{"e", "-", "d"}], ")"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"(", 
                  RowBox[{"i", "-", "h"}], ")"}]}], "+", 
                RowBox[{"b", " ", 
                 RowBox[{"(", 
                  RowBox[{"g", "-", "i"}], ")"}]}], "+", 
                RowBox[{"c", " ", 
                 RowBox[{"(", 
                  RowBox[{"h", "-", "g"}], ")"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"d", " ", 
                 RowBox[{"(", 
                  RowBox[{"h", "-", "i"}], ")"}]}], "+", 
                RowBox[{"e", " ", 
                 RowBox[{"(", 
                  RowBox[{"i", "-", "g"}], ")"}]}], "+", 
                RowBox[{"f", " ", 
                 RowBox[{"(", 
                  RowBox[{"g", "-", "h"}], ")"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"g", " ", 
                 RowBox[{"(", 
                  RowBox[{"k", "-", "l"}], ")"}]}], "+", 
                RowBox[{"h", " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "-", "j"}], ")"}]}], "+", 
                RowBox[{"i", " ", 
                 RowBox[{"(", 
                  RowBox[{"j", "-", "k"}], ")"}]}]}], ")"}], "2"], "+", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"e", "-", "f"}], ")"}], "2"]}], ")"}], " ", 
              SuperscriptBox["j", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"d", "-", "f"}], ")"}], "2"]}], ")"}], " ", 
              SuperscriptBox["k", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"d", "-", "e"}], ")"}], "2"]}], ")"}], " ", 
              SuperscriptBox["l", "2"]}]}], ")"}]}], "+", 
          "\[IndentingNewLine]", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"c", "-", "a"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"c", "-", "b"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"f", "-", "d"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"f", "-", "e"}], ")"}]}]}], ")"}], " ", "j", " ", 
              "k"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"b", "-", "a"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"b", "-", "c"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"e", "-", "d"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"e", "-", "f"}], ")"}]}]}], ")"}], " ", "j", " ", 
              "l"}], "+", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"a", "-", "b"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"a", "-", "c"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"d", "-", "e"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"d", "-", "f"}], ")"}]}]}], ")"}], " ", "k", " ", 
              "l"}]}], ")"}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "27", "*)"}], 
        RowBox[{"L4\[Sigma]", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"c", "-", "a"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"d", "-", "e"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"e", "-", "f"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"f", "-", "d"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"g", "-", "h"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"h", "-", "i"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"i", "-", "g"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"j", "-", "k"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"k", "-", "l"}], ")"}], "2"], "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"l", "-", "j"}], ")"}], "2"]}], ")"}], "^", "2"}], 
           "/", "4"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"b", " ", "d"}], "-", 
                RowBox[{"c", " ", "d"}], "-", 
                RowBox[{"a", " ", "e"}], "+", 
                RowBox[{"c", " ", "e"}], "+", 
                RowBox[{"a", " ", "f"}], "-", 
                RowBox[{"b", " ", "f"}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"b", " ", "g"}], "-", 
                RowBox[{"c", " ", "g"}], "-", 
                RowBox[{"a", " ", "h"}], "+", 
                RowBox[{"c", " ", "h"}], "+", 
                RowBox[{"a", " ", "i"}], "-", 
                RowBox[{"b", " ", "i"}]}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"e", " ", "g"}], "-", 
                RowBox[{"f", " ", "g"}], "-", 
                RowBox[{"d", " ", "h"}], "+", 
                RowBox[{"f", " ", "h"}], "+", 
                RowBox[{"d", " ", "i"}], "-", 
                RowBox[{"e", " ", "i"}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"b", " ", "j"}], "-", 
                RowBox[{"c", " ", "j"}], "-", 
                RowBox[{"a", " ", "k"}], "+", 
                RowBox[{"c", " ", "k"}], "+", 
                RowBox[{"a", " ", "l"}], "-", 
                RowBox[{"b", " ", "l"}]}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "e"}], " ", "j"}], "+", 
                RowBox[{"f", " ", "j"}], "+", 
                RowBox[{"d", " ", "k"}], "-", 
                RowBox[{"f", " ", "k"}], "-", 
                RowBox[{"d", " ", "l"}], "+", 
                RowBox[{"e", " ", "l"}]}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"h", " ", "j"}], "-", 
                RowBox[{"i", " ", "j"}], "-", 
                RowBox[{"g", " ", "k"}], "+", 
                RowBox[{"i", " ", "k"}], "+", 
                RowBox[{"g", " ", "l"}], "-", 
                RowBox[{"h", " ", "l"}]}], ")"}], "2"]}], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "28", "*)"}], 
        RowBox[{"L4a3", "=", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"ag", "+", "dj"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"bh", "+", "ek"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"ci", "+", "fl"}], ")"}], "2"]}], ")"}], "2"], "/", 
           "4"}], "+", "agek"}]}], ",", 
        RowBox[{"(*", "29", "*)"}], 
        RowBox[{"L4b3", "=", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"ag", "-", "dj"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"bh", "-", "ek"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"ci", "-", "fl"}], ")"}], "2"]}], ")"}], "2"], "/", 
           "4"}], "+", "agek"}]}], ",", 
        RowBox[{"(*", "30", "*)"}], 
        RowBox[{"L4c3", "=", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"ab", "+", "de"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"bc", "+", "ef"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"ca", "+", "fd"}], ")"}], "2"]}], ")"}], "2"], "/", 
           "4"}], "-", "abef"}]}], ",", 
        RowBox[{"(*", "31", "*)"}], 
        RowBox[{"L4d3", "=", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"ab", "-", "de"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"bc", "-", "ef"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"ca", "-", "fd"}], ")"}], "2"]}], ")"}], "2"], "/", 
           "4"}], "-", "abef"}]}], ",", 
        RowBox[{"(*", "32", "*)"}], 
        RowBox[{"L4a6", "=", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ag", "2"], "+", 
              SuperscriptBox["bh", "2"], "+", 
              SuperscriptBox["ci", "2"], "-", 
              SuperscriptBox["dj", "2"], "-", 
              SuperscriptBox["fl", "2"], "-", 
              SuperscriptBox["ek", "2"]}], ")"}], "2"], "/", "4"}], "+", 
          "agek"}]}], ",", 
        RowBox[{"(*", "33", "*)"}], 
        RowBox[{"L4b6", "=", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ab", "2"], "+", 
              SuperscriptBox["bc", "2"], "+", 
              SuperscriptBox["ca", "2"], "-", 
              SuperscriptBox["de", "2"], "-", 
              SuperscriptBox["ef", "2"], "-", 
              SuperscriptBox["fd", "2"]}], ")"}], "2"], "/", "4"}], "+", 
          "abef"}]}], ",", 
        RowBox[{"(*", "34", "*)"}], 
        RowBox[{"L4c6", "=", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ab", "2"], "+", 
              SuperscriptBox["bc", "2"], "+", 
              SuperscriptBox["ca", "2"], "-", 
              SuperscriptBox["de", "2"], "-", 
              SuperscriptBox["ef", "2"], "-", 
              SuperscriptBox["fd", "2"]}], ")"}], "2"], "/", "4"}], "-", 
          "abef"}]}], ",", "\n", "\t", 
        RowBox[{"(*", "35", "*)"}], 
        RowBox[{"L4d6", "=", " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ag", "2"], "+", 
              SuperscriptBox["bh", "2"], "+", 
              SuperscriptBox["ci", "2"], "+", 
              SuperscriptBox["dj", "2"], "+", 
              SuperscriptBox["fl", "2"], "+", 
              SuperscriptBox["ek", "2"]}], ")"}], "2"], "/", "4"}], "-", 
          "agek"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "36", "*)"}], 
        RowBox[{"L49", "=", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ab", "2"], "-", 
              SuperscriptBox["de", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ab", "2"], "-", 
              SuperscriptBox["ef", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ab", "2"], "-", 
              SuperscriptBox["fd", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bc", "2"], "-", 
              SuperscriptBox["de", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bc", "2"], "-", 
              SuperscriptBox["ef", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bc", "2"], "-", 
              SuperscriptBox["fd", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ca", "2"], "-", 
              SuperscriptBox["de", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ca", "2"], "-", 
              SuperscriptBox["ef", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ca", "2"], "-", 
              SuperscriptBox["fd", "2"]}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "37", "*)"}], 
        RowBox[{"L49a", "=", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ag", "2"], "-", 
              SuperscriptBox["dj", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ag", "2"], "-", 
              SuperscriptBox["ek", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ag", "2"], "-", 
              SuperscriptBox["fl", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bh", "2"], "-", 
              SuperscriptBox["dj", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bh", "2"], "-", 
              SuperscriptBox["ek", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bh", "2"], "-", 
              SuperscriptBox["fl", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ci", "2"], "-", 
              SuperscriptBox["dj", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ci", "2"], "-", 
              SuperscriptBox["ek", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ci", "2"], "-", 
              SuperscriptBox["fl", "2"]}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "38", "*)"}], 
        RowBox[{"L49b", "=", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ab", "2"], "-", 
              SuperscriptBox["dj", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ab", "2"], "-", 
              SuperscriptBox["ek", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ab", "2"], "-", 
              SuperscriptBox["fl", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bc", "2"], "-", 
              SuperscriptBox["dj", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bc", "2"], "-", 
              SuperscriptBox["ek", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bc", "2"], "-", 
              SuperscriptBox["fl", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ca", "2"], "-", 
              SuperscriptBox["dj", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ca", "2"], "-", 
              SuperscriptBox["ek", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ca", "2"], "-", 
              SuperscriptBox["fl", "2"]}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "39", "*)"}], 
        RowBox[{"L49c", "=", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ag", "2"], "-", 
              SuperscriptBox["de", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ag", "2"], "-", 
              SuperscriptBox["ef", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ag", "2"], "-", 
              SuperscriptBox["fd", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bh", "2"], "-", 
              SuperscriptBox["de", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bh", "2"], "-", 
              SuperscriptBox["ef", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["bh", "2"], "-", 
              SuperscriptBox["fd", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ci", "2"], "-", 
              SuperscriptBox["de", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ci", "2"], "-", 
              SuperscriptBox["ef", "2"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["ci", "2"], "-", 
              SuperscriptBox["fd", "2"]}], ")"}], "2"]}], ")"}]}]}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 PageBreakWithin->Automatic,
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{"ds", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<o1\>\"", ",", "\"\<o2\>\"", ",", "\"\<o3\>\"", ",", "\"\<o4\>\"", 
     ",", "\"\<l22a\>\"", ",", "\"\<l22b\>\"", ",", "\"\<p22\>\"", ",", 
     "\"\<q22\>\"", ",", "\"\<r22\>\"", ",", "\"\<s22\>\"", ",", 
     "\"\<p23\>\"", ",", "\"\<q23\>\"", ",", "\"\<r23\>\"", ",", 
     "\"\<s23\>\"", ",", "\"\<q24\>\"", ",", "\"\<s24\>\"", ",", 
     "\"\<p26\>\"", ",", "\"\<q26\>\"", ",", "\"\<r26\>\"", ",", 
     "\"\<s26\>\"", ",", "\"\<l3\>\"", ",", "\"\<l4p\>\"", ",", "\"\<l4q\>\"",
      ",", "\"\<l4r\>\"", ",", "\"\<l4s\>\"", ",", "\"\<L4Q\>\"", ",", 
     "\"\<L4\[Sigma]\>\"", ",", "\"\<L4a3\>\"", ",", "\"\<L4b3\>\"", ",", 
     "\"\<L4c3\>\"", ",", "\"\<L4d3\>\"", ",", "\"\<L4a6\>\"", ",", 
     "\"\<L4b6\>\"", ",", "\"\<L4c6\>\"", ",", "\"\<L4d6\>\"", ",", 
     "\"\<L49\>\"", ",", "\"\<L49a\>\"", ",", "\"\<L49b\>\"", ",", 
     "\"\<L49c\>\""}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8",
  FontFamily->"Arial"],
 ".11 Polar-Vector, Hyperbolics, ",
 StyleBox["sh, toPol, toVec, tohyPol, tohyVec, ",
  FontSlant->"Italic"],
 "16 element loops."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<D8\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "15", ",", "4", ",", "13", ",", "6", ",", "11", 
         ",", "8", ",", "9", ",", "10", ",", "7", ",", "12", ",", "5", ",", 
         "14", ",", "3", ",", "16", ",", "1", ",", "1", ",", "1", ",", "1", 
         ",", "2", ",", "2"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "e", "+", "i", "-", "m"}], ")"}], "^", "2"}], 
         "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "f", "+", "j", "-", "n"}], ")"}], "^", "2"}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"c", "-", "g", "+", "k", "-", "o"}], ")"}], "^", "2"}], 
         "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "-", "h", "+", "l", "-", "p"}], ")"}], "^", "2"}]}], 
        ",", 
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"a", "-", "i"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"c", "-", "k"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"b", "-", "j"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"d", "-", "l"}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"c", "-", "k"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"e", "-", "m"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"d", "-", "l"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"f", "-", "n"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"a", "-", "i"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"g", "-", "o"}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"e", "-", "m"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"g", "-", "o"}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"b", "-", "j"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"h", "-", "p"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"f", "-", "n"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"h", "-", "p"}], ")"}]}]}], ")"}], "^", "2"}]}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q16\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "10", ",", "15", ",", "12", ",", "13", ",", "14", ",", "11",
          ",", "16", ",", "9", ",", "2", ",", "7", ",", "4", ",", "5", ",", 
         "6", ",", "3", ",", "8", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "2", ",", "2"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "e", "+", "i", "-", "m"}], ")"}], "^", "2"}], 
         "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "f", "+", "j", "-", "n"}], ")"}], "^", "2"}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"c", "-", "g", "+", "k", "-", "o"}], ")"}], "^", "2"}], 
         "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "-", "h", "+", "l", "-", "p"}], ")"}], "^", "2"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "i"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "j"}], ")"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "j"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "k"}], ")"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], "4"], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "i"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "-", "l"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "k"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "-", "l"}], ")"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], "4"], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "k"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "i"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"e", "-", "m"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "j"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"e", "-", "m"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "-", "l"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"e", "-", "m"}], ")"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], "4"], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "-", "l"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "i"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"f", "-", "n"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "j"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"f", "-", "n"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "k"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"f", "-", "n"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"e", "-", "m"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"f", "-", "n"}], ")"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], "4"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "i"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"e", "-", "m"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "j"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"g", "-", "o"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "k"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"g", "-", "o"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "-", "l"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"g", "-", "o"}], ")"}], "2"]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"g", "-", "o"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"f", "-", "n"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"g", "-", "o"}], ")"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}], "4"], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "j"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"f", "-", "n"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "i"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"h", "-", "p"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "k"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"h", "-", "p"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"d", "-", "l"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"h", "-", "p"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"e", "-", "m"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"h", "-", "p"}], ")"}], "2"]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"h", "-", "p"}], ")"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"g", "-", "o"}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"h", "-", "p"}], ")"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}], "4"]}]}], "}"}]}]}], "]"}]}], ";", 
  
  RowBox[{
   RowBox[{"sh", "[", "\"\<D4C2\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "7", ",", "4", ",", "5", ",", "6", ",", "3", ",", 
         "8", ",", "9", ",", "10", ",", "15", ",", "12", ",", "13", ",", "14",
          ",", "11", ",", "16", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2"}], "}"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e", "+", "i", "-", "m"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f", "+", "j", "-", "n"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g", "+", "k", "-", "o"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h", "+", "l", "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e", "-", "i", "+", "m"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f", "-", "j", "+", "n"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g", "-", "k", "+", "o"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h", "-", "l", "+", "p"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4C4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "4", ",", "3", ",", "2", ",", "13", ",", "16", ",", "15", 
         ",", "14", ",", "9", ",", "12", ",", "11", ",", "10", ",", "5", ",", 
         "8", ",", "7", ",", "6", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "+", "b", "+", "c", "+", "d", "-", "i", "-", "j", "-", "k", 
            "-", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "e", "+", "f", "+", "g", "+", "h", "-", "m", "-", "n", "-", "o", 
            "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "b", "+", "c", "-", "d", "-", "i", "+", "j", "-", "k", 
            "+", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "e", "-", "f", "+", "g", "-", "h", "-", "m", "+", "n", "-", "o", 
            "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "c", "+", "e", "-", "g", "+", "i", "-", "k", "+", "m", 
            "-", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "b", "-", "d", "+", "f", "-", "h", "+", "j", "-", "l", "+", "n", 
            "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "c", "-", "e", "+", "g", "+", "i", "-", "k", "-", "m", 
            "+", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "b", "-", "d", "-", "f", "+", "h", "+", "j", "-", "l", "-", "n", 
            "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "c", "+", "f", "-", "h", "-", "i", "+", "k", "-", "n", 
            "+", "p"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "b", "-", "d", "-", "e", "+", "g", "-", "j", "+", "l", "+", "m", 
            "-", "o"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "c", "-", "f", "+", "h", "-", "i", "+", "k", "+", "n", 
            "-", "p"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "b", "-", "d", "+", "e", "-", "g", "-", "j", "+", "l", "-", "m", 
            "+", "o"}], ")"}], "2"]}]}], "}"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q8C2\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "6", ",", "7", ",", "8", ",", "5", ",", "2", ",", "3", ",", 
         "4", ",", "9", ",", "14", ",", "15", ",", "16", ",", "13", ",", "10",
          ",", "11", ",", "12", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2"}], "}"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e", "+", "i", "-", "m"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f", "+", "j", "-", "n"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g", "+", "k", "-", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h", "+", "l", "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e", "-", "i", "+", "m"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f", "-", "j", "+", "n"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g", "-", "k", "+", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h", "-", "l", "+", "p"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<KK\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14",
          ",", "15", ",", "16", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "-", "i", "-", "j", "+", "k", "+", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "-", "i", "+", "j", "-", "k", "+", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
         "h", "-", "i", "+", "j", "+", "k", "-", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}]}], "}"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_", ",", "m_", ",", 
       "n_", ",", "o_", ",", "p_"}], "}"}], ",", "\"\<KK\>\""}], "]"}], ":=", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
      "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
      "h", "+", "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
      "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
      "h", "+", "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
      "h", "-", "i", "-", "j", "-", "k", "-", "l", "+", "m", "+", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
      "h", "-", "i", "-", "j", "+", "k", "+", "l", "+", "m", "+", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
      "h", "-", "i", "+", "j", "-", "k", "+", "l", "+", "m", "-", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
      "h", "-", "i", "+", "j", "+", "k", "-", "l", "+", "m", "-", "n", "-", 
      "o", "+", "p"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_", ",", "m_", ",", 
       "n_", ",", "o_", ",", "p_"}], "}"}], ",", "\"\<KK\>\""}], "]"}], ":=", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
      "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
       "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", 
       "o", "+", "p"}], ",", 
      RowBox[{
      "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
       "h", "+", "i", "+", "j", "+", "k", "-", "l", "+", "m", "-", "n", "-", 
       "o", "-", "p"}], ",", 
      RowBox[{
      "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
       "h", "+", "i", "+", "j", "-", "k", "+", "l", "-", "m", "-", "n", "+", 
       "o", "-", "p"}], ",", 
      RowBox[{
      "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
       "h", "+", "i", "+", "j", "-", "k", "-", "l", "-", "m", "+", "n", "-", 
       "o", "+", "p"}], ",", 
      RowBox[{
      "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
       "h", "+", "i", "-", "j", "-", "k", "-", "l", "+", "m", "+", "n", "+", 
       "o", "-", "p"}], ",", 
      RowBox[{
      "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
       "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-", 
       "o", "+", "p"}], ",", 
      RowBox[{
      "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
       "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "-", "n", "+", 
       "o", "+", "p"}], ",", 
      RowBox[{
      "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
       "h", "+", "i", "-", "j", "+", "k", "+", "l", "-", "m", "+", "n", "-", 
       "o", "-", "p"}], ",", 
      RowBox[{
      "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
       "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-", 
       "o", "-", "p"}], ",", 
      RowBox[{
      "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
       "h", "-", "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", "+", 
       "o", "+", "p"}], ",", 
      RowBox[{
      "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
       "h", "-", "i", "-", "j", "+", "k", "-", "l", "+", "m", "+", "n", "-", 
       "o", "+", "p"}], ",", 
      RowBox[{
      "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
       "h", "-", "i", "-", "j", "+", "k", "+", "l", "+", "m", "-", "n", "+", 
       "o", "-", "p"}], ",", 
      RowBox[{
      "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
       "h", "-", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-", 
       "o", "+", "p"}], ",", 
      RowBox[{
      "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
       "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", "+", 
       "o", "-", "p"}], ",", 
      RowBox[{
      "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
       "h", "-", "i", "+", "j", "-", "k", "+", "l", "+", "m", "+", "n", "-", 
       "o", "-", "p"}], ",", 
      RowBox[{
      "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
       "h", "-", "i", "+", "j", "-", "k", "-", "l", "+", "m", "-", "n", "+", 
       "o", "+", "p"}]}], "}"}], "/", "16"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4K\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "4", ",", "3", ",", "2", ",", "5", ",", "8", ",", "7", ",", 
         "6", ",", "9", ",", "12", ",", "11", ",", "10", ",", "13", ",", "16",
          ",", "15", ",", "14", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", 
         ",", "1", ",", "0."}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "-", "i", "+", "j", "-", "k", "+", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "c", "-", "e", "+", "g", "-", "i", "+", "k", "+", "m", 
            "-", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "b", "-", "d", "-", "f", "+", "h", "-", "j", "+", "l", "+", "n", 
            "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "c", "+", "e", "-", "g", "-", "i", "+", "k", "-", "m", 
            "+", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "b", "-", "d", "+", "f", "-", "h", "-", "j", "+", "l", "-", "n", 
            "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "c", "-", "e", "+", "g", "+", "i", "-", "k", "-", "m", 
            "+", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "b", "-", "d", "-", "f", "+", "h", "+", "j", "-", "l", "-", "n", 
            "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "c", "+", "e", "-", "g", "+", "i", "-", "k", "+", "m", 
            "-", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "b", "-", "d", "+", "f", "-", "h", "+", "j", "-", "l", "+", "n", 
            "-", "p"}], ")"}], "2"]}]}], "}"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_", ",", "m_", ",", 
       "n_", ",", "o_", ",", "p_"}], "}"}], ",", "\"\<C4K\>\""}], "]"}], ":=",
    "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
      "h", "-", "i", "-", "j", "-", "k", "-", "l", "+", "m", "+", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-", 
      "o", "+", "p"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
      "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-", 
      "o", "+", "p"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
      "h", "-", "i", "+", "j", "-", "k", "+", "l", "+", "m", "-", "n", "+", 
      "o", "-", "p"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+", 
      "o", "-", "p"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
      "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-", 
      "o", "-", "p"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-", 
      "o", "-", "p"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", "ij", "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "c", "-", "e", "+", "g", "-", "i", "+", "k", "+", "m", "-", 
         "o"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "d", "-", "f", "+", "h", "-", "j", "+", "l", "+", "n", "-", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
        "b", "-", "d", "-", "f", "+", "h", "-", "j", "+", "l", "+", "n", "-", 
         "p"}], "\[Equal]", "0"}], ",", "0", ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{
         "a", "-", "c", "-", "e", "+", "g", "-", "i", "+", "k", "+", "m", "-",
           "o"}], ",", 
         RowBox[{
         "b", "-", "d", "-", "f", "+", "h", "-", "j", "+", "l", "+", "n", "-",
           "p"}]}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", "kl", "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "c", "+", "e", "-", "g", "-", "i", "+", "k", "-", "m", "+", 
         "o"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "d", "+", "f", "-", "h", "-", "j", "+", "l", "-", "n", "+", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
        "b", "-", "d", "+", "f", "-", "h", "-", "j", "+", "l", "-", "n", "+", 
         "p"}], "\[Equal]", "0"}], ",", "0", ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{
         "a", "-", "c", "+", "e", "-", "g", "-", "i", "+", "k", "-", "m", "+",
           "o"}], ",", 
         RowBox[{
         "b", "-", "d", "+", "f", "-", "h", "-", "j", "+", "l", "-", "n", "+",
           "p"}]}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", "mn", "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "c", "-", "e", "+", "g", "+", "i", "-", "k", "-", "m", "+", 
         "o"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "d", "-", "f", "+", "h", "+", "j", "-", "l", "-", "n", "+", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
        "b", "-", "d", "-", "f", "+", "h", "+", "j", "-", "l", "-", "n", "+", 
         "p"}], "\[Equal]", "0"}], ",", "0", ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{
         "a", "-", "c", "-", "e", "+", "g", "+", "i", "-", "k", "-", "m", "+",
           "o"}], ",", 
         RowBox[{
         "b", "-", "d", "-", "f", "+", "h", "+", "j", "-", "l", "-", "n", "+",
           "p"}]}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", "op", "*)"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "c", "+", "e", "-", "g", "+", "i", "-", "k", "+", "m", "-", 
         "o"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "d", "+", "f", "-", "h", "+", "j", "-", "l", "+", "n", "-", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
        "b", "-", "d", "+", "f", "-", "h", "+", "j", "-", "l", "+", "n", "-", 
         "p"}], "\[Equal]", "0"}], ",", "0", ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{
         "a", "-", "c", "+", "e", "-", "g", "+", "i", "-", "k", "+", "m", "-",
           "o"}], ",", 
         RowBox[{
         "b", "-", "d", "+", "f", "-", "h", "+", "j", "-", "l", "+", "n", "-",
           "p"}]}], "]"}]}], "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "ii_", ",", "j_", ",", "kk_", ",", "l_", ",", "mm_", 
       ",", "n_", ",", "oo_", ",", "p_"}], "}"}], ",", "\[IndentingNewLine]", 
     "\"\<C4K\>\""}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"i", "=", 
        RowBox[{"2", 
         SqrtBox["ii"]}]}], ",", 
       RowBox[{"k", "=", 
        RowBox[{"2", 
         SqrtBox["kk"]}]}], ",", 
       RowBox[{"m", "=", 
        RowBox[{"2", 
         SqrtBox["mm"]}]}], ",", 
       RowBox[{"o", "=", 
        RowBox[{"2", 
         SqrtBox["oo"]}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "  ", 
       RowBox[{"(*", "a", "*)"}], 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", 
         RowBox[{"i", " ", 
          RowBox[{"Cos", "[", "j", "]"}]}], "+", 
         RowBox[{"k", " ", 
          RowBox[{"Cos", "[", "l", "]"}]}], "+", 
         RowBox[{"m", " ", 
          RowBox[{"Cos", "[", "n", "]"}]}], "+", 
         RowBox[{"o", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "b", "*)"}], 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", 
         RowBox[{"i", " ", 
          RowBox[{"Sin", "[", "j", "]"}]}], "+", 
         RowBox[{"k", " ", 
          RowBox[{"Sin", "[", "l", "]"}]}], "+", 
         RowBox[{"m", " ", 
          RowBox[{"Sin", "[", "n", "]"}]}], "+", 
         RowBox[{"o", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "c", "*)"}], 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "-", 
         RowBox[{"i", " ", 
          RowBox[{"Cos", "[", "j", "]"}]}], "-", 
         RowBox[{"k", " ", 
          RowBox[{"Cos", "[", "l", "]"}]}], "-", 
         RowBox[{"m", " ", 
          RowBox[{"Cos", "[", "n", "]"}]}], "-", 
         RowBox[{"o", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "d", "*)"}], 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "-", 
         RowBox[{"i", " ", 
          RowBox[{"Sin", "[", "j", "]"}]}], "-", 
         RowBox[{"k", " ", 
          RowBox[{"Sin", "[", "l", "]"}]}], "-", 
         RowBox[{"m", " ", 
          RowBox[{"Sin", "[", "n", "]"}]}], "-", 
         RowBox[{"o", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "e", "*)"}], 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "-", 
         RowBox[{"i", " ", 
          RowBox[{"Cos", "[", "j", "]"}]}], "+", 
         RowBox[{"k", " ", 
          RowBox[{"Cos", "[", "l", "]"}]}], "-", 
         RowBox[{"m", " ", 
          RowBox[{"Cos", "[", "n", "]"}]}], "+", 
         RowBox[{"o", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "f", "*)"}], 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "-", 
         RowBox[{"i", " ", 
          RowBox[{"Sin", "[", "j", "]"}]}], "+", 
         RowBox[{"k", " ", 
          RowBox[{"Sin", "[", "l", "]"}]}], "-", 
         RowBox[{"m", " ", 
          RowBox[{"Sin", "[", "n", "]"}]}], "+", 
         RowBox[{"o", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "g", "*)"}], 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "+", 
         RowBox[{"i", " ", 
          RowBox[{"Cos", "[", "j", "]"}]}], "-", 
         RowBox[{"k", " ", 
          RowBox[{"Cos", "[", "l", "]"}]}], "+", 
         RowBox[{"m", " ", 
          RowBox[{"Cos", "[", "n", "]"}]}], "-", 
         RowBox[{"o", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "h", "*)"}], 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", 
         RowBox[{"i", " ", 
          RowBox[{"Sin", "[", "j", "]"}]}], "-", 
         RowBox[{"k", " ", 
          RowBox[{"Sin", "[", "l", "]"}]}], "+", 
         RowBox[{"m", " ", 
          RowBox[{"Sin", "[", "n", "]"}]}], "-", 
         RowBox[{"o", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "i", "*)"}], 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
         "h", "-", 
         RowBox[{"i", " ", 
          RowBox[{"Cos", "[", "j", "]"}]}], "-", 
         RowBox[{"k", " ", 
          RowBox[{"Cos", "[", "l", "]"}]}], "+", 
         RowBox[{"m", " ", 
          RowBox[{"Cos", "[", "n", "]"}]}], "+", 
         RowBox[{"o", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "j", "*)"}], 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "-", 
         RowBox[{"i", " ", 
          RowBox[{"Sin", "[", "j", "]"}]}], "-", 
         RowBox[{"k", " ", 
          RowBox[{"Sin", "[", "l", "]"}]}], "+", 
         RowBox[{"m", " ", 
          RowBox[{"Sin", "[", "n", "]"}]}], "+", 
         RowBox[{"o", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "k", "*)"}], 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
         "h", "+", 
         RowBox[{"i", " ", 
          RowBox[{"Cos", "[", "j", "]"}]}], "+", 
         RowBox[{"k", " ", 
          RowBox[{"Cos", "[", "l", "]"}]}], "-", 
         RowBox[{"m", " ", 
          RowBox[{"Cos", "[", "n", "]"}]}], "-", 
         RowBox[{"o", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "l", "*)"}], 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", 
         RowBox[{"i", " ", 
          RowBox[{"Sin", "[", "j", "]"}]}], "+", 
         RowBox[{"k", " ", 
          RowBox[{"Sin", "[", "l", "]"}]}], "-", 
         RowBox[{"m", " ", 
          RowBox[{"Sin", "[", "n", "]"}]}], "-", 
         RowBox[{"o", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "m", "*)"}], 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", 
         RowBox[{"i", " ", 
          RowBox[{"Cos", "[", "j", "]"}]}], "-", 
         RowBox[{"k", " ", 
          RowBox[{"Cos", "[", "l", "]"}]}], "-", 
         RowBox[{"m", " ", 
          RowBox[{"Cos", "[", "n", "]"}]}], "+", 
         RowBox[{"o", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "n", "*)"}], 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "+", 
         RowBox[{"i", " ", 
          RowBox[{"Sin", "[", "j", "]"}]}], "-", 
         RowBox[{"k", " ", 
          RowBox[{"Sin", "[", "l", "]"}]}], "-", 
         RowBox[{"m", " ", 
          RowBox[{"Sin", "[", "n", "]"}]}], "+", 
         RowBox[{"o", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "o", "*)"}], 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", 
         RowBox[{"i", " ", 
          RowBox[{"Cos", "[", "j", "]"}]}], "+", 
         RowBox[{"k", " ", 
          RowBox[{"Cos", "[", "l", "]"}]}], "+", 
         RowBox[{"m", " ", 
          RowBox[{"Cos", "[", "n", "]"}]}], "-", 
         RowBox[{"o", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "p", "*)"}], 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "-", 
         RowBox[{"i", " ", 
          RowBox[{"Sin", "[", "j", "]"}]}], "+", 
         RowBox[{"k", " ", 
          RowBox[{"Sin", "[", "l", "]"}]}], "+", 
         RowBox[{"m", " ", 
          RowBox[{"Sin", "[", "n", "]"}]}], "-", 
         RowBox[{"o", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}]}], "}"}], "/", "16"}]}], "]"}]}],
   ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<KiC4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "13", ",", "16", ",", "15", 
         ",", "14", ",", "9", ",", "10", ",", "11", ",", "12", ",", "5", ",", 
         "8", ",", "7", ",", "6", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "1", ",", "2", ",", "2"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "+", "b", "+", "c", "+", "d", "-", "i", "-", "j", "-", "k", 
            "-", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "e"}], "-", "f", "-", "g", "-", "h", "+", "m", "+", 
            "n", "+", "o", "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "b", "+", "c", "-", "d", "-", "i", "+", "j", "-", "k", 
            "+", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "e"}], "+", "f", "-", "g", "+", "h", "+", "m", "-", 
            "n", "+", "o", "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "+", "i", "-", "k"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "+", "j", "-", "l"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "g", "+", "m", "-", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"f", "-", "h", "+", "n", "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "-", "i", "+", "k"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "-", "j", "+", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "g", "-", "m", "+", "o"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"f", "-", "h", "-", "n", "+", "p"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<C4iC4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "4", ",", "3", ",", "2", ",", "13", ",", "14", ",", "15", 
         ",", "16", ",", "9", ",", "12", ",", "11", ",", "10", ",", "5", ",", 
         "6", ",", "7", ",", "8", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "1", ",", "2", ",", "2"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "+", "b", "+", "c", "+", "d", "-", "i", "-", "j", "-", "k", 
            "-", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "e"}], "-", "f", "-", "g", "-", "h", "+", "m", "+", 
            "n", "+", "o", "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "b", "+", "c", "-", "d", "-", "i", "+", "j", "-", "k", 
            "+", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "e"}], "+", "f", "-", "g", "+", "h", "+", "m", "-", 
            "n", "+", "o", "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "+", "i", "-", "k"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "+", "j", "-", "l"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "g", "+", "m", "-", "o"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"f", "-", "h", "+", "n", "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "-", "i", "+", "k"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "-", "j", "+", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "g", "-", "m", "+", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"f", "-", "h", "-", "n", "+", "p"}], ")"}], "2"]}]}], 
       "}"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<P16\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "13", ",", "14", ",", "15", 
         ",", "16", ",", "9", ",", "10", ",", "11", ",", "12", ",", "5", ",", 
         "6", ",", "7", ",", "8", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "1", ",", "1", ",", "1", ",", "2"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "-", "l", "-", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "+", "d", "-", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "+", "l", "-", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "+", "d", "-", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "+", "l", "-", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "-", "d", "-", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "-", "l", "-", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"a", "-", "i"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"e", "-", "m"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"b", "-", "j"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"f", "-", "n"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"c", "-", "k"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"g", "-", "o"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"d", "-", "l"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"h", "-", "p"}], ")"}]}]}], ")"}], "^", "2"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "i"}], ")"}], "2"], "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "-", "j"}], ")"}], "2"], "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"c", "-", "k"}], ")"}], "2"], "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"d", "-", "l"}], ")"}], "2"], "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"e", "-", "m"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"f", "-", "n"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"g", "-", "o"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"h", "-", "p"}], ")"}], "2"]}], ")"}], "^", "2"}]}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Oct\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "15",
          ",", "16", ",", "9", ",", "2", ",", "3", ",", "4", ",", "5", ",", 
         "6", ",", "7", ",", "8", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "1", ",", "1", ",", "1", ",", "4"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "i"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "j"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "k"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "m"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"f", "-", "n"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"g", "-", "o"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"h", "-", "p"}], ")"}], "2"]}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q8M2\>\"", "]"}], 
   RowBox[{"(*", 
    RowBox[{"Split", " ", "Octonion", " ", "loop"}], "*)"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "6", ",", "7", ",", "8", ",", "5", ",", "2", ",", "3", ",", 
         "4", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14",
          ",", "\[IndentingNewLine]", "15", ",", "16", ",", "1", ",", "1", 
         ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "4"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", "+",
          "o", "-", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+",
          "o", "+", "p"}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "h"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"j", "-", "n"}], ")"}], "2"], "-", "\[IndentingNewLine]", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"k", "-", "o"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"l", "-", "p"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"i", "-", "m"}], ")"}], "2"]}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 TextJustification->0,
 FontSize->9],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL4\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"(*", 
      RowBox[{"see", " ", "Louenesto", " ", "p86"}], "*)"}], 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", 
         RowBox[{"-", "4"}], ",", "5", ",", 
         RowBox[{"-", "6"}], ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "8"}], ",", "9", ",", 
         RowBox[{"-", "10"}], ",", 
         RowBox[{"-", "11"}], ",", 
         RowBox[{"-", "12"}], ",", 
         RowBox[{"-", "13"}], ",", 
         RowBox[{"-", "14"}], ",", 
         RowBox[{"-", "15"}], ",", "16", ",", "4"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"], "+", 
           SuperscriptBox["d", "2"], "+", 
           SuperscriptBox["e", "2"], "+", 
           SuperscriptBox["f", "2"], "+", 
           SuperscriptBox["g", "2"], "+", 
           SuperscriptBox["h", "2"], "+", 
           SuperscriptBox["i", "2"], "+", 
           SuperscriptBox["j", "2"], "+", 
           SuperscriptBox["k", "2"], "+", 
           SuperscriptBox["l", "2"], "+", 
           SuperscriptBox["m", "2"], "+", 
           SuperscriptBox["n", "2"], "+", 
           SuperscriptBox["o", "2"], "+", 
           SuperscriptBox["p", "2"]}], ")"}], "^", "2"}], "-", 
        RowBox[{"4", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "b"}], "+", 
              RowBox[{"c", " ", "d"}], "+", 
              RowBox[{"e", " ", "f"}], "+", 
              RowBox[{"g", " ", "h"}], "+", 
              RowBox[{"i", " ", "j"}], "+", 
              RowBox[{"k", " ", "l"}], "+", 
              RowBox[{"m", " ", "n"}], "+", 
              RowBox[{"o", " ", "p"}]}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "c"}], "-", 
              RowBox[{"b", " ", "d"}], "+", 
              RowBox[{"e", " ", "g"}], "-", 
              RowBox[{"f", " ", "h"}], "+", 
              RowBox[{"i", " ", "k"}], "-", 
              RowBox[{"j", " ", "l"}], "+", 
              RowBox[{"m", " ", "o"}], "-", 
              RowBox[{"n", " ", "p"}]}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "e"}], "-", 
              RowBox[{"b", " ", "f"}], "-", 
              RowBox[{"c", " ", "g"}], "+", 
              RowBox[{"d", " ", "h"}], "+", 
              RowBox[{"i", " ", "m"}], "-", 
              RowBox[{"j", " ", "n"}], "-", 
              RowBox[{"k", " ", "o"}], "+", 
              RowBox[{"l", " ", "p"}]}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "i"}], "-", 
              RowBox[{"b", " ", "j"}], "-", 
              RowBox[{"c", " ", "k"}], "+", 
              RowBox[{"d", " ", "l"}], "-", 
              RowBox[{"e", " ", "m"}], "+", 
              RowBox[{"f", " ", "n"}], "+", 
              RowBox[{"g", " ", "o"}], "-", 
              RowBox[{"h", " ", "p"}]}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", " ", "i"}], "-", 
              RowBox[{"g", " ", "j"}], "+", 
              RowBox[{"f", " ", "k"}], "-", 
              RowBox[{"e", " ", "l"}], "-", 
              RowBox[{"d", " ", "m"}], "+", 
              RowBox[{"c", " ", "n"}], "-", 
              RowBox[{"b", " ", "o"}], "+", 
              RowBox[{"a", " ", "p"}]}], ")"}], "^", "2"}]}], ")"}]}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL13\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", 
         RowBox[{"-", "3"}], ",", "4", ",", 
         RowBox[{"-", "5"}], ",", "6", ",", 
         RowBox[{"-", "7"}], ",", 
         RowBox[{"-", "8"}], ",", 
         RowBox[{"-", "9"}], ",", "10", ",", 
         RowBox[{"-", "11"}], ",", 
         RowBox[{"-", "12"}], ",", 
         RowBox[{"-", "13"}], ",", 
         RowBox[{"-", "14"}], ",", "15", ",", 
         RowBox[{"-", "16"}], ",", "4"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"], "+", 
           SuperscriptBox["d", "2"], "+", 
           SuperscriptBox["e", "2"], "+", 
           SuperscriptBox["f", "2"], "+", 
           SuperscriptBox["g", "2"], "+", 
           SuperscriptBox["h", "2"], "+", 
           SuperscriptBox["i", "2"], "+", 
           SuperscriptBox["j", "2"], "+", 
           SuperscriptBox["k", "2"], "+", 
           SuperscriptBox["l", "2"], "+", 
           SuperscriptBox["m", "2"], "+", 
           SuperscriptBox["n", "2"], "+", 
           SuperscriptBox["o", "2"], "+", 
           SuperscriptBox["p", "2"]}], ")"}], "^", "2"}], "+", 
        RowBox[{"4", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", "b"}], "+", 
               RowBox[{"c", " ", "d"}], "+", 
               RowBox[{"e", " ", "f"}], "+", 
               RowBox[{"g", " ", "h"}], "+", 
               RowBox[{"i", " ", "j"}], "+", 
               RowBox[{"k", " ", "l"}], "+", 
               RowBox[{"m", " ", "n"}], "+", 
               RowBox[{"o", " ", "p"}]}], ")"}], "^", "2"}]}], 
           "\[IndentingNewLine]", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "b"}], " ", "c"}], "+", 
              RowBox[{"a", " ", "d"}], "-", 
              RowBox[{"f", " ", "g"}], "+", 
              RowBox[{"e", " ", "h"}], "-", 
              RowBox[{"j", " ", "k"}], "+", 
              RowBox[{"i", " ", "l"}], "-", 
              RowBox[{"n", " ", "o"}], "+", 
              RowBox[{"m", " ", "p"}]}], ")"}], "^", "2"}], 
           "\[IndentingNewLine]", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "b"}], " ", "e"}], "+", 
              RowBox[{"a", " ", "f"}], "+", 
              RowBox[{"d", " ", "g"}], "-", 
              RowBox[{"c", " ", "h"}], "-", 
              RowBox[{"j", " ", "m"}], "+", 
              RowBox[{"i", " ", "n"}], "+", 
              RowBox[{"l", " ", "o"}], "-", 
              RowBox[{"k", " ", "p"}]}], ")"}], "^", "2"}], 
           "\[IndentingNewLine]", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "b"}], " ", "i"}], "+", 
              RowBox[{"a", " ", "j"}], "+", 
              RowBox[{"d", " ", "k"}], "-", 
              RowBox[{"c", " ", "l"}], "+", 
              RowBox[{"f", " ", "m"}], "-", 
              RowBox[{"e", " ", "n"}], "-", 
              RowBox[{"h", " ", "o"}], "+", 
              RowBox[{"g", " ", "p"}]}], ")"}], "^", "2"}], 
           "\[IndentingNewLine]", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "g"}], " ", "i"}], "+", 
              RowBox[{"h", " ", "j"}], "+", 
              RowBox[{"e", " ", "k"}], "-", 
              RowBox[{"f", " ", "l"}], "-", 
              RowBox[{"c", " ", "m"}], "+", 
              RowBox[{"d", " ", "n"}], "+", 
              RowBox[{"a", " ", "o"}], "-", 
              RowBox[{"b", " ", "p"}]}], ")"}], "^", "2"}]}], ")"}]}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL22\>\"", "]"}], "=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=."}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "5"}], ",", "6", ",", "7", ",", "8", ",", 
         RowBox[{"-", "9"}], ",", "10", ",", "11", ",", "12", ",", 
         RowBox[{"-", "13"}], ",", 
         RowBox[{"-", "14"}], ",", 
         RowBox[{"-", "15"}], ",", "16", ",", "4"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"], "+", 
           SuperscriptBox["d", "2"], "-", 
           SuperscriptBox["e", "2"], "-", 
           SuperscriptBox["f", "2"], "-", 
           SuperscriptBox["g", "2"], "-", 
           SuperscriptBox["h", "2"], "-", 
           SuperscriptBox["i", "2"], "-", 
           SuperscriptBox["j", "2"], "-", 
           SuperscriptBox["k", "2"], "-", 
           SuperscriptBox["l", "2"], "+", 
           SuperscriptBox["m", "2"], "+", 
           SuperscriptBox["n", "2"], "+", 
           SuperscriptBox["o", "2"], "+", 
           SuperscriptBox["p", "2"]}], ")"}], "^", "2"}], "+", 
        RowBox[{"4", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", "b"}], "+", 
               RowBox[{"c", " ", "d"}], "-", 
               RowBox[{"e", " ", "f"}], "-", 
               RowBox[{"g", " ", "h"}], "-", 
               RowBox[{"i", " ", "j"}], "-", 
               RowBox[{"k", " ", "l"}], "+", 
               RowBox[{"m", " ", "n"}], "+", 
               RowBox[{"o", " ", "p"}]}], ")"}], "^", "2"}]}], 
           "\[IndentingNewLine]", "-", 
           RowBox[{
            RowBox[{"(", " ", 
             RowBox[{
              RowBox[{"a", " ", "c"}], "-", 
              RowBox[{"b", " ", "d"}], "-", 
              RowBox[{"e", " ", "g"}], "+", 
              RowBox[{"f", " ", "h"}], "-", 
              RowBox[{"i", " ", "k"}], "+", 
              RowBox[{"j", " ", "l"}], "+", 
              RowBox[{"m", " ", "o"}], "-", 
              RowBox[{"n", " ", "p"}]}], ")"}], "^", "2"}], 
           "\[IndentingNewLine]", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "e"}], "-", 
              RowBox[{"b", " ", "f"}], "-", 
              RowBox[{"c", " ", "g"}], "+", 
              RowBox[{"d", " ", "h"}], "-", 
              RowBox[{"i", " ", "m"}], "+", 
              RowBox[{"j", " ", "n"}], "+", 
              RowBox[{"k", " ", "o"}], "-", 
              RowBox[{"l", " ", "p"}]}], ")"}], "^", "2"}], 
           "\[IndentingNewLine]", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", "i"}], "-", 
              RowBox[{"b", " ", "j"}], "-", 
              RowBox[{"c", " ", "k"}], "+", 
              RowBox[{"d", " ", "l"}], "+", 
              RowBox[{"e", " ", "m"}], "-", 
              RowBox[{"f", " ", "n"}], "-", 
              RowBox[{"g", " ", "o"}], "+", 
              RowBox[{"h", " ", "p"}]}], ")"}], "^", "2"}], 
           "\[IndentingNewLine]", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", " ", "i"}], "-", 
              RowBox[{"g", " ", "j"}], "+", 
              RowBox[{"f", " ", "k"}], "-", 
              RowBox[{"e", " ", "l"}], "-", 
              RowBox[{"d", " ", "m"}], "+", 
              RowBox[{"c", " ", "n"}], "-", 
              RowBox[{"b", " ", "o"}], "+", 
              RowBox[{"a", " ", "p"}]}], ")"}], "^", "2"}]}], ")"}]}]}], 
       "}"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"found", " ", "from", " ", "conjugation"}], ",", " ", 
    RowBox[{"with", " ", "negated", " ", 
     RowBox[{"terms", "!"}], " ", 
     RowBox[{
      RowBox[{"23", "/", "7"}], "/", "8"}]}]}], "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"sh", "[", "\"\<CL31\>\"", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{
        RowBox[{"gp", "=."}], ";", 
        RowBox[{"gi", "=", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3", ",", 
           RowBox[{"-", "4"}], ",", "5", ",", 
           RowBox[{"-", "6"}], ",", 
           RowBox[{"-", "7"}], ",", 
           RowBox[{"-", "8"}], ",", 
           RowBox[{"-", "9"}], ",", "10", ",", "11", ",", "12", ",", "13", 
           ",", "14", ",", "15", ",", 
           RowBox[{"-", "16"}], ",", "4"}], "}"}]}], ";", 
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"], "-", 
             SuperscriptBox["d", "2"], "-", 
             SuperscriptBox["e", "2"], "-", 
             SuperscriptBox["f", "2"], "+", 
             SuperscriptBox["g", "2"], "+", 
             SuperscriptBox["h", "2"], "+", 
             SuperscriptBox["i", "2"], "+", 
             SuperscriptBox["j", "2"], "-", 
             SuperscriptBox["k", "2"], "-", 
             SuperscriptBox["l", "2"], "-", 
             SuperscriptBox["m", "2"], "-", 
             SuperscriptBox["n", "2"], "+", 
             SuperscriptBox["o", "2"], "+", 
             SuperscriptBox["p", "2"]}], ")"}], "2"], "+", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "g"}], " ", "i"}], "+", 
                 RowBox[{"h", " ", "j"}], "+", 
                 RowBox[{"e", " ", "k"}], "-", 
                 RowBox[{"f", " ", "l"}], "-", 
                 RowBox[{"c", " ", "m"}], "+", 
                 RowBox[{"d", " ", "n"}], "+", 
                 RowBox[{"a", " ", "o"}], "-", 
                 RowBox[{"b", " ", "p"}]}], ")"}], "^", "2"}]}], 
             "\[IndentingNewLine]", "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "b"}], " ", "i"}], "+", 
                RowBox[{"a", " ", "j"}], "-", 
                RowBox[{"d", " ", "k"}], "+", 
                RowBox[{"c", " ", "l"}], "-", 
                RowBox[{"f", " ", "m"}], "+", 
                RowBox[{"e", " ", "n"}], "-", 
                RowBox[{"h", " ", "o"}], "+", 
                RowBox[{"g", " ", "p"}]}], ")"}], "2"], "\[IndentingNewLine]",
              "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "b"}], " ", "e"}], "+", 
                RowBox[{"a", " ", "f"}], "-", 
                RowBox[{"d", " ", "g"}], "+", 
                RowBox[{"c", " ", "h"}], "-", 
                RowBox[{"j", " ", "m"}], "+", 
                RowBox[{"i", " ", "n"}], "-", 
                RowBox[{"l", " ", "o"}], "+", 
                RowBox[{"k", " ", "p"}]}], ")"}], "2"], "\[IndentingNewLine]",
              "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "b"}], " ", "c"}], "+", 
                RowBox[{"a", " ", "d"}], "+", 
                RowBox[{"f", " ", "g"}], "-", 
                RowBox[{"e", " ", "h"}], "-", 
                RowBox[{"j", " ", "k"}], "+", 
                RowBox[{"i", " ", "l"}], "+", 
                RowBox[{"n", " ", "o"}], "-", 
                RowBox[{"m", " ", "p"}]}], ")"}], "2"], "\[IndentingNewLine]",
              "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", " ", "b"}], "-", 
                RowBox[{"c", " ", "d"}], "-", 
                RowBox[{"e", " ", "f"}], "+", 
                RowBox[{"g", " ", "h"}], "+", 
                RowBox[{"i", " ", "j"}], "-", 
                RowBox[{"k", " ", "l"}], "-", 
                RowBox[{"m", " ", "n"}], "+", 
                RowBox[{"o", " ", "p"}]}], ")"}], "2"]}], ")"}]}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"sh", "[", "\"\<r31r\>\"", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{
        RowBox[{"gp", "=."}], ";", 
        RowBox[{"plex", "=", 
         RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
           RowBox[{"-", "d"}], ",", "e", ",", 
           RowBox[{"-", "f"}], ",", 
           RowBox[{"-", "g"}], ",", 
           RowBox[{"-", "h"}], ",", "i", ",", 
           RowBox[{"-", "j"}], ",", 
           RowBox[{"-", "k"}], ",", 
           RowBox[{"-", "l"}], ",", 
           RowBox[{"-", "m"}], ",", 
           RowBox[{"-", "n"}], ",", 
           RowBox[{"-", "o"}], ",", "p"}], "}"}]}], ";", 
        RowBox[{"gi", "=", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3", ",", 
           RowBox[{"-", "4"}], ",", 
           RowBox[{"-", "5"}], ",", "6", ",", "7", ",", "8", ",", "9", ",", 
           RowBox[{"-", "10"}], ",", 
           RowBox[{"-", "11"}], ",", 
           RowBox[{"-", "12"}], ",", "13", ",", "14", ",", "15", ",", 
           RowBox[{"-", "16"}], ",", "4"}], "}"}]}], ";", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             SuperscriptBox["d", "2"], "-", 
             SuperscriptBox["e", "2"], "-", 
             SuperscriptBox["f", "2"], "-", 
             SuperscriptBox["g", "2"], "-", 
             SuperscriptBox["h", "2"], "+", 
             SuperscriptBox["i", "2"], "+", 
             SuperscriptBox["j", "2"], "+", 
             SuperscriptBox["k", "2"], "+", 
             SuperscriptBox["l", "2"], "-", 
             SuperscriptBox["m", "2"], "-", 
             SuperscriptBox["n", "2"], "-", 
             SuperscriptBox["o", "2"], "-", 
             SuperscriptBox["p", "2"]}], ")"}], "^", "2"}], "-", 
          RowBox[{"4", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", " ", "b"}], "+", " ", 
                RowBox[{"c", " ", "d"}], "-", " ", 
                RowBox[{"e", " ", "f"}], "-", " ", 
                RowBox[{"g", " ", "h"}], "+", " ", 
                RowBox[{"i", " ", "j"}], "+", " ", 
                RowBox[{"k", " ", "l"}], "-", " ", 
                RowBox[{"m", " ", "n"}], "-", " ", 
                RowBox[{"o", " ", "p"}]}], ")"}], "^", "2"}], "+", 
             RowBox[{
              RowBox[{"(", " ", 
               RowBox[{
                RowBox[{"a", " ", "c"}], "-", " ", 
                RowBox[{"b", " ", "d"}], "-", " ", 
                RowBox[{"e", " ", "g"}], "+", " ", 
                RowBox[{"f", " ", "h"}], "+", " ", 
                RowBox[{"i", " ", "k"}], "-", " ", 
                RowBox[{"j", " ", "l"}], "-", " ", 
                RowBox[{"m", " ", "o"}], "+", " ", 
                RowBox[{"n", " ", "p"}]}], ")"}], "^", "2"}], "-", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"(", " ", 
               RowBox[{
                RowBox[{"a", " ", "e"}], "-", " ", 
                RowBox[{"b", " ", "f"}], "-", " ", 
                RowBox[{"c", " ", "g"}], "+", " ", 
                RowBox[{"d", " ", "h"}], "+", " ", 
                RowBox[{"i", " ", "m"}], "-", " ", 
                RowBox[{"j", " ", "n"}], "-", " ", 
                RowBox[{"k", " ", "o"}], "+", " ", 
                RowBox[{"l", " ", "p"}]}], ")"}], "^", "2"}], "+", 
             RowBox[{
              RowBox[{"(", " ", 
               RowBox[{
                RowBox[{"a", " ", "i"}], "-", " ", 
                RowBox[{"b", " ", "j"}], "-", " ", 
                RowBox[{"c", " ", "k"}], "+", " ", 
                RowBox[{"d", " ", "l"}], "+", " ", 
                RowBox[{"e", " ", "m"}], "-", " ", 
                RowBox[{"f", " ", "n"}], "-", " ", 
                RowBox[{"g", " ", "o"}], "+", " ", 
                RowBox[{"h", " ", "p"}]}], ")"}], "^", "2"}], "-", 
             RowBox[{
              RowBox[{"(", " ", 
               RowBox[{
                RowBox[{"h", " ", "i"}], "-", " ", 
                RowBox[{"g", " ", "j"}], "+", " ", 
                RowBox[{"f", " ", "k"}], "-", " ", 
                RowBox[{"e", " ", "l"}], "-", " ", 
                RowBox[{"d", " ", "m"}], "+", " ", 
                RowBox[{"c", " ", "n"}], "-", " ", 
                RowBox[{"b", " ", "o"}], "+", " ", 
                RowBox[{"a", " ", "p"}]}], ")"}], "^", "2"}]}], ")"}]}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"sh", "[", "\"\<CL04\>\"", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{
        RowBox[{"gp", "=."}], ";", 
        RowBox[{"gi", "=", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}], ",", 
           RowBox[{"-", "3"}], ",", 
           RowBox[{"-", "4"}], ",", 
           RowBox[{"-", "5"}], ",", 
           RowBox[{"-", "6"}], ",", 
           RowBox[{"-", "7"}], ",", "8", ",", 
           RowBox[{"-", "9"}], ",", 
           RowBox[{"-", "10"}], ",", 
           RowBox[{"-", "11"}], ",", "12", ",", 
           RowBox[{"-", "13"}], ",", "14", ",", "15", ",", "16", ",", "4"}], 
          "}"}]}], ";", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             SuperscriptBox["d", "2"], "+", 
             SuperscriptBox["e", "2"], "+", 
             SuperscriptBox["f", "2"], "+", 
             SuperscriptBox["g", "2"], "+", 
             SuperscriptBox["h", "2"], "+", 
             SuperscriptBox["i", "2"], "+", 
             SuperscriptBox["j", "2"], "+", 
             SuperscriptBox["k", "2"], "+", 
             SuperscriptBox["l", "2"], "+", 
             SuperscriptBox["m", "2"], "+", 
             SuperscriptBox["n", "2"], "+", 
             SuperscriptBox["o", "2"], "+", 
             SuperscriptBox["p", "2"]}], ")"}], "^", "2"}], "-", 
          RowBox[{"4", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "d"}], " ", "e"}], "+", 
                RowBox[{"c", " ", "f"}], "-", 
                RowBox[{"b", " ", "g"}], "+", 
                RowBox[{"a", " ", "h"}], "-", 
                RowBox[{"l", " ", "m"}], "+", 
                RowBox[{"k", " ", "n"}], "-", 
                RowBox[{"j", " ", "o"}], "+", 
                RowBox[{"i", " ", "p"}]}], ")"}], "^", "2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "d"}], " ", "i"}], "+", 
                RowBox[{"c", " ", "j"}], "-", 
                RowBox[{"b", " ", "k"}], "+", 
                RowBox[{"a", " ", "l"}], "+", 
                RowBox[{"h", " ", "m"}], "-", 
                RowBox[{"g", " ", "n"}], "+", 
                RowBox[{"f", " ", "o"}], "-", 
                RowBox[{"e", " ", "p"}]}], ")"}], "^", "2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "f"}], " ", "i"}], "+", 
                RowBox[{"e", " ", "j"}], "-", 
                RowBox[{"h", " ", "k"}], "+", 
                RowBox[{"g", " ", "l"}], "-", 
                RowBox[{"b", " ", "m"}], "+", 
                RowBox[{"a", " ", "n"}], "-", 
                RowBox[{"d", " ", "o"}], "+", 
                RowBox[{"c", " ", "p"}]}], ")"}], "^", "2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "g"}], " ", "i"}], "+", 
                RowBox[{"h", " ", "j"}], "+", 
                RowBox[{"e", " ", "k"}], "-", 
                RowBox[{"f", " ", "l"}], "-", 
                RowBox[{"c", " ", "m"}], "+", 
                RowBox[{"d", " ", "n"}], "+", 
                RowBox[{"a", " ", "o"}], "-", 
                RowBox[{"b", " ", "p"}]}], ")"}], "^", "2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "h"}], " ", "i"}], "-", 
                RowBox[{"g", " ", "j"}], "+", 
                RowBox[{"f", " ", "k"}], "+", 
                RowBox[{"e", " ", "l"}], "-", 
                RowBox[{"d", " ", "m"}], "-", 
                RowBox[{"c", " ", "n"}], "+", 
                RowBox[{"b", " ", "o"}], "+", 
                RowBox[{"a", " ", "p"}]}], ")"}], "^", "2"}]}], ")"}]}]}], 
         "}"}]}]}], "]"}]}], ";"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<O8\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", 
         ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", 
         "0.", ",", "1", ",", "0."}], "}"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", 
         RowBox[{"-", "9"}], ",", 
         RowBox[{"-", "10"}], ",", 
         RowBox[{"-", "11"}], ",", 
         RowBox[{"-", "12"}], ",", 
         RowBox[{"-", "13"}], ",", 
         RowBox[{"-", "14"}], ",", 
         RowBox[{"-", "15"}], ",", 
         RowBox[{"-", "16"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", 
            "+", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", "o", 
            "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", 
            "+", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-", "o", 
            "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", 
            "-", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+", "o", 
            "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", 
            "-", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-", "o", 
            "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", 
            "-", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-", "o", 
            "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", 
            "-", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", "+", "o", 
            "-", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", 
            "+", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-", "o", 
            "+", "p"}], ")"}], "2"]}], ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", 
            "+", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
           "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", "+", "o", 
            "+", "p"}], ")"}], "2"]}]}], "}"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_", ",", "m_", ",", 
       "n_", ",", "o_", ",", "p_"}], "}"}], ",", "\"\<O8\>\""}], "]"}], ":=", 
   " ", 
   RowBox[{"{", "      ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", "o", "+", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
        "h"}], ",", 
       RowBox[{
       "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", "o", "+", 
        "p"}]}], "]"}], ",", "\[IndentingNewLine]", "      ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-", "o", "+", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
       "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
        "h"}], ",", 
       RowBox[{
       "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-", "o", "+", 
        "p"}]}], "]"}], ",", "\[IndentingNewLine]", "      ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+", "o", "-", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
       "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
        "h"}], ",", 
       RowBox[{
       "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+", "o", "-", 
        "p"}]}], "]"}], ",", "\[IndentingNewLine]", "      ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-", "o", "-", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
       "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
        "h"}], ",", 
       RowBox[{
       "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-", "o", "-", 
        "p"}]}], "]"}], ",", "\[IndentingNewLine]", "      ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-", "o", "-", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
        "h"}], ",", 
       RowBox[{
       "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-", "o", "-", 
        "p"}]}], "]"}], ",", "\[IndentingNewLine]", "      ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", "+", "o", "-", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
       "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
        "h"}], ",", 
       RowBox[{
       "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", "+", "o", "-", 
        "p"}]}], "]"}], ",", "\[IndentingNewLine]", "       ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-", "o", "+", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
       "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
        "h"}], ",", 
       RowBox[{
       "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-", "o", "+", 
        "p"}]}], "]"}], ",", "\[IndentingNewLine]", "       ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", "+", "o", "+", 
         "p"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
       "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
        "h"}], ",", 
       RowBox[{
       "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", "+", "o", "+", 
        "p"}]}], "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ii_", ",", "j_", ",", "kk_", ",", "l_", ",", "mm_", ",", "n_", ",", 
       "oo_", ",", "p_", ",", "qq_", ",", "r_", ",", "ss_", ",", "t_", ",", 
       "uu_", ",", "v_", ",", "ww_", ",", "x_"}], "}"}], ",", "\"\<O8\>\""}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"i", "=", 
        SqrtBox["ii"]}], ",", 
       RowBox[{"k", "=", 
        SqrtBox["kk"]}], ",", 
       RowBox[{"m", "=", 
        SqrtBox["mm"]}], ",", 
       RowBox[{"o", "=", 
        SqrtBox["oo"]}], ",", 
       RowBox[{"q", "=", 
        SqrtBox["qq"]}], ",", 
       RowBox[{"s", "=", 
        SqrtBox["ss"]}], ",", 
       RowBox[{"u", "=", 
        SqrtBox["uu"]}], ",", 
       RowBox[{"w", "=", 
        SqrtBox["ww"]}]}], "}"}], ",", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Cos", "[", "j", "]"}]}], "+", 
          RowBox[{"k", " ", 
           RowBox[{"Cos", "[", "l", "]"}]}], "+", 
          RowBox[{"m", " ", 
           RowBox[{"Cos", "[", "n", "]"}]}], "+", 
          RowBox[{"o", " ", 
           RowBox[{"Cos", "[", "p", "]"}]}], "+", 
          RowBox[{"q", " ", 
           RowBox[{"Cos", "[", "r", "]"}]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"Cos", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Cos", "[", "j", "]"}]}], "-", 
          RowBox[{"k", " ", 
           RowBox[{"Cos", "[", "l", "]"}]}], "-", 
          RowBox[{"m", " ", 
           RowBox[{"Cos", "[", "n", "]"}]}], "+", 
          RowBox[{"o", " ", 
           RowBox[{"Cos", "[", "p", "]"}]}], "+", 
          RowBox[{"q", " ", 
           RowBox[{"Cos", "[", "r", "]"}]}], "-", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"Cos", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Cos", "[", "j", "]"}]}], "-", 
          RowBox[{"k", " ", 
           RowBox[{"Cos", "[", "l", "]"}]}], "+", 
          RowBox[{"m", " ", 
           RowBox[{"Cos", "[", "n", "]"}]}], "-", 
          RowBox[{"o", " ", 
           RowBox[{"Cos", "[", "p", "]"}]}], "+", 
          RowBox[{"q", " ", 
           RowBox[{"Cos", "[", "r", "]"}]}], "-", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"w", " ", 
           RowBox[{"Cos", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Cos", "[", "j", "]"}]}], "+", 
          RowBox[{"k", " ", 
           RowBox[{"Cos", "[", "l", "]"}]}], "-", 
          RowBox[{"m", " ", 
           RowBox[{"Cos", "[", "n", "]"}]}], "-", 
          RowBox[{"o", " ", 
           RowBox[{"Cos", "[", "p", "]"}]}], "+", 
          RowBox[{"q", " ", 
           RowBox[{"Cos", "[", "r", "]"}]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"w", " ", 
           RowBox[{"Cos", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Cos", "[", "j", "]"}]}], "+", 
          RowBox[{"k", " ", 
           RowBox[{"Cos", "[", "l", "]"}]}], "+", 
          RowBox[{"m", " ", 
           RowBox[{"Cos", "[", "n", "]"}]}], "+", 
          RowBox[{"o", " ", 
           RowBox[{"Cos", "[", "p", "]"}]}], "-", 
          RowBox[{"q", " ", 
           RowBox[{"Cos", "[", "r", "]"}]}], "-", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"w", " ", 
           RowBox[{"Cos", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Cos", "[", "j", "]"}]}], "-", 
          RowBox[{"k", " ", 
           RowBox[{"Cos", "[", "l", "]"}]}], "-", 
          RowBox[{"m", " ", 
           RowBox[{"Cos", "[", "n", "]"}]}], "+", 
          RowBox[{"o", " ", 
           RowBox[{"Cos", "[", "p", "]"}]}], "-", 
          RowBox[{"q", " ", 
           RowBox[{"Cos", "[", "r", "]"}]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"w", " ", 
           RowBox[{"Cos", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Cos", "[", "j", "]"}]}], "-", 
          RowBox[{"k", " ", 
           RowBox[{"Cos", "[", "l", "]"}]}], "+", 
          RowBox[{"m", " ", 
           RowBox[{"Cos", "[", "n", "]"}]}], "-", 
          RowBox[{"o", " ", 
           RowBox[{"Cos", "[", "p", "]"}]}], "-", 
          RowBox[{"q", " ", 
           RowBox[{"Cos", "[", "r", "]"}]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"Cos", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Cos", "[", "j", "]"}]}], "+", 
          RowBox[{"k", " ", 
           RowBox[{"Cos", "[", "l", "]"}]}], "-", 
          RowBox[{"m", " ", 
           RowBox[{"Cos", "[", "n", "]"}]}], "-", 
          RowBox[{"o", " ", 
           RowBox[{"Cos", "[", "p", "]"}]}], "-", 
          RowBox[{"q", " ", 
           RowBox[{"Cos", "[", "r", "]"}]}], "-", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"Cos", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Sin", "[", "j", "]"}]}], "+", 
          RowBox[{"k", " ", 
           RowBox[{"Sin", "[", "l", "]"}]}], "+", 
          RowBox[{"m", " ", 
           RowBox[{"Sin", "[", "n", "]"}]}], "+", 
          RowBox[{"o", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}], "+", 
          RowBox[{"q", " ", 
           RowBox[{"Sin", "[", "r", "]"}]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Sin", "[", "j", "]"}]}], "-", 
          RowBox[{"k", " ", 
           RowBox[{"Sin", "[", "l", "]"}]}], "-", 
          RowBox[{"m", " ", 
           RowBox[{"Sin", "[", "n", "]"}]}], "+", 
          RowBox[{"o", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}], "+", 
          RowBox[{"q", " ", 
           RowBox[{"Sin", "[", "r", "]"}]}], "-", 
          RowBox[{"s", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Sin", "[", "j", "]"}]}], "-", 
          RowBox[{"k", " ", 
           RowBox[{"Sin", "[", "l", "]"}]}], "+", 
          RowBox[{"m", " ", 
           RowBox[{"Sin", "[", "n", "]"}]}], "-", 
          RowBox[{"o", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}], "+", 
          RowBox[{"q", " ", 
           RowBox[{"Sin", "[", "r", "]"}]}], "-", 
          RowBox[{"s", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], "-", 
          RowBox[{"w", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Sin", "[", "j", "]"}]}], "+", 
          RowBox[{"k", " ", 
           RowBox[{"Sin", "[", "l", "]"}]}], "-", 
          RowBox[{"m", " ", 
           RowBox[{"Sin", "[", "n", "]"}]}], "-", 
          RowBox[{"o", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}], "+", 
          RowBox[{"q", " ", 
           RowBox[{"Sin", "[", "r", "]"}]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], "-", 
          RowBox[{"w", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Sin", "[", "j", "]"}]}], "+", 
          RowBox[{"k", " ", 
           RowBox[{"Sin", "[", "l", "]"}]}], "+", 
          RowBox[{"m", " ", 
           RowBox[{"Sin", "[", "n", "]"}]}], "+", 
          RowBox[{"o", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}], "-", 
          RowBox[{"q", " ", 
           RowBox[{"Sin", "[", "r", "]"}]}], "-", 
          RowBox[{"s", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], "-", 
          RowBox[{"w", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Sin", "[", "j", "]"}]}], "-", 
          RowBox[{"k", " ", 
           RowBox[{"Sin", "[", "l", "]"}]}], "-", 
          RowBox[{"m", " ", 
           RowBox[{"Sin", "[", "n", "]"}]}], "+", 
          RowBox[{"o", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}], "-", 
          RowBox[{"q", " ", 
           RowBox[{"Sin", "[", "r", "]"}]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], "-", 
          RowBox[{"w", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Sin", "[", "j", "]"}]}], "-", 
          RowBox[{"k", " ", 
           RowBox[{"Sin", "[", "l", "]"}]}], "+", 
          RowBox[{"m", " ", 
           RowBox[{"Sin", "[", "n", "]"}]}], "-", 
          RowBox[{"o", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}], "-", 
          RowBox[{"q", " ", 
           RowBox[{"Sin", "[", "r", "]"}]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"i", " ", 
           RowBox[{"Sin", "[", "j", "]"}]}], "+", 
          RowBox[{"k", " ", 
           RowBox[{"Sin", "[", "l", "]"}]}], "-", 
          RowBox[{"m", " ", 
           RowBox[{"Sin", "[", "n", "]"}]}], "-", 
          RowBox[{"o", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}], "-", 
          RowBox[{"q", " ", 
           RowBox[{"Sin", "[", "r", "]"}]}], "-", 
          RowBox[{"s", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"Sin", "[", "x", "]"}]}]}]}], "}"}], "/", "16"}]}]}], 
    "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["8.",
  FontFamily->"Arial"],
 "12 Shapes for larger tables."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sh", "[", "\"\<C3C4C2\>\"", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fa", "=", 
       RowBox[{
       "a", "-", "b", "-", "g", "+", "h", "+", "m", "-", "n", "-", "s", "+", 
        "t"}]}], ",", 
      RowBox[{"fb", "=", 
       RowBox[{
       "b", "-", "c", "-", "h", "+", "i", "+", "n", "-", "o", "-", "t", "+", 
        "u"}]}], ",", 
      RowBox[{"fc", "=", 
       RowBox[{
       "c", "-", "a", "-", "i", "+", "g", "+", "o", "-", "m", "-", "u", "+", 
        "s"}]}], ",", 
      RowBox[{"fd", "=", 
       RowBox[{
       "d", "-", "e", "-", "j", "+", "k", "+", "p", "-", "q", "-", "v", "+", 
        "w"}]}], ",", 
      RowBox[{"fe", "=", 
       RowBox[{
       "e", "-", "f", "-", "k", "+", "l", "+", "q", "-", "r", "-", "w", "+", 
        "x"}]}], ",", 
      RowBox[{"ff", "=", 
       RowBox[{
       "f", "-", "d", "-", "l", "+", "j", "+", "r", "-", "p", "-", "x", "+", 
        "v"}]}], ",", 
      RowBox[{"ga", "=", 
       RowBox[{
       "a", "-", "b", "-", "g", "+", "h", "-", "m", "+", "n", "+", "s", "-", 
        "t"}]}], ",", 
      RowBox[{"gb", "=", 
       RowBox[{
       "b", "-", "c", "-", "h", "+", "i", "-", "n", "+", "o", "+", "t", "-", 
        "u"}]}], ",", 
      RowBox[{"gc", "=", 
       RowBox[{
       "c", "-", "a", "-", "i", "+", "g", "-", "o", "+", "m", "+", "u", "-", 
        "s"}]}], ",", 
      RowBox[{"gd", "=", 
       RowBox[{
       "d", "-", "e", "-", "j", "+", "k", "-", "p", "+", "q", "+", "v", "-", 
        "w"}]}], ",", 
      RowBox[{"ge", "=", 
       RowBox[{
       "e", "-", "f", "-", "k", "+", "l", "-", "q", "+", "r", "+", "w", "-", 
        "x"}]}], ",", 
      RowBox[{"gf", "=", 
       RowBox[{
       "f", "-", "d", "-", "l", "+", "j", "-", "r", "+", "p", "-", "v", "+", 
        "x"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"gp", "=."}], ";", 
     RowBox[{"gi", "=", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "3", ",", "2", ",", "10", ",", "12", ",", "11", ",", "7", 
        ",", "9", ",", "8", ",", "4", ",", "6", ",", "5", ",", "13", ",", 
        "15", ",", "14", ",", "22", ",", "24", ",", "23", ",", "19", ",", 
        "21", ",", "20", ",", "16", ",", "18", ",", "17", ",", "1", ",", "1", 
        ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
        ",", "1", ",", "1", ",", "1"}], "}"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
        "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", 
        "o", "+", "p", "+", "q", "+", "r", "+", "s", "+", "t", "+", "u", "+", 
        "v", "+", "w", "+", "x"}], ",", "\[IndentingNewLine]", 
       RowBox[{
       "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
        "h", "+", "i", "-", "j", "-", "k", "-", "l", "+", "m", "+", "n", "+", 
        "o", "-", "p", "-", "q", "-", "r", "+", "s", "+", "t", "+", "u", "-", 
        "v", "-", "w", "-", "x"}], ",", "\[IndentingNewLine]", 
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
        "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-", 
        "o", "-", "p", "-", "q", "-", "r", "-", "s", "-", "t", "-", "u", "-", 
        "v", "-", "w", "-", "x"}], ",", "\[IndentingNewLine]", 
       RowBox[{
       "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
        "h", "+", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-", 
        "o", "+", "p", "+", "q", "+", "r", "-", "s", "-", "t", "-", "u", "+", 
        "v", "+", "w", "+", "x"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i", "-", "m", 
           "-", "n", "-", "o", "+", "s", "+", "t", "+", "u"}], ")"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l", "-", "p", 
           "-", "q", "-", "r", "+", "v", "+", "w", "+", "x"}], ")"}], "2"]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i", "+", "m", 
           "+", "n", "+", "o", "-", "s", "-", "t", "-", "u"}], ")"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l", "+", "p", 
           "+", "q", "+", "r", "-", "v", "-", "w", "-", "x"}], ")"}], "2"]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", "    ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
            "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", 
             "-", "k", "+", "m", "-", "n", "+", "p", "-", "q", "+", "s", "-", 
             "t", "+", "v", "-", "w"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
            "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
             "-", "l", "+", "n", "-", "o", "+", "q", "-", "r", "+", "t", "-", 
             "u", "+", "w", "-", "x"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "+", 
             "i", "-", "j", "+", "l", "-", "m", "+", "o", "-", "p", "+", "r", 
             "-", "s", "+", "u", "-", "v", "+", "x"}], ")"}], "2"]}], ")"}], 
        "/", "2"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", "    ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
            "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", 
             "-", "k", "-", "m", "+", "n", "-", "p", "+", "q", "-", "s", "+", 
             "t", "-", "v", "+", "w"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
            "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", 
             "-", "l", "-", "n", "+", "o", "-", "q", "+", "r", "-", "t", "+", 
             "u", "-", "w", "+", "x"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "+", 
             "i", "-", "j", "+", "l", "+", "m", "-", "o", "+", "p", "-", "r", 
             "+", "s", "-", "u", "+", "v", "-", "x"}], ")"}], "2"]}], ")"}], 
        "/", "2"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", "    ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
            "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", 
             "+", "k", "+", "m", "-", "n", "-", "p", "+", "q", "+", "s", "-", 
             "t", "-", "v", "+", "w"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
            "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", 
             "+", "l", "+", "n", "-", "o", "-", "q", "+", "r", "+", "t", "-", 
             "u", "-", "w", "+", "x"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "-", "g", "+", 
             "i", "+", "j", "-", "l", "-", "m", "+", "o", "+", "p", "-", "r", 
             "-", "s", "+", "u", "+", "v", "-", "x"}], ")"}], "2"]}], ")"}], 
        "/", "2"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", "    ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
            "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", 
             "+", "k", "-", "m", "+", "n", "+", "p", "-", "q", "-", "s", "+", 
             "t", "+", "v", "-", "w"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
            "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", 
             "+", "l", "-", "n", "+", "o", "+", "q", "-", "r", "-", "t", "+", 
             "u", "+", "w", "-", "x"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "-", "g", "+", 
             "i", "+", "j", "-", "l", "+", "m", "-", "o", "-", "p", "+", "r", 
             "+", "s", "-", "u", "-", "v", "+", "x"}], ")"}], "2"]}], ")"}], 
        "/", "2"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"fa", "+", "fd"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"fa", "-", "fd"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"fb", "+", "fe"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"fb", "-", "fe"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"fc", "+", "ff"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"fc", "-", "ff"}], ")"}], "4"]}], ")"}], "/", "4"}], "-",
         
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["fa", "2"], "+", 
           SuperscriptBox["fb", "2"], "+", 
           SuperscriptBox["fc", "2"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["fd", "2"], "+", 
           SuperscriptBox["fe", "2"], "+", 
           SuperscriptBox["ff", "2"]}], ")"}]}]}], ",", "\[IndentingNewLine]",
        
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"ga", "+", "gd"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"ga", "-", "gd"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"gb", "+", "ge"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"gb", "-", "ge"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"gc", "+", "gf"}], ")"}], "4"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"gc", "-", "gf"}], ")"}], "4"]}], ")"}], "/", "4"}], "-",
         
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["ga", "2"], "+", 
           SuperscriptBox["gb", "2"], "+", 
           SuperscriptBox["gc", "2"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["gd", "2"], "+", 
           SuperscriptBox["ge", "2"], "+", 
           SuperscriptBox["gf", "2"]}], ")"}]}]}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True,
 FontSize->9],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL31C2\>\"", "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{"gp", "=."}], ";", 
       RowBox[{"gi", "=", 
        RowBox[{"{", 
         RowBox[{
         "1", ",", "18", ",", "3", ",", "4", ",", "5", ",", "6", ",", "23", 
          ",", "8", ",", "9", ",", "10", ",", "27", ",", "12", ",", "29", ",",
           "14", ",", "31", ",", "32", ",", "17", ",", "2", ",", "19", ",", 
          "20", ",", "21", ",", "22", ",", "7", ",", "24", ",", "25", ",", 
          "26", ",", "11", ",", "28", ",", "13", ",", "30", ",", "15", ",", 
          "16", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
          ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
          "1", ",", "1", ",", "1", ",", "1", ",", "4"}], "}"}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+",
           "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", 
          "-", "o", "-", "p", "+", "q", "+", "r", "+", "s", "+", "t", "+", 
          "u", "+", "v", "+", "w", "+", "x", "-", "y", "-", "z", "-", 
          "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-",
           "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", 
          "-", "o", "-", "p", "+", "q", "+", "r", "+", "s", "+", "t", "-", 
          "u", "-", "v", "-", "w", "-", "x", "+", "y", "+", "z", "+", 
          "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-",
           "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", 
          "-", "o", "-", "p", "+", "q", "+", "r", "-", "s", "-", "t", "+", 
          "u", "+", "v", "-", "w", "-", "x", "+", "y", "+", "z", "-", 
          "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+",
           "h", "-", "i", "-", "j", "+", "k", "+", "l", "+", "m", "+", "n", 
          "-", "o", "-", "p", "+", "q", "+", "r", "-", "s", "-", "t", "-", 
          "u", "-", "v", "+", "w", "+", "x", "-", "y", "-", "z", "+", 
          "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-",
           "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", 
          "+", "o", "-", "p", "+", "q", "-", "r", "+", "s", "-", "t", "+", 
          "u", "-", "v", "+", "w", "-", "x", "+", "y", "-", "z", "+", 
          "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+",
           "h", "-", "i", "+", "j", "-", "k", "+", "l", "+", "m", "-", "n", 
          "+", "o", "-", "p", "+", "q", "-", "r", "+", "s", "-", "t", "-", 
          "u", "+", "v", "-", "w", "+", "x", "-", "y", "+", "z", "-", 
          "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+",
           "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", 
          "+", "o", "-", "p", "+", "q", "-", "r", "-", "s", "+", "t", "+", 
          "u", "-", "v", "-", "w", "+", "x", "-", "y", "+", "z", "+", 
          "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-",
           "h", "+", "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", 
          "+", "o", "-", "p", "+", "q", "-", "r", "-", "s", "+", "t", "-", 
          "u", "+", "v", "+", "w", "-", "x", "+", "y", "-", "z", "-", 
          "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-",
           "h", "-", "i", "+", "j", "+", "k", "-", "l", "+", "m", "-", "n", 
          "-", "o", "+", "p", "+", "q", "-", "r", "-", "s", "+", "t", "-", 
          "u", "+", "v", "+", "w", "-", "x", "-", "y", "+", "z", "+", 
          "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+",
           "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", 
          "-", "o", "+", "p", "+", "q", "-", "r", "-", "s", "+", "t", "+", 
          "u", "-", "v", "-", "w", "+", "x", "+", "y", "-", "z", "-", 
          "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+",
           "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", 
          "-", "o", "+", "p", "+", "q", "-", "r", "+", "s", "-", "t", "-", 
          "u", "+", "v", "-", "w", "+", "x", "+", "y", "-", "z", "+", 
          "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-",
           "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", 
          "-", "o", "+", "p", "+", "q", "-", "r", "+", "s", "-", "t", "+", 
          "u", "-", "v", "+", "w", "-", "x", "-", "y", "+", "z", "-", 
          "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+",
           "h", "+", "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", 
          "+", "o", "+", "p", "+", "q", "+", "r", "-", "s", "-", "t", "-", 
          "u", "-", "v", "+", "w", "+", "x", "+", "y", "+", "z", "-", 
          "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-",
           "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", 
          "+", "o", "+", "p", "+", "q", "+", "r", "-", "s", "-", "t", "+", 
          "u", "+", "v", "-", "w", "-", "x", "-", "y", "-", "z", "+", 
          "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-",
           "h", "-", "i", "-", "j", "-", "k", "-", "l", "+", "m", "+", "n", 
          "+", "o", "+", "p", "+", "q", "+", "r", "+", "s", "+", "t", "-", 
          "u", "-", "v", "-", "w", "-", "x", "-", "y", "-", "z", "-", 
          "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+",
           "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", 
          "+", "o", "+", "p", "+", "q", "+", "r", "+", "s", "+", "t", "+", 
          "u", "+", "v", "+", "w", "+", "x", "+", "y", "+", "z", "+", 
          "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{"h", "-", "x"}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{"i", "-", "y"}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"g", "-", "w"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"j", "-", "z"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"f", "-", "v"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"k", "-", "\[Alpha]"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"e", "-", "u"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"l", "-", "\[Beta]"}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"d", "-", "t"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"m", "-", "\[Gamma]"}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"c", "-", "s"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"b", "-", "r"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"a", "-", "q"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", 
               "2"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"g", "-", "w"}], ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"i", "-", "y"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"h", "-", "x"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"j", "-", "z"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"e", "-", "u"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"k", "-", "\[Alpha]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"f", "-", "v"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "-", "\[Beta]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"c", "-", "s"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"m", "-", "\[Gamma]"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"d", "-", "t"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"a", "-", "q"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"b", "-", "r"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", "2"}],
              "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"f", "-", "v"}], ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"i", "-", "y"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"e", "-", "u"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"j", "-", "z"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"h", "-", "x"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"k", "-", "\[Alpha]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"g", "-", "w"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "-", "\[Beta]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"b", "-", "r"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"m", "-", "\[Gamma]"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"a", "-", "q"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"d", "-", "t"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"c", "-", "s"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", "2"}],
              "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"d", "-", "t"}], ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"i", "-", "y"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"c", "-", "s"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"j", "-", "z"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"b", "-", "r"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"k", "-", "\[Alpha]"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"a", "-", "q"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"l", "-", "\[Beta]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"h", "-", "x"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"m", "-", "\[Gamma]"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"g", "-", "w"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"f", "-", "v"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"e", "-", "u"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", "2"}],
              "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"d", "-", "t"}], ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"e", "-", "u"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"c", "-", "s"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"f", "-", "v"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"b", "-", "r"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"g", "-", "w"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"a", "-", "q"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"h", "-", "x"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"l", "-", "\[Beta]"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"m", "-", "\[Gamma]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"k", "-", "\[Alpha]"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"j", "-", "z"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"i", "-", "y"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", 
              "2"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"a", "-", "q"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"b", "-", "r"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"c", "-", "s"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"d", "-", "t"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"e", "-", "u"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"f", "-", "v"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"g", "-", "w"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"h", "-", "x"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"i", "-", "y"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"j", "-", "z"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"k", "-", "\[Alpha]"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"l", "-", "\[Beta]"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"m", "-", "\[Gamma]"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"n", "-", "\[Delta]"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}], "2"], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"p", "-", "\[Zeta]"}], ")"}], "2"]}], ")"}], "^", 
           "2"}]}]}], "}"}]}]}], "]"}], " ", "NEEDS", " ", "REVISION"}]}], 
  " ", "*)"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 FontSize->9],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"sh", "[", "\"\<CL4C2\>\"", "]"}], ":=", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{"gp", "=."}], ";", 
       RowBox[{"gi", "=", 
        RowBox[{"{", 
         RowBox[{
         "1", ",", "2", ",", "3", ",", "20", ",", "5", ",", "22", ",", "23", 
          ",", "24", ",", "9", ",", "26", ",", "27", ",", "28", ",", "29", 
          ",", "30", ",", "31", ",", "16", ",", "17", ",", "18", ",", "19", 
          ",", "4", ",", "21", ",", "6", ",", "7", ",", "8", ",", "25", ",", 
          "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "15", ",", 
          "32", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
          ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
          "1", ",", "1", ",", "1", ",", "1", ",", "4"}], "}"}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+",
           "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", 
          "-", "o", "-", "p", "+", "q", "+", "r", "+", "s", "+", "t", "+", 
          "u", "+", "v", "+", "w", "+", "x", "-", "y", "-", "z", "-", 
          "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-",
           "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", 
          "-", "o", "-", "p", "+", "q", "+", "r", "+", "s", "+", "t", "-", 
          "u", "-", "v", "-", "w", "-", "x", "+", "y", "+", "z", "+", 
          "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-",
           "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", 
          "-", "o", "-", "p", "+", "q", "+", "r", "-", "s", "-", "t", "+", 
          "u", "+", "v", "-", "w", "-", "x", "+", "y", "+", "z", "-", 
          "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+",
           "h", "-", "i", "-", "j", "+", "k", "+", "l", "+", "m", "+", "n", 
          "-", "o", "-", "p", "+", "q", "+", "r", "-", "s", "-", "t", "-", 
          "u", "-", "v", "+", "w", "+", "x", "-", "y", "-", "z", "+", 
          "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-",
           "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", 
          "+", "o", "-", "p", "+", "q", "-", "r", "+", "s", "-", "t", "+", 
          "u", "-", "v", "+", "w", "-", "x", "+", "y", "-", "z", "+", 
          "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+",
           "h", "-", "i", "+", "j", "-", "k", "+", "l", "+", "m", "-", "n", 
          "+", "o", "-", "p", "+", "q", "-", "r", "+", "s", "-", "t", "-", 
          "u", "+", "v", "-", "w", "+", "x", "-", "y", "+", "z", "-", 
          "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+",
           "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", 
          "+", "o", "-", "p", "+", "q", "-", "r", "-", "s", "+", "t", "+", 
          "u", "-", "v", "-", "w", "+", "x", "-", "y", "+", "z", "+", 
          "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-",
           "h", "+", "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", 
          "+", "o", "-", "p", "+", "q", "-", "r", "-", "s", "+", "t", "-", 
          "u", "+", "v", "+", "w", "-", "x", "+", "y", "-", "z", "-", 
          "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "-", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-",
           "h", "-", "i", "+", "j", "+", "k", "-", "l", "+", "m", "-", "n", 
          "-", "o", "+", "p", "+", "q", "-", "r", "-", "s", "+", "t", "-", 
          "u", "+", "v", "+", "w", "-", "x", "-", "y", "+", "z", "+", 
          "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+",
           "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", 
          "-", "o", "+", "p", "+", "q", "-", "r", "-", "s", "+", "t", "+", 
          "u", "-", "v", "-", "w", "+", "x", "+", "y", "-", "z", "-", 
          "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+",
           "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", 
          "-", "o", "+", "p", "+", "q", "-", "r", "+", "s", "-", "t", "-", 
          "u", "+", "v", "-", "w", "+", "x", "+", "y", "-", "z", "+", 
          "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-",
           "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", 
          "-", "o", "+", "p", "+", "q", "-", "r", "+", "s", "-", "t", "+", 
          "u", "-", "v", "+", "w", "-", "x", "-", "y", "+", "z", "-", 
          "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+",
           "h", "+", "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", 
          "+", "o", "+", "p", "+", "q", "+", "r", "-", "s", "-", "t", "-", 
          "u", "-", "v", "+", "w", "+", "x", "+", "y", "+", "z", "-", 
          "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-",
           "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", 
          "+", "o", "+", "p", "+", "q", "+", "r", "-", "s", "-", "t", "+", 
          "u", "+", "v", "-", "w", "-", "x", "-", "y", "-", "z", "+", 
          "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-",
           "h", "-", "i", "-", "j", "-", "k", "-", "l", "+", "m", "+", "n", 
          "+", "o", "+", "p", "+", "q", "+", "r", "+", "s", "+", "t", "-", 
          "u", "-", "v", "-", "w", "-", "x", "-", "y", "-", "z", "-", 
          "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
         "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+",
           "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", 
          "+", "o", "+", "p", "+", "q", "+", "r", "+", "s", "+", "t", "+", 
          "u", "+", "v", "+", "w", "+", "x", "+", "y", "+", "z", "+", 
          "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
          "\[CurlyEpsilon]", "+", "\[Zeta]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"h", "-", "x"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"i", "-", "y"}], ")"}]}], "-", 
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"g", "-", "w"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"j", "-", "z"}], ")"}]}], "+", 
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"f", "-", "v"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"k", "-", "\[Alpha]"}], ")"}]}], "-", 
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"e", "-", "u"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"l", "-", "\[Beta]"}], ")"}]}], "-", 
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"d", "-", "t"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"m", "-", "\[Gamma]"}], ")"}]}], "+", 
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"c", "-", "s"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "-", 
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"b", "-", "r"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "+", 
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"a", "-", "q"}], ")"}], 
               RowBox[{"(", 
                RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", "2"}]}],
           "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"a", "-", "q"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"i", "-", "y"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"b", "-", "r"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"j", "-", "z"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"c", "-", "s"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"k", "-", "\[Alpha]"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"d", "-", "t"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"l", "-", "\[Beta]"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"e", "-", "u"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"m", "-", "\[Gamma]"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"f", "-", "v"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"g", "-", "w"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"h", "-", "x"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", "2"}], 
          "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"a", "-", "q"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"e", "-", "u"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"b", "-", "r"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"f", "-", "v"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"c", "-", "s"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"g", "-", "w"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"d", "-", "t"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"h", "-", "x"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"i", "-", "y"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"m", "-", "\[Gamma]"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"j", "-", "z"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"k", "-", "\[Alpha]"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"l", "-", "\[Beta]"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", "2"}], 
          "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"a", "-", "q"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"c", "-", "s"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"b", "-", "r"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "-", "t"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"e", "-", "u"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"g", "-", "w"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"f", "-", "v"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"h", "-", "x"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"i", "-", "y"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"k", "-", "\[Alpha]"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"j", "-", "z"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"l", "-", "\[Beta]"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"m", "-", "\[Gamma]"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"n", "-", "\[Delta]"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", "2"}], 
          "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"a", "-", "q"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"b", "-", "r"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"c", "-", "s"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"d", "-", "t"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"e", "-", "u"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"f", "-", "v"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"g", "-", "w"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"h", "-", "x"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"i", "-", "y"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"j", "-", "z"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"k", "-", "\[Alpha]"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"l", "-", "\[Beta]"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"m", "-", "\[Gamma]"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"n", "-", "\[Delta]"}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"p", "-", "\[Zeta]"}], ")"}]}]}], ")"}], "^", "2"}], 
          "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"a", "-", "q"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"b", "-", "r"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"c", "-", "s"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"d", "-", "t"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"e", "-", "u"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"f", "-", "v"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"g", "-", "w"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"h", "-", "x"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"i", "-", "y"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"j", "-", "z"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"k", "-", "\[Alpha]"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"l", "-", "\[Beta]"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"m", "-", "\[Gamma]"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"n", "-", "\[Delta]"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"o", "-", "\[CurlyEpsilon]"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"p", "-", "\[Zeta]"}], ")"}], "2"]}], ")"}], "^", 
           "2"}]}]}], "}"}]}]}], "]"}], " ", "NEEDS", " ", "REVISION"}]}], 
  "*)"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 FontSize->9]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["9. Exported functions.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "1 Loop Procedures ",
 StyleBox["abbr, gpd, shape, hoopFactor, hoopShape, frag, frag2, tidy, \
toSignedTable, cosorbit, \[Omega]=2\[Pi]/3.",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"abbr", "[", 
    RowBox[{"t_", ",", 
     RowBox[{"o_:", "1"}], ",", 
     RowBox[{"n_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "=", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"l", "=", 
        RowBox[{
         RowBox[{"Length", "[", "t", "]"}], "-", "1"}]}], ",", 
       RowBox[{"f", "=", 
        RowBox[{"First", "[", "t", "]"}]}], ",", 
       RowBox[{"r", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{"t", ",", "1"}], "]"}]}], ",", "s", ",", 
       RowBox[{"u", "=", 
        RowBox[{"Union", "[", 
         RowBox[{"Drop", "[", 
          RowBox[{"t", ",", "1"}], "]"}], "]"}]}], ",", "ui"}], "}"}], ",", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ui", "=", 
          RowBox[{"u", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", 
         RowBox[{"s", "=", 
          RowBox[{"Length", "[", 
           RowBox[{"Position", "[", 
            RowBox[{"r", ",", "ui"}], "]"}], "]"}]}], " ", ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"s", ">", "1"}], ",", 
           RowBox[{
            RowBox[{"u", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "=", 
            SubscriptBox["ui", "s"]}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "u", "]"}]}], "}"}]}], "]"}], ";", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"o", " ", "f"}], "}"}], ",", "u", ",", "n"}], "]"}], 
       "]"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gpd", "[", "gg_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "gg", "]"}], "\[Equal]", "1"}], "&&", 
          RowBox[{
           RowBox[{"Head", "[", "gg", "]"}], "\[Equal]", 
           "TraditionalForm"}]}], ",", 
         RowBox[{"gg", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "gg"}], "]"}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "g", "]"}], "\[Equal]", 
         RowBox[{"Length", "[", 
          RowBox[{"g", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "&&", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"MatrixQ", "[", 
           RowBox[{"g", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}], "||", 
          RowBox[{
           RowBox[{"Union", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Abs", "[", "g", "]"}], ",", "1"}], "]"}], "]"}], 
           "\[Equal]", 
           RowBox[{"Sort", "[", 
            RowBox[{"Abs", "[", 
             RowBox[{"g", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}]}], ")"}]}], ",", 
       "g", ",", 
       RowBox[{
        StyleBox[
         RowBox[{"Print", "[", 
          RowBox[{
           RowBox[{"Short", "[", "g", "]"}], ",", 
           "\"\< is not a groupoid\>\""}], "]"}],
         FontColor->RGBColor[1, 0, 1]], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"pr", "<", "3"}], ",", 
          RowBox[{"Abort", "[", "]"}]}], "]"}]}]}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"shape", "[", 
    RowBox[{
     RowBox[{"a_", "?", "VectorQ"}], ",", 
     RowBox[{"g_:", "gmn"}]}], "]"}], ":=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sh", "[", "g", "]"}], "/.", 
      RowBox[{"fromAlph", "[", "a", "]"}]}], ",", "hmin"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"hoopFactor", "[", 
    RowBox[{"f_Symbol:", "fp"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "gf", ",", 
       RowBox[{"gl", "=", 
        RowBox[{"Length", "[", "glo", "]"}]}], ",", "n", ",", 
       RowBox[{"res", "=", 
        RowBox[{"{", "}"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Abs", "[", "glo", "]"}], ",", "1"}], "]"}]}], ";", 
      RowBox[{"gi", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "gi", "]"}], ",", "1"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "*", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"i", "=", "ii"}], ";", 
           RowBox[{"Sign", "[", 
            RowBox[{"glo", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"gi", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
               RowBox[{"gi", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], 
            "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "gl"}], "}"}]}], "]"}]}]}], ";", 
      RowBox[{"gf", "=", 
       RowBox[{"f", "[", "glo", "]"}]}], ";", 
      RowBox[{"gf", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", "gf", "]"}], "===", "Times"}], ",", 
         RowBox[{"List", "@@", "gf"}], ",", 
         RowBox[{"{", "gf", "}"}]}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "that", " ", "deals", " ", "with", " ", "single", " ", "and", " ", 
         "repeated", " ", "single", " ", 
         RowBox[{"factors", ".", " ", "Remove"}], " ", "any"}], " ", "-", 
        RowBox[{"1", " ", "factor"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"gf", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "===", 
         RowBox[{"-", "1"}]}], ",", 
        RowBox[{"gf", "=", 
         RowBox[{"Drop", "[", 
          RowBox[{"gf", ",", "1"}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"n", "=", 
          RowBox[{"gf", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "n", "]"}], "===", "Power"}], ",", 
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"res", ",", 
              RowBox[{"n", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"gi", ",", 
              RowBox[{"n", "[", 
               RowBox[{"[", 
                RowBox[{"-", "1"}], "]"}], "]"}]}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"res", ",", "n"}], "]"}], ";", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"gi", ",", "1"}], "]"}]}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "gf", "]"}]}], "}"}]}], "]"}], ";", 
      "res"}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hoopShape", "[", "]"}], ":=", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", "glo", "]"}], "===", "List"}], ",", 
     RowBox[{"hoopShape", "[", 
      RowBox[{"glo", ",", 
       RowBox[{"-", "1"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Head", "[", "gmn", "]"}], "===", "Symbol"}], ",", 
     StyleBox[
      RowBox[{"Print", "[", "\"\<Neither glo nor gmn set\>\"", "]"}],
      FontColor->RGBColor[1, 0, 1]], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"sh", "[", "gmn", "]"}], "]"}], "===", "sh"}], ",", 
     RowBox[{"frag", "[", 
      RowBox[{"hoopFactor", "[", "fa", "]"}], "]"}], ",", 
     "\[IndentingNewLine]", "True", ",", 
     RowBox[{"sh", "[", "gmn", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hoopShape", "[", 
    RowBox[{
     RowBox[{"m_", "?", "IntegerQ"}], ",", "n_"}], "]"}], ":=", 
   RowBox[{"hoopShape", "[", 
    RowBox[{"mp", "[", 
     RowBox[{"m", ",", "n"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hoopShape", "[", 
     RowBox[{"X_", ",", 
      RowBox[{"o_:", "0"}]}], "]"}], "/;", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Head", "[", "X", "]"}], "===", "String"}], ")"}], "||", 
     RowBox[{
      RowBox[{"Head", "[", "X", "]"}], "===", "Symbol"}]}]}], ":=", 
   RowBox[{"hoopShape", "[", 
    RowBox[{
     RowBox[{"makeProtoloop", "[", "X", "]"}], ",", "o"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hoopShape", "[", 
     RowBox[{"X_", ",", 
      RowBox[{"o_:", "0"}]}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Head", "[", "X", "]"}], "\[Equal]", "TraditionalForm"}]}], ":=",
    
   RowBox[{"hoopShape", "[", 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "o"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hoopShape", "[", 
     RowBox[{"X_", ",", 
      RowBox[{"o_:", "0"}]}], "]"}], "/;", 
    RowBox[{"MatrixQ", "[", "X", "]"}]}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "=", "X"}], ",", "gf", ",", "gm", ",", 
       RowBox[{"res", "=", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"r", "=", 
        RowBox[{"{", "}"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"X", "===", "glo"}], ",", "Null", ",", 
        RowBox[{"g", "=", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"o", "\[Equal]", 
            RowBox[{"-", "1"}]}], ",", "X", ",", 
           RowBox[{"caylindex", "[", 
            RowBox[{"gpd", "[", "X", "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"o", ">", "0"}], "&&", 
         RowBox[{"!", 
          RowBox[{"(", 
           RowBox[{"conservativeQ", "[", "]"}], ")"}]}]}], ",", 
        RowBox[{
         StyleBox[
          RowBox[{"Print", "[", "\"\<Table not conservative\>\"", "]"}],
          FontColor->RGBColor[1, 0, 1]], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"id", "[", "g", "]"}], ";", 
      RowBox[{"hoopFactor", "[", "]"}], ";", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", 
            RowBox[{"X", "\[LeftDoubleBracket]", 
             RowBox[{"in", ",", "1"}], "\[RightDoubleBracket]"}], "]"}], "===",
            "Symbol"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{
             "alph", "\[LeftDoubleBracket]", "in", "\[RightDoubleBracket]"}], 
             "\[Rule]", 
             RowBox[{"X", "\[LeftDoubleBracket]", 
              RowBox[{"in", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
           "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"in", ",", "mm"}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"gm", "=", 
       RowBox[{
        RowBox[{"fp", "[", "g", "]"}], "/.", "r"}]}], ";", 
      RowBox[{"res", "=", 
       RowBox[{"sh", "[", "gmn", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"gmn", "\[Equal]", "\"\<Unrecognised\>\""}], "||", 
         RowBox[{
          RowBox[{"Head", "[", "res", "]"}], "\[Equal]", "sh"}]}], ",", 
        RowBox[{
         RowBox[{"res", "=", 
          RowBox[{"frag", "[", 
           RowBox[{"fa", "[", "g", "]"}], "]"}]}], ";", 
         RowBox[{
          RowBox[{"sh", "[", "gmn", "]"}], "=", 
          RowBox[{"frag", "[", 
           RowBox[{"res", ",", "o"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"gmn", "\[NotEqual]", "Unrecognized"}], ")"}], "&&", 
         RowBox[{
          RowBox[{"fp", "[", 
           RowBox[{"makeProtoloop", "[", "gmn", "]"}], "]"}], "===", "gm"}]}],
         ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"o", ">", "0"}], ",", 
           StyleBox[
            RowBox[{"Print", "[", 
             RowBox[{"gmn", "<>", "Protoloop"}], "]"}],
            FontColor->RGBColor[0, 1, 0]]}], "]"}], ";", 
         "\[IndentingNewLine]", "   ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "res", "]"}], "\[Equal]", "sh"}], ",", 
           RowBox[{
            RowBox[{"res", "=", 
             RowBox[{"hoopFactor", "[", "fa", "]"}]}], ";", 
            RowBox[{
             RowBox[{"sh", "[", "gmn", "]"}], "=", "res"}]}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"gmn", "\[NotEqual]", "Unrecognized"}], "&&", 
         RowBox[{
          RowBox[{"Length", "[", "res", "]"}], "===", 
          RowBox[{"Length", "[", "gm", "]"}]}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"o", ">", "0"}], ",", 
          StyleBox[
           RowBox[{"Print", "[", 
            RowBox[{"gmn", "<>", "Isomorph"}], "]"}],
           FontColor->RGBColor[0, 1, 0]]}], "]"}], ",", "\[IndentingNewLine]",
         "True", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"o", "\[NotEqual]", "0"}], ",", 
          StyleBox[
           RowBox[{"Print", "[", 
            RowBox[{"gmn", "<>", "\"\<Shape found\>\""}], "]"}],
           FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "r", "]"}], "\[Equal]", "mm"}], ",", 
        RowBox[{"res", "/.", "r"}], ",", "res"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"hoopShape", "[", 
    RowBox[{"Unrecognized", ",", 
     RowBox[{"o_:", "0"}]}], "]"}], ":=", 
   RowBox[{"sh", "[", "Unrecognized", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"hoopShape", "[", 
     RowBox[{"X_", ",", 
      RowBox[{"o_:", "0"}]}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Head", "[", "X", "]"}], "\[Equal]", "List"}]}], ":=", 
   RowBox[{"hoopShape", "[", 
    RowBox[{
     RowBox[{"makeProtoloop", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"X", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"X", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hoopShape", "[", 
    RowBox[{"gg_", ",", 
     RowBox[{"o_:", "0"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "=", 
        RowBox[{"makeProtoloop", "[", "gg", "]"}]}], ",", "res"}], "}"}], ",",
      
     RowBox[{
      RowBox[{"res", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"g", "===", "\"\<No Protoloop\>\""}], ",", 
         RowBox[{
          RowBox[{"hoopFactor", "[", "fa", "]"}], ";", 
          RowBox[{"sh", "[", "Unrecognized", "]"}]}], ",", 
         RowBox[{"sh", "[", 
          RowBox[{
           RowBox[{"gd", "[", "]"}], "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}], 
        "]"}]}], ";", 
      RowBox[{"frag", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", "res", "]"}], "\[Equal]", "sh"}], ",", 
          RowBox[{"hoopFactor", "[", "fa", "]"}], ",", "res", ",", "res"}], 
         "]"}], ",", "o"}], "]"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"polsort", "[", "P_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "l", ",", 
        RowBox[{"p", "=", 
         RowBox[{"Expand", "[", "P", "]"}]}], ",", "t", ",", "v"}], "}"}], 
      ",", 
      RowBox[{
       RowBox[{"v", "=", 
        RowBox[{"Variables", "[", "p", "]"}]}], ";", " ", 
       RowBox[{"l", "=", 
        RowBox[{"Length", "[", "v", "]"}]}], ";", " ", 
       RowBox[{"t", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"p", ",", 
            RowBox[{"v", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], ";", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"p", "[", 
            RowBox[{"[", 
             RowBox[{"t", "[", 
              RowBox[{"[", 
               RowBox[{"v", ",", "j", ",", "1"}], "]"}], "]"}], "]"}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"Length", "[", 
              RowBox[{"t", "[", 
               RowBox[{"[", "v", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "l"}], "}"}]}], "]"}]}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"frag", "[", 
    RowBox[{"p_", ",", 
     RowBox[{"o_:", "0"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"P", ",", "res"}], "}"}], ",", 
     RowBox[{
      RowBox[{"P", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"MatrixQ", "[", "p", "]"}], ",", 
         RowBox[{"fa", "[", "p", "]"}], ",", "p"}], "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "P", "]"}], "===", "Plus"}], ",", 
        RowBox[{"P", "=", 
         RowBox[{"{", "P", "}"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", 
          RowBox[{"res", "=", 
           RowBox[{"sh", "[", "P", "]"}]}], "]"}], "===", "List"}], ",", 
        "res", ",", 
        RowBox[{
         RowBox[{"res", "=", 
          RowBox[{"{", "}"}]}], ";", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"res", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", 
                 RowBox[{"P", "[", 
                  RowBox[{"[", "ii", "]"}], "]"}], "]"}], "===", "Power"}], 
               ",", 
               RowBox[{"frag2", "[", 
                RowBox[{
                 RowBox[{"P", "[", 
                  RowBox[{"[", 
                   RowBox[{"ii", ",", "1"}], "]"}], "]"}], ",", "o"}], "]"}], 
               ",", 
               RowBox[{"frag2", "[", 
                RowBox[{
                 RowBox[{"P", "[", 
                  RowBox[{"[", "ii", "]"}], "]"}], ",", "o"}], "]"}]}], 
              "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"ii", ",", 
             RowBox[{"Length", "[", "P", "]"}]}], "}"}]}], "]"}], ";", 
         "res"}]}], "]"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"frag2", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", "P_", ")"}], "?", "PolynomialQ"}], ",", 
     RowBox[{"o_:", "0"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ai", ",", "aj", ",", 
       RowBox[{"d", "=", "1"}], ",", "err", ",", "f", ",", 
       RowBox[{"fn", "=", "0"}], ",", 
       RowBox[{"f2", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", "}"}]}], "}"}]}], ",", "i", ",", 
       RowBox[{"kf", "=", 
        RowBox[{"{", "}"}]}], ",", "l", ",", 
       RowBox[{"np", "=", "1"}], ",", "nw", ",", 
       RowBox[{"p", "=", 
        RowBox[{"polsort", "[", 
         RowBox[{"Expand", "[", "P", "]"}], "]"}]}], ",", "pi", ",", "pip", 
       ",", "p1", ",", "p2", ",", 
       RowBox[{"res", "=", 
        RowBox[{"{", "}"}]}], ",", "sgn", ",", "t", ",", "v", ",", 
       RowBox[{"vf", "=", 
        RowBox[{"{", "}"}]}], ",", "addnew"}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"P", "===", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "-", 
           SuperscriptBox["b", "2"]}]}], "||", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p", "=", 
            RowBox[{"polsort", "[", 
             RowBox[{"Expand", "[", "P", "]"}], "]"}]}], ";", 
           RowBox[{
            RowBox[{"MatrixQ", "[", "p", "]"}], "===", "False"}]}], ")"}], "||",
          
         RowBox[{
          RowBox[{"Max", "[", 
           RowBox[{"Exponent", "[", 
            RowBox[{
             RowBox[{"Plus", "@@", "p"}], ",", "a"}], "]"}], "]"}], 
          "\[NotEqual]", "2"}]}], ",", 
        RowBox[{"Return", "[", "P", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"addnew", "[", "t_", "]"}], ":=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"MemberQ", "[", 
              RowBox[{"res", ",", "t"}], "]"}], "===", "False"}], ",", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"res", ",", "t"}], "]"}]}], "]"}]}], ";", " ", 
         RowBox[{"l", "=", 
          RowBox[{"Length", "[", "p", "]"}]}], ";", " ", 
         RowBox[{"f", "=", 
          RowBox[{"FactorInteger", "[", "l", "]"}]}], ";", " ", 
         RowBox[{"v", "=", 
          RowBox[{"Variables", "[", "p", "]"}]}], ";", "\[IndentingNewLine]", 
         
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"pi", "=", 
             RowBox[{"p", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ";", " ", 
            RowBox[{"ai", "=", 
             RowBox[{"v", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ";", " ", 
            RowBox[{"sgn", "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Position", "[", 
                 RowBox[{"pi", ",", 
                  RowBox[{"-", 
                   RowBox[{"ai", "^", "2"}]}]}], "]"}], "\[Equal]", 
                RowBox[{"{", "}"}]}], ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"Which", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "pi", "]"}], "\[Equal]", "1"}], ",", 
              RowBox[{"addnew", "[", "pi", "]"}], ",", "\[IndentingNewLine]", 
              
              RowBox[{
               RowBox[{"Length", "[", "pi", "]"}], "\[Equal]", "2"}], ",", 
              RowBox[{"addnew", "[", 
               RowBox[{"sgn", "*", 
                RowBox[{
                 RowBox[{"pos", "[", 
                  RowBox[{"ai", "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"sgn", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Plus", "@@", "pi"}], "-", 
                    RowBox[{"sgn", "*", 
                    RowBox[{"ai", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{"2", "*", "ai"}], ")"}]}]}], "]"}], "^", "2"}]}], 
               "]"}], ",", 
              RowBox[{
               RowBox[{"Length", "[", 
                RowBox[{"Union", "[", 
                 RowBox[{
                  RowBox[{"Position", "[", 
                   RowBox[{"pi", ",", 
                    RowBox[{"sgn", "*", "2"}]}], "]"}], ",", 
                  RowBox[{"Position", "[", 
                   RowBox[{"pi", ",", 
                    RowBox[{
                    RowBox[{"-", "sgn"}], "*", "2"}]}], "]"}]}], "]"}], "]"}],
                "\[GreaterEqual]", 
               RowBox[{
                RowBox[{"Length", "[", "pi", "]"}], "-", "1"}]}], ",", 
              "\[IndentingNewLine]", "  ", 
              RowBox[{"addnew", "[", 
               RowBox[{"sgn", "*", 
                RowBox[{"pos", "[", 
                 RowBox[{"Simplify", "[", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"ai", "/", "2"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"sgn", "*", 
                    RowBox[{"Plus", "@@", "pi"}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{"ai", "*", "2"}], ")"}]}]}], ")"}], "^", "2"}], 
                  "]"}], "]"}]}], "]"}], ",", 
              RowBox[{
               RowBox[{"Mod", "[", 
                RowBox[{
                 RowBox[{"Length", "[", "pi", "]"}], ",", "3"}], "]"}], 
               "\[Equal]", "0"}], ",", 
              RowBox[{
               RowBox[{"d", "=", "2"}], ";", " ", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"p2", "=", 
                    RowBox[{"Position", "[", 
                    RowBox[{"vf", ",", "ai"}], "]"}]}], ")"}], "===", 
                  RowBox[{"{", "}"}]}], ",", 
                 RowBox[{
                  RowBox[{"fn", "++"}], ";", " ", 
                  RowBox[{"np", "=", "fn"}], ";", " ", 
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"vf", ",", 
                    RowBox[{"Variables", "[", "pi", "]"}]}], "]"}], ";", " ", 
                  
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"kf", ",", "sgn"}], "]"}]}], ",", 
                 RowBox[{
                  RowBox[{"aj", "=", "ai"}], ";", " ", 
                  RowBox[{"If", "[", 
                   RowBox[{"True", ",", 
                    RowBox[{"aj", "=", 
                    RowBox[{"-", "ai"}]}]}], "]"}], ";", " ", 
                  RowBox[{"np", "=", 
                   RowBox[{"First", "[", 
                    RowBox[{"Flatten", "[", "p2", "]"}], "]"}]}]}]}], "]"}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"pip", "=", 
                RowBox[{"Expand", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Plus", "@@", "pi"}], "/", "ai"}], "-", 
                  RowBox[{"sgn", "*", "ai"}]}], "]"}]}], ";", 
               RowBox[{"AppendTo", "[", 
                RowBox[{
                 RowBox[{"f2", "[", 
                  RowBox[{"[", "np", "]"}], "]"}], ",", 
                 RowBox[{"pos", "[", 
                  RowBox[{"Plus", "@@", 
                   RowBox[{"Flatten", "[", 
                    RowBox[{"{", 
                    RowBox[{"ai", ",", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], "*", 
                    RowBox[{"Union", "[", 
                    RowBox[{
                    RowBox[{"sgn", "*", 
                    RowBox[{"Extract", "[", 
                    RowBox[{"pip", ",", 
                    RowBox[{"Position", "[", 
                    RowBox[{"pip", ",", 
                    RowBox[{"2", "*", "_"}]}], "]"}]}], "]"}]}], ",", 
                    RowBox[{"sgn", "*", 
                    RowBox[{"Extract", "[", 
                    RowBox[{"pip", ",", 
                    RowBox[{"Position", "[", 
                    RowBox[{"pip", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "_"}]}], "]"}]}], "]"}]}]}], 
                    "]"}]}]}], "}"}], "]"}]}], "]"}]}], "]"}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"o", ">", "2"}], ",", 
                 StyleBox[
                  RowBox[{"Print", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    "\"\<pi,pip,f2\>\"", ",", "pi", ",", "pip", ",", "f2"}], 
                    "}"}], "]"}],
                  FontColor->RGBColor[0, 1, 0]]}], "]"}]}], ",", 
              "\[IndentingNewLine]", 
              StyleBox["_",
               FontColor->RGBColor[1, 0, 1]], 
              StyleBox[",",
               FontColor->RGBColor[1, 0, 1]], 
              StyleBox[
               RowBox[{"Abort", "[", "]"}],
               FontColor->RGBColor[1, 0, 1]]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}], ";", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"d", "\[Equal]", "2"}], ",", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"p1", "=", 
               RowBox[{"Union", "[", 
                RowBox[{"f2", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", " ", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"p1", "\[NotEqual]", 
                 RowBox[{"{", "}"}]}], ",", 
                RowBox[{
                 RowBox[{"sgn", "=", 
                  RowBox[{"kf", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], ";", " ", 
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"res", ",", 
                   RowBox[{"sgn", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{"p1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", "2"}]}]}], 
                  "]"}], ";", " ", 
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"res", ",", 
                   RowBox[{"sgn", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", 
                    RowBox[{"p1", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "^", "2"}]}]}], 
                  "]"}], ";", " ", 
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"res", ",", 
                   RowBox[{"sgn", "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"p1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", 
                    RowBox[{"p1", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "^", "2"}]}]}], 
                  "]"}]}]}], "]"}], ";", " ", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"o", ">", "0"}], ",", 
                StyleBox[
                 RowBox[{"Print", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<i,p1,res\>\"", ",", "i", ",", "p1", ",", "res"}], 
                   "}"}], "]"}],
                 FontColor->RGBColor[0, 1, 0]]}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{"Length", "[", "f2", "]"}]}], "}"}]}], "]"}]}], "]"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"res", "=", 
          RowBox[{
           RowBox[{"Plus", "@@", "res"}], "/", "d"}]}], ";", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "res", "]"}], "\[Equal]", "List"}], ",", 
           RowBox[{"res", "=", 
            RowBox[{"res", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"err", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Expand", "[", 
              RowBox[{"P", "-", "res"}], "]"}], "}"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"Plus", "[", 
                RowBox[{"a_", ",", 
                 RowBox[{"Times", "[", 
                  RowBox[{"c_", ",", "b_"}], "]"}]}], "]"}], "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"a", ",", 
                 RowBox[{"b", " ", "c"}]}], "}"}]}], ",", 
              RowBox[{
               RowBox[{"Plus", "[", 
                RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"a", ",", "b"}], "}"}]}]}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"err", "\[NotEqual]", 
            RowBox[{"{", "0", "}"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"v", "=", 
               RowBox[{"Variables", "[", 
                RowBox[{"err", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", " ", 
              RowBox[{"pip", "=", 
               RowBox[{"Position", "[", 
                RowBox[{"res", ",", 
                 RowBox[{
                  RowBox[{"v", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "+", 
                  RowBox[{
                   RowBox[{"v", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], 
                   RowBox[{"(", 
                    RowBox[{"sgn", "=", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"err", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], ",", "1", ",",
                     
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}]}], "]"}]}], ")"}]}]}]}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"res", "=", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"res", ",", 
                 RowBox[{
                  RowBox[{"v", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "-", 
                  RowBox[{"sgn", "*", 
                   RowBox[{"v", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ",", "pip"}], 
                "]"}]}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{"Length", "[", "err", "]"}]}], "}"}]}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"End", " ", "Do"}], "*)"}], "\[IndentingNewLine]", "]"}], 
         RowBox[{"(*", 
          RowBox[{"End", " ", 
           RowBox[{"If", "[", 
            RowBox[{"err", "\[NotEqual]", 
             RowBox[{"{", "0", "}"}]}]}]}], "*)"}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], 
      RowBox[{"(*", 
       RowBox[{"End", " ", 
        RowBox[{"If", "[", "P", " "}]}], "*)"}], ";", 
      RowBox[{"err", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Expand", "[", 
           RowBox[{"P", "-", "res"}], "]"}], "}"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Plus", "[", 
             RowBox[{"a_", ",", 
              RowBox[{"Times", "[", 
               RowBox[{"c_", ",", "b_"}], "]"}]}], "]"}], "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"a", ",", 
              RowBox[{"b", " ", "c"}]}], "}"}]}], ",", 
           RowBox[{
            RowBox[{"Plus", "[", 
             RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"a", ",", "b"}], "}"}]}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"err", "\[NotEqual]", 
         RowBox[{"{", "0", "}"}]}], ",", 
        RowBox[{
         RowBox[{
         "Print", "[", "\"\<Frag2 failed to correct an error\>\"", "]"}], ";",
          
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "res"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"SetAttributes", "[", 
  RowBox[{"frag2", ",", "Listable"}], "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[TextData[{
 "\tfrag2 heuristically attempts to fragment the quadratic factors of loop \
tables. ",
 StyleBox["polsort ",
  FontSlant->"Italic"],
 "is used on the expanded polynomial; if this is not a matrix the polynomial \
is rejected as unsymmetrical. Polynomials higher than quadratic are returned \
unchanged. An ",
 StyleBox["addnew",
  FontSlant->"Italic"],
 " function is defined; it adds new terms to ",
 StyleBox["res",
  FontSlant->"Italic"],
 ", ignoring any already present. Factors of length = 1 ( and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["a", "2"]}], "-", 
   SuperscriptBox["b", "2"]}]],
  PageWidth->WindowWidth,
  InitializationCell->True],
 ") are passed through unchanged. Non-ternary terms are created with a \
positive first component. Ternary terms have a divisor ",
 StyleBox["d",
  FontSlant->"Italic"],
 "=2 and are handled next, with various adjustments. The result is compared \
with the original, and errors are fiddled."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tidy", "[", 
   RowBox[{
    RowBox[{"gg_", "?", "indexTableQ"}], ",", 
    RowBox[{"n_:", "-", "1"}], ",", 
    RowBox[{"o_:", "1"}], ",", 
    RowBox[{"p_:", 
     RowBox[{"{", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", 
      RowBox[{"g", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "gg", "]"}], "\[Equal]", "1"}], ",", 
         RowBox[{"gg", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "gg"}], "]"}]}], ",", "gl", 
      ",", "m", ",", "nb", ",", "r", ",", "q"}], "}"}], ",", 
    RowBox[{
     RowBox[{"gl", "=", 
      RowBox[{"Length", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "n", "]"}], "==", "0"}], ",", 
       RowBox[{"b", "=", 
        RowBox[{
         RowBox[{"subgroups", "[", "g", "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"-", "n"}], "]"}], "]"}]}], ",", 
       RowBox[{"b", "=", "n"}], ",", 
       RowBox[{"b", "=", "n"}]}], "]"}], ";", " ", 
     StyleBox[
      RowBox[{"(*", " ", 
       RowBox[{
       "Find", " ", "subgroup", " ", "if", " ", "list", " ", "not", " ", 
        "supplied"}], " ", "*)"}],
      FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
     RowBox[{"nb", "=", 
      RowBox[{"Length", "[", "b", "]"}]}], ";", 
     RowBox[{"m", "=", 
      RowBox[{"gl", "/", "nb"}]}], ";", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"IntegerQ", "[", "m", "]"}]}], ",", 
       RowBox[{"Abort", "[", "]"}]}], "]"}], ";", "  ", 
     StyleBox[
      RowBox[{"(*", " ", 
       RowBox[{"nb", " ", "must", " ", "divide", " ", "gl"}], " ", "*)"}],
      FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
     RowBox[{"r", "=", 
      RowBox[{"Complement", "[", 
       RowBox[{
        RowBox[{"Range", "[", "gl", "]"}], ",", "b"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{"r", ",", "o"}], "]"}], ",", 
       RowBox[{"b", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"b", ",", 
          RowBox[{"{", "o", "}"}]}], "]"}]}]}], "]"}], ";", 
     RowBox[{"r", "=", 
      RowBox[{"Complement", "[", 
       RowBox[{"r", ",", "b"}], "]"}]}], ";", 
     RowBox[{"c", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"b", ",", "r"}], "]"}]}], ";", 
     RowBox[{"b", "=", "c"}], ";", 
     RowBox[{"d", "=", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"reorder", "[", 
         RowBox[{"g", ",", "c"}], "]"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"nb", "+", "1"}], "]"}], "]"}]}], ";", 
     StyleBox[
      RowBox[{"(*", " ", 
       RowBox[{
       "Run", " ", "to", " ", "find", " ", "column", " ", "for", " ", 
        "sorting"}], " ", "*)"}],
      FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"[", 
          RowBox[{"j", "+", "nb"}], "]"}], "]"}], "=", 
        RowBox[{"c", "[", 
         RowBox[{"[", 
          RowBox[{"d", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2", ",", "nb"}], "}"}]}], "]"}], ";", " ", 
     StyleBox[
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Rearrange", " ", "col", " ", "nb"}], "+", "1"}], " ", "*)"}],
      
      FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"m", ">", "2"}], ",", 
       RowBox[{
        RowBox[{"b", "=", 
         RowBox[{"Take", "[", 
          RowBox[{"b", ",", 
           RowBox[{"2", "nb"}]}], "]"}]}], ";", 
        RowBox[{"r", "=", 
         RowBox[{"Complement", "[", 
          RowBox[{
           RowBox[{"Range", "[", "gl", "]"}], ",", "b"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "p", "]"}], ">", "1"}], ",", 
          RowBox[{
           RowBox[{"b", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"b", ",", "p"}], "]"}]}], ";", 
           RowBox[{"b", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"b", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", "gl", "]"}], ",", "b"}], "]"}]}], 
             "]"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"MemberQ", "[", 
              RowBox[{"r", ",", "p"}], "]"}], ",", 
             RowBox[{"b", "=", 
              RowBox[{"Join", "[", 
               RowBox[{"b", ",", 
                RowBox[{"{", "p", "}"}]}], "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"b", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"b", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{"r", ",", "b"}], "]"}]}], "]"}]}]}]}], "]"}]}]}], 
      "]"}], ";", 
     StyleBox[
      RowBox[{"(*", " ", 
       RowBox[{"Add", " ", "other", " ", "elements"}], " ", "*)"}],
      FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
     RowBox[{"Print", "[", "b", "]"}], ";", 
     RowBox[{"reorder", "[", 
      RowBox[{"g", ",", "b"}], "]"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ts", "[", "a___", "]"}], ":=", 
   RowBox[{"toSignedTable", "[", "a", "]"}]}], ";", 
  RowBox[{
   RowBox[{"toSignedTable", "[", 
    RowBox[{
     RowBox[{"g_", "?", "indexTableQ"}], ",", 
     RowBox[{"r_Integer", ":", "2"}], ",", 
     RowBox[{"reo_", ":", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"o_", ":", "0"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"diags", ",", "diagelements", ",", "dis", ",", 
       RowBox[{"gg", "=", "g"}], ",", "i", ",", "j", ",", 
       RowBox[{"l", "=", 
        RowBox[{"Length", "[", "g", "]"}]}], ",", 
       RowBox[{"nex", "=", "1"}], ",", 
       RowBox[{"n", "=", 
        RowBox[{"Abs", "[", "r", "]"}]}], ",", "ps", ",", 
       RowBox[{"rr", "=", 
        RowBox[{"{", "}"}]}], ",", "res", ",", "s"}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"reo", "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{
         RowBox[{"gg", "=", 
          RowBox[{"reorder", "[", 
           RowBox[{"gg", ",", "reo"}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"o", ">", "1"}], ",", 
           StyleBox[
            RowBox[{"Print", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<reordered\>\"", ",", 
               RowBox[{"tf", "[", "gg", "]"}]}], "}"}], "]"}],
            FontColor->RGBColor[0, 1, 0]]}], "]"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "gg", "]"}], "===", 
         RowBox[{"Length", "[", "g", "]"}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"negatableQ", "[", 
            RowBox[{"gg", ",", "n"}], "]"}], "\[Equal]", "True"}], ",", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"o", ">", "2"}], ",", 
             StyleBox[
              RowBox[{"Print", "[", 
               RowBox[{"{", 
                RowBox[{
                "\"\<Immediately \>\"", ",", "n", ",", "\"\<negatable\>\""}], 
                "}"}], "]"}],
              FontColor->RGBColor[0, 1, 0]]}], "]"}], ";", 
           RowBox[{"gg", "=", 
            RowBox[{"Take", "[", 
             RowBox[{
              RowBox[{"Transpose", "[", 
               RowBox[{"Take", "[", 
                RowBox[{"gg", ",", 
                 FractionBox["l", "n"]}], "]"}], "]"}], ",", 
              FractionBox["l", "n"]}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"diags", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"gg", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ",", "ii"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"{", 
               RowBox[{"ii", ",", "l"}], "}"}]}], "]"}]}], ";", 
           RowBox[{"diagelements", "=", 
            RowBox[{"Union", "[", "diags", "]"}]}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"o", "\[NotEqual]", "0"}], ",", 
             StyleBox[
              RowBox[{"Print", "[", 
               RowBox[{"{", 
                RowBox[{
                "diags", ",", "\"\<diags,elems\>\"", ",", "diagelements"}], 
                "}"}], "]"}],
              FontColor->RGBColor[0, 1, 0]]}], "]"}], ";", 
           RowBox[{"res", "=", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               FractionBox["l", "n"], "}"}]}], "]"}]}], ";", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Mod", "[", 
                  RowBox[{
                   RowBox[{"Length", "[", 
                    RowBox[{
                    "diagelements", "\[LeftDoubleBracket]", "jj", 
                    "\[RightDoubleBracket]"}], "]"}], ",", "n"}], "]"}], 
                 "\[NotEqual]", "0"}], ",", 
                RowBox[{
                 StyleBox[
                  RowBox[{"Print", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    "\"\<not \>\"", ",", "n", ",", "\"\<negatable\>\""}], 
                    "}"}], "]"}],
                  FontColor->RGBColor[1, 0, 1]], ";", 
                 RowBox[{"Abort", "[", "]"}]}], ",", 
                RowBox[{
                 RowBox[{"ps", "=", 
                  RowBox[{"Position", "[", 
                   RowBox[{"diags", ",", 
                    RowBox[{
                    RowBox[{"Union", "[", "diagelements", "]"}], 
                    "\[LeftDoubleBracket]", "jj", "\[RightDoubleBracket]"}]}],
                    "]"}]}], ";", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", ">", "1"}], ",", 
                   StyleBox[
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<ps,jj,nex\>\"", ",", "ps", ",", "jj", ",", "nex"}], 
                    "}"}], "]"}],
                    FontColor->RGBColor[0, 1, 0]]}], "]"}], ";", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"Length", "[", "ps", "]"}], ",", "n"}], "]"}], 
                    "\[NotEqual]", "0"}], ",", 
                   RowBox[{
                    StyleBox[
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<not \>\"", ",", "n", ",", "\"\<negatable\>\""}], 
                    "}"}], "]"}],
                    FontColor->RGBColor[1, 0, 1]], ";", 
                    RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
                 RowBox[{"Do", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    "res", "\[LeftDoubleBracket]", "nex", 
                    "\[RightDoubleBracket]"}], "=", 
                    RowBox[{
                    "ps", "\[LeftDoubleBracket]", "nx", 
                    "\[RightDoubleBracket]"}]}], ";", 
                    RowBox[{"nex", "++"}]}], ",", 
                   RowBox[{"{", 
                    RowBox[{"nx", ",", 
                    FractionBox[
                    RowBox[{"Length", "[", "ps", "]"}], "n"]}], "}"}]}], 
                  "]"}]}]}], "]"}], ";", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                RowBox[{
                 StyleBox["Print",
                  FontColor->RGBColor[0, 1, 0]], 
                 StyleBox["[",
                  FontColor->RGBColor[0, 1, 0]], 
                 StyleBox[
                  RowBox[{"Flatten", "[", 
                   RowBox[{"{", 
                    RowBox[{"\"\<res\>\"", ",", "res"}], "}"}], "]"}],
                  FontColor->RGBColor[0, 1, 0]], "]"}]}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"jj", ",", 
               RowBox[{"Length", "[", 
                FractionBox["diagelements", "n"], "]"}]}], "}"}]}], "]"}], 
           ";", 
           RowBox[{"gg", "=", 
            RowBox[{"reorder", "[", 
             RowBox[{"g", ",", 
              RowBox[{"Flatten", "[", "res", "]"}]}], "]"}]}]}]}], "]"}]}], 
       "]"}], ";", 
      RowBox[{"s", "=", 
       RowBox[{"Length", "[", "gg", "]"}]}], ";", 
      RowBox[{"i", "=."}], ";", 
      RowBox[{"rr", "=", 
       RowBox[{"{", "}"}]}], ";", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"Which", "[", 
         RowBox[{
          RowBox[{"n", "\[Equal]", "2"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"rr", ",", 
            RowBox[{
             RowBox[{"i", "+", "s"}], "\[Rule]", 
             RowBox[{"-", "i"}]}]}], "]"}], ",", 
          RowBox[{"n", "\[Equal]", "3"}], ",", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"rr", ",", 
             RowBox[{
              RowBox[{"i", "+", "s"}], "\[Rule]", 
              RowBox[{"\[DoubleStruckCapitalJ]", " ", "i"}]}]}], "]"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"rr", ",", 
             RowBox[{
              RowBox[{"i", "+", 
               RowBox[{"2", " ", "s"}]}], "\[Rule]", 
              RowBox[{
              "\[DoubleStruckCapitalJ]", " ", "\[DoubleStruckCapitalJ]", " ", 
               "i"}]}]}], "]"}]}], ",", 
          RowBox[{"n", "\[Equal]", "4"}], ",", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"rr", ",", 
             RowBox[{
              RowBox[{"i", "+", "s"}], "\[Rule]", 
              RowBox[{"\[ImaginaryI]", " ", "i"}]}]}], "]"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"rr", ",", 
             RowBox[{
              RowBox[{"i", "+", 
               RowBox[{"2", " ", "s"}]}], "\[Rule]", 
              RowBox[{"-", "i"}]}]}], "]"}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"rr", ",", 
             RowBox[{
              RowBox[{"i", "+", 
               RowBox[{"3", " ", "s"}]}], "\[Rule]", 
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], " ", "i"}]}]}], "]"}]}]}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "s"}], "}"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"o", ">", "1"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"{", 
          RowBox[{"rr", ",", "s"}], "}"}], "]"}]}], "]"}], ";", 
      RowBox[{"glo", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"gg", "\[LeftDoubleBracket]", 
           RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "/.", 
          "\[InvisibleSpace]", "rr"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "s"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "s"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"mm", "=", 
       RowBox[{"Length", "[", "glo", "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"indexTableQ", "[", "glo", "]"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"r", ">", "0"}], "&&", 
           RowBox[{
            RowBox[{"conservativeQ", "[", "glo", "]"}], "\[NotEqual]", 
            "True"}]}], ",", 
          RowBox[{
           StyleBox[
            RowBox[{"Print", "[", "\"\<Fail, non-conservative.\>\"", "]"}],
            FontColor->RGBColor[1, 0, 1]], ";", 
           RowBox[{"\"\<TraditionalForm\>\"", "[", "glo", "]"}]}], ",", 
          "glo"}], "]"}], ",", 
        StyleBox[
         RowBox[{"Print", "[", "\"\<Fail, not an indexTable.\>\"", "]"}],
         FontColor->RGBColor[1, 0, 1]]}], "]"}], ";", 
      RowBox[{"id", "[", "glo", "]"}], ";", "glo"}]}], "]"}]}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"abbrFactors", "[", 
    RowBox[{"g_", ",", 
     RowBox[{"p_:", "power2"}]}], "]"}], ":=", 
   StyleBox["\[IndentingNewLine]",
    FontColor->RGBColor[1, 0, 0]], 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ap", ",", "f", ",", 
       RowBox[{"ff", "=", 
        RowBox[{"fp", "[", 
         RowBox[{"g", ",", "p"}], "]"}]}], ",", "fi", ",", "fj", ",", 
       RowBox[{"i", "=", "1"}], ",", "l", ",", 
       RowBox[{"res", "=", 
        RowBox[{"{", "}"}]}], ",", "temp"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"NumberQ", "[", 
          RowBox[{"First", "[", "ff", "]"}], "]"}], ",", 
         RowBox[{"Drop", "[", 
          RowBox[{"ff", ",", "1"}], "]"}], ",", "ff"}], "]"}]}], ";", 
      RowBox[{"f", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"NumberQ", "[", 
          RowBox[{"First", "[", "f", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"Drop", "[", 
           RowBox[{"f", ",", "1"}], "]"}], "}"}], ",", "f"}], "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"First", "[", "f", "]"}], "<", "0"}], ",", 
        RowBox[{"f", "=", 
         RowBox[{"-", "f"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", 
         RowBox[{"Length", "[", "f", "]"}]}], ",", 
        RowBox[{
         RowBox[{"fi", "=", 
          RowBox[{"f", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "f", "]"}], "===", "1"}], ",", 
           RowBox[{
            RowBox[{"i", "++"}], ";", 
            RowBox[{"fi", "=", 
             RowBox[{
              RowBox[{"Exponent", "[", 
               RowBox[{"f", ",", "\"\<a\>\""}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ";", 
            RowBox[{"fj", "=", "1"}], ";", 
            RowBox[{"Goto", "[", "done", "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "f", "]"}], "===", "Power"}], ",", 
           RowBox[{
            RowBox[{"i", "++"}], ";", 
            RowBox[{"fj", "=", 
             RowBox[{"Last", "[", "f", "]"}]}], ";", 
            RowBox[{"fi", "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", 
                 RowBox[{"f", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"-", "2"}], ",", 
                    RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "===", 
                "Power"}], ",", 
               RowBox[{"f", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"-", "2"}], ",", 
                  RowBox[{"-", "1"}], ",", 
                  RowBox[{"-", "1"}]}], "]"}], "]"}], ",", "1"}], "]"}]}], 
            ";", 
            RowBox[{"Goto", "[", "done", "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Head", "[", "f", "]"}], "===", "Plus"}], "&&", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", 
                RowBox[{"f", "[", 
                 RowBox[{"[", 
                  RowBox[{"-", "1"}], "]"}], "]"}], "]"}], "===", "Power"}], "||",
               
              RowBox[{
               RowBox[{"Head", "[", 
                RowBox[{"f", "[", 
                 RowBox[{"[", 
                  RowBox[{"-", "1"}], "]"}], "]"}], "]"}], "===", "Times"}]}],
              ")"}]}], ",", 
           RowBox[{
            RowBox[{"i", "=", 
             RowBox[{"Length", "[", "f", "]"}]}], ";", 
            RowBox[{"fi", "=", 
             RowBox[{"Exponent", "[", 
              RowBox[{"f", ",", "\"\<a\>\""}], "]"}]}], ";", 
            RowBox[{"fj", "=", "1"}], ";", 
            RowBox[{"Goto", "[", "done", "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"NumberQ", "[", 
            RowBox[{"(", 
             RowBox[{"fj", "=", 
              RowBox[{"Last", "[", "fi", "]"}]}], ")"}], "]"}], ",", 
           RowBox[{"fi", "=", 
            RowBox[{"Last", "[", 
             RowBox[{"Drop", "[", 
              RowBox[{"fi", ",", 
               RowBox[{"-", "1"}]}], "]"}], "]"}]}], ",", 
           RowBox[{"fj", "=", "1"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"fi", "=", 
          RowBox[{"Switch", "[", 
           RowBox[{
            RowBox[{"Length", "[", "fi", "]"}], ",", "0", ",", "1", ",", "1", 
            ",", "1", ",", "2", ",", 
            RowBox[{"Last", "[", "fi", "]"}], ",", "_", ",", 
            RowBox[{"Last", "[", 
             RowBox[{"Last", "[", "fi", "]"}], "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Label", "[", "done", "]"}], ";", 
         RowBox[{"fi", "=", 
          RowBox[{"fi", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\"\<a\>\"", "\[Rule]", "1"}], ",", 
             RowBox[{
              RowBox[{"-", "\"\<a\>\""}], "\[Rule]", "1"}], ",", 
             RowBox[{"a", "->", "1"}]}], "}"}]}]}], ";", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"res", ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"fj", "\[Equal]", "1"}], ",", 
             RowBox[{"ToString", "[", "fi", "]"}], ",", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"ToString", "[", "fi", "]"}], ")"}], 
              RowBox[{"ToString", "[", "fj", "]"}]]}], "]"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"i", "++"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"temp", "=", 
       RowBox[{"Union", "[", 
        RowBox[{"res", "=", 
         RowBox[{"Sort", "[", 
          RowBox[{"Flatten", "[", "res", "]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ap", "=", 
          RowBox[{"temp", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", 
         RowBox[{"l", "=", 
          RowBox[{"Length", "[", 
           RowBox[{"Position", "[", 
            RowBox[{"res", ",", "ap", ",", "1"}], "]"}], "]"}]}], ";", 
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "ap", "]"}], ">", "1"}], "&&", 
            RowBox[{"l", "\[Equal]", "1"}]}], ",", 
           SuperscriptBox[
            RowBox[{"ap", "[", 
             RowBox[{"[", "1", "]"}], "]"}], 
            RowBox[{"ap", "[", 
             RowBox[{"[", "2", "]"}], "]"}]], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Length", "[", "ap", "]"}], ">", "1"}], ",", 
           SubsuperscriptBox[
            RowBox[{"ap", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "l", 
            RowBox[{"ap", "[", 
             RowBox[{"[", "2", "]"}], "]"}]], ",", "\[IndentingNewLine]", 
           RowBox[{"l", "\[Equal]", "1"}], ",", "ap", ",", 
           "\[IndentingNewLine]", "True", ",", 
           SubscriptBox["ap", "l"]}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "temp", "]"}]}], "}"}]}], "]"}]}]}], "]"}]}],
   ";"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"cosorbit", "[", 
   RowBox[{"\[Theta]_", ",", 
    RowBox[{"phaselist_:", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5"}], 
      "}"}]}], ",", 
    RowBox[{"scale_:", "1"}], ",", 
    RowBox[{"meanlist_:", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "24", "}"}]}], "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "phaselist", "]"}]}], ",", "i"}], "}"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"i", "=", 
        RowBox[{"phaselist", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ";", 
       RowBox[{
        RowBox[{"meanlist", "[", 
         RowBox[{"[", "j", "]"}], "]"}], "+", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"NumberQ", "[", "i", "]"}], ",", 
          RowBox[{"scale", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Mod", "[", 
               RowBox[{"i", ",", "m"}], "]"}], " ", 
              RowBox[{"\[Pi]", "/", "m"}]}]}], "]"}]}], ",", "0"}], "]"}]}]}],
       ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "m"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "=", 
    RowBox[{"2", 
     RowBox[{"\[Pi]", "/", "3"}]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Used", " ", "widely", " ", "in", " ", 
    RowBox[{"orbits", ".", " ", "Placed"}], " ", "here", " ", "to", " ", 
    "avoid", " ", "evaluation", " ", "in", " ", "their", " ", 
    RowBox[{"definitions", "."}]}], "*)"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "2 Generation by ",
 StyleBox["ca, co, unsign, sgroup, planarCom",
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ca", "[", 
    RowBox[{"{", 
     RowBox[{"m_", ",", 
      RowBox[{"a_:", "1"}]}], "}"}], "]"}], ":=", 
   RowBox[{"ca", "[", 
    RowBox[{"m", ",", "a"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"ca", "[", 
    RowBox[{"m_Integer", "?", "Positive"}], "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{"i", "+", "j", "-", "2"}], ",", "m"}], "]"}], "+", "1"}], ",",
      
     RowBox[{"{", 
      RowBox[{"i", ",", "m"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "m"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ca", "[", 
    RowBox[{
     RowBox[{"m_Integer", "?", "Positive"}], ",", "a_Integer"}], "]"}], ":=", 
   
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"k", "=", 
        RowBox[{"Abs", "[", "a", "]"}]}], ",", "test"}], "}"}], ",", 
     RowBox[{
      RowBox[{"test", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"GCD", "[", 
           RowBox[{"m", ",", "k"}], "]"}], "\[Equal]", "1"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{
              RowBox[{"i", "+", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"EvenQ", "[", "i", "]"}], ",", 
                 RowBox[{
                  RowBox[{"j", " ", "k"}], "-", "k", "+", "1"}], ",", "j"}], 
                "]"}], "-", "2"}], ",", "m"}], "]"}], "+", "1"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "m"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "m"}], "}"}]}], "]"}], ",", 
         RowBox[{
          StyleBox[
           RowBox[{"Print", "[", 
            RowBox[{
            "m", ",", "\"\< \>\"", ",", "k", ",", "\"\< \>\"", ",", 
             "\"\<GCD not 1\>\""}], "]"}],
           FontColor->RGBColor[1, 0, 1]], ";", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"{", "}"}]}], "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "<", "0"}], "&&", 
         RowBox[{
          RowBox[{"associativeQ", "[", 
           RowBox[{"test", ",", "1"}], "]"}], "\[Equal]", "False"}]}], ",", 
        RowBox[{
         StyleBox[
          RowBox[{"Print", "[", "\"\<Not a group\>\"", "]"}],
          FontColor->RGBColor[1, 0, 1]], ";", "test"}], ",", "test", ",", 
        "test"}], "]"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"co", "[", 
   RowBox[{
    RowBox[{"g_", "?", "indexTableQ"}], ",", 
    RowBox[{"gg_", "?", "indexTableQ"}], ",", 
    RowBox[{"hh_", "?", "indexTableQ"}], ",", "a_Integer", ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"co", "[", 
   RowBox[{"g", ",", 
    RowBox[{"co", "[", 
     RowBox[{"gg", ",", "hh", ",", "a"}], "]"}], ",", "o"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"co", "[", 
   RowBox[{
    RowBox[{"g_", "?", "indexTableQ"}], ",", 
    RowBox[{"h_", "?", "indexTableQ"}], ",", 
    RowBox[{"gg_", "?", "indexTableQ"}], ",", 
    RowBox[{"hh_", "?", "indexTableQ"}], ",", "a_Integer", ",", 
    RowBox[{"o_Integer:", "0"}], ",", 
    RowBox[{"p_:", "0"}]}], "]"}], ":=", 
  RowBox[{"co", "[", 
   RowBox[{"g", ",", 
    RowBox[{"co", "[", 
     RowBox[{"h", ",", 
      RowBox[{"co", "[", 
       RowBox[{"gg", ",", "hh", ",", "a"}], "]"}], ",", "o"}], "]"}], ",", 
    "p"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"co", "[", 
    RowBox[{
     RowBox[{"gg_", "?", "indexTableQ"}], ",", 
     RowBox[{"hh_", "?", "indexTableQ"}], ",", 
     RowBox[{"a_:", "0"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"any", ",", 
       RowBox[{"as", "=", 
        RowBox[{"Abs", "[", "a", "]"}]}], ",", 
       RowBox[{"g1", "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", "gg", "]"}], "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"h1", "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", "hh", "]"}], "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"unsign", "[", "gg", "]"}]}], ",", 
       RowBox[{"h", "=", 
        RowBox[{"unsign", "[", "hh", "]"}]}], ",", "im", ",", "lm", ",", 
       RowBox[{"test", "=", 
        RowBox[{"{", "}"}]}], ",", "t", ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"g1", " ", "h1"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"gg", ",", "\[ImaginaryI]"}], "]"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"g", "=", 
         RowBox[{"gg", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"any_", "/;", 
              RowBox[{
               RowBox[{"Re", "[", "any", "]"}], "<", "0"}]}], "->", 
             RowBox[{
              RowBox[{"-", "any"}], "+", 
              RowBox[{"2", "g1"}]}]}], ",", 
            RowBox[{
             RowBox[{"Complex", "[", 
              RowBox[{"r_", ",", "i_"}], "]"}], "\[Rule]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"i", "<", "0"}], ",", 
               RowBox[{
                RowBox[{"-", "i"}], "+", 
                RowBox[{"3", "g1"}]}], ",", 
               RowBox[{"i", "+", "g1"}]}], "]"}]}]}], "}"}]}]}]}], "]"}], ";",
       
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"gg", ",", "\[DoubleStruckCapitalJ]"}], "]"}], 
         "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"g", "=", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"gg", "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Times", "[", 
                   RowBox[{
                    RowBox[{
                    "\[DoubleStruckCapitalJ]", " ", 
                    "\[DoubleStruckCapitalJ]"}], ",", "any_"}], "]"}], 
                  "\[Rule]", 
                  RowBox[{"any", "+", 
                   RowBox[{"2", "g1"}]}]}], ",", 
                 RowBox[{
                  RowBox[{"Times", "[", 
                   RowBox[{"\[DoubleStruckCapitalJ]", ",", "any_"}], "]"}], 
                  "\[Rule]", 
                  RowBox[{"any", "+", "g1"}]}], ",", 
                 RowBox[{
                  RowBox[{
                  "\[DoubleStruckCapitalJ]", " ", "\[DoubleStruckCapitalJ]"}],
                   "\[Rule]", 
                  RowBox[{
                   RowBox[{"2", "g1"}], "+", "1"}]}], ",", 
                 RowBox[{"\[DoubleStruckCapitalJ]", "\[Rule]", 
                  RowBox[{"g1", "+", "1"}]}]}], "}"}]}], ")"}], "-", "1"}], 
            ",", 
            RowBox[{"3", "g1"}]}], "]"}], "+", "1"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"h", "\[NotEqual]", "hh"}], ",", 
        StyleBox[
         RowBox[{
         "Print", "[", "\"\<Second matrix must not be signed\>\"", "]"}],
         FontColor->RGBColor[1, 0, 1]], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"as", "\[Equal]", "7"}], "&&", 
           RowBox[{"h", "\[NotEqual]", "C3"}]}], ",", 
          StyleBox[
           RowBox[{"Print", "[", "\"\<Second matrix must be C3\>\"", "]"}],
           FontColor->RGBColor[1, 0, 1]], ",", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"lm", "=", 
              RowBox[{"l", "-", "1"}]}], ";", 
             RowBox[{"Do", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"t", "=", 
                 RowBox[{"{", "}"}]}], ";", 
                RowBox[{"Do", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Do", "[", 
                   RowBox[{
                    RowBox[{"Which", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"as", "\[Equal]", "0"}], "||", 
                    RowBox[{"as", "\[Equal]", "1"}]}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], " ", "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"as", "<", "3"}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EvenQ", "[", "l", "]"}], "&&", 
                    RowBox[{"i", ">", "1"}]}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], " ", "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"g1", "+", "2", "-", "i"}], ",", "j"}], 
                    "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], " ", "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                    "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"as", "\[Equal]", "3"}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EvenQ", "[", "j", "]"}], "&&", 
                    RowBox[{"k", ">", "1"}]}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"k", "+", 
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "2"}], ")"}], " ", "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ",", "m"}], "]"}], "+", "1"}]}], "]"}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], " ", "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                    "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"as", "\[Equal]", "4"}], ",", 
                    RowBox[{
                    RowBox[{"im", "=", 
                    RowBox[{"4", " ", "lm", " ", 
                    RowBox[{"(", 
                    RowBox[{"i", "-", "1"}], ")"}]}]}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EvenQ", "[", "l", "]"}], "&&", 
                    RowBox[{"EvenQ", "[", "i", "]"}]}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], " ", "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"i", "+", "im", "-", "1"}], ",", "g1"}], "]"}], 
                    "+", "1"}], ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                    "]"}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], " ", "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                    "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"as", "\[Equal]", "7"}], ",", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"lm", "\[Equal]", "2"}], ",", 
                    RowBox[{"lm", "=", "3"}]}], "]"}], ";", 
                    RowBox[{"im", "=", 
                    RowBox[{"lm", " ", 
                    RowBox[{"(", 
                    RowBox[{"i", "-", "1"}], ")"}]}]}], ";", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], " ", "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"i", "+", "im", "-", "1"}], ",", "g1"}], "]"}], 
                    "+", "1"}], ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                    "]"}]}], ",", "\[IndentingNewLine]", "True", ",", 
                    RowBox[{
                    StyleBox[
                    RowBox[{"Print", "[", 
                    RowBox[{"Unknown", " ", "a"}], "]"}],
                    FontColor->RGBColor[1, 0, 1]], ";", 
                    RowBox[{"Abort", "[", "]"}]}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "g1"}], "}"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"k", ",", "h1"}], "}"}]}], "]"}], ";", 
                RowBox[{"AppendTo", "[", 
                 RowBox[{"test", ",", 
                  RowBox[{
                   RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"t", "-", "1"}], ",", "m"}], "]"}], "+", "1"}]}], 
                 "\[IndentingNewLine]", "  ", "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "g1"}], "}"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"l", ",", "h1"}], "}"}]}], "]"}]}], "]"}]}], "]"}], ";", 
      
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "<", "0"}], "||", 
         RowBox[{"as", "\[Equal]", "1"}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"loopQ", "[", "test", "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"associativeQ", "[", "test", "]"}], ",", "test", ",", 
            RowBox[{
             StyleBox[
              RowBox[{"Print", "[", "\"\<Not associative\>\"", "]"}],
              FontColor->RGBColor[0, 1, 0]], ";", "test"}]}], "]"}], ",", 
          StyleBox[
           RowBox[{"Print", "[", "\"\<Not a quasigroup\>\"", "]"}],
           FontColor->RGBColor[0, 1, 0]]}], "]"}], ",", "test", ",", "test"}],
        "]"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"unsign", "[", 
    RowBox[{"g_", "?", "MatrixQ"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"l", "=", 
        RowBox[{"Length", "[", "g", "]"}]}], ",", "r", ",", "e", ",", "i", 
       ",", "ar", ",", "ai", ",", "m", ",", "p"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Union", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Sign", "[", "g", "]"}], "]"}], "]"}], "]"}], ",", "1", 
         ",", 
         RowBox[{
          RowBox[{"p", "=", "0"}], ";", "l"}], ",", "2", ",", 
         RowBox[{
          RowBox[{"p", "=", "l"}], ";", 
          RowBox[{"2", "l"}]}], ",", "_", ",", 
         RowBox[{
          RowBox[{"p", "=", 
           RowBox[{"2", "l"}]}], ";", 
          RowBox[{"4", "l"}]}]}], "]"}]}], ";", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"e", "=", 
          RowBox[{"g", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "k"}], "]"}], "]"}]}], ";", 
         RowBox[{"r", "=", 
          RowBox[{"Re", "[", "e", "]"}]}], ";", 
         RowBox[{"ar", "=", 
          RowBox[{"Abs", "[", "r", "]"}]}], ";", 
         RowBox[{"i", "=", 
          RowBox[{"Im", "[", "e", "]"}]}], ";", 
         RowBox[{"ai", "=", 
          RowBox[{"Abs", "[", "i", "]"}]}], ";", 
         RowBox[{"r", "=", 
          RowBox[{"ar", "+", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"r", "<", "0"}], ",", "p", ",", "0"}], "]"}]}]}], ";", 
         RowBox[{"i", "=", 
          RowBox[{"ai", "+", 
           RowBox[{"Which", "[", 
            RowBox[{
             RowBox[{"i", "\[Equal]", "0"}], ",", "0", ",", 
             RowBox[{"i", "<", "0"}], ",", 
             RowBox[{"3", "l"}], ",", 
             RowBox[{"i", ">", "0"}], ",", "l"}], "]"}]}]}], ";", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"r", "+", "i", "-", "1"}], ",", "m"}], "]"}], "+", 
          "1"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "l"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "l"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sgroup", "[", 
   RowBox[{"m_", "?", "IntegerQ"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"e", "=", 
       RowBox[{"Permutations", "[", 
        RowBox[{"Range", "[", "m", "]"}], "]"}]}], ",", "n", ",", "p"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "e", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "=", 
         RowBox[{"Position", "[", 
          RowBox[{"e", ",", 
           RowBox[{"Apply", "[", 
            RowBox[{"permute", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"e", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{"e", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"p", "===", 
           RowBox[{"{", "}"}]}], ",", "0", ",", 
          RowBox[{"p", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell["\<\
permfromQ[p_List,n_Integer]:=
  Length[Complement[p,Range[n]]]\[Equal]0&&Sort[p]\[Equal]Union[p]
  permute[P_List,p_List]:=If[permfromQ[p,Length[P]],P[[p]],Print[{P,p,\" \
error\"}]];\
\>", "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell["\<\
planarCom[m_]:=Table[(Mod[i+j-2,m]+1)*If[i+j>m+1,-1,1],{i,m},{j,m}]; \
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "3 Functions ",
 StyleBox["centralizer, period, orderCount",
  FontSlant->"Italic"],
 ", etc."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"centralizer", "[", 
   RowBox[{
    RowBox[{"a_", "?", "IntegerQ"}], ",", 
    RowBox[{"g_:", "glo"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"gg", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "g", "]"}], "\[Equal]", "1"}], ",", 
         RowBox[{"g", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "g"}], "]"}]}], ",", "b", ",", 
      
      RowBox[{"c", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"b", "=", 
         RowBox[{"gg", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"gg", "[", 
            RowBox[{"[", 
             RowBox[{"a", ",", "i"}], "]"}], "]"}], "==", 
           RowBox[{"gg", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "a"}], "]"}], "]"}]}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"c", ",", "b"}], "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "gg", "]"}]}], "}"}]}], "]"}], ";", "c"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"period", "[", 
   RowBox[{"g_:", "glo"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"gg", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "g", "]"}], "\[Equal]", "1"}], ",", 
         RowBox[{"g", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "g"}], "]"}]}], ",", "lg", ",",
       "a", ",", "aa", ",", "b", ",", "j", ",", 
      RowBox[{"P", "=", 
       RowBox[{"{", "1", "}"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"lg", "=", 
      RowBox[{"Length", "[", "gg", "]"}]}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "=", 
         RowBox[{"gg", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ";", 
        RowBox[{"aa", "=", "a"}], ";", 
        RowBox[{"j", "=", "2"}], ";", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "=", 
              RowBox[{"gg", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "aa"}], "]"}], "]"}]}], ")"}], "!=", "1"}], 
           "&&", 
           RowBox[{"j", "<", "lg"}]}], ",", 
          RowBox[{
           RowBox[{"j", "++"}], ";", 
           RowBox[{"aa", "=", "b"}]}]}], "]"}], ";", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"P", ",", "j"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", "lg"}], "}"}]}], "]"}], ";", "P"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"orderCount", "[", 
   RowBox[{"g_:", "glo"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Position", "[", 
      RowBox[{
       RowBox[{"period", "[", "g", "]"}], ",", "i"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Max", "[", 
       RowBox[{"Union", "[", 
        RowBox[{"period", "[", "g", "]"}], "]"}], "]"}]}], "}"}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"center", "[", 
    RowBox[{"g_:", "glo"}], "]"}], ":=", 
   RowBox[{"centre", "[", "g", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"centre", "[", 
   RowBox[{"g_:", "glo"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"gg", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "g", "]"}], "\[Equal]", "1"}], ",", 
         RowBox[{"g", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "g"}], "]"}]}], ",", "lg", ",",
       "a", ",", "j", ",", 
      RowBox[{"Z", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"lg", "=", 
      RowBox[{"Length", "[", "gg", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "=", 
         RowBox[{"gg", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ";", 
        RowBox[{"j", "=", "1"}], ";", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"gg", "[", 
             RowBox[{"[", 
              RowBox[{"a", ",", "j"}], "]"}], "]"}], "==", 
            RowBox[{"gg", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "a"}], "]"}], "]"}]}], "&&", 
           RowBox[{"j", "<", "lg"}]}], ",", 
          RowBox[{"j", "++"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"j", "==", "lg"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"Z", ",", "a"}], "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "lg"}], "}"}]}], "]"}], ";", "Z"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"gInverse", "[", 
   RowBox[{"g_:", "glo"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gg", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "g", "]"}], "\[Equal]", "1"}], ",", 
        RowBox[{"g", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "g"}], "]"}]}], "}"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"gg", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", "1"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "gg", "]"}]}], "}"}]}], "]"}], "]"}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"lcoset", "[", 
   RowBox[{"h_", ",", 
    RowBox[{"g_:", "glo"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gg", "=", 
      RowBox[{"gpd", "[", "g", "]"}]}], "}"}], ",", 
    RowBox[{"Intersection", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Union", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"gg", "[", 
           RowBox[{"[", 
            RowBox[{"x", ",", 
             RowBox[{"h", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", 
            RowBox[{"Length", "[", "h", "]"}]}], "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"Length", "[", "gg", "]"}]}], "}"}]}], "]"}], "]"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"rcoset", "[", 
   RowBox[{"h_", ",", 
    RowBox[{"g_:", "glo"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gg", "=", 
      RowBox[{"gpd", "[", "g", "]"}]}], "}"}], ",", 
    RowBox[{"Intersection", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Union", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"gg", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"h", "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", "x"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", 
            RowBox[{"Length", "[", "h", "]"}]}], "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"Length", "[", "gg", "]"}]}], "}"}]}], "]"}], "]"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"normalSubgroup", "[", 
    RowBox[{"h_", ",", 
     RowBox[{"g_:", "glo"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"lcoset", "[", 
     RowBox[{"h", ",", "g"}], "]"}], "\[Equal]", 
    RowBox[{"rcoset", "[", 
     RowBox[{"h", ",", "g"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"factorGroup", "[", 
    RowBox[{"n_", ",", 
     RowBox[{"g_:", "glo"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"gg", "=", 
        RowBox[{"gpd", "[", "g", "]"}]}], ",", "lc", ",", "loc", ",", "lg", 
       ",", "lt"}], "}"}], ",", 
     RowBox[{
      RowBox[{"lg", "=", 
       RowBox[{"Length", "[", "gg", "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"lc", "=", 
           RowBox[{"lcoset", "[", 
            RowBox[{"n", ",", "gg"}], "]"}]}], ")"}], "\[NotEqual]", 
         RowBox[{"rcoset", "[", 
          RowBox[{"n", ",", "gg"}], "]"}]}], ",", 
        StyleBox[
         RowBox[{"Print", "[", 
          RowBox[{"n", ",", "\"\< is not a Normal subgroup\>\""}], "]"}],
         FontColor->RGBColor[1, 0, 1]], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lg", "\[Equal]", 
           RowBox[{"Length", "[", "n", "]"}]}], ",", 
          RowBox[{"id", "[", "gg", "]"}], ",", 
          RowBox[{
           RowBox[{"lt", "=", 
            RowBox[{"First", "[", 
             RowBox[{"Transpose", "[", "lc", "]"}], "]"}]}], ";", 
           RowBox[{"loc", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"lc", ",", "i"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "lg"}], "}"}]}], "]"}]}], ";", 
           RowBox[{"id", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"loc", "[", 
               RowBox[{"[", 
                RowBox[{"gg", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"lt", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                   RowBox[{"lt", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
               "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"Length", "[", "lt", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", 
                RowBox[{"Length", "[", "lt", "]"}]}], "}"}]}], "]"}], 
            "\[IndentingNewLine]", "]"}]}]}], "]"}]}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"allFactorGroups", "[", 
   RowBox[{
    RowBox[{"g_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}], ",", 
    RowBox[{"i1_:", "2"}], ",", 
    RowBox[{"i2_:", "49"}], ",", 
    RowBox[{"p_:", 
     RowBox[{"{", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", 
      RowBox[{"f", "=", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"gg", "=", 
       RowBox[{"gpd", "[", "g", "]"}]}], ",", 
      RowBox[{"i", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"p", "\[NotEqual]", 
          RowBox[{"{", "}"}]}], ",", "i1", ",", "i2"}], "]"}]}], ",", "lc", 
      ",", "lg", ",", "loc", ",", "lr", ",", "n", ",", "res", ",", "s"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{"lg", "=", 
      RowBox[{"Length", "[", "gg", "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"o", "\[Equal]", "0"}], ",", 
       RowBox[{"s", "=", 
        RowBox[{"subgroups", "[", 
         RowBox[{"gg", ",", "0", ",", "i1", ",", "i"}], "]"}]}]}], "]"}], ";",
      
     RowBox[{"s", "=", "sg"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{"s", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"lc", "=", 
             RowBox[{"lcoset", "[", 
              RowBox[{"n", ",", "gg"}], "]"}]}], ")"}], "\[Equal]", 
           RowBox[{"rcoset", "[", 
            RowBox[{"n", ",", "gg"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"res", "=", 
            RowBox[{"First", "[", 
             RowBox[{"Transpose", "[", "lc", "]"}], "]"}]}], ";", 
           RowBox[{"lr", "=", 
            RowBox[{"Length", "[", "res", "]"}]}], ";", "\[IndentingNewLine]",
            
           RowBox[{"loc", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"lc", ",", "i"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "lg"}], "}"}]}], "]"}]}], ";", 
           RowBox[{"a", "=", 
            RowBox[{"id", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"loc", "[", 
                RowBox[{"[", 
                 RowBox[{"gg", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"res", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"res", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
                "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "lr"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "lr"}], "}"}]}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"p", "\[NotEqual]", 
              RowBox[{"{", "}"}]}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"MemberQ", "[", 
                RowBox[{"p", ",", 
                 RowBox[{"b", "=", 
                  RowBox[{
                   RowBox[{"gd", "[", "a", "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}], ",", 
               RowBox[{
                RowBox[{"f", "=", "b"}], ";", 
                RowBox[{"Goto", "[", "tag", "]"}]}]}], "]"}]}], "]"}]}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"f", ",", "a"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Length", "[", "s", "]"}]}], "}"}]}], "]"}], ";", 
     RowBox[{"Label", "[", "tag", "]"}], ";", "f"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "4 Tests for Table Properties ",
 StyleBox["abelianQ ",
  FontSlant->"Italic"],
 "etc."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[TextData[{
 "Note that, for signed tables, these tests are \"up to a sign\" insofar as \
the absolute values of the indices replace signed indices unless the test is \
capitalised; ",
 StyleBox["MoufangQ",
  FontSlant->"Italic"],
 " test for exact, ",
 StyleBox["moufangQ",
  FontSlant->"Italic"],
 " for a signed match."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[{
 RowBox[{
  RowBox[{"abelianQ", "[", 
   RowBox[{"gg_:", "glo"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"g", "=", 
      RowBox[{"gpd", "[", "gg", "]"}]}], "}"}], ",", 
    RowBox[{"g", "===", 
     RowBox[{"Transpose", "[", "g", "]"}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"associativeQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}],
                     ",", "k"}], "\[RightDoubleBracket]"}], "]"}], 
                  "\[NotEqual]", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "k"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], "\[RightDoubleBracket]"}], "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "===", "0"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                    "]"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AssociativeQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"g", "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}],
                     ",", "k"}], "\[RightDoubleBracket]"}], "\[NotEqual]", 
                  RowBox[{"g", "\[LeftDoubleBracket]", 
                   RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "k"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], "\[RightDoubleBracket]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "===", "0"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                    "]"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"abelGrassmanQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{
        RowBox[{"Dimensions", "[", "g", "]"}], "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", 
           RowBox[{
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}],
                     ",", "k"}], "\[RightDoubleBracket]"}], "]"}], 
                  "\[NotEqual]", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "j"}], "\[RightDoubleBracket]"}], "]"}],
                     ",", "i"}], "\[RightDoubleBracket]"}], "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "===", "0"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                    "]"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"alternativeQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m", ",", "x", ",", "y", ",", 
       "xy", ",", "x2", ",", "y2"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", 
        RowBox[{
         RowBox[{"x", "=", 
          RowBox[{"Abs", "[", 
           RowBox[{"g", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "i"}], "]"}], "]"}], "]"}]}], ";", 
         RowBox[{"x2", "=", 
          RowBox[{"Abs", "[", 
           RowBox[{"g", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "i"}], "\[RightDoubleBracket]"}], "]"}]}], ";", 
         
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"y", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", 
            RowBox[{"xy", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Abs", "[", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"x", ",", "xy"}], "\[RightDoubleBracket]"}], "]"}], 
               "\[NotEqual]", 
               RowBox[{"Abs", "[", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"x2", ",", "y"}], "\[RightDoubleBracket]"}], "]"}]}],
               ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                RowBox[{"Throw", "[", 
                 RowBox[{"{", 
                  RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                 "]"}], ",", 
                RowBox[{"Throw", "[", "False", "]"}], ",", 
                RowBox[{"Throw", "[", "False", "]"}]}], "]"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Abs", "[", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"xy", ",", "y"}], "\[RightDoubleBracket]"}], "]"}], 
               "\[NotEqual]", 
               RowBox[{"Abs", "[", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"x", ",", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"y", ",", "y"}], "\[RightDoubleBracket]"}], 
                   "]"}]}], "\[RightDoubleBracket]"}], "]"}]}], ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                RowBox[{"Throw", "[", 
                 RowBox[{"{", 
                  RowBox[{"False", ",", "i", ",", "j", ",", "k", ",", "2"}], 
                  "}"}], "]"}], ",", 
                RowBox[{"Throw", "[", "False", "]"}], ",", 
                RowBox[{"Throw", "[", "False", "]"}]}], "]"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"j", "++"}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"amQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"(*", 
   RowBox[{"ref", " ", 
    RowBox[{
     RowBox[{"raoulc", "@", "pacific"}], ".", "net", ".", "ph"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m", ",", "xy", ",", "yx", 
       ",", "xz", ",", "zx"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", 
           RowBox[{
            RowBox[{"xy", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", 
            RowBox[{"yx", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"j", ",", "i"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"xz", "=", 
                RowBox[{"Abs", "[", 
                 RowBox[{"g", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "k"}], "]"}], "]"}], "]"}]}], ";", 
               RowBox[{"zx", "=", 
                RowBox[{"Abs", "[", 
                 RowBox[{"g", "[", 
                  RowBox[{"[", 
                   RowBox[{"k", ",", "i"}], "]"}], "]"}], "]"}]}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"g", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"yx", ",", "zx"}], "]"}], "]"}], "]"}]}], "]"}], 
                   "]"}], "\[NotEqual]", 
                  RowBox[{"g", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"xy", ",", "xz"}], "]"}], "]"}], "]"}], ",", 
                    "i"}], "]"}], "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "===", "0"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "False", ",", "i", ",", "j", ",", "k", " ", ",", 
                    "\"\< amQ\>\""}], "}"}], "]"}]}], "]"}]}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", "1"}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"bolQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m", ",", "xz", ",", "yz", 
       ",", "zx", ",", "zy"}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"g", ",", 
           RowBox[{"Complex", "[", 
            RowBox[{"_", ",", "_"}], "]"}]}], "]"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"Throw", "[", "\"\<Complex\>\"", "]"}]}], "]"}], ";", 
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"xz", "=", 
                RowBox[{"Abs", "[", 
                 RowBox[{"g", "\[LeftDoubleBracket]", 
                  RowBox[{"i", ",", "k"}], "\[RightDoubleBracket]"}], "]"}]}],
                ";", 
               RowBox[{"yz", "=", 
                RowBox[{"Abs", "[", 
                 RowBox[{"g", "\[LeftDoubleBracket]", 
                  RowBox[{"j", ",", "k"}], "\[RightDoubleBracket]"}], "]"}]}],
                ";", 
               RowBox[{"zx", "=", 
                RowBox[{"Abs", "[", 
                 RowBox[{"g", "\[LeftDoubleBracket]", 
                  RowBox[{"k", ",", "i"}], "\[RightDoubleBracket]"}], "]"}]}],
                ";", 
               RowBox[{"zy", "=", 
                RowBox[{"Abs", "[", 
                 RowBox[{"g", "\[LeftDoubleBracket]", 
                  RowBox[{"k", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}],
                ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "yz"}], "\[RightDoubleBracket]"}], ",", 
                    "i"}], "]"}], "]"}], "]"}], "\[NotEqual]", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "zx"}], "]"}], "]"}], "]"}], "]"}], 
                    "]"}]}], "]"}], "]"}], "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "===", "0"}], ",", 
                   StyleBox[
                    RowBox[{"Throw", "[", "False", "]"}],
                    FontColor->RGBColor[1, 0, 1]], ",", 
                   StyleBox[
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "False", ",", "i", ",", "j", ",", "k", " ", ",", 
                    "\"\< left Bol\>\""}], "}"}], "]"}],
                    FontColor->RGBColor[1, 0, 1]]}], "]"}]}], "]"}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"zy", ",", "k"}], "\[RightDoubleBracket]"}]}], 
                    "]"}], "]"}], "]"}], "\[NotEqual]", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"xz", ",", "j"}], "]"}], "]"}], "]"}], ",", "k"}],
                     "]"}], "]"}], "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "===", "0"}], ",", 
                   StyleBox[
                    RowBox[{"Throw", "[", "False", "]"}],
                    FontColor->RGBColor[1, 0, 1]], 
                   StyleBox[",",
                    FontColor->RGBColor[1, 0, 1]], 
                   StyleBox[
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "False", ",", "i", ",", "j", ",", "k", " ", ",", 
                    "\"\< right Bol\>\""}], "}"}], "]"}],
                    FontColor->RGBColor[1, 0, 1]]}], "]"}]}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"cQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"(*", 
   RowBox[{"ref", " ", 
    RowBox[{
     RowBox[{"raoulc", "@", "pacific"}], ".", "net", ".", "ph"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m", ",", "xy", ",", "yy"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", 
           RowBox[{
            RowBox[{"xy", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", 
            RowBox[{"yy", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"j", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"g", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"xy", ",", "j"}], "\[RightDoubleBracket]"}], 
                    "]"}], ",", "k"}], "]"}], "]"}], "\[NotEqual]", 
                  RowBox[{"g", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"yy", ",", "k"}], "]"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "===", "0"}], ",", 
                   StyleBox[
                    RowBox[{"Throw", "[", "False", "]"}],
                    FontColor->RGBColor[1, 0, 1]], 
                   StyleBox[",",
                    FontColor->RGBColor[1, 0, 1]], 
                   StyleBox[
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "False", ",", "i", ",", "j", ",", "k", " ", ",", 
                    "\"\< cQ\>\""}], "}"}], "]"}],
                    FontColor->RGBColor[1, 0, 1]]}], "]"}]}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", "1"}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"conservativeQ", "[", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"A", ",", "B", ",", "l"}], "}"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"associativeQ", "[", "glo", "]"}], "&&", 
       RowBox[{"!", 
        RowBox[{"signedTableQ", "[", "glo", "]"}]}]}], ",", "True", ",", 
      RowBox[{
       RowBox[{"mm", "=", 
        RowBox[{"Length", "[", "glo", "]"}]}], ";", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", "99"}], "}"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "mm"}], "}"}]}], "]"}]}], ";", 
          RowBox[{"B", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", "99"}], "}"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "mm"}], "}"}]}], "]"}]}], ";", 
          RowBox[{"AB", "=", 
           RowBox[{"Det", "[", 
            RowBox[{"gmap", "[", 
             RowBox[{"glo", ",", 
              RowBox[{"hoopTimes", "[", 
               RowBox[{"A", ",", "B"}], "]"}]}], "]"}], "]"}]}]}], ",", 
         RowBox[{"AB", "\[Equal]", "0"}]}], "]"}], ";", 
       RowBox[{"A", "=", 
        RowBox[{"Det", "[", 
         RowBox[{"gmap", "[", 
          RowBox[{"glo", ",", "A"}], "]"}], "]"}]}], ";", 
       RowBox[{"B", "=", 
        RowBox[{"Det", "[", 
         RowBox[{"gmap", "[", 
          RowBox[{"glo", ",", "B"}], "]"}], "]"}]}], ";", 
       RowBox[{"A", "=", 
        RowBox[{"A", " ", "B"}]}], ";", 
       RowBox[{"B", "=", 
        RowBox[{"Abs", "[", 
         RowBox[{"AB", "-", "A"}], "]"}]}], ";", 
       RowBox[{"A", "=", 
        RowBox[{"Abs", "[", 
         RowBox[{"AB", "+", "A"}], "]"}]}], ";", 
       RowBox[{
        RowBox[{"Chop", "[", 
         FractionBox[
          RowBox[{"Min", "[", 
           RowBox[{"A", ",", "B"}], "]"}], 
          RowBox[{"Max", "[", 
           RowBox[{"A", ",", "B"}], "]"}]], "]"}], "\[Equal]", "0"}]}]}], 
     "]"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"conservativeQ", "[", 
   RowBox[{
    RowBox[{"gg_", ":", "glo"}], ",", 
    RowBox[{"t_:", "Real"}], ",", 
    RowBox[{"r_:", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"A", ",", "B", ",", "da", ",", "db", ",", "dab", ",", 
      RowBox[{"g", "=", 
       RowBox[{"gpd", "[", "gg", "]"}]}], ",", "l", ",", 
      RowBox[{"R", "=", "r"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"mm", "=", 
      RowBox[{"Length", "[", "g", "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"associativeQ", "[", "g", "]"}], "&&", 
        RowBox[{"!", 
         RowBox[{"signedTableQ", "[", "g", "]"}]}]}], ",", "True", ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"t", "===", "Real"}], ",", 
          RowBox[{"R", "=", 
           RowBox[{"Re", "[", "r", "]"}]}]}], "]"}], ";", 
        RowBox[{"A", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"RandomReal", "[", "R", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "mm"}], "}"}]}], "]"}]}], ";", 
        RowBox[{"B", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"RandomReal", "[", "R", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "mm"}], "}"}]}], "]"}]}], ";", 
        RowBox[{"da", "=", 
         RowBox[{"Det", "[", 
          RowBox[{"gmap", "[", 
           RowBox[{"g", ",", "A"}], "]"}], "]"}]}], ";", 
        RowBox[{"db", "=", 
         RowBox[{"Det", "[", 
          RowBox[{"gmap", "[", 
           RowBox[{"g", ",", "B"}], "]"}], "]"}]}], ";", 
        RowBox[{"dab", "=", 
         RowBox[{"Det", "[", 
          RowBox[{"gmap", "[", 
           RowBox[{"g", ",", 
            RowBox[{"hoopTimes", "[", 
             RowBox[{"A", ",", "B", ",", "g"}], "]"}]}], "]"}], "]"}]}], ";", 
        
        RowBox[{"A", "=", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"da", " ", "db"}], "-", "dab"}], "]"}]}], ";", 
        RowBox[{"B", "=", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"da", " ", "db"}], "+", "dab"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"Chop", "[", 
          FractionBox[
           RowBox[{"Min", "[", 
            RowBox[{"A", ",", "B"}], "]"}], 
           RowBox[{"Max", "[", 
            RowBox[{"A", ",", "B"}], "]"}]], "]"}], "\[Equal]", "0"}]}]}], 
      "]"}]}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"entropicQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"l", "=", "1"}], ",", 
       RowBox[{"m", "=", 
        RowBox[{"Length", "[", "g", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"abelianQ", "[", "g", "]"}], ",", 
        RowBox[{"Throw", "[", "True", "]"}]}], "]"}], ";", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
              
              RowBox[{
               RowBox[{"While", "[", 
                RowBox[{
                 RowBox[{"l", "\[LessEqual]", "m"}], ",", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", "l"}], "]"}], "]"}], "]"}]}], "]"}], 
                    "]"}], "]"}], "\[NotEqual]", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "k"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "l"}], "]"}], "]"}], "]"}]}], "]"}], 
                    "]"}], "]"}]}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"o", "===", "0"}], ",", 
                    RowBox[{"Throw", "[", "False", "]"}], ",", 
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k", ",", "l"}],
                     "}"}], "]"}]}], "]"}]}], "]"}], ";", "\n", 
                  "                ", 
                  RowBox[{"l", "++"}]}]}], "]"}], ";", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"l", "=", "1"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", "1"}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"flexibleQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", "\n", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", 
        StyleBox[
         RowBox[{"(*", " ", 
          RowBox[{"Negated", " ", 
           RowBox[{"associators", ".", "  ", "This"}], " ", "is", " ", "NOT", 
           " ", "as", " ", "described", " ", "in", " ", "PMA", " ", "p92"}], 
          " ", "*)"}],
         FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], "]"}], ",", "k"}], 
                    "]"}], "]"}], "-", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "k"}], "]"}], "]"}], "]"}]}], "]"}], 
                    "]"}]}], "\[NotEqual]", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", "j"}], "]"}], "]"}], "]"}], ",", "i"}], 
                    "]"}], "]"}]}], "+", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "i"}], "]"}], "]"}], "]"}]}], "]"}], 
                    "]"}]}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "===", "0"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k", ",", "l"}],
                     "}"}], "]"}]}], "]"}]}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", "1"}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"fenyvesQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m", ",", "axy", ",", "zx", 
       ",", "azx"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", 
           RowBox[{
            RowBox[{"axy", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"zx", "=", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"k", ",", "i"}], "\[RightDoubleBracket]"}]}], ";", 
               RowBox[{"azx", "=", 
                RowBox[{"Abs", "[", "zx", "]"}]}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"axy", ",", "k"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], "]"}], "]"}], "]"}], "\[NotEqual]", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "azx"}], "]"}], "]"}], "]"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                   RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"axy", ",", "k"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], "]"}], "]"}], ",", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "azx"}], "]"}], "]"}], "]"}]}], 
                    "\[RightDoubleBracket]"}]}], "}"}], "]"}], ";", 
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                    "]"}]}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}]}], "]"}]}], "]"}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"flexQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", "\n", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"j", "\[LessEqual]", "m"}], ",", 
        StyleBox[
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
           "This", " ", "is", " ", "as", " ", "described", " ", "in", " ", 
            "PMA", " ", "p92"}], ",", " ", 
           RowBox[{"with", " ", "Abs"}]}], " ", "*)"}],
         FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"k", "\[LessEqual]", "m"}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Abs", "[", 
                RowBox[{"g", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", "j"}], "]"}], "]"}], "]"}], ",", "k"}], 
                  "]"}], "]"}], "]"}], "===", 
               RowBox[{"Abs", "[", 
                RowBox[{"g", "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", 
                   RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "k"}], "]"}], "]"}], "]"}]}], "]"}], 
                 "]"}], "]"}]}], ",", ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"o", "===", "0"}], ",", 
                RowBox[{"Throw", "[", "False", "]"}], ",", 
                RowBox[{"Throw", "[", 
                 RowBox[{"{", 
                  RowBox[{"False", ",", "j", ",", "k"}], "}"}], "]"}]}], 
               "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"k", "++"}]}]}], "]"}], ";", 
         RowBox[{"j", "++"}], ";", 
         RowBox[{"k", "=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hamiltonianQ", "[", 
    RowBox[{"g_:", "glo"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s", "=", 
       RowBox[{"subgroups", "[", "g", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"!", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], "&&", 
      RowBox[{"!", 
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"normalSubgroup", "[", 
            RowBox[{"s", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "s", "]"}]}], "}"}]}], "]"}], ",", 
         "False"}], "]"}]}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"indexTableQ", "[", 
   RowBox[{"gg_:", "glo"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"g", ",", 
      RowBox[{"i", "=", "2"}], ",", "l", ",", "r", ",", "c", ",", "t"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"gg", "\[NotEqual]", 
        RowBox[{"{", 
         RowBox[{"{", "}"}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g", "=", 
         RowBox[{"Abs", "[", 
          RowBox[{"gpd", "[", "gg", "]"}], "]"}]}], ";", 
        RowBox[{"r", "=", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "gg", "]"}], "\[Equal]", "1"}], ",", 
           RowBox[{"gg", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"gg", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
        RowBox[{"t", "=", 
         RowBox[{"Transpose", "[", "g", "]"}]}], ";", 
        RowBox[{"c", "=", 
         RowBox[{"t", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", 
        RowBox[{"l", "=", 
         RowBox[{"Length", "[", "g", "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"r", "\[Equal]", "c", "\[Equal]", 
           RowBox[{"Range", "[", "l", "]"}]}], ",", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"i", "\[LessEqual]", "l"}], "&&", 
             RowBox[{"r", "\[Equal]", 
              RowBox[{"Union", "[", 
               RowBox[{"Abs", "[", 
                RowBox[{"g", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "\[Equal]", 
              RowBox[{"Union", "[", 
               RowBox[{"Abs", "[", 
                RowBox[{"t", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}]}], ",", 
            RowBox[{"i", "++"}]}], "]"}]}], "]"}]}], ",", 
       RowBox[{"l", "=", "i"}]}], "]"}], ";", 
     RowBox[{"i", ">", "l"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Q", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"(*", 
   RowBox[{"Wrong", " ", 
    RowBox[{"name", "?"}]}], "*)"}], 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", "j", ",", "k", ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m", ",", "xx", ",", "axx", 
       ",", "xy", ",", "axy"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", 
        RowBox[{
         RowBox[{"xx", "=", 
          RowBox[{"g", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "i"}], "]"}], "]"}]}], ";", 
         RowBox[{"axx", "=", 
          RowBox[{"Abs", "[", "xx", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", 
           RowBox[{
            RowBox[{"xy", "=", 
             RowBox[{"g", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}], ";", 
            RowBox[{"axy", "=", 
             RowBox[{"Abs", "[", "xy", "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Abs", "[", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"axy", ",", "axx"}], "\[RightDoubleBracket]"}], 
                "]"}], "\[NotEqual]", 
               RowBox[{"Abs", "[", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "axx"}], "]"}], "]"}], "]"}]}], 
                 "\[RightDoubleBracket]"}], "]"}]}], ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                RowBox[{
                 StyleBox[
                  RowBox[{"Print", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"axy", ",", "axx"}], "\[RightDoubleBracket]"}], 
                    ",", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "axx"}], "]"}], "]"}], "]"}]}], 
                    "\[RightDoubleBracket]"}]}], "}"}], "]"}],
                  FontColor->RGBColor[0, 1, 0]], ";", 
                 RowBox[{"Throw", "[", 
                  RowBox[{"{", 
                   RowBox[{"False", ",", "i", ",", "j"}], "}"}], "]"}]}], ",",
                 
                RowBox[{"Throw", "[", "False", "]"}], ",", 
                RowBox[{"Throw", "[", "False", "]"}]}], "]"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"jacobiQ", "[", 
    RowBox[{"A_", ",", "B_", ",", "C_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"AB", "=", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", "B"}], "]"}]}], ",", 
       RowBox[{"BA", "=", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"B", ",", "A"}], "]"}]}], ",", 
       RowBox[{"AC", "=", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", "C"}], "]"}]}], ",", 
       RowBox[{"CA", "=", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"C", ",", "A"}], "]"}]}], ",", 
       RowBox[{"BC", "=", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"B", ",", "C"}], "]"}]}], ",", 
       RowBox[{"CB", "=", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"C", ",", "B"}], "]"}]}], ",", "abc", ",", "bca", ",", 
       "cab"}], "}"}], ",", 
     RowBox[{
      RowBox[{"abc", "=", 
       RowBox[{
        RowBox[{"hoopTimes", "[", 
         RowBox[{
          RowBox[{"AB", "-", "BA"}], ",", "C"}], "]"}], "-", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"C", ",", 
          RowBox[{"AB", "-", "BA"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"bca", "=", 
       RowBox[{
        RowBox[{"hoopTimes", "[", 
         RowBox[{
          RowBox[{"BC", "-", "CB"}], ",", "A"}], "]"}], "-", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"BC", "-", "CB"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"cab", "=", 
       RowBox[{
        RowBox[{"hoopTimes", "[", 
         RowBox[{
          RowBox[{"CA", "-", "AC"}], ",", "B"}], "]"}], "-", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"B", ",", 
          RowBox[{"CA", "-", "AC"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"abc", "+", "bca"}], "\[Equal]", 
       RowBox[{"-", "cab"}]}]}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"MoufangQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m", ",", "axy", ",", "zx", 
       ",", "azx", ",", "yz", ",", "ayz"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", 
           RowBox[{
            RowBox[{"axy", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"zx", "=", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"k", ",", "i"}], "\[RightDoubleBracket]"}]}], ";", 
               RowBox[{"azx", "=", 
                RowBox[{"Abs", "[", "zx", "]"}]}], ";", 
               RowBox[{"yz", "=", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"j", ",", "k"}], "\[RightDoubleBracket]"}]}], ";", 
               RowBox[{"ayz", "=", 
                RowBox[{"Abs", "[", "yz", "]"}]}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sign", "[", "zx", "]"}], 
                   RowBox[{"Sign", "[", "yz", "]"}], 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"azx", ",", "ayz"}], "\[RightDoubleBracket]"}]}], 
                  "\[NotEqual]", 
                  RowBox[{"g", "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", "axy"}], "]"}], "]"}], "]"}], ",", 
                    "k"}], "\[RightDoubleBracket]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                   RowBox[{
                    StyleBox[
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Sign", "[", "zx", "]"}], 
                    RowBox[{"Sign", "[", "yz", "]"}], 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"azx", ",", "ayz"}], "\[RightDoubleBracket]"}]}], 
                    ",", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", "axy"}], "]"}], "]"}], "]"}], ",", 
                    "k"}], "\[RightDoubleBracket]"}]}], "}"}], "]"}],
                    FontColor->RGBColor[0, 1, 0]], ";", 
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                    "]"}]}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}]}], "]"}]}], "]"}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"moufangQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m", ",", "axy", ",", "zx", 
       ",", "azx", ",", "yz", ",", "ayz"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", 
           RowBox[{
            RowBox[{"axy", "=", 
             RowBox[{"Abs", "[", 
              RowBox[{"g", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
            ";", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"zx", "=", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"k", ",", "i"}], "\[RightDoubleBracket]"}]}], ";", 
               RowBox[{"azx", "=", 
                RowBox[{"Abs", "[", "zx", "]"}]}], ";", 
               RowBox[{"yz", "=", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"j", ",", "k"}], "\[RightDoubleBracket]"}]}], ";", 
               RowBox[{"ayz", "=", 
                RowBox[{"Abs", "[", "yz", "]"}]}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"azx", ",", "ayz"}], "\[RightDoubleBracket]"}], 
                   "]"}], "\[NotEqual]", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", "axy"}], "]"}], "]"}], "]"}], ",", 
                    "k"}], "\[RightDoubleBracket]"}], "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                   RowBox[{
                    StyleBox[
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"azx", ",", "ayz"}], "\[RightDoubleBracket]"}], 
                    ",", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"k", ",", "axy"}], "]"}], "]"}], "]"}], ",", 
                    "k"}], "\[RightDoubleBracket]"}]}], "}"}], "]"}],
                    FontColor->RGBColor[0, 1, 0]], ";", 
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                    "]"}]}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}]}], "]"}]}], "]"}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"moufangLQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "j"}], "\[RightDoubleBracket]"}], "]"}],
                     ",", "k"}], "\[RightDoubleBracket]"}], "]"}], ",", "i"}],
                     "]"}], "]"}], "]"}], "\[NotEqual]", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "i"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], "]"}], "]"}], "]"}]}], "\[RightDoubleBracket]"}],
                    "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                   StyleBox[
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                    "]"}],
                    FontColor->RGBColor[0, 1, 0]], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}]}], "]"}]}], "]"}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"moufangRQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "g", "]"}]}], ";", 
      RowBox[{"a", "=", 
       RowBox[{"abelianQ", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"j", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"k", "\[LessEqual]", "m"}], ",", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "k"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], "\[RightDoubleBracket]"}], "]"}]}], "]"}], "]"}],
                    "]"}], "\[NotEqual]", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "k"}], "\[RightDoubleBracket]"}], "]"}],
                     ",", "j"}], "\[RightDoubleBracket]"}], "]"}], ",", "k"}],
                     "]"}], "]"}], "]"}]}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"o", "\[NotEqual]", "0"}], ",", 
                   StyleBox[
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "i", ",", "j", ",", "k"}], "}"}], 
                    "]"}],
                    FontColor->RGBColor[0, 1, 0]], ",", 
                   RowBox[{"Throw", "[", "False", "]"}], ",", 
                   RowBox[{"Throw", "[", "False", "]"}]}], "]"}]}], "]"}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"k", "++"}]}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"k", "=", 
             RowBox[{"If", "[", 
              RowBox[{"a", ",", "j", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
         RowBox[{"i", "++"}], ";", 
         RowBox[{"j", "=", 
          RowBox[{"If", "[", 
           RowBox[{"a", ",", "i", ",", "1"}], "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"negatableQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"f_:", "2"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"g", "=", 
       RowBox[{"gpd", "[", "gg", "]"}]}], ",", "g1", ",", "s1", ",", "i", ",",
       "j", ",", "g2", ",", "l", ",", "m", ",", "t"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"l", "=", 
      RowBox[{"Length", "[", "g", "]"}]}], ";", 
     RowBox[{"m", "=", 
      RowBox[{
       RowBox[{"Length", "[", "g", "]"}], "/", "f"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"IntegerQ", "[", "m", "]"}]}], ",", "False", ",", 
       RowBox[{
        RowBox[{"g1", "=", 
         RowBox[{"pick", "[", 
          RowBox[{"g", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "m"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "m"}], "}"}]}], "]"}]}], ";", 
        RowBox[{"s1", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Sign", "[", 
            RowBox[{"g1", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "m"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "m"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"g1", "=", 
         RowBox[{"g1", "/", "s1"}]}], ";", 
        RowBox[{"g2", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{
              RowBox[{"g1", "+", 
               RowBox[{"e", " ", "m"}], "-", "1"}], ",", "l"}], "]"}], "+", 
            RowBox[{"1", "*", "s1"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"e", ",", "f"}], "}"}]}], "]"}]}], ";", 
        RowBox[{"j", "=", "0"}], ";", 
        RowBox[{"Catch", "[", 
         RowBox[{
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"i", "=", "0"}], ";", "\[IndentingNewLine]", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"MemberQ", "[", 
                 RowBox[{"g2", ",", 
                  RowBox[{"pick", "[", 
                   RowBox[{"g", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"m", " ", "i"}], "+", "1"}], ",", 
                    RowBox[{
                    RowBox[{"m", " ", "i"}], "+", "m"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"m", " ", "j"}], "+", "1"}], ",", 
                    RowBox[{
                    RowBox[{"m", " ", "j"}], "+", "m"}]}], "}"}]}], "]"}]}], 
                 "]"}], ",", "Null", ",", 
                RowBox[{"Throw", "[", "False", "]"}]}], "]"}], ";", 
              RowBox[{"i", "++"}], ";", 
              RowBox[{"i", "<", "f"}]}], "]"}], ";", 
            RowBox[{"j", "++"}], ";", 
            RowBox[{"j", "<", "f"}]}], "]"}], ";", "True"}], "]"}]}]}], 
      "]"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"loopQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", " ", 
    RowBox[{"O_:", "0"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"i", " ", "=", " ", "1"}], ",", " ", 
       RowBox[{"g", " ", "=", " ", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", " ", "Len", ",", " ", "l", 
       ",", " ", "o", ",", " ", "t"}], "}"}], ",", " ", 
     RowBox[{
      RowBox[{"Len", " ", "=", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"g", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", " ", 
      RowBox[{"l", " ", "=", " ", 
       RowBox[{"Union", "[", 
        RowBox[{"g", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", " ", 
      RowBox[{"t", " ", "=", " ", 
       RowBox[{"Transpose", "[", "g", "]"}]}], ";", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "l", "]"}], " ", "==", " ", "Len"}], " ", "&&",
          " ", 
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"t", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], " ", "==", " ", "l"}]}], 
        ",", " ", "Null", ",", " ", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"O", " ", "!=", " ", "0"}], ",", " ", 
           RowBox[{"Print", "[", 
            RowBox[{"{", 
             RowBox[{
             "\"\< First row, col incorrect\>\"", ",", " ", "l", ",", " ", 
              RowBox[{"t", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], ";", 
         " ", 
         RowBox[{"Throw", "[", "False", "]"}]}]}], "]"}], ";", " ", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", " ", "<=", " ", "Len"}], ",", " ", 
        RowBox[{
         RowBox[{"o", " ", "=", " ", 
          RowBox[{"Complement", "[", 
           RowBox[{"l", ",", " ", 
            RowBox[{"Abs", "[", 
             RowBox[{"g", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "]"}]}], ";", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"o", " ", "!=", " ", 
            RowBox[{"{", "}"}]}], ",", " ", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"O", " ", "!=", " ", "0"}], ",", " ", 
              RowBox[{"Print", "[", 
               RowBox[{"{", 
                RowBox[{
                "i", ",", " ", "\"\< row missing\>\"", ",", " ", "o"}], "}"}],
                "]"}]}], "]"}], ";", " ", 
            RowBox[{"Throw", "[", "False", "]"}]}]}], "]"}], ";", " ", 
         RowBox[{"o", " ", "=", " ", 
          RowBox[{"Complement", "[", 
           RowBox[{"l", ",", " ", 
            RowBox[{"Abs", "[", 
             RowBox[{"t", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "]"}]}], ";", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"o", " ", "!=", " ", 
            RowBox[{"{", "}"}]}], ",", " ", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"O", " ", "!=", " ", "0"}], ",", " ", 
              RowBox[{"Print", "[", 
               RowBox[{"{", 
                RowBox[{
                "i", ",", " ", "\"\< col missing\>\"", ",", " ", "o"}], "}"}],
                "]"}]}], "]"}], ";", " ", 
            RowBox[{"Throw", "[", "False", "]"}]}]}], "]"}], ";", " ", 
         RowBox[{"i", "++"}]}]}], "]"}], ";", " ", "True"}]}], "]"}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 FontFamily->"Courier New"],

Cell[BoxData[
 RowBox[{
  RowBox[{"signedTableQ", "[", 
   RowBox[{"gg_:", "glo"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Union", "[", 
        RowBox[{"gg", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "\[NotEqual]", 
       RowBox[{"Union", "[", 
        RowBox[{"Flatten", "[", "gg", "]"}], "]"}]}], ")"}], "&&", 
     RowBox[{"indexTableQ", "[", "gg", "]"}]}], ",", "True", ",", "False", 
    ",", "False"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"associator", "[", 
   RowBox[{
    RowBox[{"g_:", "glo"}], ",", "i_", ",", "j_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", "k"}], "]"}], "]"}], "-", 
   
   RowBox[{"g", "[", 
    RowBox[{"[", 
     RowBox[{"i", ",", 
      RowBox[{"g", "[", 
       RowBox[{"[", 
        RowBox[{"j", ",", "k"}], "]"}], "]"}]}], "]"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pick", "[", 
    RowBox[{"g_", ",", "m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Take", "[", 
        RowBox[{"g", ",", "m"}], "]"}], "]"}], ",", "n"}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"reductiveQ", "[", 
   RowBox[{
    RowBox[{"gg_:", "glo"}], ",", 
    RowBox[{"o_", ":", "0"}]}], "]"}], ":=", 
  RowBox[{"(*", 
   RowBox[{"Ref", 
    RowBox[{"??", " ", 
     RowBox[{"Everything", ",", " ", 
      RowBox[{"including", " ", "C5n"}], ",", "C6n", ",", "Alt12n", ",", " ", 
      "passes"}]}]}], "*)"}], 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "=", 
        RowBox[{"gpd", "[", "gg", "]"}]}], ",", 
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"k", "=", "1"}], ",", 
       RowBox[{"m", "=", 
        RowBox[{"Length", "[", "g", "]"}]}], ",", "xy", ",", "xx", ",", 
       "yxx"}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MatrixQ", "[", "g", "]"}], ",", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{"i", "\[LessEqual]", "m"}], ",", 
          RowBox[{
           RowBox[{"xx", "=", 
            RowBox[{"Abs", "[", 
             RowBox[{"g", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "i"}], "\[RightDoubleBracket]"}], "]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"While", "[", 
            RowBox[{
             RowBox[{"j", "\[LessEqual]", "m"}], ",", 
             RowBox[{
              RowBox[{"xy", "=", 
               RowBox[{"Abs", "[", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
              ";", 
              RowBox[{"yxx", "=", 
               RowBox[{"Abs", "[", 
                RowBox[{"g", "\[LeftDoubleBracket]", 
                 RowBox[{"j", ",", "xx"}], "\[RightDoubleBracket]"}], "]"}]}],
               ";", 
              RowBox[{"(*", 
               RowBox[{
                RowBox[{"Print", "[", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "j", ",", "xx", ",", "xy", ",", 
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"xy", ",", "xx"}], "\[RightDoubleBracket]"}], ",",
                    
                   RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "yxx"}], "\[RightDoubleBracket]"}]}], 
                  "}"}], "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{"g", "\[LeftDoubleBracket]", 
                   RowBox[{"xy", ",", "xx"}], "\[RightDoubleBracket]"}], 
                  "]"}], "\[Equal]", 
                 RowBox[{"Abs", "[", 
                  RowBox[{"g", "[", 
                   RowBox[{"[", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "yxx"}], "\[RightDoubleBracket]"}], 
                    "]"}], "]"}], "]"}], "]"}]}], ",", "Null", ",", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"o", "===", "0"}], ",", 
                  RowBox[{"Throw", "[", "False", "]"}], ",", 
                  StyleBox[
                   RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "False", ",", "i", ",", "j", ",", "\"\< reductiveQ\>\""}],
                     "}"}], "]"}],
                   FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"j", "++"}], ";", 
              RowBox[{"k", "=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
           
           RowBox[{"i", "++"}], ";", 
           RowBox[{"j", "=", "1"}]}]}], "]"}], ",", 
        StyleBox[
         RowBox[{"Throw", "[", 
          RowBox[{"{", 
           RowBox[{"False", ",", "g", ",", "\"\< not a matrix\>\""}], "}"}], 
          "]"}],
         FontColor->RGBColor[1, 0, 1]]}], "]"}], ";", "\[IndentingNewLine]", 
      "True"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"ref", " ", "Raoul", " ", "Cawagas"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"riffQ", "[", 
    RowBox[{
     RowBox[{"gg_:", "glo"}], ",", 
     RowBox[{"o_", ":", "0"}]}], "]"}], ":=", 
   RowBox[{"Catch", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g", "=", 
         RowBox[{"gpd", "[", "gg", "]"}]}], ",", 
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"j", "=", "1"}], ",", 
        RowBox[{"k", "=", "1"}], ",", "m", ",", "xy", ",", "zxy", ",", "yz"}],
        "}"}], ",", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"Length", "[", "g", "]"}]}], ";", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"i", "\[LessEqual]", "m"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"j", "\[LessEqual]", "m"}], ",", 
            RowBox[{
             RowBox[{"xy", "=", 
              RowBox[{"Abs", "[", 
               RowBox[{"g", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}], 
             ";", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{"k", "\[LessEqual]", "m"}], ",", 
               RowBox[{
                RowBox[{"yz", "=", 
                 RowBox[{"Abs", "[", 
                  RowBox[{"g", "\[LeftDoubleBracket]", 
                   RowBox[{"j", ",", "k"}], "\[RightDoubleBracket]"}], 
                  "]"}]}], ";", 
                RowBox[{"zxy", "=", 
                 RowBox[{"Abs", "[", 
                  RowBox[{"g", "\[LeftDoubleBracket]", 
                   RowBox[{"k", ",", "xy"}], "\[RightDoubleBracket]"}], 
                  "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"xy", ",", "zxy"}], "\[RightDoubleBracket]"}], 
                    "]"}], "\[Equal]", 
                   RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "yz"}], "\[RightDoubleBracket]"}], 
                    "]"}], ",", "i"}], "\[RightDoubleBracket]"}], "]"}], ",", 
                    "j"}], "\[RightDoubleBracket]"}], "]"}]}], ",", "Null", 
                  ",", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"o", "===", "0"}], ",", 
                    RowBox[{"Throw", "[", "False", "]"}], ",", 
                    StyleBox[
                    RowBox[{"Throw", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "False", ",", "i", ",", "j", ",", "k", ",", 
                    "\"\< riffQ\>\""}], "}"}], "]"}],
                    FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"k", "++"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"j", "++"}], ";", 
             RowBox[{"k", "=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"i", "++"}], ";", 
          RowBox[{"j", "=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       "True"}]}], "]"}], "]"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "5 Operations",
 StyleBox[" reorder, gmap, caylindex, toIndexTable, lmatrix, rmatrix, mutant",
  
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"reorder", "[", 
   RowBox[{
    RowBox[{"g_", "?", "indexTableQ"}], ",", "p_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gg", ",", "n", ",", "m", ",", 
      RowBox[{"l", "=", 
       RowBox[{"Length", "[", "p", "]"}]}], ",", "o", ",", "gp"}], "}"}], ",",
     
    RowBox[{
     RowBox[{"gg", "=", 
      RowBox[{"gpd", "[", "g", "]"}]}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "gg", "]"}]}], ";", 
     RowBox[{"gp", "=", 
      RowBox[{"Abs", "[", "gg", "]"}]}], ";", 
     RowBox[{"m", "=", 
      RowBox[{"Min", "[", 
       RowBox[{"n", ",", "l"}], "]"}]}], ";", 
     RowBox[{"o", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"p", ",", 
        RowBox[{"Complement", "[", 
         RowBox[{
          RowBox[{"Range", "[", "n", "]"}], ",", "p"}], "]"}]}], "]"}]}], ";",
      
     StyleBox[
      RowBox[{"(*", " ", 
       RowBox[{
       "Extend", " ", "p", " ", "to", " ", "full", " ", "size", " ", "of", 
        " ", "g"}], " ", "*)"}],
      FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
     RowBox[{"o", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"o", ",", "i"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], ";", "\n", "   ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"o", "\[LeftDoubleBracket]", 
         RowBox[{"gp", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{
           "p", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
           "p", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}], 
          "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], 
        RowBox[{"Sign", "[", 
         RowBox[{"gg", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"p", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"p", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "m"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "m"}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gmap", "[", 
    RowBox[{
     RowBox[{"g_:", "glo"}], ",", "v_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"gg", "=", 
        RowBox[{"gpd", "[", "g", "]"}]}], ",", "m", ",", "i", ",", 
       RowBox[{"st", "=", "1"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"Positive", "[", "gg", "]"}], ",", "False", ",", "2"}], 
         "]"}], ",", 
        RowBox[{
         RowBox[{"st", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Sign", "[", 
             RowBox[{"gg", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Length", "[", "gg", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"Length", "[", "gg", "]"}]}], "}"}]}], "]"}]}], ";", 
         RowBox[{"gg", "=", 
          RowBox[{"Abs", "[", "gg", "]"}]}]}]}], "]"}], ";", 
      RowBox[{
       RowBox[{"m", "[", "i_", "]"}], ":=", 
       RowBox[{"v", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{"m", ",", "gg", ",", "1"}], "]"}], "*", "st"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"caylindex", "[", "g_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"gg", "=", 
        RowBox[{"gpd", "[", "g", "]"}]}], ",", "e", ",", "j", ",", "l", ",", 
       "n", ",", "s"}], "}"}], ",", 
     RowBox[{
      RowBox[{"l", "=", 
       RowBox[{"Length", "[", "gg", "]"}]}], ";", 
      RowBox[{"n", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"j", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", "l"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"e", "=", 
       RowBox[{"gg", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", 
      RowBox[{"s", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"e", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "->", 
          RowBox[{"n", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "l", ",", "1", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"gg", "/.", "s"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"toIndexTable", "[", 
    RowBox[{"g_:", "glo"}], "]"}], ":=", 
   RowBox[{"unshuffle", "[", 
    RowBox[{"Transpose", "[", 
     RowBox[{"unshuffle", "[", 
      RowBox[{"gpd", "[", "g", "]"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"unshuffle", "[", "g_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"l", "=", 
        RowBox[{"Length", "[", "g", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"p", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"g", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"p", ",", "i"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"lmatrix", "[", 
    RowBox[{"g_:", "glo"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"gg", "=", 
        RowBox[{"gpd", "[", "g", "]"}]}], ",", "m", ",", "s", ",", "t"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "gg", "]"}]}], ";", 
      RowBox[{"t", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "m"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "m"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"s", "=", 
            RowBox[{"gg", "\[LeftDoubleBracket]", 
             RowBox[{"l", ",", "k"}], "\[RightDoubleBracket]"}]}], ";", 
           RowBox[{
            RowBox[{"t", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{"Abs", "[", "s", "]"}], ",", "k"}], 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{"l", " ", 
             RowBox[{"Sign", "[", "s", "]"}]}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "m"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"l", ",", "m"}], "}"}]}], "]"}], ";", "t"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"rmatrix", "[", 
    RowBox[{"g_:", "glo"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"gg", "=", 
        RowBox[{"gpd", "[", "g", "]"}]}], ",", "m", ",", "s", ",", "t"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "gg", "]"}]}], ";", 
      RowBox[{"t", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "m"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "m"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"s", "=", 
            RowBox[{"gg", "\[LeftDoubleBracket]", 
             RowBox[{"l", ",", "k"}], "\[RightDoubleBracket]"}]}], ";", 
           RowBox[{
            RowBox[{"t", "\[LeftDoubleBracket]", 
             RowBox[{"l", ",", 
              RowBox[{"Abs", "[", "s", "]"}]}], "\[RightDoubleBracket]"}], 
            "=", 
            RowBox[{"k", " ", 
             RowBox[{"Sign", "[", "s", "]"}]}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "m"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"l", ",", "m"}], "}"}]}], "]"}], ";", "t"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"mutant", "[", 
   RowBox[{
    RowBox[{"gg_", "?", "indexTableQ"}], ",", "ps_List"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "gg", "]"}]}], ",", "o", ",", 
      RowBox[{"p", "=", 
       RowBox[{"Abs", "[", "ps", "]"}]}], ",", "res", ",", 
      RowBox[{"s", "=", 
       RowBox[{"Sign", "[", "ps", "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", "1"}], "||", 
        RowBox[{
         RowBox[{"Max", "[", "p", "]"}], ">", "m"}]}], ",", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<ps wrong\>\"", ",", "ps"}], "}"}], "]"}], ";", 
        RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"o", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"p", ",", 
        RowBox[{"Complement", "[", 
         RowBox[{
          RowBox[{"Range", "[", "m", "]"}], ",", "p"}], "]"}]}], "]"}]}], ";",
      
     RowBox[{"s", "=", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"s", ",", 
          RowBox[{"Table", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}], "]"}], ",", "m"}], 
       "]"}]}], ";", 
     RowBox[{"res", "=", "gg"}], ";", 
     RowBox[{"inv", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"o", ",", "i"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}], ";", 
     StyleBox["\[IndentingNewLine]",
      FontColor->RGBColor[0, 0, 1]], 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"sj", "=", 
         RowBox[{"s", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], ";", 
        RowBox[{"ij", "=", 
         RowBox[{"inv", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], ";", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "=", 
            RowBox[{"gg", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ";", 
           RowBox[{"o", "=", 
            RowBox[{"inv", "[", 
             RowBox[{"[", 
              RowBox[{"Abs", "[", "p", "]"}], "]"}], "]"}]}], ";", 
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"inv", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "ij"}], "]"}], "]"}], 
            "=", 
            RowBox[{"sj", " ", 
             RowBox[{"s", "[", 
              RowBox[{"[", "i", "]"}], "]"}], 
             RowBox[{"Sign", "[", "p", "]"}], "o", " ", 
             RowBox[{"s", "[", 
              RowBox[{"[", "o", "]"}], "]"}]}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "2", ",", "m"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2", ",", "m"}], "}"}]}], "]"}], ";", "res"}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "6 Loops from Relators, ",
 StyleBox["ge; ",
  FontSlant->"Italic"],
 "Monovectors Clifford ",
 StyleBox["cl",
  FontSlant->"Italic"],
 "; Cayley-Dickson ",
 StyleBox["cd; ",
  FontSlant->"Italic"],
 "Moufang doubling",
 StyleBox[" md.",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"smax", "=", "100"}], ";", 
  RowBox[{
   RowBox[{"streprpt", "[", 
    RowBox[{"str_", ",", "rul_", ",", 
     RowBox[{"imax_:", "smax"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s1", "=", "str"}], ",", "s2", ",", 
       RowBox[{"ii", "=", "1"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"s2", "=", 
           RowBox[{"StringReplace", "[", 
            RowBox[{"s1", ",", "rul"}], "]"}]}], ")"}], "\[NotEqual]", "s1"}],
         ",", 
        RowBox[{
         RowBox[{"ii", "++"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"ii", ">", "imax"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"imax", "\[Equal]", "99"}], ",", 
             RowBox[{"OK", "=", "\"\<Fail\>\""}], ",", 
             RowBox[{
              StyleBox[
               RowBox[{"Print", "[", 
                RowBox[{
                "s1", ",", "\"\< \>\"", ",", "s2", ",", "\"\< \>\"", ",", 
                 "\"\<Failed. Increase smax?\>\""}], "]"}],
               FontColor->RGBColor[1, 0, 1]], ";", 
              RowBox[{"Abort", "[", "]"}]}]}], "]"}]}], "]"}], ";", 
         RowBox[{"s1", "=", "s2"}]}]}], "]"}], ";", "s2"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"matstrep", "[", 
   RowBox[{
    RowBox[{"l_", "?", "MatrixQ"}], ",", "rul_", ",", 
    RowBox[{"sm_:", "smax"}]}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"streprpt", "[", 
     RowBox[{
      RowBox[{"l", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", "rul", ",", "sm"}], "]"}],
     ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{
       RowBox[{"Dimensions", "[", 
        RowBox[{"l", ",", "1"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{
       RowBox[{"Dimensions", "[", 
        RowBox[{"l", ",", "2"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ruleExpand", "[", "a___", "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Rule", "[", 
      RowBox[{
       RowBox[{"stringExpand", "[", 
        RowBox[{"ToString", "[", 
         RowBox[{"a", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"stringExpand", "[", 
        RowBox[{"ToString", "[", 
         RowBox[{"a", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "a", "]"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",\

 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"stringExpand", "[", "t_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "g", ",", "l", ",", 
      RowBox[{"n", "=", "1"}], ",", 
      RowBox[{"res", "=", "\"\<\>\""}], ",", 
      RowBox[{"s", "=", 
       RowBox[{"ToString", "[", "t", "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"s", "\[Equal]", "\"\<\>\""}], ",", "res", ",", 
       RowBox[{
        RowBox[{"l", "=", 
         RowBox[{"StringLength", "[", "s", "]"}]}], ";", 
        RowBox[{"g", "=", 
         RowBox[{"StringTake", "[", 
          RowBox[{"s", ",", "1"}], "]"}]}], ";", 
        RowBox[{"res", "=", 
         RowBox[{"res", "<>", "g"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"g", "=", 
            RowBox[{"StringTake", "[", 
             RowBox[{"s", ",", 
              RowBox[{"{", "n", "}"}]}], "]"}]}], ";", 
           RowBox[{"n", "++"}], ";", 
           RowBox[{"n", "\[LessEqual]", "l"}]}], ",", 
          RowBox[{
           RowBox[{"f", "=", 
            RowBox[{"StringTake", "[", 
             RowBox[{"s", ",", 
              RowBox[{"{", "n", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
           
           RowBox[{"e", "=", 
            RowBox[{"ToExpression", "[", "f", "]"}]}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"IntegerQ", "[", "e", "]"}], ",", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"n", "<", "l"}], "&&", 
                 RowBox[{"IntegerQ", "[", 
                  RowBox[{"ToExpression", "[", 
                   RowBox[{"StringTake", "[", 
                    RowBox[{"s", ",", 
                    RowBox[{"{", 
                    RowBox[{"n", "+", "1"}], "}"}]}], "]"}], "]"}], "]"}]}], 
                ",", 
                RowBox[{
                 RowBox[{"e", "=", 
                  RowBox[{"ToExpression", "[", 
                   RowBox[{"StringTake", "[", 
                    RowBox[{"s", ",", 
                    RowBox[{"{", 
                    RowBox[{"n", ",", 
                    RowBox[{"n", "+", "1"}]}], "}"}]}], "]"}], "]"}]}], ";", 
                 RowBox[{"n", "++"}], ";"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"Do", "[", 
               RowBox[{
                RowBox[{"res", "=", 
                 RowBox[{"res", "<>", "g"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{"e", "-", "1"}]}], "}"}]}], "]"}]}], ",", 
             RowBox[{"res", "=", 
              RowBox[{"res", "<>", "f"}]}]}], "]"}]}]}], "]"}]}]}], "]"}], 
     ";", "\[IndentingNewLine]", "res"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ge", "[", 
    RowBox[{
     RowBox[{"gp_", "?", "VectorQ"}], ",", 
     RowBox[{"pre_:", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"o_:", "0"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "=", 
        RowBox[{"{", "}"}]}], ",", "cr", ",", "j", ",", 
       RowBox[{"l", "=", 
        RowBox[{
         RowBox[{"IntegerPart", "[", 
          RowBox[{"Plus", "@@", "gp"}], "]"}], "+", "2"}]}], ",", 
       RowBox[{"le", "=", 
        RowBox[{"Length", "[", "gp", "]"}]}], ",", 
       RowBox[{"ln", "=", "1"}], ",", "lh", ",", 
       RowBox[{"n", "=", 
        RowBox[{"{", "\"\<\>\"", "}"}]}], ",", "new", ",", "p", ",", "st", 
       ",", "rhs", ",", "lhs", ",", 
       RowBox[{"t", "=", 
        RowBox[{"ruleExpand", "[", "pre", "]"}]}], ",", "si", ",", "sij"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"cr", "=", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"CharacterRange", "[", 
          RowBox[{"\"\<a\>\"", ",", "\"\<g\>\""}], "]"}], ",", "le"}], 
        "]"}]}], ";", 
      RowBox[{"Catch", "[", 
       StyleBox[
        RowBox[{"(*", 
         RowBox[{"Reject", " ", "bad", " ", 
          RowBox[{"rules", "."}]}], "*)"}],
        FontColor->RGBColor[0, 0, 1]], 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"o", "\[NotEqual]", "0"}], ",", 
          RowBox[{"Do", "[", 
           StyleBox[
            RowBox[{"(*", 
             RowBox[{
              RowBox[{"i", " ", "loop"}], ",", "Relators"}], "*)"}],
            FontColor->RGBColor[0, 0, 1]], 
           RowBox[{
            RowBox[{"Do", "[", 
             StyleBox[
              RowBox[{"(*", 
               RowBox[{
                RowBox[{"r", " ", "loop"}], ",", 
                RowBox[{"each", " ", "rule"}]}], "*)"}],
              FontColor->RGBColor[0, 0, 1]], 
             RowBox[{
              RowBox[{"Do", "[", 
               StyleBox[
                RowBox[{"(*", 
                 RowBox[{
                  RowBox[{"k", " ", "loop"}], ",", 
                  RowBox[{
                   RowBox[{"lhs", " ", "&"}], " ", "rhs"}]}], "*)"}],
                FontColor->RGBColor[0, 0, 1]], 
               RowBox[{
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"rhs", "=", 
                    RowBox[{"Characters", "[", 
                    RowBox[{"t", "[", 
                    RowBox[{"[", 
                    RowBox[{"r", ",", "2"}], "]"}], "]"}], "]"}]}], ")"}], 
                    "\[NotEqual]", 
                    RowBox[{"Sort", "[", "rhs", "]"}]}], "||", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"lhs", "=", 
                    RowBox[{"Characters", "[", 
                    RowBox[{"t", "[", 
                    RowBox[{"[", 
                    RowBox[{"r", ",", "1"}], "]"}], "]"}], "]"}]}], ")"}], 
                    "\[Equal]", 
                    RowBox[{"Sort", "[", "lhs", "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"Length", "[", 
                    RowBox[{"Union", "[", "lhs", "]"}], "]"}], ">", "1"}]}], 
                    ")"}]}], ",", 
                   RowBox[{
                    StyleBox[
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Bad order\>\"", ",", 
                    RowBox[{"t", "[", 
                    RowBox[{"[", "r", "]"}], "]"}]}], "}"}], "]"}],
                    FontColor->RGBColor[1, 0, 1]], ";", 
                    RowBox[{"Throw", "[", "Null", "]"}]}]}], "]"}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Length", "[", 
                    RowBox[{"Complement", "[", 
                    RowBox[{
                    RowBox[{"Union", "[", 
                    RowBox[{"lhs", ",", "rhs"}], "]"}], ",", "cr"}], "]"}], 
                    "]"}], ">", "0"}], ",", 
                   RowBox[{
                    StyleBox[
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Unknown Relator \>\"", ",", 
                    RowBox[{"t", "[", 
                    RowBox[{"[", "r", "]"}], "]"}], ",", "cr"}], "}"}], "]"}],
                    
                    FontColor->RGBColor[1, 0, 1]], 
                    StyleBox[";",
                    FontColor->RGBColor[1, 0, 1]], 
                    RowBox[{"Throw", "[", "Null", "]"}]}]}], "]"}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"j", "=", 
                  RowBox[{"Length", "[", 
                   RowBox[{"Position", "[", 
                    RowBox[{
                    RowBox[{"Characters", "[", 
                    RowBox[{"t", "[", 
                    RowBox[{"[", 
                    RowBox[{"r", ",", "k"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"cr", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], ";", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"GCD", "[", 
                    RowBox[{"j", ",", 
                    RowBox[{"IntegerPart", "[", 
                    RowBox[{"gp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "]"}], ">", 
                    "1"}], "&&", 
                    RowBox[{"j", "\[NotEqual]", "0"}], "&&", 
                    RowBox[{"j", "\[NotEqual]", 
                    RowBox[{"IntegerPart", "[", 
                    RowBox[{"gp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}]}]}], ",", 
                   RowBox[{
                    StyleBox[
                    RowBox[{"Print", "[", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Bad GCD \>\"", ",", "j", ",", 
                    RowBox[{"gp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"t", "[", 
                    RowBox[{"[", "r", "]"}], "]"}]}], "}"}], "]"}],
                    FontColor->RGBColor[1, 0, 1]], 
                    StyleBox[";",
                    FontColor->RGBColor[1, 0, 1]], 
                    RowBox[{"Throw", "[", "Null", "]"}]}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "2"}], "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"r", ",", 
                RowBox[{"Length", "[", "t", "]"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Length", "[", "gp", "]"}]}], "}"}]}], "]"}]}], "]"}], 
        ";", 
        RowBox[{"strep", "=", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         StyleBox[
          RowBox[{"(*", 
           RowBox[{"i", " ", 
            RowBox[{"loop", ".", " ", "Add"}], " ", "the", " ", "rules", " ", 
            "to", " ", "reduce", " ", "repetitions"}], "*)"}],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          RowBox[{
           RowBox[{"st", "=", 
            RowBox[{"cr", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ";", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"t", ",", 
             RowBox[{
              RowBox[{"Do", "[", 
               RowBox[{
                RowBox[{"st", "=", 
                 RowBox[{"st", "<>", 
                  RowBox[{"cr", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"IntegerPart", "[", 
                   RowBox[{"gp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "-", "1"}], 
                 "}"}]}], "]"}], ";", 
              RowBox[{"Rule", "[", 
               RowBox[{"st", ",", "\"\<\>\""}], "]"}]}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "le"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         StyleBox[
          RowBox[{"(*", 
           RowBox[{"i", ",", 
            RowBox[{"j", " ", 
             RowBox[{"loops", ".", " ", "Add"}], " ", "abelianQ", " ", 
             "rules"}]}], "*)"}],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          RowBox[{
           RowBox[{"new", "=", 
            RowBox[{"Rule", "[", 
             RowBox[{
              RowBox[{"lh", "=", 
               RowBox[{
                RowBox[{"cr", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "<>", 
                RowBox[{"cr", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
              RowBox[{
               RowBox[{"cr", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "<>", 
               RowBox[{"cr", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}]}], ";", 
           RowBox[{"Do", "[", 
            StyleBox[
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"k", " ", "loop"}], ",", " ", 
               RowBox[{"redundant", " ", "rules"}]}], "*)"}],
             FontColor->RGBColor[0, 0, 1]], 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"lh", "\[Equal]", 
                RowBox[{"t", "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"new", "=", "\"\<\>\""}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", 
               RowBox[{
                RowBox[{"Length", "[", "t", "]"}], "-", "1"}]}], "}"}]}], 
            "]"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Length", "[", "new", "]"}], "\[Equal]", "2"}], ",", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"t", ",", "new"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "le"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", 
            RowBox[{"i", "+", "1"}], ",", "le"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         StyleBox[
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"i", " ", "loop"}], ",", 
            RowBox[{
             RowBox[{"symbols", ".", " ", "Build"}], " ", "the", " ", 
             "element", " ", "list"}]}], "*)"}],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          RowBox[{
           RowBox[{"si", "=", 
            RowBox[{"cr", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], ";", 
           RowBox[{"sij", "=", "si"}], ";", 
           RowBox[{"p", "=", 
            RowBox[{
             RowBox[{"IntegerPart", "[", 
              RowBox[{"gp", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "-", "1"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Do", "[", 
            StyleBox[
             RowBox[{"(*", 
              RowBox[{"j", " ", 
               RowBox[{"loop", ".", "Repetitions"}]}], "*)"}],
             FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"Do", "[", 
               StyleBox[
                RowBox[{"(*", 
                 RowBox[{
                  RowBox[{"k", " ", "loop"}], ",", 
                  RowBox[{
                   RowBox[{"new", " ", "element"}], "=", 
                   RowBox[{"j", " ", "repeats", " ", "of", " ", 
                    RowBox[{"k", "'"}], "th", " ", "existing", " ", 
                    "element"}]}]}], "*)"}],
                FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"AppendTo", "[", 
                 RowBox[{"n", ",", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"k", "\[Equal]", "1"}], ",", "sij", ",", 
                    RowBox[{
                    RowBox[{"n", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], "<>", "sij"}]}], "]"}]}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "ln"}], "}"}]}], "]"}], ";", 
              RowBox[{"sij", "=", 
               RowBox[{"sij", "<>", "si"}]}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "p"}], "}"}]}], "]"}], ";", 
           RowBox[{"ln", "=", 
            RowBox[{"Length", "[", "n", "]"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "le"}], "}"}]}], "]"}], ";", 
        StyleBox[
         RowBox[{"(*", 
          RowBox[{"element", " ", "list", " ", "completed"}], "*)"}],
         FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"g", ",", 
            StyleBox[
             RowBox[{"(*", 
              RowBox[{"add", " ", "successive", " ", 
               RowBox[{
                RowBox[{"n", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "<>", "n"}], " ", "rows", 
               " ", "to", " ", "g"}], "*)"}],
             FontColor->RGBColor[0, 0, 1]], 
            RowBox[{"MapThread", "[", 
             RowBox[{"StringJoin", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"n", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "ln"}], "}"}]}], "]"}], ",", "n"}], 
               "}"}]}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "ln"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"g", "=", 
         RowBox[{"matstrep", "[", 
          RowBox[{"g", ",", "t"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"o", "==", "0"}], ",", 
          RowBox[{
           RowBox[{"genel", "=."}], ";", 
           RowBox[{"matel", "=."}], ";", 
           RowBox[{"strep", "=."}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"genel", "=", 
            RowBox[{"n", "/.", 
             RowBox[{"\"\<\>\"", "\[Rule]", "1"}]}]}], ";", 
           RowBox[{"matel", "=", 
            RowBox[{"g", "/.", 
             RowBox[{"\"\<\>\"", "\[Rule]", "1"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"o", "<", "0"}], ",", 
             StyleBox[
              RowBox[{"(*", 
               RowBox[{"Noncommutative", " ", "mods"}], "*)"}],
              FontColor->RGBColor[0, 0, 1]], 
             RowBox[{
              RowBox[{"ClearAllOperators", "[", "]"}], ";", 
              RowBox[{"SetOperators", "[", 
               RowBox[{"Drop", "[", 
                RowBox[{"genel", ",", "1"}], "]"}], "]"}]}]}], "]"}], ";", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{"Do", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"st", "=", 
                 RowBox[{"Rule", "[", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"o", "<", "0"}], ",", 
                    RowBox[{
                    RowBox[{"matel", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "**", " ", 
                    RowBox[{"matel", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "j"}], "]"}], "]"}]}], ",", 
                    RowBox[{"Diamond", "[", 
                    RowBox[{
                    RowBox[{"matel", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"matel", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "j"}], "]"}], "]"}]}], "]"}]}], "]"}], 
                   ",", " ", 
                   RowBox[{"matel", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}]}], ";", 
                RowBox[{"If", "[", " ", 
                 RowBox[{
                  RowBox[{"MemberQ", "[", 
                   RowBox[{"strep", ",", "st"}], "]"}], ",", ",", 
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"strep", ",", "st"}], "]"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "2", ",", "ln"}], "}"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"i", ",", "2", ",", "ln"}], "}"}]}], "]"}]}]}], "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"g", "=", 
         RowBox[{"caylindex", "[", "g", "]"}]}], ";", 
        StyleBox[
         RowBox[{"(*", 
          RowBox[{"Convert", " ", "to", " ", "a", " ", "signed", " ", 
           RowBox[{"table", "?"}]}], "*)"}],
         FontColor->RGBColor[0, 0, 1]], 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"IntegerQ", "[", 
            RowBox[{"ln", "=", 
             RowBox[{"Last", "[", "gp", "]"}]}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"le", "=", 
            RowBox[{
             RowBox[{"Length", "[", "g", "]"}], "/", "ln"}]}], ";", 
           RowBox[{"g", "=", 
            RowBox[{"ts", "[", 
             RowBox[{"g", ",", 
              RowBox[{"IntegerPart", "[", "ln", "]"}]}], "]"}]}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"o", "\[NotEqual]", "0"}], ",", 
             RowBox[{
              RowBox[{"genel", "=", 
               RowBox[{"Take", "[", 
                RowBox[{"genel", ",", "le"}], "]"}]}], ";", 
              RowBox[{"matel", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{"Take", "[", 
                 RowBox[{
                  RowBox[{"Transpose", "[", 
                   RowBox[{"Take", "[", 
                    RowBox[{"matel", ",", "le"}], "]"}], "]"}], ",", "le"}], 
                 "]"}], "]"}]}]}]}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", "o", "]"}], "\[NotEqual]", "0"}], ",", 
          StyleBox[
           RowBox[{"(*", 
            RowBox[{"Report", " ", "properties"}], "*)"}],
           FontColor->RGBColor[0, 0, 1]], 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"loopQ", "[", "g", "]"}], ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"associativeQ", "[", 
               RowBox[{"g", ",", "1"}], "]"}], ",", "g", ",", 
              RowBox[{
               StyleBox[
                RowBox[{"Print", "[", "\"\<Non-associative\>\"", "]"}],
                FontColor->RGBColor[0, 1, 0]], ";", "g"}]}], "]"}], ",", 
            StyleBox[
             RowBox[{"Print", "[", "\"\<Not a quasigroup\>\"", "]"}],
             FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"glo", "=", "g"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"cl", "[", 
      RowBox[{"p_Integer", ",", 
       RowBox[{"q_:", "0"}]}], "]"}], ":=", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"CliffordG", ".", "m"}], " ", "implements", " ", "a", " ", 
       "Geometric", " ", "Algebra", " ", "version"}], " ", "*)"}], " ", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"g", ",", "l", ",", 
         RowBox[{"n", "=", "q"}], ",", 
         RowBox[{"ng", "=", 
          RowBox[{"Length", "[", "gr", "]"}]}], ",", "o", ",", "result", ",", 
         "z"}], "}"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"IntegerQ", "[", "n", "]"}], ",", 
          RowBox[{"o", "=", 
           RowBox[{"Complement", "[", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"p", "+", "q"}], "]"}], ",", 
             RowBox[{"Range", "[", "q", "]"}]}], "]"}]}], ",", 
          StyleBox[
           RowBox[{"(*", " ", 
            RowBox[{"no", ",", " ", 
             RowBox[{
             "extract", " ", "negative", " ", "squares", " ", "from", " ", 
              "list", " ", 
              RowBox[{"{", "n", "}"}]}]}], " ", "*)"}],
           FontColor->RGBColor[0, 0, 1]], " ", 
          RowBox[{
           RowBox[{"o", "=", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", "p", "]"}], ",", "q"}], "]"}]}], ";", 
           RowBox[{"n", "=", "0"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"l", "=", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"p", "+", "n"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"g", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"IntegerDigits", "[", 
            RowBox[{"i", ",", "2", ",", 
             RowBox[{"p", "+", "n"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"l", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
        StyleBox[
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"binary", " ", "form", " ", "for", " ", "indices", " ", 
             RowBox[{"e", ".", "g", ".", " ", "if"}], " ", "l"}], "=", "8"}], 
           ",", " ", 
           RowBox[{"index", " ", "6", " ", "becomes", " ", 
            RowBox[{"{", 
             RowBox[{"1", ",", "1", ",", "0"}], "}"}]}]}], " ", "*)"}],
         FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
        RowBox[{"result", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"walsh", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"g", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "*", 
               RowBox[{"g", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], ",", "o"}], "]"}], "*", 
            RowBox[{"walsh", "[", 
             RowBox[{
              RowBox[{"g", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "*", 
              RowBox[{"grayinv", "[", 
               RowBox[{"g", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "]"}], "*", 
            "\[IndentingNewLine]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"FromDigits", "[", 
               RowBox[{
                RowBox[{"Mod", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"g", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "+", 
                   RowBox[{"g", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], ",", "2"}], "]"}], ",", 
                "2"}], "]"}], " ", "+", "1"}], ")"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"j", ",", "l"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "result"}]}], "]"}]}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"clf", "[", 
    RowBox[{"cp_Integer", ",", 
     RowBox[{"cq_:", "0"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"cLength", "=", 
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"cp", "+", "cq"}], ")"}]}]}], ",", 
       RowBox[{"pt", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          SuperscriptBox["2", "i"], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"cp", "+", "1"}], ",", 
            RowBox[{"cp", "+", "cq"}]}], "}"}]}], "]"}]}], ",", "a", ",", 
       "b"}], "}"}], ",", 
     RowBox[{
      RowBox[{"edig", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "=", 
          RowBox[{"Reverse", "[", 
           RowBox[{"IntegerDigits", "[", 
            RowBox[{"j", ",", "2"}], "]"}], "]"}]}], ";", 
         RowBox[{"b", "=", 
          RowBox[{"{", "}"}]}], ";", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"a", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "\[NotEqual]", "0"}], ",", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"b", ",", 
               RowBox[{
                RowBox[{"a", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", 
                RowBox[{"2", "^", "i"}]}]}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "a", "]"}]}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"edig", ",", "b"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          StyleBox["0",
           FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
           FontColor->RGBColor[1, 0, 0]], 
          SuperscriptBox["2", 
           RowBox[{"cp", "+", "cq", "+", "1"}]]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"a", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{"i", "\[Equal]", "1"}], ",", "j", ",", 
           RowBox[{"j", "\[Equal]", "1"}], ",", "i", ",", 
           "\[IndentingNewLine]", 
           RowBox[{"i", "\[Equal]", "j"}], ",", 
           RowBox[{
            RowBox[{"Signature", "[", 
             RowBox[{"Flatten", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"edig", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"edig", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "+", "1"}]}], "}"}], "]"}], 
             "]"}], "*", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"OddQ", "[", 
               RowBox[{"Length", "[", 
                RowBox[{"Intersection", "[", 
                 RowBox[{"pt", ",", 
                  RowBox[{"edig", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], ",",
               
              RowBox[{"-", "1"}], ",", "1"}], "]"}]}], ",", 
           "\[IndentingNewLine]", "True", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"BitXor", "[", 
               RowBox[{
                RowBox[{"i", "-", "1"}], ",", 
                RowBox[{"j", "-", "1"}]}], "]"}], "+", "1"}], ")"}], 
            RowBox[{"Signature", "[", 
             RowBox[{"Flatten", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"edig", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"edig", "[", 
                  RowBox[{"[", "j", "]"}], "]"}], "+", "1"}]}], "}"}], "]"}], 
             "]"}], 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"OddQ", "[", 
               RowBox[{"Length", "[", 
                RowBox[{"Intersection", "[", 
                 RowBox[{"pt", ",", 
                  RowBox[{"edig", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], ",", 
                  RowBox[{"edig", "[", 
                   RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], "]"}], ",",
               
              RowBox[{"-", "1"}], ",", "1"}], "]"}]}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"i", ",", "cLength"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "cLength"}], "}"}]}], "]"}]}], ";", "a"}]}], 
    "]"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", "g_String", "}"}], "]"}], ":=", 
   RowBox[{"ToExpression", "[", "g", "]"}]}], ";", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"{", "1", "}"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", "2", "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", 
     RowBox[{"-", "2"}], "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "3"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", "2.", "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", "3", "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "}"}]}], 
  RowBox[{"(*", "C3", "*)"}], ";", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", "3.", "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", 
     RowBox[{"-", "3"}], "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "2"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", "4", "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1", ",", "2", ",", "3"}], "}"}]}], "}"}]}], 
  RowBox[{"(*", "C4", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", "4.", "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}], ",", "1", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", 
     RowBox[{"-", "4"}], "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}], ",", "1", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}], ",", "3"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", 
     RowBox[{"-", "4."}], "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}]}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cd", "[", 
   RowBox[{"{", "gamma__", "}"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", "=", 
       RowBox[{"Last", "[", 
        RowBox[{"{", "gamma", "}"}], "]"}]}], ",", "n", ",", "q", ",", "r", 
      ",", 
      StyleBox[
       RowBox[{"(*", "Recursion", "*)"}],
       FontColor->RGBColor[0, 1, 1]], 
      StyleBox[
       RowBox[{"m", "=", 
        RowBox[{"cd", "[", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"{", "gamma", "}"}], ",", 
           RowBox[{"-", "1"}]}], "]"}], "]"}]}],
       FontColor->RGBColor[0, 1, 1]]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"q", "=", 
      RowBox[{"Length", "[", "m", "]"}]}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"IntegerPart", "[", "l", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"ListQ", "[", "l", "]"}], ",", 
       RowBox[{"co", "[", 
        RowBox[{"m", ",", 
         RowBox[{"ca", "[", "l", "]"}]}], "]"}], 
       StyleBox[
        RowBox[{"(*", 
         RowBox[{"compose", " ", "with", " ", "group"}], "*)"}],
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox[",",
        FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
       RowBox[{"StringQ", "[", "l", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"co", "[", 
        RowBox[{"m", ",", 
         RowBox[{"ToExpression", "[", "l", "]"}]}], "]"}], "          ", 
       StyleBox[
        RowBox[{"(*", 
         RowBox[{"compose", " ", "with", " ", "hoop"}], "*)"}],
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox[",",
        FontColor->GrayLevel[0]], "\[IndentingNewLine]", "True", 
       "                                                 ", 
       StyleBox[
        RowBox[{"(*", " ", 
         RowBox[{"new", " ", "relator"}], "*)"}],
        FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"i", "\[LessEqual]", "q"}], "&&", 
            RowBox[{"j", "\[LessEqual]", "q"}]}], ",", 
           RowBox[{"m", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}], 
           StyleBox[
            RowBox[{"(*", " ", 
             RowBox[{"Top", "-", "left"}], " ", "*)"}],
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
           RowBox[{"i", "\[LessEqual]", "q"}], ",", 
           RowBox[{"modqr", "[", 
            RowBox[{"q", ",", 
             RowBox[{"m", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"j", "-", "q"}], ",", "i"}], "]"}], "]"}]}], "]"}], 
           "          ", 
           StyleBox[
            RowBox[{"(*", " ", 
             RowBox[{"Top", "-", "right"}], " ", "*)"}],
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
           RowBox[{"j", "\[LessEqual]", "q"}], ",", 
           RowBox[{
            RowBox[{"r", "=", 
             RowBox[{"m", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"i", "-", "q"}], ",", "j"}], "]"}], "]"}]}], ";", 
            "                     ", 
            StyleBox[
             RowBox[{"(*", " ", 
              RowBox[{"Bottom", " ", "left"}], "*)"}],
             FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
            RowBox[{"Which", "[", " ", 
             RowBox[{
              RowBox[{"!", 
               RowBox[{"IntegerQ", "[", "l", "]"}]}], ",", 
              RowBox[{"modqr", "[", 
               RowBox[{"q", ",", "r"}], "]"}], 
              StyleBox[
               RowBox[{"(*", " ", 
                RowBox[{"simple", ",", " ", 
                 RowBox[{"real", " ", "l"}]}], " ", "*)"}],
               FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
              RowBox[{"j", "\[NotEqual]", "1"}], ",", 
              RowBox[{"n", " ", 
               RowBox[{"modqr", "[", 
                RowBox[{"q", ",", "r"}], "]"}]}], "       ", 
              StyleBox[
               RowBox[{"(*", " ", 
                RowBox[{
                "negate", " ", "all", " ", "but", " ", "col", " ", "1"}], " ",
                 "*)"}],
               FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
              "True", ",", 
              RowBox[{"q", "+", 
               RowBox[{"Abs", "[", "r", "]"}]}]}], "]"}]}], "            ", 
           StyleBox[
            RowBox[{"(*", " ", 
             RowBox[{"shift", " ", "by", " ", "default"}], "*)"}],
            FontColor->RGBColor[0, 0, 1]], " ", 
           StyleBox[",",
            FontColor->GrayLevel[0]], "\[IndentingNewLine]", "True", ",", 
           RowBox[{
            RowBox[{"r", "=", 
             RowBox[{"m", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"j", "-", "q"}], ",", 
                RowBox[{"i", "-", "q"}]}], "]"}], "]"}]}], "      ", 
            StyleBox[
             RowBox[{"(*", " ", 
              RowBox[{
               RowBox[{"Bottom", "-", 
                RowBox[{"right", " ", "i"}]}], ",", 
               RowBox[{"j", ">", "q"}]}], "*)"}],
             FontColor->RGBColor[0, 0, 1]], 
            StyleBox[";",
             FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"IntegerQ", "[", "l", "]"}], "&&", 
               RowBox[{"j", "\[NotEqual]", 
                RowBox[{"q", "+", "1"}]}], "&&", 
               RowBox[{"q", ">", "1"}]}], ",", " ", "r", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"n", " ", "r"}]}], 
             StyleBox[
              RowBox[{"(*", " ", 
               RowBox[{
               "negate", " ", "all", " ", "but", " ", "col", " ", "1", " ", 
                "if", " ", "l", " ", "negative", " ", "real"}], "*)"}],
              FontColor->RGBColor[0, 0, 1]], "]"}]}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"2", "q"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"2", "q"}]}], "}"}]}], "]"}]}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"modqr", "[", 
   RowBox[{"q_", ",", "r_", ",", 
    RowBox[{"s_:", "2"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"q", "+", 
          RowBox[{"Abs", "[", "r", "]"}]}], ")"}], "-", "1"}], ",", 
       RowBox[{"s", " ", "q"}]}], "]"}], "+", "1"}], ")"}], 
   RowBox[{"Sign", "[", "r", "]"}]}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[TextData[{
 "Cayley-Dickson Doubling Procedure ",
 StyleBox["cd",
  FontSlant->"Italic"],
 ". The classic procedure started with reals with \"-\"\[Times]\"-\"=\"+\" \
and successively introduced new relators i,j,k... that square to -1 and \
anti-commute with earlier relators, thereby defining A\[Times]A\[RightArrow]B \
with a specific multiplication rule. This gives \[DoubleStruckCapitalR]\
\[Times]\[DoubleStruckCapitalR]\[RightArrow]\[DoubleStruckCapitalC], \
\[DoubleStruckCapitalC]\[Times]\[DoubleStruckCapitalC]\[RightArrow]\
\[DoubleStruckCapitalH], \[DoubleStruckCapitalH]\[Times]\
\[DoubleStruckCapitalH]\[RightArrow]\[DoubleStruckCapitalO], \
\[DoubleStruckCapitalO]\[Times]\[DoubleStruckCapitalO]\[RightArrow]Sed, etc. \
The procedure is implemented in ",
 StyleBox["cd",
  FontSlant->"Italic"],
 ", with a list of the squares of the relators as argument. Hence cd[{-1}] \
gives the signed index table for \[DoubleStruckCapitalC] (called C4c), \
cd[{-1,-1}] gives \[DoubleStruckCapitalH] (called Qr), cd[{-1,-1,-1}] gives \
\[DoubleStruckCapitalO] (called Octr), cd[{-1,-1,-1,-1}] gives Sedenions \
(called Sed).  Commutativity is lost on going to \[DoubleStruckCapitalH], \
associativity is lost on going to \[DoubleStruckCapitalO], \
square-associativity and the Moufang property are lost on going to Sed. These \
algebras have symbolic multiplication tables with determinants that factorize \
into the sum of the squares of their elements. The factors are conserved \
functions (and denominators for vector inverses) for \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], and \
\[DoubleStruckCapitalO], which are \"real algebras without divisors of zero\" \
because the denominator is only zero in the trivial (real) case. Sed is not \
conservative.\nThis procedure was generalized by Schafer to allow new \
elements that square to +1. This is implemented by providing arguments that \
are 1; cd[{1,1}] gives Study numbers; cd[{1,-1}] gives Clifford(2); \
cd[{-1,1}], cd[{-1,1,1}], cd[{-1,1,1,1}] and cd[{-1,1,1,1,1}] give O2, O4, O8 \
& O16, i.e. algebras that consist of 2, 4, 8, and 16 copies of the complex \
plane.\nI realised that there is a prior stage, in which unsigned numbers are \
doubled to give real numbers. This is included in the procedure, so cd[{}] \
and cd[{1}] give the C1 & C2 groups, corresponding to Primal & Real numbers.\n\
A few more hoops can be created by negating parts of the lower half of the \
table. This is implemented by using reals, \"1.\" or \"-1.\" but often gives \
non-conservative tables.\nI then realized that other tables could be doubled. \
This was implemented by providing a list of predefined tables and (later) \
\"",
 StyleBox["cd[{g_String}] =ToExpression[g];",
  FontSlant->"Italic"],
 "\" to allow any loop incantation to be used as an optional first relator. \n\
As ",
 StyleBox["cd",
  FontSlant->"Italic"],
 " created signed tables, it was further modified to compose the table with a \
cyclic group Cn by (optionally) making the final relators ",
 StyleBox["{n}",
  FontSlant->"Italic"],
 " or \"",
 StyleBox["loopname",
  FontSlant->"Italic"],
 "\". (Only the ",
 StyleBox["{n}",
  FontSlant->"Italic"],
 " format is acceptable in the ",
 StyleBox["loop[[]]",
  FontSlant->"Italic"],
 " lists as \"\" cannot be used there.) This gives the parent loops of the \
signed tables.\nAnother modification, Moufang doubling ",
 StyleBox["md,",
  FontSlant->"Italic"],
 " implements the creation of some Moufang Loops, described in the Wikipedia \
Moufang Loop article and implemented in the GAP Loop package. It reproduces \
13 of the D3Mn etc tables from GAP Loop package:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "md", "]"}], ";", 
  RowBox[{
   RowBox[{"md", "[", 
    RowBox[{
     RowBox[{"g_", "?", "MatrixQ"}], ",", 
     RowBox[{"l_:", 
      RowBox[{"{", "}"}]}]}], "]"}], 
   StyleBox[
    RowBox[{"(*", 
     RowBox[{"From", " ", "Loop", " ", "in", " ", "GAP"}], "*)"}],
    FontColor->RGBColor[0, 0, 1]], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"Length", "[", "g", "]"}]}], ",", 
       RowBox[{"gin", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"l", "\[Equal]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{"gInverse", "[", "g", "]"}], ",", "l"}], "]"}]}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"res", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"2", "m"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"2", "m"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
            RowBox[{"g", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}]}], 
           StyleBox[
            RowBox[{"(*", " ", 
             RowBox[{"Top", "-", 
              RowBox[{"left", " ", "g"}]}], " ", "*)"}],
            FontColor->RGBColor[0, 0, 1]], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", 
               RowBox[{"j", "+", "m"}]}], "]"}], "]"}], "=", 
            RowBox[{
             RowBox[{"g", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "i"}], "]"}], "]"}], "+", "m"}]}], 
           StyleBox[
            RowBox[{"(*", " ", 
             RowBox[{"Top", "-", 
              RowBox[{"right", " ", 
               SuperscriptBox["g", "T"]}], "+", "m"}], "*)"}],
            FontColor->RGBColor[0, 0, 1]], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"i", "+", "m"}], ",", "j"}], "]"}], "]"}], "=", 
            RowBox[{
             RowBox[{"g", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", 
                RowBox[{"gin", "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], "+", "m"}]}],
            
           StyleBox[
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"Bottom", " ", "left", " ", "g"}], "+", 
              RowBox[{"m", " ", "reordered"}]}], "*)"}],
            FontColor->RGBColor[0, 0, 1]], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"i", "+", "m"}], ",", 
               RowBox[{"j", "+", "m"}]}], "]"}], "]"}], "=", 
            RowBox[{"g", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"gin", "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", "i"}], "]"}], "]"}]}]}], 
          
          StyleBox[
           RowBox[{"(*", " ", 
            RowBox[{"Bottom", " ", "right", " ", 
             SuperscriptBox["g", "T"], " ", "reordered"}], "*)"}],
           FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", "m"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "m"}], "}"}]}], "]"}], ";", "res"}]}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.7 Groups from Permutations, ",
  FontFamily->"Arial"],
 StyleBox["pe.",
  FontFamily->"Arial",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pe", "[", 
   RowBox[{"mm_", ",", 
    RowBox[{"maxel_:", "72"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"g", "=", 
       RowBox[{"{", 
        RowBox[{"Range", "[", 
         RowBox[{"Max", "[", 
          RowBox[{"Flatten", "[", "mm", "]"}], "]"}], "]"}], "}"}]}], ",", 
      "i", ",", "j", ",", "k", ",", "n", ",", 
      RowBox[{"o", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"permel", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Depth", "[", "mm", "]"}], "<", "3"}], ",", 
       RowBox[{
        StyleBox[
         RowBox[{"Print", "[", 
          RowBox[{
          "mm", ",", "\"\<is not a list of permutations or cycles\>\""}], 
          "]"}],
         FontColor->RGBColor[1, 0, 1]], ";", 
        RowBox[{"Goto", "[", "tag", "]"}]}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{"mm", ",", 
         RowBox[{"g", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{
        StyleBox[
         RowBox[{"Print", "[", 
          RowBox[{
           RowBox[{"g", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< unacceptable\>\""}], 
          "]"}],
         FontColor->RGBColor[1, 0, 1]], ";", 
        RowBox[{"Goto", "[", "tag", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"j", "=", 
         RowBox[{"mm", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", 
        RowBox[{"k", "=", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"VectorQ", "[", "j", "]"}], ",", "j", ",", 
           RowBox[{"fromCycles", "[", "j", "]"}]}], "]"}]}], ";", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"g", ",", "k"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "mm", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"j", "=", "2"}], ";", 
     RowBox[{"k", "=", "1"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"j", "\[LessEqual]", 
        RowBox[{"Length", "[", "g", "]"}]}], ",", 
       RowBox[{
        RowBox[{"k", "++"}], ";", 
        RowBox[{"n", "=", 
         RowBox[{"permute", "[", 
          RowBox[{
           RowBox[{
           "g", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
           "g", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}]}], 
          "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"(", 
            RowBox[{"MemberQ", "[", 
             RowBox[{"g", ",", "n"}], "]"}], ")"}]}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"g", ",", "n"}], "]"}]}], "]"}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"k", "\[GreaterEqual]", 
           RowBox[{"Length", "[", "g", "]"}]}], ",", 
          RowBox[{
           RowBox[{"k", "=", "1"}], ";", 
           RowBox[{"j", "++"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"j", ">", 
              RowBox[{"maxel", "+", "1"}]}], ",", 
             RowBox[{
              RowBox[{"Print", "[", "\"\<Large\>\"", "]"}], ";", 
              RowBox[{"i", "=", 
               RowBox[{"l", "+", "1"}]}], ";", 
              RowBox[{"j", "=", 
               RowBox[{"l", "+", "1"}]}], ";", 
              RowBox[{"i", "=", "0"}], ";", 
              RowBox[{"mm", "=", "0"}], ";", 
              RowBox[{"nn", "=", "0"}], ";", 
              RowBox[{"Goto", "[", "tag", "]"}]}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", 
     RowBox[{"permel", "=", "g"}], ";", 
     RowBox[{"o", "=", 
      RowBox[{"caylindex", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"permute", "[", 
          RowBox[{
           RowBox[{
           "g", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
           "g", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", "g", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"Length", "[", "g", "]"}]}], "}"}]}], "]"}], "]"}]}], ";", 
     
     RowBox[{"Label", "[", "tag", "]"}], ";", 
     RowBox[{"glo", "=", "o"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.8 MatrixGroups using extended signs, ",
  FontFamily->"Arial"],
 StyleBox["ma, mg, ms",
  FontFamily->"Arial",
  FontSlant->"Italic"],
 StyleBox[".",
  FontFamily->"Arial"],
 StyleBox[" ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ma", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"mm__", "?", "MatrixQ"}], "}"}], ",", 
    RowBox[{"maxel_:", "73"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"{", "mm", "}"}]}], ",", "mi", ",", "g", ",", 
      RowBox[{"j", "=", "2"}], ",", 
      RowBox[{"k", "=", "1"}], ",", 
      RowBox[{"mx", "=", "2"}], ",", "n"}], "}"}], ",", 
    RowBox[{
     RowBox[{"mi", "=", 
      RowBox[{"minsign", "[", "m", "]"}]}], ";", 
     RowBox[{"g", "=", 
      RowBox[{"union", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"IdentityMatrix", "[", 
          RowBox[{"Length", "[", 
           RowBox[{
           "m", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "]"}],
           "]"}], ",", "mm"}], "}"}], "]"}]}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"j", "\[LessEqual]", 
        RowBox[{"Length", "[", "g", "]"}]}], ",", 
       RowBox[{
        RowBox[{"k", "++"}], ";", 
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{
           RowBox[{
           "g", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ".", 
           RowBox[{
           "g", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}]}], "/.",
           "mi"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", "\[InvisibleSpace]", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"(", 
            RowBox[{"MemberQ", "[", 
             RowBox[{"g", ",", "n"}], "]"}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"g", ",", "n"}], "]"}], ";", 
           RowBox[{"mx", "++"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"mx", ">", "maxel"}], ",", 
             RowBox[{
              RowBox[{"k", "=", "9999"}], ";", 
              RowBox[{"j", "=", "mx"}]}]}], "]"}]}]}], "]"}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"k", "\[GreaterEqual]", 
           RowBox[{"Length", "[", "g", "]"}]}], ",", 
          RowBox[{
           RowBox[{"k", "=", "1"}], ";", 
           RowBox[{"j", "++"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"j", ">", "maxel"}], ",", 
             RowBox[{
              RowBox[{"matel", "=", 
               RowBox[{"{", "}"}]}], ";", 
              RowBox[{"g", "=", 
               RowBox[{"{", 
                RowBox[{"{", "}"}], "}"}]}], ";", 
              RowBox[{"Goto", "[", "tag", "]"}]}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", 
     RowBox[{"matel", "=", "g"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"o", "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"g", "=", 
         RowBox[{"caylindex", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "g", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              ".", 
              RowBox[{
              "g", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}], "/.",
              "\[InvisibleSpace]", "mi"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Length", "[", "g", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"Length", "[", "g", "]"}]}], "}"}]}], "]"}], "]"}]}], 
        ";", 
        RowBox[{"glo", "=", "g"}]}]}], "]"}], ";", 
     RowBox[{"Label", "[", "tag", "]"}], ";", "g"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mg", "[", 
   RowBox[{
    RowBox[{"v_", "?", "VectorQ"}], ",", "u_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"ma", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"[", 
           RowBox[{"Abs", "[", 
            RowBox[{"v", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "]"}], 
         RowBox[{"Sign", "[", 
          RowBox[{"v", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "v", "]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"mm", "+", "1"}]}], "]"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"ms", "[", 
   RowBox[{
    RowBox[{"v__", "?", "ListQ"}], ",", 
    RowBox[{"u_:", "u2"}], ",", 
    RowBox[{"maxel_:", "64"}]}], "]"}], ":=", 
  RowBox[{"(*", 
   RowBox[{"Version", " ", "2", "s"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gg", ",", "gij", ",", 
      RowBox[{"i", "=", "2"}], ",", 
      RowBox[{"j", "=", "2"}], ",", "l", ",", "mi", ",", "new", ",", "n", ",",
       "p", ",", "s", ",", 
      RowBox[{"tot", "=", "0"}], ",", 
      RowBox[{"m", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"VectorQ", "[", "v", "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Sign", "[", 
             RowBox[{"v", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], 
            RowBox[{"u", "[", 
             RowBox[{"[", 
              RowBox[{"Abs", "[", 
               RowBox[{"v", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "v", "]"}]}], "}"}]}], "]"}], ",", "v"}], 
        "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"s", "=", 
      RowBox[{"Union", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{
         RowBox[{"Variables", "[", "m", "]"}], "\[Intersection]", 
         "signlist"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MatrixQ", "[", 
         RowBox[{"m", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "True"}], ",", ",", 
       RowBox[{
        RowBox[{"Print", "[", " ", "\"\<Not a list or matrix\>\"", "]"}], ";",
         
        RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"l", "=", 
      RowBox[{"Length", "[", 
       RowBox[{"m", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", 
     RowBox[{"n", "=", 
      RowBox[{
       RowBox[{"Length", "[", "m", "]"}], "+", "1"}]}], ";", 
     RowBox[{"matel", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{"m", ",", 
        RowBox[{"IdentityMatrix", "[", "l", "]"}]}], "]"}]}], ";", 
     RowBox[{"mi", "=", 
      StyleBox[
       RowBox[{"minsign", "[", "matel", "]"}],
       FontColor->RGBColor[1, 0, 0]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"j", "=", "2"}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"new", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"matel", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ".", 
              RowBox[{"matel", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "/.", "mi"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"mstst", "[", 
               RowBox[{"new", ",", "s"}], "]"}], "\[Equal]", "0"}], ",", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"matel", ",", "new"}], "]"}]}], "]"}], ";", 
           RowBox[{"tot", "++"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "matel", "]"}], ">", "maxel"}], "||", 
              RowBox[{"tot", ">", 
               RowBox[{"4", " ", "maxel"}]}]}], ",", 
             RowBox[{
              RowBox[{"Print", "[", "matel", "]"}], ";", 
              RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"j", "<", 
            RowBox[{"Length", "[", "matel", "]"}]}]}], ",", 
          RowBox[{"j", "++"}]}], "]"}], ";", 
        RowBox[{"i", "<", 
         RowBox[{"Length", "[", "matel", "]"}]}]}], ",", 
       RowBox[{"i", "++"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "matel", "]"}]}], ";", 
     RowBox[{"gg", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"matel", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ".", 
          RowBox[{"matel", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "/.", "mi"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"gij", "=", 
         RowBox[{"gg", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ";", 
        RowBox[{"p", "=", 
         RowBox[{"mstst", "[", 
          RowBox[{"gij", ",", "s"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"gg", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
         RowBox[{"p", " ", 
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"matel", ",", 
             RowBox[{"p", " ", "gij"}]}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "n"}], "}"}]}], "]"}], ";", 
     RowBox[{"glo", "=."}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"indexTableQ", "[", "gg", "]"}], "==", "True"}], ",", 
       RowBox[{"glo", "=", "gg"}]}], "]"}], ";", "glo"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mstst", "[", 
    RowBox[{"m_", ",", "s_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"i", "=", "0"}], ",", 
       RowBox[{"l", "=", 
        RowBox[{"Length", "[", "s", "]"}]}], ",", 
       RowBox[{"res", "=", "0"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i", "<", "l"}], ",", 
        RowBox[{
         RowBox[{"i", "++"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"matel", ",", 
              RowBox[{
               RowBox[{"s", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "m"}]}], "]"}], "\[Equal]", 
            RowBox[{"{", "}"}]}], ",", ",", 
           RowBox[{
            RowBox[{"res", "=", 
             RowBox[{"s", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ";", 
            RowBox[{"i", "=", "l"}]}]}], "]"}]}]}], "]"}], ";", "res"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"msi", "[", 
   RowBox[{
    RowBox[{"v__", "?", "ListQ"}], ",", 
    RowBox[{"u_:", "u2"}], ",", 
    RowBox[{"si_:", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "\[ImaginaryI]", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], ",", 
    RowBox[{"maxel_:", "64"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gg", ",", "gij", ",", 
      RowBox[{"i", "=", "2"}], ",", 
      RowBox[{"j", "=", "2"}], ",", "l", ",", "mi", ",", "new", ",", "n", ",",
       "p", ",", "s", ",", 
      RowBox[{"tot", "=", "0"}], ",", 
      RowBox[{"m", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"VectorQ", "[", "v", "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Sign", "[", 
             RowBox[{"v", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], 
            RowBox[{"u", "[", 
             RowBox[{"[", 
              RowBox[{"Abs", "[", 
               RowBox[{"v", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "v", "]"}]}], "}"}]}], "]"}], ",", "v"}], 
        "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"s", "=", 
      RowBox[{"Union", "[", 
       RowBox[{"si", ",", 
        RowBox[{
         RowBox[{"Variables", "[", "m", "]"}], "\[Intersection]", 
         "signlist"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MatrixQ", "[", 
         RowBox[{"m", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "True"}], ",", ",", 
       RowBox[{
        RowBox[{"Print", "[", " ", "\"\<Not a list or matrix\>\"", "]"}], ";",
         
        RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"l", "=", 
      RowBox[{"Length", "[", 
       RowBox[{"m", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", 
     RowBox[{"n", "=", 
      RowBox[{
       RowBox[{"Length", "[", "m", "]"}], "+", "1"}]}], ";", 
     RowBox[{"matel", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{"m", ",", 
        RowBox[{"IdentityMatrix", "[", "l", "]"}]}], "]"}]}], ";", 
     RowBox[{"mi", "=", 
      RowBox[{"minsign", "[", "matel", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"j", "=", "2"}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"new", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"matel", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ".", 
              RowBox[{"matel", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "/.", "mi"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"mstst", "[", 
               RowBox[{"new", ",", "s"}], "]"}], "\[Equal]", "0"}], ",", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"matel", ",", "new"}], "]"}]}], "]"}], ";", 
           RowBox[{"tot", "++"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "matel", "]"}], ">", "maxel"}], "||", 
              RowBox[{"tot", ">", 
               RowBox[{"4", " ", "maxel"}]}]}], ",", 
             RowBox[{
              RowBox[{"Print", "[", "matel", "]"}], ";", 
              RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"j", "<", 
            RowBox[{"Length", "[", "matel", "]"}]}]}], ",", 
          RowBox[{"j", "++"}]}], "]"}], ";", 
        RowBox[{"i", "<", 
         RowBox[{"Length", "[", "matel", "]"}]}]}], ",", 
       RowBox[{"i", "++"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "matel", "]"}]}], ";", 
     RowBox[{"gg", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"matel", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ".", 
          RowBox[{"matel", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "/.", "mi"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"gij", "=", 
         RowBox[{"gg", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ";", 
        RowBox[{"p", "=", 
         RowBox[{"mstst", "[", 
          RowBox[{"gij", ",", "s"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"gg", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
         RowBox[{"p", " ", 
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"matel", ",", 
             RowBox[{"p", " ", "gij"}]}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "n"}], "}"}]}], "]"}], ";", 
     RowBox[{"glo", "=."}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"indexTableQ", "[", "gg", "]"}], "==", "True"}], ",", 
       RowBox[{"glo", "=", "gg"}]}], "]"}], ";", "glo"}]}], "]"}]}]}], "Input",\

 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "9 Protoloops",
 StyleBox[" makeProtoloop[G_,o_],  mp, gd.",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"mp", "[", "]"}], ":=", 
   RowBox[{"makeProtoloop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mm", ",", "nn"}], "}"}], ",", "0"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"mp", "[", 
    RowBox[{
     RowBox[{"m_", "?", "IntegerQ"}], ",", 
     RowBox[{"n_", "?", "IntegerQ"}]}], "]"}], ":=", 
   RowBox[{"makeProtoloop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "n"}], "}"}], ",", "0"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"mp", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_"}], "}"}], ",", 
     RowBox[{"o_", "?", "IntegerQ"}]}], "]"}], ":=", 
   RowBox[{"makeProtoloop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], ",", "o"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"mp", "[", 
    RowBox[{
     RowBox[{"m_", "?", "IntegerQ"}], ",", 
     RowBox[{"n_", "?", "IntegerQ"}], ",", 
     RowBox[{"o_", "?", "IntegerQ"}]}], "]"}], ":=", 
   RowBox[{"makeProtoloop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "n"}], "}"}], ",", "o"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"mp", "[", "a_", "]"}], ":=", 
   RowBox[{"makeProtoloop", "[", 
    RowBox[{"a", ",", "0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeProtoloop", "[", 
    RowBox[{
     RowBox[{"m_", "?", "IntegerQ"}], ",", 
     RowBox[{"n_", "?", "IntegerQ"}], ",", 
     RowBox[{"o_", "?", "IntegerQ"}]}], "]"}], ":=", 
   RowBox[{"makeProtoloop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "n"}], "}"}], ",", "o"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeProtoloop", "[", 
    RowBox[{
     RowBox[{"m_", "?", "IntegerQ"}], ",", 
     RowBox[{"n_", "?", "IntegerQ"}]}], "]"}], ":=", 
   RowBox[{"makeProtoloop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "n"}], "}"}], ",", "0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeProtoloop", "[", "G_", "]"}], ":=", 
   RowBox[{"makeProtoloop", "[", 
    RowBox[{"G", ",", "0"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"makeProtoloop", "[", 
    RowBox[{"G_", ",", 
     RowBox[{"o_", "?", "IntegerQ"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g", ",", "l", ",", "res", ",", 
       RowBox[{"mx", "=", "mg"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"matel", "=."}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "G", "]"}], "===", "Symbol"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"{", 
           RowBox[{
           "G", ",", "\"\<not a known Table. Changed to a string.\>\""}], 
           "}"}], "]"}], ";", 
         RowBox[{"G", "=", 
          RowBox[{"ToString", "[", "G", "]"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"MatrixQ", "[", "G", "]"}], ",", 
        RowBox[{"id", "[", 
         RowBox[{"caylindex", "[", "G", "]"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Head", "[", "G", "]"}], "===", "String"}], ",", 
        RowBox[{
         RowBox[{"g", "=", 
          RowBox[{"Position", "[", 
           RowBox[{"loop", ",", "G", ",", "3", ",", "1"}], "]"}]}], ";", 
         "\[IndentingNewLine]", "  ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"g", "===", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Unknown case \>\"", ",", "o", ",", "\"\< \>\"", ",", "G"}],
               "}"}], "]"}], ";", 
            RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", "   ", 
         RowBox[{"mm", "=", 
          RowBox[{"g", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", 
         RowBox[{"nn", "=", 
          RowBox[{"g", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Length", "[", "G", "]"}], "===", "2"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"loop", "[", 
             RowBox[{"[", 
              RowBox[{"G", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "]"}], 
           "\[GreaterEqual]", 
           RowBox[{"G", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"mm", "=", 
            RowBox[{"G", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"G", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
          RowBox[{"Return", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<Unknown mm,nn \>\"", ",", "G"}], "}"}], "]"}]}], " ",
          "]"}], ",", "\[IndentingNewLine]", "True", ",", 
        RowBox[{"mm", "=", 
         RowBox[{"Length", "[", "loop", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Sign", "[", 
          RowBox[{
           RowBox[{"loop", "[", 
            RowBox[{"[", 
             RowBox[{"mm", ",", "nn"}], "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}], "\[NotEqual]", 
         "1"}], ",", 
        RowBox[{"mx", "=", "ms"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"mm", "\[GreaterEqual]", 
          RowBox[{"Length", "[", "loop", "]"}]}], "||", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l", "=", 
            RowBox[{"loop", "[", 
             RowBox[{"[", "mm", "]"}], "]"}]}], ")"}], "==", 
          RowBox[{"{", "}"}]}], "||", 
         RowBox[{
          RowBox[{"Length", "[", "l", "]"}], "<", "nn"}]}], ",", 
        RowBox[{"gmn", "=", "\"\<Unrecognized\>\""}], ",", 
        RowBox[{
         RowBox[{"l", "=", 
          RowBox[{"l", "[", 
           RowBox[{"[", "nn", "]"}], "]"}]}], ";", 
         RowBox[{"gmn", "=", 
          RowBox[{"loop", "[", 
           RowBox[{"[", 
            RowBox[{"mm", ",", "nn", ",", "1"}], "]"}], "]"}]}]}]}], "]"}], 
      ";", 
      RowBox[{"res", "=", 
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"o", "<", "1"}], "&&", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "!=", "\"\<ca[]\>\""}]}], ",", 
         RowBox[{"ToExpression", "[", 
          RowBox[{"l", "[", 
           RowBox[{"[", "4", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
         
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"o", "==", "0"}], "||", 
            RowBox[{"o", "\[Equal]", "1"}]}], ")"}], "&&", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "\[NotEqual]", 
           RowBox[{"{", "}"}]}]}], ",", 
         RowBox[{"ge", "[", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", 
           RowBox[{"l", "[", 
            RowBox[{"[", "6", "]"}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"o", "==", "0"}], "||", 
            RowBox[{"o", "\[Equal]", "2"}]}], ")"}], "&&", 
          RowBox[{
           RowBox[{"Length", "[", "l", "]"}], ">", "6"}], "&&", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "7", "]"}], "]"}], "\[NotEqual]", 
           RowBox[{"{", "}"}]}]}], ",", 
         RowBox[{"mx", "[", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "7", "]"}], "]"}], ",", "u2"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"o", "==", "0"}], "||", 
            RowBox[{"o", "\[Equal]", "3"}]}], ")"}], "&&", 
          RowBox[{
           RowBox[{"Length", "[", "l", "]"}], ">", "7"}], "&&", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "8", "]"}], "]"}], "\[NotEqual]", 
           RowBox[{"{", "}"}]}]}], ",", 
         RowBox[{"mx", "[", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "8", "]"}], "]"}], ",", "u3"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"o", "==", "0"}], "||", 
            RowBox[{"o", "\[Equal]", "4"}]}], ")"}], "&&", 
          RowBox[{
           RowBox[{"Length", "[", "l", "]"}], ">", "8"}], "&&", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "9", "]"}], "]"}], "\[NotEqual]", 
           RowBox[{"{", "}"}]}]}], ",", 
         RowBox[{"mx", "[", 
          RowBox[{
           RowBox[{"l", "[", 
            RowBox[{"[", "9", "]"}], "]"}], ",", "u4"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"o", "==", "0"}], "||", 
            RowBox[{"o", "\[Equal]", "5"}]}], ")"}], "&&", 
          RowBox[{
           RowBox[{"Length", "[", "l", "]"}], ">", "9"}]}], ",", 
         RowBox[{"ToExpression", "[", 
          RowBox[{"l", "[", 
           RowBox[{"[", "10", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]",
          
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"o", "==", "0"}], "||", 
            RowBox[{"o", "\[Equal]", "6"}]}], ")"}], "&&", 
          RowBox[{
           RowBox[{"Length", "[", "l", "]"}], ">", "10"}]}], ",", 
         RowBox[{"ToExpression", "[", 
          RowBox[{"l", "[", 
           RowBox[{"[", "11", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]",
          "True", ",", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{"{", 
            RowBox[{"G", ",", "\"\<No Protoloop\>\"", ",", "o"}], "}"}], 
           "]"}], ";", 
          RowBox[{"{", "}"}]}]}], "]"}]}], ";", 
      RowBox[{"id", "[", "res", "]"}], ";", 
      RowBox[{"glo", "=", "res"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gd", "[", "]"}], ":=", 
   RowBox[{"gd", "[", 
    RowBox[{"mm", ",", "nn"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"gd", "[", 
    RowBox[{"{", 
     RowBox[{"m_Integer", ",", "n_Integer"}], "}"}], "]"}], ":=", 
   RowBox[{"gd", "[", 
    RowBox[{"m", ",", "n"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"gd", "[", 
    RowBox[{
     RowBox[{"m_Integer:", "mm"}], ",", 
     RowBox[{"n_Integer:", "nn"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"m", ">", "0"}], "&&", 
      RowBox[{
       RowBox[{"loop", "[", 
        RowBox[{"[", "m", "]"}], "]"}], "\[NotEqual]", 
       RowBox[{"{", "}"}]}], "&&", 
      RowBox[{"n", ">", "0"}], "&&", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"loop", "[", 
         RowBox[{"[", "m", "]"}], "]"}], "]"}], "\[GreaterEqual]", "n"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mm", "=", "m"}], ",", 
       RowBox[{"nn", "=", "n"}], ",", 
       RowBox[{"loop", "[", 
        RowBox[{"[", 
         RowBox[{"m", ",", "n"}], "]"}], "]"}]}], "}"}], ",", 
     "\"\<Not a loop index\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"gd", "[", "g_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "i", "}"}], ",", 
    RowBox[{"Which", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "g", "]"}], "===", "String"}], "&&", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"i", "=", 
          RowBox[{"Position", "[", 
           RowBox[{"loop", ",", "g", ",", "3", ",", "1"}], "]"}]}], ")"}], 
        "\[NotEqual]", 
        RowBox[{"{", "}"}]}]}], ",", 
      RowBox[{"gd", "[", 
       RowBox[{
        RowBox[{"mm", "=", 
         RowBox[{"i", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
        RowBox[{"nn", "=", 
         RowBox[{"i", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "g", "]"}], "===", "String"}], "&&", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"i", "=", 
          RowBox[{"Position", "[", 
           RowBox[{"loop", ",", 
            RowBox[{"g", "<>", "\"\<?\>\""}], ",", "3", ",", "1"}], "]"}]}], 
         ")"}], "\[NotEqual]", 
        RowBox[{"{", "}"}]}]}], ",", 
      RowBox[{"gd", "[", 
       RowBox[{
        RowBox[{"mm", "=", 
         RowBox[{"i", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
        RowBox[{"nn", "=", 
         RowBox[{"i", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "]"}], ",", 
      "\[IndentingNewLine]", "True", ",", 
      RowBox[{
      "Print", "[", 
       "\"\<Not a loop index or known mnemonic. Try as a string?\>\"", 
       "]"}]}], "]"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "10 Loop identification",
 StyleBox[" id, idc",
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", 
   RowBox[{"id", ",", "idc"}], "]"}], ";", 
  RowBox[{"id", "=."}], ";", 
  RowBox[{"idc", "=."}], ";", 
  RowBox[{"mm", "=."}], ";", 
  RowBox[{"nn", "=", ".0"}], ";", 
  RowBox[{"glo", "=."}], ";", 
  RowBox[{"(*", 
   RowBox[{"for", " ", "extensions"}], "*)"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"idc", "[", "G_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"conservativeQ", "[", "G", "]"}], ",", 
     RowBox[{"id", "[", "G", "]"}], ",", "\"\<Not conservative.\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"idc", "[", 
    RowBox[{"G_", ",", 
     RowBox[{"L_", "?", "ListQ"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"conservativeQ", "[", "G", "]"}], ",", 
     RowBox[{"id", "[", 
      RowBox[{"G", ",", "L"}], "]"}], ",", "\"\<Not conservative.\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"id", "[", "]"}], ":=", 
   RowBox[{"id", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mm", ",", "nn"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"G_:", 
     RowBox[{"{", 
      RowBox[{"mm", ",", "nn"}], "}"}]}], "]"}], ":=", 
   RowBox[{"id", "[", 
    RowBox[{"G", ",", 
     RowBox[{"{", "}"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{
     RowBox[{"G_:", 
      RowBox[{"{", 
       RowBox[{"mm", ",", "nn"}], "}"}]}], ",", 
     RowBox[{"L_", "?", "ListQ"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ln", ",", "lg", ",", "j", ",", "jj", ",", "M"}], "}"}], ",", 
     RowBox[{
      RowBox[{"nn", "=", "1"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "G", "]"}], "===", "TraditionalForm"}], ",", 
        RowBox[{"M", "=", 
         RowBox[{"G", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{"M", "=", "G"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "G", "]"}], "===", "String"}], ",", 
        RowBox[{"M", "=", 
         RowBox[{"mp", "[", "G", "]"}]}]}], "]"}], ";", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Dimensions", "[", "M", "]"}], "\[Equal]", 
         RowBox[{"{", "2", "}"}]}], ",", 
        RowBox[{
         RowBox[{"mm", "=", 
          RowBox[{"M", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", 
         RowBox[{"nn", "=", 
          RowBox[{"M", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ";", 
         RowBox[{"M", "=", 
          RowBox[{"{", "}"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"MatrixQ", "[", "M", "]"}], ",", 
        RowBox[{
         RowBox[{"M", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "L", "]"}], ">", "0"}], ",", 
            RowBox[{"reorder", "[", 
             RowBox[{"M", ",", "L"}], "]"}], ",", "M"}], "]"}]}], ";", 
         RowBox[{"mm", "=", 
          RowBox[{"Length", "[", "M", "]"}]}]}], ",", "\[IndentingNewLine]", 
        "True", ",", 
        RowBox[{
         RowBox[{"mm", "=", 
          RowBox[{"Length", "[", "loop", "]"}]}], ";", 
         RowBox[{"glo", "=."}], ";", 
         RowBox[{"M", "=", 
          RowBox[{"{", "}"}]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"lg", "=", 
       RowBox[{"Length", "[", "M", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"lg", ">", "1"}], "&&", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"j", "=", 
            RowBox[{"Position", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"loop", "[", 
                RowBox[{"[", "lg", "]"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", 
                 RowBox[{"{", "2", "}"}]}], "]"}], "]"}], ",", 
              RowBox[{"dico", "[", "M", "]"}], ",", "3", ",", "1"}], "]"}]}], 
           ")"}], "\[NotEqual]", 
          RowBox[{"{", "}"}]}]}], ",", 
        RowBox[{"nn", "=", 
         RowBox[{"j", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
        RowBox[{"mm", "=", 
         RowBox[{"Length", "[", "loop", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"jj", "=", 
       RowBox[{"loop", "[", 
        RowBox[{"[", 
         RowBox[{"mm", ",", "nn", ",", "3"}], "]"}], "]"}]}], ";", 
      RowBox[{"ln", "=", "nn"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Switch", "[", 
       RowBox[{"jj", ",", "0", ",", ",", "\[IndentingNewLine]", "1", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"trico", "[", "M", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", 
            SubscriptBox["3", "2"]}], "}"}], ",", "\"\<C9\>\"", ",", 
          RowBox[{"{", "9", "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C3C3\>\""}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "3"}], "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "4"}], ";", "\"\<Alt9n\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "2", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"fa", "[", "M", "]"}], "]"}], "\[Equal]", "2"}], ",", 
          "\"\<Dav\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "4"}], ";", "\"\<C4C2r\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "3", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0"}], "]"}], "\[Equal]", "9"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "3"}], ";", "\"\<C8C2\>\""}], ",", 
          "\"\<C4C4\>\""}], "]"}], ",", "\[IndentingNewLine]", "4", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "5", ",", "5"}], "]"}], "\[NotEqual]",
            "1"}], ",", "\"\<C3C25\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C75\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "5", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"trico", "[", "M", "]"}], "===", 
           RowBox[{"{", 
            RowBox[{"3", ",", 
             SubscriptBox["3", "5"]}], "}"}]}], ",", "\"\<C18\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "3"}], ";", "\"\<C3C3C2\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "6", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"trico", "[", "M", "]"}], "===", 
           RowBox[{"{", 
            RowBox[{"9", ",", 
             SubscriptBox["1", "9"]}], "}"}]}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "3"}], ";", "\"\<E18\>\""}], ",", 
          "\"\<D9\>\""}], "]"}], ",", "\[IndentingNewLine]", "7", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"fa", "[", "M", "]"}], "]"}], "\[Equal]", "2"}], ",", 
          "\"\<O2\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "6"}], ";", "\"\<C4C3j\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "8", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"trico", "[", "M", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", 
            SubscriptBox["3", "8"]}], "}"}], ",", "\"\<C27\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"9", ",", 
            SubscriptBox["9", "2"]}], "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C9C3\>\""}], ",", 
          RowBox[{"{", "27", "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "4"}], ";", "\"\<C3C3C3\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "9", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0"}], "]"}], "\[Equal]", "1"}], ",", 
          "\"\<C25\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C5C5\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "10", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"trico", "[", "M", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"9", ",", 
            SubscriptBox["9", "2"]}], "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<g2704\>\""}], ",", 
          RowBox[{"{", "27", "}"}], ",", "\"\<P27\>\""}], "]"}], ",", 
        "\[IndentingNewLine]", "11", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"subgroups", "[", 
           RowBox[{"M", ",", "0", ",", "0", ",", "8"}], "]"}], ",", "33", ",",
           
          RowBox[{
           RowBox[{"nn", "+=", "31"}], ";", "\"\<g3233\>\""}], ",", "37", ",",
           
          RowBox[{
           RowBox[{"nn", "+=", "22"}], ";", "\"\<g3224\>\""}], ",", "any_", 
          ",", "\"\<g3202\>\""}], "]"}], ",", "\[IndentingNewLine]", "12", 
        ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"conservativeQ", "[", "M", "]"}], ",", "\"\<C4C4r\>\"", ",",
           
          RowBox[{
           RowBox[{"nn", "+=", "2"}], ";", "\"\<C4Kcn\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "13", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"trico", "[", "M", "]"}], "===", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             SubscriptBox["1", "13"], ",", "2"}], "}"}]}], ",", 
          "\"\<CL31\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<CL22\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "14", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "8"}], ",", 
          "\"\<KiC8\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "6"}], ";", "\"\<g3211\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "15", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"trico", "[", "M", "]"}], "===", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             SubscriptBox["1", "11"], ",", 
             SubscriptBox["2", "2"]}], "}"}]}], ",", "\"\<CL4\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "3"}], ";", "\"\<CL13\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "16", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"trico", "[", "M", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            SubscriptBox["1", "13"], ",", "2"}], "}"}], ",", "\"\<r31r\>\"", 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            SubscriptBox["1", "11"], ",", 
            SubscriptBox["2", "2"]}], "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<r31s\>\""}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            SubscriptBox["1", "15"]}], "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "2"}], ";", "\"\<r31t\>\""}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            SubscriptBox["1", "7"], ",", 
            SubscriptBox["2", "4"]}], "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "3"}], ";", "\"\<r31u\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "17", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "8"}], ",", 
          "\"\<C4iC4C2\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "6"}], ";", "\"\<KiQ8\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "18", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"Max", "[", 
           RowBox[{"First", "[", 
            RowBox[{"Transpose", "[", 
             RowBox[{"collect", "[", 
              RowBox[{"subgroupTypes", "[", 
               RowBox[{"subgroups", "[", 
                RowBox[{"M", ",", "1", ",", "16", ",", "16"}], "]"}], "]"}], 
              "]"}], "]"}], "]"}], "]"}], ",", "2", ",", 
          RowBox[{
           RowBox[{"mm", "=", "32"}], ";", 
           RowBox[{"nn", "=", "25"}], ";", "\"\<D4C4\>\""}], ",", "3", ",", 
          RowBox[{
           RowBox[{"mm", "=", "32"}], ";", 
           RowBox[{"nn", "=", "30"}], ";", "\"\<G3230\>\""}], ",", "4", ",", 
          RowBox[{
           RowBox[{"mm", "=", "32"}], ";", 
           RowBox[{"nn", "=", "31"}], ";", "\"\<g3231\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "19", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "==", "4"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "6"}], ";", "\"\<Q8C4\>\""}], ",", 
          "\"\<g3226\>\""}], "]"}], ",", "\[IndentingNewLine]", "20", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"conservativeQ", "[", "M", "]"}], ",", "\"\<QC2c\>\"", ",", 
          
          RowBox[{
           RowBox[{"nn", "+=", "19"}], ";", "\"\<QC2cn\>\""}]}], "]"}], ",", 
        "21", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "4"}], ",", 
          
          RowBox[{"\"\<g64091\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "13"}]}]}], ",", 
          RowBox[{"\"\<g64078\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        "22", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"M", ",", 
             RowBox[{"-", "\[ImaginaryI]"}]}], "]"}], "===", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C3i\>\""}], ",", "\"\<C12c\>\""}], 
         "]"}], ",", "\[IndentingNewLine]", "23", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "3", ",", "3"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<C36\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "6"}], ";", "\"\<C12C3\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "24", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "3", ",", "3"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<C18C2\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "9"}], ";", "\"\<C6C6\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "25", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "3", ",", "3"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<D18\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "9"}], ";", "\"\<E18C2\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "26", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "3", ",", "3"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<Q36\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "6"}], ";", "\"\<C3iQ12\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "27", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "3", ",", "3"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<g3603\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "8"}], ";", "\"\<A4C3\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "28", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"37", ",", "38"}], "}"}]}], "]"}], ",", "37", ",", 
          RowBox[{"\"\<g64104\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "38", ",", 
          RowBox[{"\"\<g64105\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "29", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"trico", "[", "M", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", 
            SubscriptBox["3", "20"]}], "}"}], ",", "\"\<C63\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"9", ",", 
            SubscriptBox["9", "6"]}], "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C7C3C3\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "30", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "3", ",", "3"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<C45\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C5C3C3\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "31", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"trico", "[", "M", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", 
            SubscriptBox["3", "6"], ",", 
            SubscriptBox["21", "2"]}], "}"}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C6n3\>\""}], ",", 
          RowBox[{"{", 
           RowBox[{"45", ",", 
            SubscriptBox["3", "6"]}], "}"}], ",", "\"\<g2101C3\>\""}], "]"}], 
        ",", "\[IndentingNewLine]", "32", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "\[Equal]", 
           "7"}], ",", "\"\<C3C4C4\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "3"}], ";", "\"\<C24C2\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "33", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "4"}], ",", 
          
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<g4805\>\""}], ",", 
          "\"\<C8D3\>\""}], "]"}], ",", "\[IndentingNewLine]", "34", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"subgroups", "[", 
           RowBox[{"M", ",", "0", ",", "32", ",", "0", ",", 
            RowBox[{"{", 
             RowBox[{
             "3", ",", "7", ",", "11", ",", "15", ",", "36", ",", "38", ",", 
              "42"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", "36", ",", 
          RowBox[{"\"\<g64116\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "116"}]}], ",", "\[IndentingNewLine]", "3", ",",
           
          RowBox[{"\"\<g64117\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "117"}]}], ",", "\[IndentingNewLine]", "7", ",",
           
          RowBox[{"\"\<g64117\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "117"}]}], ",", "\[IndentingNewLine]", "_", ",",
           
          RowBox[{"\"\<g64124\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "124"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        "35", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "\[Equal]", 
           "15"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "2"}], ";", "\"\<C4D6\>\""}], ",", 
          "\"\<P48\>\""}], "]"}], ",", "\[IndentingNewLine]", "36", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "\[Equal]", 
           "3"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"centre", "[", "M", "]"}], "]"}], "\[NotEqual]", "4"}], 
            ",", "\"\<C24g17C2\>\"", ",", 
            RowBox[{
             RowBox[{"nn", "++"}], ";", "\"\<g4810\>\""}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "2"}], ";", "\"\<Q12C4\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "37", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"subgroups", "[", 
           RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], ",", "11", 
          ",", "\"\<A4C4\>\"", ",", "7", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "2"}], ";", "\"\<g4833\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "38", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgrpPerm", "[", 
            RowBox[{"M", ",", "0", ",", "7", ",", "7"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<C49\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C7C7\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "39", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgrpPerm", "[", 
            RowBox[{"M", ",", "0", ",", "5", ",", "5"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<C50\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C10C5\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "40", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgrpPerm", "[", 
            RowBox[{"M", ",", "0", ",", "5", ",", "5"}], "]"}], "\[Equal]", 
           "1"}], ",", "\"\<D25\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<C5nD5\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "41", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgrpPerm", "[", 
            RowBox[{"M", ",", "0", ",", "9", ",", "9"}], "]"}], "\[Equal]", 
           "4"}], ",", "\"\<P54\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "5"}], ";", "\"\<E18nC3\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "42", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"Position", "[", 
             RowBox[{
              RowBox[{"allFactorGroups", "[", 
               RowBox[{"M", ",", "0", ",", "9", ",", "9"}], "]"}], ",", 
              "\"\<D3\>\""}], "]"}], "]"}], "===", "3"}], ",", 
          RowBox[{
           RowBox[{"mm", "=", "54"}], ";", 
           RowBox[{"nn", "=", "ln"}], ";", "\"\<D9C3a\>\""}], ",", 
          RowBox[{
           RowBox[{"mm", "=", "54"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}], ";", "\"\<g5406\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "43", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"trico", "[", "M", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", 
            SubscriptBox["1", "27"], ",", 
            SubscriptBox["3", "8"]}], "}"}], ",", "D27", ",", "_", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "13"}], ";", "\"\<D27b\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "44", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"39", ",", "40"}], "}"}]}], "]"}], ",", "39", ",", 
          RowBox[{"\"\<g64118\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "40", ",", 
          RowBox[{"\"\<g64119\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "45", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"trico", "[", "M", "]"}], "===", 
           RowBox[{"{", 
            RowBox[{"9", ",", 
             SubscriptBox["3", "9"], ",", 
             SubscriptBox["9", "2"]}], "}"}]}], ",", "\"\<C9D3\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "8"}], ";", "\"\<D3C3C3\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "46", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"allFactorGroups", "[", 
             RowBox[{"M", ",", "0", ",", "2", ",", "2"}], "]"}], ",", 
            "\"\<g3215\>\""}], "]"}], ",", 
          RowBox[{"\"\<g64022\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "3"}]}]}], ",", 
          RowBox[{
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}], ";", "\"\<g64019\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "47", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"allFactorGroups", "[", 
             RowBox[{"M", ",", "0", ",", "2", ",", "2"}], "]"}], ",", 
            "\"\<D4nC4\>\""}], "]"}], ",", 
          RowBox[{"\"\<g64013\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}], ";", "\"\<g64014\>\""}]}], "]"}], ",",
         "\[IndentingNewLine]", "48", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "\[Equal]", 
           "27"}], ",", "\"\<g64020\>\"", ",", 
          RowBox[{
           RowBox[{"nn", "+=", "2"}], ";", "\"\<g64022\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "49", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"subgroups", "[", 
           RowBox[{"M", ",", "0", ",", "8", ",", "8"}], "]"}], ",", "7", ",", 
          "\"\<g64026\>\"", ",", 
          RowBox[{"nn", "+=", "24"}], ",", "\"\<g64050\>\""}], "]"}], ",", 
        "\[IndentingNewLine]", "50", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"16", ",", "17"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "17", ",", 
          RowBox[{"\"\<g64027\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "16", ",", 
          RowBox[{"\"\<g64051\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "24"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "51", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"allFactorGroups", "[", 
             RowBox[{"M", ",", "0", ",", "2", ",", "2"}], "]"}], ",", 
            "\"\<g3211\>\""}], "]"}], ",", 
          RowBox[{"\"\<g64020\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}], ",", 
          RowBox[{
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}], ";", "\"\<g64018\>\""}]}], "]"}], ",", 
        "\[IndentingNewLine]", "52", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", "9", ",", "14", ",", "40", ",", "42"}], 
             "}"}]}], "]"}], ",", "\[IndentingNewLine]", "40", ",", 
          RowBox[{"\"\<g64106\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "85"}]}]}], ",", "\[IndentingNewLine]", "42", 
          ",", 
          RowBox[{"\"\<g64108\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "87"}]}]}], ",", "\[IndentingNewLine]", "_", 
          ",", 
          RowBox[{"\"\<g64021\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        "53", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"subgroups", "[", 
            RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "\[Equal]", 
           "31"}], ",", "\"\<g64135\>\"", ",", 
          RowBox[{"\"\<g64136\>\"", ";", 
           RowBox[{"nn", "++"}]}]}], "]"}], ",", "\[IndentingNewLine]", "54", 
        ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "4"}], ",", 
          
          RowBox[{"\"\<g64177\>\"", ";", 
           RowBox[{"nn", "+=", "43"}]}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"subgroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "\[Equal]", 
             "35"}], ",", 
            RowBox[{"\"\<g64190\>\"", ";", 
             RowBox[{"nn", "+=", "56"}]}], ",", "\"\<g64134\>\""}], "]"}]}], 
         "]"}], ",", "\[IndentingNewLine]", "55", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"subgroups", "[", 
           RowBox[{"M", ",", "0", ",", "32", ",", "0", ",", 
            RowBox[{"{", 
             RowBox[{"16", ",", "17"}], "}"}]}], "]"}], ",", "16", ",", 
          RowBox[{
           RowBox[{"nn", "=", "ln"}], ";", "\"\<g64044\>\""}], ",", "17", ",",
           
          RowBox[{
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}], ";", "\"\<g64045\>\""}]}], "]"}], ",",
         "\[IndentingNewLine]", "56", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"subgroups", "[", 
           RowBox[{"M", ",", "0", ",", "16", ",", "16"}], "]"}], ",", "19", 
          ",", 
          RowBox[{"\"\<g64057\>\"", ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "11", ",", 
          RowBox[{"\"\<g64064\>\"", ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "7"}]}]}], ",", "7", ",", 
          RowBox[{"\"\<g64082\>\"", ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "25"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "57", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"31", ",", "42"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "31", ",", 
          RowBox[{"\"\<g64167\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "42", ",", 
          RowBox[{"\"\<g64176\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "9"}]}]}], ",", "_", ",", 
          RowBox[{"\"\<g64173\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "6"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "58", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"22", ",", "43", ",", "28"}], "}"}]}], "]"}], ",", "22", 
          ",", 
          RowBox[{"\"\<g64100\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "43", ",", 
          RowBox[{"\"\<g64109\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "9"}]}]}], ",", "28", ",", 
          RowBox[{"\"\<g64151\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "51"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "59", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"11", ",", "28", ",", "37", ",", "38", ",", "42"}], 
             "}"}]}], "]"}], ",", "\[IndentingNewLine]", "37", ",", 
          RowBox[{"\"\<g64088\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "38", ",",
           
          RowBox[{"\"\<g64089\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}], ",", "\[IndentingNewLine]", "42", 
          ",", 
          RowBox[{"\"\<g64097\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "9"}]}]}], ",", "\[IndentingNewLine]", "11", 
          ",", 
          RowBox[{"\"\<g64101\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "13"}]}]}], ",", "\[IndentingNewLine]", "28", 
          ",", 
          RowBox[{"\"\<g64152\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "64"}]}]}], ",", "\[IndentingNewLine]", "_", 
          ",", 
          RowBox[{"\"\<g64102\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "14"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "60", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"5", ",", "4", ",", "17", ",", "24"}], "}"}]}], "]"}], 
          ",", "\[IndentingNewLine]", "5", ",", 
          RowBox[{"\"\<g64017\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "4", ",", 
          
          RowBox[{"\"\<g64084\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "67"}]}]}], ",", "\[IndentingNewLine]", "17", 
          ",", 
          RowBox[{"\"\<g64184\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "167"}]}]}], ",", "\[IndentingNewLine]", "24", 
          ",", 
          RowBox[{"Switch", "[", 
           RowBox[{
            RowBox[{"allFactorGroups", "[", 
             RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
              RowBox[{"{", 
               RowBox[{"36", ",", "38"}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", "36", ",", 
            RowBox[{"\"\<g64112\>\"", ";", 
             RowBox[{"mm", "=", "64"}], ";", 
             RowBox[{"nn", "=", 
              RowBox[{"ln", "+", "95"}]}]}], ",", "\[IndentingNewLine]", "38",
             ",", 
            RowBox[{"\"\<g64114\>\"", ";", 
             RowBox[{"mm", "=", "64"}], ";", 
             RowBox[{"nn", "=", 
              RowBox[{"ln", "+", "97"}]}]}], ",", "\[IndentingNewLine]", "_", 
            ",", 
            RowBox[{"\"\<g64113\>\"", ";", 
             RowBox[{"mm", "=", "64"}], ";", 
             RowBox[{"nn", "=", 
              RowBox[{"ln", "+", "96"}]}]}]}], "]"}], ",", 
          "\[IndentingNewLine]", "_", ",", 
          RowBox[{"Switch", "[", 
           RowBox[{
            RowBox[{"allFactorGroups", "[", 
             RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
              RowBox[{"{", 
               RowBox[{"36", ",", "37", ",", "38"}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", "36", ",", 
            RowBox[{"\"\<g64185\>\"", ";", 
             RowBox[{"mm", "=", "64"}], ";", 
             RowBox[{"nn", "=", 
              RowBox[{"ln", "+", "168"}]}]}], ",", "\[IndentingNewLine]", 
            "37", ",", 
            RowBox[{"\"\<g64085\>\"", ";", 
             RowBox[{"mm", "=", "64"}], ";", 
             RowBox[{"nn", "=", 
              RowBox[{"ln", "+", "68"}]}]}], ",", "\[IndentingNewLine]", "38",
             ",", 
            RowBox[{"\"\<g64086\>\"", ";", 
             RowBox[{"mm", "=", "64"}], ";", 
             RowBox[{"nn", "=", 
              RowBox[{"ln", "+", "69"}]}]}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", "61", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"16", ",", "36"}], "}"}]}], "]"}], ",", "36", ",", 
          RowBox[{"\"\<g64083\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "16", ",", 
          RowBox[{"\"\<g64183\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "100"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "62", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"37", ",", "38"}], "}"}]}], "]"}], ",", "37", ",", 
          RowBox[{"\"\<g64113\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "38", ",", 
          RowBox[{"\"\<g64114\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "63", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"31", ",", "34"}], "}"}]}], "]"}], ",", "31", ",", 
          RowBox[{"\"\<g64074\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "34", ",", 
          RowBox[{"\"\<g64080\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "6"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "64", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"31", ",", "32"}], "}"}]}], "]"}], ",", "31", ",", 
          RowBox[{"\"\<g64071\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "4"}]}]}], ",", "_", ",", 
          RowBox[{"\"\<g64067\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        "65", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"23", ",", "25", ",", "26", ",", "28"}], "}"}]}], "]"}], 
          ",", "26", ",", 
          RowBox[{"\"\<g64072\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}], ",", "_", ",", 
          RowBox[{"\"\<g64070\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        "66", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"25", ",", "26", ",", "30", ",", "31", ",", "33"}], 
             "}"}]}], "]"}], ",", "\[IndentingNewLine]", "31", ",", 
          RowBox[{"\"\<g64063\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "_", ",", 
          
          RowBox[{"\"\<g64068\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "5"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "67", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"22", ",", "31"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "22", ",", 
          RowBox[{"\"\<g64062\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "_", ",", 
          
          RowBox[{"\"\<g64069\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "7"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "68", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"28", ",", "33"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "28", ",", 
          RowBox[{"\"\<g64061\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "33", ",",
           
          RowBox[{"\"\<g64209\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "148"}]}]}], ",", "\[IndentingNewLine]", "_", 
          ",", 
          RowBox[{"\"\<g64210\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "149"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "69", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", "24"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "2", ",", 
          RowBox[{"\"\<g64056\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "24", ",",
           
          RowBox[{"\"\<g64195\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "139"}]}]}], ",", "\[IndentingNewLine]", "_", 
          ",", 
          RowBox[{"\"\<g64198\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "142"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "70", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"40", ",", "42"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "40", ",", 
          RowBox[{"\"\<g64129\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "42", ",",
           
          RowBox[{"\"\<g64133\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "4"}]}]}], ",", "\[IndentingNewLine]", "_", 
          ",", 
          RowBox[{"\"\<g64161\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "32"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "71", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"40", ",", "42"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "42", ",", 
          RowBox[{"\"\<g64130\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "40", ",",
           
          RowBox[{"\"\<g64131\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "72", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"conservativeQ", "[", "M", "]"}], ",", "\"\<C3C2\>\"", ",", 
          
          RowBox[{
           RowBox[{"nn", "+=", "12"}], ";", "\"\<C6an\>\""}]}], "]"}], ",", 
        "73", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "4"}], ",", 
          
          RowBox[{"\"\<g64178\>\"", ";", 
           RowBox[{"nn", "+=", "41"}]}], ",", "\"\<g64137\>\""}], "]"}], ",", 
        "\[IndentingNewLine]", "74", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"collect", "[", 
            RowBox[{"allFactorGroups", "[", 
             RowBox[{"M", ",", "0", ",", "8", ",", "8", ",", 
              RowBox[{"{", 
               RowBox[{"16", ",", "16"}], "}"}]}], "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "\[IndentingNewLine]",
           "11", ",", 
          RowBox[{"\"\<g64159\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "17"}]}]}], ",", "\[IndentingNewLine]", "17", 
          ",", 
          RowBox[{"\"\<g64157\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "15"}]}]}], ",", "\[IndentingNewLine]", "23", 
          ",", 
          RowBox[{"\"\<g64145\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "3"}]}]}], ",", "\[IndentingNewLine]", "_", 
          ",", 
          RowBox[{"\"\<g64142\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        "75", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"40", ",", "42"}], "}"}]}], "]"}], ",", "40", ",", 
          RowBox[{"\"\<Q8pQ8\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "42", ",", 
          RowBox[{"\"\<g64160\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "4"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "76", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"40", ",", "42"}], "}"}]}], "]"}], ",", "40", ",", 
          RowBox[{"\"\<g54162\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "42", ",", 
          RowBox[{"\"\<g64163\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "77", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"40", ",", "42"}], "}"}]}], "]"}], ",", "40", ",", 
          RowBox[{"\"\<g54164\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "42", ",", 
          RowBox[{"\"\<g64166\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "78", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"31", ",", "42"}], "}"}]}], "]"}], ",", "31", ",", 
          RowBox[{"\"\<g54168\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "42", ",", 
          RowBox[{"\"\<g64180\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "12"}]}]}], ",", "_", ",", 
          RowBox[{"\"\<g64179\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "11"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "79", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"18", ",", "34"}], "}"}]}], "]"}], ",", "18", ",", 
          RowBox[{"\"\<g54186\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "12"}]}]}], ",", "34", ",", 
          RowBox[{"\"\<g64174\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        "80", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"34", ",", "39"}], "}"}]}], "]"}], ",", "34", ",", 
          RowBox[{"\"\<g54175\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "39", ",", 
          RowBox[{"\"\<g64181\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "6"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "81", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", "19", "}"}]}], "]"}], ",", "19", ",", 
          RowBox[{"\"\<g64187\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "_", ",", 
          RowBox[{"\"\<g64189\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}]}], "]"}], ",", "82", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{"allFactorGroups", "[", 
           RowBox[{"M", ",", "0", ",", "2", ",", "2", ",", 
            RowBox[{"{", 
             RowBox[{"27", ",", "34", ",", "39"}], "}"}]}], "]"}], ",", "27", 
          ",", 
          RowBox[{"\"\<g64202\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "34", ",", 
          RowBox[{"\"\<g64211\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "9"}]}]}], ",", "39", ",", 
          RowBox[{"\"\<g64250\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "48"}]}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", "83", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"collect", "[", 
            RowBox[{"allFactorGroups", "[", 
             RowBox[{"M", ",", "0", ",", "8", ",", "8", ",", 
              RowBox[{"{", 
               RowBox[{"16", ",", "16"}], "}"}]}], "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "\[IndentingNewLine]",
           "50", ",", 
          RowBox[{"\"\<g64205\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "51", ",",
           
          RowBox[{"\"\<g64205\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "59", ",",
           
          RowBox[{"\"\<g64205\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "\[IndentingNewLine]", "73", ",",
           
          RowBox[{"\"\<g64206\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}], ",", "\[IndentingNewLine]", "63", 
          ",", 
          RowBox[{"\"\<g64207\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}], ",", "\[IndentingNewLine]", "49", 
          ",", 
          RowBox[{"\"\<g64213\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "8"}]}]}], ",", "\[IndentingNewLine]", "_", 
          ",", 
          RowBox[{"\"\<g64205\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        "84", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"collect", "[", 
             RowBox[{"allFactorGroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
            
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "24"}], ",", 
          RowBox[{"\"\<g64208\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64214\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "6"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "85", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"collect", "[", 
             RowBox[{"allFactorGroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
            
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "102"}], ",", 
          
          RowBox[{"\"\<g64215\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64216\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "86", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"collect", "[", 
             RowBox[{"allFactorGroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
            
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "38"}], ",", 
          RowBox[{"\"\<g64227\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64231\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "4"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "87", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"collect", "[", 
             RowBox[{"allFactorGroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
            
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "62"}], ",", 
          RowBox[{"\"\<g64219\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64221\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "88", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"collect", "[", 
             RowBox[{"allFactorGroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
            
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "18"}], ",", 
          RowBox[{"\"\<g64228\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64229\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "89", ",", 
        RowBox[{"Switch", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"collect", "[", 
            RowBox[{"allFactorGroups", "[", 
             RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "58", ",", 
          RowBox[{"\"\<g64232\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", "44", ",", 
          RowBox[{"\"\<g64240\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "8"}]}]}], ",", "42", ",", 
          RowBox[{"\"\<g64234?36\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "90", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"collect", "[", 
             RowBox[{"allFactorGroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
            
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "71"}], ",", 
          RowBox[{"\"\<g64241\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64242\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "91", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"collect", "[", 
             RowBox[{"allFactorGroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
            
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "33"}], ",", 
          RowBox[{"\"\<g64247\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64248\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "1"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "92", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"collect", "[", 
             RowBox[{"allFactorGroups", "[", 
              RowBox[{"M", ",", "0", ",", "4", ",", "4"}], "]"}], "]"}], "[", 
            
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "35"}], ",", 
          RowBox[{"\"\<g64251\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64253\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "93", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "4"}], ",", 
          
          RowBox[{"\"\<g64254\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64257\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "3"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "94", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "4"}], ",", 
          
          RowBox[{"\"\<g64256\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64258\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "2"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "95", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "4"}], ",", 
          
          RowBox[{"\"\<g64255\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64259\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "4"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "96", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"centre", "[", "M", "]"}], "]"}], "\[Equal]", "4"}], ",", 
          
          RowBox[{"\"\<g64???\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", "ln"}]}], ",", 
          RowBox[{"\"\<g64???\>\"", ";", 
           RowBox[{"mm", "=", "64"}], ";", 
           RowBox[{"nn", "=", 
            RowBox[{"ln", "+", "4"}]}]}]}], "]"}], ",", "\[IndentingNewLine]",
         "97", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"fp", "[", "M", "]"}], "]"}], "\[Equal]", "6"}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "18"}], ";", "\"\<O4k\>\""}], ",", 
          "\"\<O4\>\""}], "]"}], ",", "\[IndentingNewLine]", "98", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"conservativeQ", "[", "M", "]"}]}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<D4M4n\>\""}], ",", 
          "\"\<Q8M2\>\""}], "]"}], ",", "\[IndentingNewLine]", "99", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"associativeQ", "[", "M", "]"}]}], ",", 
          RowBox[{
           RowBox[{"nn", "+=", "20"}], ";", "\"\<C8pC2M\>\""}], ",", 
          "\"\<g3238\>\""}], "]"}], ",", "\[IndentingNewLine]", "100", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"M", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "3"}], "]"}], "]"}], "\[Equal]", 
           RowBox[{"-", "1"}]}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<CL12\>\""}], ",", "\"\<CL3\>\""}], 
         "]"}], ",", "\[IndentingNewLine]", "101", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"M", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "3"}], "]"}], "]"}], "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{"nn", "++"}], ";", "\"\<CL11\>\""}], ",", "\"\<CL2\>\""}], 
         "]"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"mm", "\[NotEqual]", 
         RowBox[{"Length", "[", "loop", "]"}]}], ",", 
        RowBox[{"glo", "=", "M"}]}], "]"}], ";", 
      RowBox[{"gmn", "=", 
       RowBox[{"loop", "[", 
        RowBox[{"[", 
         RowBox[{"mm", ",", "nn", ",", "1"}], "]"}], "]"}]}]}]}], 
    "]"}]}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "11 Subgroup Routines ",
 StyleBox["subgroups, subgroupTypes, collect, dico, etc",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"subgroups", "[", 
    RowBox[{
     RowBox[{"G_", "?", "MatrixQ"}], ",", 
     RowBox[{"o_:", "0"}], ",", 
     RowBox[{"i1_:", "2"}], ",", 
     RowBox[{"i2_:", "49"}], ",", 
     RowBox[{"pp_:", "associativeQ"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", "divs", ",", "dl", ",", 
       RowBox[{"f", "=", 
        RowBox[{"-", "1"}]}], ",", "g", ",", "i", ",", "j", ",", 
       RowBox[{"l", "=", 
        RowBox[{"Length", "[", "G", "]"}]}], ",", 
       RowBox[{"n", "=", "0"}], ",", 
       RowBox[{"p", "=", "pp"}], ",", "r", ",", 
       RowBox[{"test", "=", "0"}], ",", 
       RowBox[{"v", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"G", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"i1", "\[NotEqual]", "2"}], "&&", 
         RowBox[{
          RowBox[{"GCD", "[", 
           RowBox[{"l", ",", "i1"}], "]"}], "\[Equal]", "1"}]}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"i1", ",", "\"\< is not a factor of \>\"", ",", "l"}], 
          "]"}], ";", " ", 
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"i", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"NumberQ", "[", "i2", "]"}], ",", 
         RowBox[{"Max", "[", 
          RowBox[{"i1", ",", "i2"}], "]"}], ",", "i1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"o", "<", "0"}], ",", " ", 
        RowBox[{
         RowBox[{"test", "=", 
          RowBox[{"{", 
           RowBox[{"-", "o"}], "}"}]}], ";", 
         RowBox[{"i", "=", "i1"}]}], ",", 
        RowBox[{"p", "\[Equal]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"p", "=", "associativeQ"}], ",", 
        RowBox[{"ListQ", "[", "p", "]"}], ",", 
        RowBox[{"test", "=", "p"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"divs", "=", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Drop", "[", 
             RowBox[{
              RowBox[{"Divisors", "[", "l", "]"}], ",", 
              RowBox[{"-", "1"}]}], "]"}], ",", "1"}], "]"}], "-", "1"}], ",",
          
         RowBox[{
          RowBox[{"i", ">", "#1", ">=", 
           RowBox[{"i1", "-", "1"}]}], "&"}]}], "]"}]}], ";", 
      RowBox[{"sg", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"globa", "=", "G"}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Now", " ", "find", " ", "all", " ", "potential", " ", "subloops", " ",
         "in", " ", "the", " ", "range"}], " ", "*)"}], "\[IndentingNewLine]",
       
      RowBox[{"d", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"KS", "[", 
            RowBox[{"v", ",", 
             RowBox[{"divs", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "divs", "]"}]}], "}"}]}], "]"}], ",", 
         "1"}], "]"}]}], ";", 
      RowBox[{"dl", "=", 
       RowBox[{"Length", "[", "d", "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"o", ">", "2"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"{", 
           RowBox[{"dl", ",", "\"\< cases\>\""}], "}"}], "]"}], ";"}]}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"j", "=", "0"}], ";", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"j", "++"}], ";", 
         RowBox[{"j", "<", "dl"}]}], ",", 
        RowBox[{
         RowBox[{"r", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"d", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"select", "[", "r", "]"}], "\[Equal]", "r"}], ",", 
           RowBox[{"(*", " ", 
            RowBox[{"quasi", "-", 
             RowBox[{"group", " ", "filter"}]}], " ", "*)"}], 
           RowBox[{
            RowBox[{"g", "=", 
             RowBox[{"reorder", "[", 
              RowBox[{"G", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"Which", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"ListQ", "[", "test", "]"}], ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"associativeQ", "[", "g", "]"}], "&&", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"f", "=", 
                    RowBox[{"id", "[", "g", "]"}]}], ")"}], "\[NotEqual]", 
                  "\"\<Unrecognised\>\""}], "&&", 
                 RowBox[{"MemberQ", "[", 
                  RowBox[{"test", ",", 
                   RowBox[{"f", "=", 
                    RowBox[{
                    RowBox[{"gd", "[", "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], ",", 
                RowBox[{"Goto", "[", "tag", "]"}], ",", 
                RowBox[{
                 RowBox[{"globa", "=", "G"}], ";", 
                 RowBox[{"f", "=", "0"}]}]}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"p", "[", "g", "]"}], ",", 
              RowBox[{
               RowBox[{"n", "++"}], ";", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"sg", ",", "r"}], "]"}]}]}], "]"}]}]}], 
          "\[IndentingNewLine]", "]"}]}]}], "]"}], ";", 
      RowBox[{"Label", "[", "tag", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"f", ">", 
         RowBox[{"-", "1"}]}], ",", "f", ",", 
        RowBox[{"(*", " ", 
         RowBox[{"target", " ", 
          RowBox[{"found", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"o", "\[Equal]", "0"}], ",", "n", ",", " ", 
        RowBox[{"(*", " ", "count", "  ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"o", "\[Equal]", "1"}], ",", "sg", ",", 
        RowBox[{"(*", " ", 
         RowBox[{"subloop", " ", "list"}], " ", "*)"}], "\[IndentingNewLine]",
         "True", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\< Number of subloops = \>\"", ",", "n"}], "]"}], ";", 
         "sg"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"KS", "[", 
   RowBox[{"l_List", ",", "1", ",", 
    RowBox[{"gap_:", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"lef_:", 
     RowBox[{"{", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Partition", "[", 
   RowBox[{"l", ",", "1"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"KS", "[", 
   RowBox[{"l_List", ",", 
    RowBox[{"k_Integer", "?", "Positive"}], ",", 
    RowBox[{"gap_:", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"lef_:", 
     RowBox[{"{", "}"}]}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"{", "l", "}"}], "/;", 
   RowBox[{"(", 
    RowBox[{"k", "==", 
     RowBox[{"Length", "[", "l", "]"}]}], ")"}]}]}], "\n", 
 RowBox[{
  RowBox[{"KS", "[", 
   RowBox[{"l_List", ",", 
    RowBox[{"k_Integer", "?", "Positive"}], ",", 
    RowBox[{"gap_:", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"lef_:", 
     RowBox[{"{", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"f", "=", 
       RowBox[{"First", "[", "l", "]"}]}], ",", "g", ",", "ngap", ",", 
      "nlf"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"nlf", "=", 
      RowBox[{"Append", "[", 
       RowBox[{"lef", ",", "f"}], "]"}]}], ";", 
     RowBox[{"ngap", "=", 
      RowBox[{"Append", "[", 
       RowBox[{"gap", ",", "f"}], "]"}]}], ";", 
     RowBox[{"g", "=", 
      RowBox[{"Length", "[", 
       RowBox[{"Intersection", "[", 
        RowBox[{
         RowBox[{"select", "[", "nlf", "]"}], ",", "gap"}], "]"}], "]"}]}], 
     ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"g", ">", "0"}], ",", 
       RowBox[{"KS", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"l", ",", "1"}], "]"}], ",", "k", ",", "ngap", ",", "lef"}],
         "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Prepend", "[", 
              RowBox[{"#", ",", "f"}], "]"}], ")"}], "&"}], ",", 
           RowBox[{"KS", "[", 
            RowBox[{
             RowBox[{"Drop", "[", 
              RowBox[{"l", ",", "1"}], "]"}], ",", 
             RowBox[{"k", "-", "1"}], ",", "gap", ",", "nlf"}], "]"}]}], 
          "]"}], ",", 
         RowBox[{"KS", "[", 
          RowBox[{
           RowBox[{"Drop", "[", 
            RowBox[{"l", ",", "1"}], "]"}], ",", "k", ",", "ngap", ",", 
           "lef"}], "]"}]}], "]"}]}], "]"}]}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"dico", "[", "g_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"gg", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "g", "]"}], "\[Equal]", "1"}], ",", 
          RowBox[{"g", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           ",", "g", ",", "gf"}], "]"}]}], ",", 
       RowBox[{"o", "=", "1"}], ",", 
       RowBox[{"n", "=", 
        RowBox[{"{", "}"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"gf", "=", 
       RowBox[{"Sign", "[", 
        RowBox[{"Flatten", "[", "gg", "]"}], "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"abelianQ", "[", "gg", "]"}], ",", 
        RowBox[{"o", "=", "1."}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"gg", "===", 
         RowBox[{"Abs", "[", "gg", "]"}]}], ",", "Null", ",", 
        RowBox[{
         RowBox[{"o", "=", 
          RowBox[{"-", "o"}]}], ";", 
         RowBox[{"n", "=", 
          RowBox[{"{", 
           RowBox[{"negco", "[", "gg", "]"}], "}"}]}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"MemberQ", "[", 
          RowBox[{"gf", ",", "\[ImaginaryI]"}], "]"}], "||", 
         RowBox[{"MemberQ", "[", 
          RowBox[{"gf", ",", 
           RowBox[{"-", "\[ImaginaryI]"}]}], "]"}]}], ",", 
        RowBox[{"o", "=", 
         RowBox[{"\[ImaginaryI]", " ", "o"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"MemberQ", "[", 
          RowBox[{"gf", ",", "\[DoubleStruckCapitalJ]"}], "]"}], "||", 
         RowBox[{"MemberQ", "[", 
          RowBox[{"gf", ",", 
           SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "]"}]}], ",", 
        RowBox[{"o", "=", 
         RowBox[{"\[DoubleStruckCapitalJ]", " ", "o"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "gg", "]"}], "\[Equal]", "32"}], ",", 
        RowBox[{"n", "=", 
         RowBox[{"{", 
          RowBox[{"subgrpPerm", "[", 
           RowBox[{"gg", ",", "0", ",", "4", ",", "4"}], "]"}], "}"}]}]}], 
       "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "gg", "]"}], "\[Equal]", "64"}], ",", 
        RowBox[{"n", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Max", "[", 
            RowBox[{"orderCount", "[", "gg", "]"}], "]"}], ",", 
           RowBox[{"nabco", "[", "gg", "]"}]}], "}"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "gg", "]"}], "\[Equal]", "54"}], "||", 
         RowBox[{
          RowBox[{"Length", "[", "gg", "]"}], "\[Equal]", "72"}]}], ",", 
        RowBox[{"n", "=", 
         RowBox[{"{", 
          RowBox[{"subgrpPerm", "[", 
           RowBox[{"gg", ",", "0", ",", "3", ",", "3"}], "]"}], "}"}]}]}], 
       "]"}], ";", 
      RowBox[{"abbr", "[", 
       RowBox[{
        RowBox[{"Distribution", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"gg", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "i"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "gg", "]"}]}], "}"}]}], "]"}], "]"}], ",",
         "o", ",", "n"}], "]"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"trico", "[", "g_", "]"}], ":=", 
   RowBox[{"abbr", "[", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "g", "]"}], ">", "1"}], ",", 
      RowBox[{"Distribution", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"g", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", 
            RowBox[{"g", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "i"}], "]"}], "]"}]}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", "g", "]"}]}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"Distribution", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"g", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "i", ",", 
            RowBox[{"g", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "i", ",", "i"}], "]"}], "]"}]}], "]"}], "]"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"g", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], "]"}]}],
      "]"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"nabco", "[", "g_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "g", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"g", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "^", "2"}], "-", 
      RowBox[{"Length", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", 
          RowBox[{"Transpose", "[", 
           RowBox[{"g", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", "0"}], "]"}], 
       "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "g", "]"}], "^", "2"}], "-", 
      RowBox[{"Length", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"g", "-", 
          RowBox[{"Transpose", "[", "g", "]"}]}], ",", "0"}], "]"}], 
       "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"negco", "[", "g_", "]"}], ":=", 
   RowBox[{"Length", "[", 
    RowBox[{"Position", "[", 
     RowBox[{
      RowBox[{"g", "-", 
       RowBox[{"Abs", "[", "g", "]"}]}], ",", 
      RowBox[{"a_", "/;", 
       RowBox[{"a", "\[NotEqual]", "0"}]}]}], "]"}], "]"}]}], ";"}]}], "Input",\

 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"subgrpPerm", "[", 
    RowBox[{"g_", ",", 
     RowBox[{"a_", ":", "0"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{
           RowBox[{"Last", "/@", 
            RowBox[{"Sort", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"RandomReal", "[", "]"}], ",", "#1"}], "}"}], "&"}],
                ")"}], "/@", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"Length", "[", "g", "]"}], "-", "1"}], "]"}]}], 
             "]"}]}], "+", "1"}]}], "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"subgroups", "[", 
      RowBox[{
       RowBox[{"reorder", "[", 
        RowBox[{"g", ",", "p"}], "]"}], ",", "a"}], "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"subgrpPerm", "[", 
    RowBox[{"g_", ",", "a_", ",", "b_", ",", "c_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{
           RowBox[{"Last", "/@", 
            RowBox[{"Sort", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"RandomReal", "[", "]"}], ",", "#1"}], "}"}], "&"}],
                ")"}], "/@", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"Length", "[", "g", "]"}], "-", "1"}], "]"}]}], 
             "]"}]}], "+", "1"}]}], "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"subgroups", "[", 
      RowBox[{
       RowBox[{"reorder", "[", 
        RowBox[{"g", ",", "p"}], "]"}], ",", "a", ",", "b", ",", "c"}], 
      "]"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"subgroupTypes", "[", 
   RowBox[{"sg_:", "sg"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", ",", 
      RowBox[{"l", "=", 
       RowBox[{"Length", "[", "sg", "]"}]}], ",", "j", ",", 
      RowBox[{"g", "=", "globa"}], ",", 
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"Last", "[", "sg", "]"}], "]"}]}], ",", "n", ",", "count", 
      ",", 
      RowBox[{"types", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"count", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"count", "[", 
         RowBox[{"[", 
          RowBox[{"Length", "[", 
           RowBox[{"sg", "[", 
            RowBox[{"[", "j", "]"}], "]"}], " ", "]"}], " ", "]"}], "]"}], 
        "++"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "l"}], "}"}]}], "]"}], ";", 
     RowBox[{"n", "=", "1"}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"c", "=", 
         RowBox[{"count", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"c", ">", "0"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"PrimeQ", "[", "i", "]"}], ",", 
            RowBox[{
             RowBox[{"n", "+=", "c"}], ";", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"types", ",", 
               RowBox[{"{", 
                RowBox[{"c", ",", 
                 RowBox[{"StringJoin", "[", 
                  RowBox[{"\"\<C\>\"", ",", 
                   RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}], "}"}]}], 
              "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"Do", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"AppendTo", "[", 
                RowBox[{"types", ",", 
                 RowBox[{"{", 
                  RowBox[{"id", "[", 
                   RowBox[{"g", ",", 
                    RowBox[{"sg", "[", 
                    RowBox[{"[", "n", "]"}], "]"}]}], "]"}], "}"}]}], "]"}], 
               ";", 
               RowBox[{"n", "++"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"z", ",", 
                RowBox[{"count", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}]}], 
         "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", "m"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "types"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"collect", "[", 
   RowBox[{"sg_:", "%"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", "=", 
       RowBox[{"Length", "[", "sg", "]"}]}], ",", 
      RowBox[{"c", "=", 
       RowBox[{"{", "}"}]}], ",", "s", ",", "s1"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"s", "=", 
            RowBox[{"sg", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ">", "1"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"c", ",", "s"}], "]"}], ",", 
         RowBox[{
          RowBox[{"s1", "=", 
           RowBox[{"Position", "[", 
            RowBox[{"c", ",", 
             RowBox[{"s", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"s1", "\[Equal]", 
             RowBox[{"{", "}"}]}], ",", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"c", ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"s", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{"s1", "=", 
              RowBox[{"s1", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", 
             RowBox[{
              RowBox[{"c", "[", 
               RowBox[{"[", 
                RowBox[{"s1", ",", "1"}], "]"}], "]"}], "=", 
              RowBox[{
               RowBox[{"c", "[", 
                RowBox[{"[", 
                 RowBox[{"s1", ",", "1"}], "]"}], "]"}], "+", "1"}]}]}]}], 
           "]"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}]}], "]"}], ";", "c"}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "12 Generalised Hoop Algebra Routines ",
 StyleBox["toPolar etc, hoopTimes, hoopInverse, hoopP",
  FontSlant->"Italic"],
 "o",
 StyleBox["wer, hoopTest, genQuadratic, c2simeq, rotateQOP.",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth],

Cell["\<\
toPolar[{a__},g_:gmn]:=toPol[{a},g];
toVector[{a__},g_:gmn]:=toVec[{a},g];
tohyPolar[{a__},g_:gmn]:=tohyPol[{a},g];
tohyVector[{a__},g_:gmn]:=tohyVec[{a},g];\
\>", "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"a_", "?", "VectorQ"}], ",", 
    RowBox[{"b_", "?", "VectorQ"}], ",", 
    RowBox[{"g_", "?", "MatrixQ"}]}], "]"}], ":=", 
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"glo", "=", "g"}], ";", 
     RowBox[{"mm", "=", 
      RowBox[{"Length", "[", "g", "]"}]}], ";", "a"}], ",", "b"}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"a_", "?", "VectorQ"}], ",", 
     RowBox[{"b_", "?", "VectorQ"}], ",", "g_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Head", "[", "g", "]"}], "===", "String"}]}], ":=", 
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"glo", "=", 
      RowBox[{"mp", "[", "g", "]"}]}], ";", 
     RowBox[{"gmn", "=", "g"}], ";", 
     RowBox[{"mm", "=", 
      RowBox[{"Length", "[", "g", "]"}]}], ";", "a"}], ",", "b"}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"a_", "?", "VectorQ"}], ",", 
    RowBox[{"b_", "?", "VectorQ"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "i", ",", "j", ",", "p", ",", "s", ",", "ss", ",", "st", ",", "t", ",", 
      "u"}], "}"}], ",", 
    RowBox[{
     RowBox[{"u", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"kk", ",", 
          RowBox[{"mm", "=", 
           RowBox[{"Length", "[", "glo", "]"}]}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"t", "=", "u"}], ";", 
     RowBox[{"i", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"a", ",", "t"}], "]"}]}], ";", 
     RowBox[{"j", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"b", ",", "t"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"s", "=", 
           RowBox[{"glo", "\[LeftDoubleBracket]", 
            RowBox[{"ll", ",", "kk"}], "\[RightDoubleBracket]"}]}], ";", 
          RowBox[{"ss", "=", 
           RowBox[{"Sign", "[", "s", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"st", "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"ss", "===", "0"}], ",", "s", ",", 
             RowBox[{"s", "/", "ss"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          
          RowBox[{
           RowBox[{
           "t", "\[LeftDoubleBracket]", "st", "\[RightDoubleBracket]"}], "+=",
            
           RowBox[{
            RowBox[{
             RowBox[{
             "i", "\[LeftDoubleBracket]", "ll", "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
             "j", "\[LeftDoubleBracket]", "kk", "\[RightDoubleBracket]"}], 
             " ", "ss"}], "/.", 
            RowBox[{"List", "\[Rule]", "0"}]}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"kk", ",", "mm"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ll", ",", "mm"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]",
      
     RowBox[{"Rl", "=", "u"}], ";", 
     RowBox[{"Rr", "=", "u"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "=", 
          RowBox[{"Position", "[", 
           RowBox[{
            RowBox[{"shape", "[", "t", "]"}], ",", "0"}], "]"}]}], ")"}], 
        "\[NotEqual]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Complement", "[", 
            RowBox[{"p", ",", 
             RowBox[{"Position", "[", 
              RowBox[{
               RowBox[{"shape", "[", "a", "]"}], ",", "0"}], "]"}]}], "]"}], 
           "\[NotEqual]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{
           RowBox[{"u", "=", 
            RowBox[{"hoopInverse", "[", "b", "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{"Do", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"s", "=", 
                 RowBox[{"glo", "\[LeftDoubleBracket]", 
                  RowBox[{"ll", ",", "kk"}], "\[RightDoubleBracket]"}]}], ";",
                 
                RowBox[{"ss", "=", 
                 RowBox[{"Sign", "[", "s", "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"st", "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"ss", "===", "0"}], ",", "s", ",", 
                   RowBox[{"s", "/", "ss"}]}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                 "Rl", "\[LeftDoubleBracket]", "st", 
                  "\[RightDoubleBracket]"}], "+=", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "u", "\[LeftDoubleBracket]", "kk", 
                    "\[RightDoubleBracket]"}], " ", 
                   RowBox[{
                   "t", "\[LeftDoubleBracket]", "ll", 
                    "\[RightDoubleBracket]"}], " ", "ss"}], "/.", 
                  RowBox[{"List", "\[Rule]", "0"}]}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"kk", ",", "mm"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"ll", ",", "mm"}], "}"}]}], "]"}], ";", 
           RowBox[{"Rl", "=", 
            RowBox[{"Chop", "[", 
             RowBox[{"a", "-", "Rl"}], "]"}]}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Complement", "[", 
            RowBox[{"p", ",", 
             RowBox[{"Position", "[", 
              RowBox[{
               RowBox[{"shape", "[", "b", "]"}], ",", "0"}], "]"}]}], "]"}], 
           "\[NotEqual]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{
           RowBox[{"u", "=", 
            RowBox[{"hoopInverse", "[", "a", "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{"Do", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"s", "=", 
                 RowBox[{"glo", "\[LeftDoubleBracket]", 
                  RowBox[{"ll", ",", "kk"}], "\[RightDoubleBracket]"}]}], ";",
                 
                RowBox[{"ss", "=", 
                 RowBox[{"Sign", "[", "s", "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"st", "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"ss", "===", "0"}], ",", "s", ",", 
                   RowBox[{"s", "/", "ss"}]}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                 "Rr", "\[LeftDoubleBracket]", "st", 
                  "\[RightDoubleBracket]"}], "+=", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "t", "\[LeftDoubleBracket]", "kk", 
                    "\[RightDoubleBracket]"}], 
                   RowBox[{
                   "u", "\[LeftDoubleBracket]", "ll", 
                    "\[RightDoubleBracket]"}], "  ", "ss"}], "/.", 
                  RowBox[{"List", "\[Rule]", "0"}]}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"kk", ",", "mm"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"ll", ",", "mm"}], "}"}]}], "]"}], ";", 
           RowBox[{"Rr", "=", 
            RowBox[{"Chop", "[", 
             RowBox[{"b", "-", "Rr"}], "]"}]}]}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", "t"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"hmin", "=", 
   RowBox[{"4", "$MachineEpsilon"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"hoopInverse", "[", 
    RowBox[{"v_", "?", "VectorQ"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "arrsz", ",", "abcsz", ",", "ls", ",", "inv", ",", "var", ",", "vec", 
       ",", "s", ",", "temp"}], "}"}], ",", 
     RowBox[{
      RowBox[{"inv", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "mm"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"vec", "=", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Append", "[", 
           RowBox[{"v", ",", "inv"}], "]"}], "]"}], ",", "mm"}], "]"}]}], ";",
       
      RowBox[{"arrsz", "=", 
       RowBox[{"shape", "[", "vec", "]"}]}], ";", 
      RowBox[{"ls", "=", 
       RowBox[{"Length", "[", "arrsz", "]"}]}], ";", 
      RowBox[{"abcsz", "=", 
       RowBox[{"hoopShape", "[", "]"}]}], ";", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "=", 
          RowBox[{"Sign", "[", 
           RowBox[{
           "gi", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
           "]"}]}], ";", 
         RowBox[{"var", "=", 
          RowBox[{"alph", "\[LeftDoubleBracket]", 
           RowBox[{
            RowBox[{"gi", "[", 
             RowBox[{"[", "ii", "]"}], "]"}], "/", "s"}], 
           "\[RightDoubleBracket]"}]}], ";", 
         RowBox[{"temp", "=", "0"}], ";", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Which", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"Chop", "[", 
                RowBox[{
                 RowBox[{
                 "arrsz", "\[LeftDoubleBracket]", "jj", 
                  "\[RightDoubleBracket]"}], ",", "hmin"}], "]"}], "]"}], "===",
               "0"}], ",", "Null", ",", "True", ",", 
             RowBox[{"temp", "+=", 
              RowBox[{"s", " ", 
               RowBox[{"gi", "\[LeftDoubleBracket]", 
                RowBox[{"mm", "+", "jj"}], "\[RightDoubleBracket]"}], 
               RowBox[{
                RowBox[{
                 SubscriptBox["\[PartialD]", "var"], 
                 RowBox[{
                 "abcsz", "\[LeftDoubleBracket]", "jj", 
                  "\[RightDoubleBracket]"}]}], "/", 
                RowBox[{
                "abcsz", "\[LeftDoubleBracket]", "jj", 
                 "\[RightDoubleBracket]"}]}]}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"jj", ",", "ls"}], "}"}]}], "]"}], ";", 
         RowBox[{
          RowBox[{
          "inv", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], "+=",
           "temp"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "mm"}], "}"}]}], "]"}], ";", 
      RowBox[{"Chop", "[", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"inv", "/", "mm"}], "/.", 
         RowBox[{"fromAlph", "[", "vec", "]"}]}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[TextData[{
 StyleBox["hoopInverse",
  FontSlant->"Italic"],
 " Procedure:- based on Cramer's method, to give Ainv.A={1,0,0...}.\n",
 StyleBox["la",
  FontSlant->"Italic"],
 " is the length of ",
 StyleBox["vec",
  FontSlant->"Italic"],
 ";  ",
 StyleBox["arrsz",
  FontSlant->"Italic"],
 " is the ",
 StyleBox["shape",
  FontSlant->"Italic"],
 " of ",
 StyleBox["vec",
  FontSlant->"Italic"],
 "; finding it also sets ",
 StyleBox["gi",
  FontSlant->"Italic"],
 ". ",
 StyleBox["abcsz",
  FontSlant->"Italic"],
 " becomes ",
 StyleBox["sh[glo]",
  FontSlant->"Italic"],
 ", the symbolic conserved factors. ",
 StyleBox["inv",
  FontSlant->"Italic"],
 " is initialised as a table of zeroes, to be filled in by the ",
 StyleBox["ii",
  FontSlant->"Italic"],
 " loop. For each ",
 StyleBox["ii",
  FontSlant->"Italic"],
 ", the sign is found from ",
 StyleBox["gi",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["var",
  FontSlant->"Italic"],
 " is the ",
 StyleBox["ii",
  FontSlant->"Italic"],
 "'th symbol used in ",
 StyleBox["abcsz",
  FontSlant->"Italic"],
 ". The ",
 StyleBox["jj",
  FontSlant->"Italic"],
 " loop ignores near-zero sizes, and adds to ",
 StyleBox["temp",
  FontSlant->"Italic"],
 " the derivations (wrt the variable ",
 StyleBox["var",
  FontSlant->"Italic"],
 " indicated by ",
 StyleBox["gi",
  FontSlant->"Italic"],
 ") of the size, divided by the size and multiplied by the sign ",
 StyleBox["s",
  FontSlant->"Italic"],
 " and by the multiplicity ",
 StyleBox["gi\[LeftDoubleBracket]la+jj\[RightDoubleBracket]",
  FontSlant->"Italic"],
 " . On completion of this loop, ",
 StyleBox["temp",
  FontSlant->"Italic"],
 " is put into ",
 StyleBox["inv",
  FontSlant->"Italic"],
 ". Finally, ",
 StyleBox["inv",
  FontSlant->"Italic"],
 " is divided by ",
 StyleBox["la",
  FontSlant->"Italic"],
 " and the symbols are replaced by whatever was supplied as ",
 StyleBox["vec",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hoopPower", "[", 
    RowBox[{"A_", ",", 
     RowBox[{"r_:", 
      RowBox[{"1", "/", "2"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "=", 
        RowBox[{"{", "}"}]}], ",", "lg", ",", "l", ",", 
       RowBox[{"s", "=", 
        RowBox[{"shape", "[", "A", "]"}]}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"r", "<", "0"}], ",", 
       RowBox[{"hoopPower", "[", 
        RowBox[{
         RowBox[{"hoopInverse", "[", "A", "]"}], ",", 
         RowBox[{"-", "r"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"l", "=", 
         RowBox[{"toPolar", "[", "A", "]"}]}], ";", 
        RowBox[{"lg", "=", 
         RowBox[{"Length", "[", "gp", "]"}]}], ";", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"a", ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"IntegerQ", "[", 
               RowBox[{"gp", "[", 
                RowBox[{"[", "ii", "]"}], "]"}], "]"}], ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Head", "[", 
                  RowBox[{"l", "[", 
                   RowBox[{"[", "ii", "]"}], "]"}], "]"}], "===", "Complex"}],
                 ",", 
                SuperscriptBox[
                 RowBox[{"l", "[", 
                  RowBox[{"[", "ii", "]"}], "]"}], "r"], ",", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Abs", "[", 
                   RowBox[{"l", "[", 
                    RowBox[{"[", "ii", "]"}], "]"}], "]"}], "r"], "  ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{"l", "[", 
                   RowBox[{"[", "ii", "]"}], "]"}], "]"}]}], ",", 
                SuperscriptBox[
                 RowBox[{"l", "[", 
                  RowBox[{"[", "ii", "]"}], "]"}], "r"]}], "]"}], ",", 
              RowBox[{"r", 
               RowBox[{"l", "[", 
                RowBox[{"[", "ii", "]"}], "]"}]}]}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "lg"}], "}"}]}], "]"}], ";", 
        RowBox[{"Chop", "[", 
         RowBox[{"toVector", "[", "a", "]"}], "]"}]}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[TextData[{
 "hoopPo",
 "wer",
 StyleBox[" procedure:- If the power is negative, calculate the positive \
power of the inverse. Find the polar form; multiply angles by the power; \
replace sizes by the signed power of the absolute size. (Complex numbers are \
raised to the power.) Recover the vector from the new polar data.",
  FontSlant->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hoopTest", "[", 
   RowBox[{
    RowBox[{"x_:", "glo"}], ",", 
    RowBox[{"t_:", "Real"}], ",", 
    RowBox[{"r_:", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1."}], ",", "1."}], "}"}]}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "A", ",", "Am", ",", "Ap", ",", "B", ",", "BA", ",", "Bi", ",", "C", ",",
       "ms", ",", 
      RowBox[{"no", "=", "\"\< No other\>\""}], ",", "pa", ",", "pb", ",", 
      "pab", ",", 
      RowBox[{"q", "=", "0"}], ",", "res", ",", "result", ",", "sx", ",", 
      RowBox[{"sz", "=", 
       RowBox[{"2", "^", 
        RowBox[{"-", "16"}]}]}], ",", "xq", ",", "X"}], "}"}], ",", 
    RowBox[{
     RowBox[{"X", "=", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "x", "]"}], "===", "TraditionalForm"}], ",", 
        RowBox[{"x", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"Head", "[", "x", "]"}], "===", "String"}], ",", 
        RowBox[{"mp", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"IntegerQ", "[", "x", "]"}], "&&", 
         RowBox[{"IntegerQ", "[", "T", "]"}]}], ",", 
        RowBox[{
         RowBox[{"t", "=", "Real"}], ";", 
         RowBox[{"mp", "[", 
          RowBox[{"x", ",", "T"}], "]"}]}], ",", "True", ",", "x"}], "]"}]}], 
     ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MatrixQ", "[", "X", "]"}], "===", "False"}], ",", 
       RowBox[{"X", "=", 
        RowBox[{"makeProtoloop", "[", "x", "]"}]}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"X", "===", "glo"}], ",", ",", 
       RowBox[{"glo", "=", 
        RowBox[{"caylindex", "[", "X", "]"}]}]}], "]"}], ";", 
     RowBox[{"gmn", "=", 
      RowBox[{"id", "[", "glo", "]"}]}], ";", 
     RowBox[{"res", "=", "gmn"}], ";", "\[IndentingNewLine]", 
     RowBox[{"hoopFactor", "[", "]"}], ";", 
     RowBox[{"ms", "=", 
      RowBox[{"minsign", "[", "glo", "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", 
         RowBox[{"sh", "[", "\"\<Unrecognized\>\"", "]"}], "]"}], "===", 
        "List"}], ",", 
       RowBox[{
        RowBox[{"sh", "[", "\"\<Unrecognized\>\"", "]"}], "=."}]}], "]"}], 
     ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", 
         RowBox[{"sh", "[", "gmn", "]"}], "]"}], "===", "sh"}], ",", 
       RowBox[{
        RowBox[{"sh", "[", "gmn", "]"}], "=", 
        RowBox[{"hoopShape", "[", "]"}]}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"o", ">", "0"}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<Hoop =\>\"", ",", "res", ",", "X", ",", "mm"}], "}"}], 
        "]"}]}], "]"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"A", "=", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"RandomReal", "[", "r", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "mm"}], "}"}]}], "]"}], "//", "N"}]}], ";"}], 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"0", ",", 
           RowBox[{"pa", "=", 
            RowBox[{
             RowBox[{"Chop", "[", 
              RowBox[{
               RowBox[{"Expand", "[", 
                RowBox[{"shape", "[", "A", "]"}], "]"}], ",", "sz"}], "]"}], "/.",
              "ms"}]}]}], "]"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}]}], ","}], "]"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"B", "=", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"RandomReal", "[", "r", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "mm"}], "}"}]}], "]"}], "//", "N"}]}], ";", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{"Chop", "[", 
             RowBox[{
              RowBox[{"pb", "=", 
               RowBox[{"Expand", "[", 
                RowBox[{"shape", "[", "B", "]"}], "]"}]}], ",", "sz"}], "]"}],
             "/.", "ms"}]}], "]"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}]}], ","}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"AB", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "B"}], "]"}]}], ";", 
     RowBox[{"pba", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{"shape", "[", "AB", "]"}], "]"}], "/.", "ms"}], ",", "sz"}],
        "]"}]}], ";", 
     RowBox[{"Am", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Expand", "[", 
            RowBox[{"pa", "*", "pb"}], "]"}], "-", "pba"}], ")"}], "/.", 
         "ms"}], ",", "sz"}], "]"}]}], ";", 
     RowBox[{"Ap", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Expand", "[", 
            RowBox[{"pa", "*", "pb"}], "]"}], "+", "pba"}], ")"}], "/.", 
         "ms"}], ",", "sz"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"o", ">", "2"}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"{", 
         RowBox[{
         "\"\<A=\>\"", ",", "A", ",", "\"\<\\nB=\>\"", ",", "B", ",", 
          "\"\<\\nAB=\>\"", ",", "AB", ",", 
          "\"\<pa,pb,pa pb,pba,pa pb-pba\>\"", ",", "pa", ",", "pb", ",", 
          RowBox[{"pa", " ", "pb"}], ",", "pba", ",", "Am", ",", 
          RowBox[{"Union", "[", "Am", "]"}], ",", "Ap", ",", 
          RowBox[{"Union", "[", "Ap", "]"}]}], "}"}], "]"}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Union", "[", "Am", "]"}], "]"}], "===", 
          RowBox[{"{", "0", "}"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Union", "[", "Ap", "]"}], "]"}], "===", 
          RowBox[{"{", "0", "}"}]}], ")"}]}], ",", 
       RowBox[{"res", "=", 
        RowBox[{"\"\<Conservative \>\"", "<>", "res"}]}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"gmn", "==", "\"\<Unrecognized\>\""}], ",", 
          RowBox[{"Print", "[", 
           RowBox[{"gmn", "<>", "\"\< Factors NOT conserved\>\""}], "]"}], 
          ",", 
          RowBox[{"Print", "[", 
           RowBox[{
           "gmn", "<>", 
            "\"\< Isomorph. Protoloop factors NOT conserved\>\""}], "]"}]}], 
         "]"}], ";", 
        RowBox[{"Goto", "[", "exit", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Ai", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Together", "[", 
          RowBox[{"Expand", "[", 
           RowBox[{"hoopInverse", "[", "A", "]"}], "]"}], "]"}], "/.", "ms"}],
         ",", "sz"}], "]"}]}], ";", 
     RowBox[{"pba", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Together", "[", 
          RowBox[{"Expand", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"AiAB", "=", 
              RowBox[{"hoopTimes", "[", 
               RowBox[{"Ai", ",", "AB"}], "]"}]}], ")"}], "-", "B"}], "]"}], 
          "]"}], "/.", "ms"}], ",", "sz"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"o", ">", "0"}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"{", 
         RowBox[{
         "\"\<A Inverse=\>\"", ",", "Ai", ",", "\"\<AiAB=\>\"", ",", "AiAB", 
          ",", "\"\<AiAB-B=\>\"", ",", "pba"}], "}"}], "]"}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Union", "[", "pba", "]"}], "===", 
        RowBox[{"{", "0", "}"}]}], ",", 
       RowBox[{
        RowBox[{"no", "=", "\"\<\>\""}], ";", 
        RowBox[{"res", "=", 
         RowBox[{"res", "<>", "\"\<, division\>\""}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", 
         RowBox[{"toPol", "[", 
          RowBox[{"A", ",", "gmn"}], "]"}], "]"}], "===", "List"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Union", "[", 
            RowBox[{"Chop", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"toVector", "[", 
                RowBox[{"toPolar", "[", "A", "]"}], "]"}], "-", "A"}], ",", 
              "sz"}], "]"}], "]"}], "===", 
           RowBox[{"{", "0", "}"}]}], ",", 
          RowBox[{
           RowBox[{"no", "=", "\"\<\>\""}], ";", 
           RowBox[{"res", "=", 
            RowBox[{"res", "<>", "\"\<, polar-vector\>\""}]}]}]}], "]"}], ";",
         
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Union", "[", 
            RowBox[{"Chop", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"hoopPower", "[", 
                RowBox[{
                 RowBox[{"hoopPower", "[", "A", "]"}], ",", "2"}], "]"}], "-",
                "A"}], ",", "sz"}], "]"}], "]"}], "===", 
           RowBox[{"{", "0", "}"}]}], ",", 
          RowBox[{
           RowBox[{"no", "=", "\"\<\>\""}], ";", 
           RowBox[{"res", "=", 
            RowBox[{"res", "<>", "\"\<, +ve Powers\>\""}]}]}]}], "]"}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"abelianQ", "[", "glo", "]"}], ",", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"q", "<", "10"}], ",", 
            RowBox[{
             RowBox[{"q", "++"}], ";", 
             RowBox[{"A", "=", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"RandomReal", "[", "r", "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "mm"}], "}"}]}], "]"}]}], ";", 
             RowBox[{"B", "=", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"RandomReal", "[", "r", "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "mm"}], "}"}]}], "]"}]}], ";", 
             RowBox[{"xq", "=", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"RandomReal", "[", "r", "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "mm"}], "}"}]}], "]"}], "//", "N"}]}], 
             ";", 
             RowBox[{"sx", "=", 
              RowBox[{"shape", "[", "xq", "]"}]}], ";", 
             RowBox[{"C", "=", 
              RowBox[{
               RowBox[{"hoopTimes", "[", 
                RowBox[{"A", ",", 
                 RowBox[{"hoopTimes", "[", 
                  RowBox[{"xq", ",", "xq"}], "]"}]}], "]"}], "+", 
               RowBox[{"hoopTimes", "[", 
                RowBox[{"B", ",", "xq"}], "]"}]}]}], ";", 
             RowBox[{"result", "=", 
              RowBox[{"Chop", "[", 
               RowBox[{"genQuadratic", "[", 
                RowBox[{"A", ",", "B", ",", "C"}], "]"}], "]"}]}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Union", "[", 
                  RowBox[{"Chop", "[", 
                   RowBox[{"sx", "-", 
                    RowBox[{"shape", "[", 
                    RowBox[{"result", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], "]"}], "===",
                  
                 RowBox[{"{", "0", "}"}]}], "||", 
                RowBox[{
                 RowBox[{"Union", "[", 
                  RowBox[{"Chop", "[", 
                   RowBox[{"sx", "-", 
                    RowBox[{"shape", "[", 
                    RowBox[{"result", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}], "]"}], "===",
                  
                 RowBox[{"{", "0", "}"}]}]}], ",", 
               RowBox[{
                RowBox[{"res", "=", 
                 RowBox[{"res", "<>", "\"\<, quadratic eqn.\>\""}]}], ";", 
                RowBox[{"q", "=", "10"}]}]}], "]"}]}]}], "]"}]}], "]"}], ";", 
        
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Union", "[", 
            RowBox[{"Chop", "[", 
             RowBox[{
              RowBox[{"hoopPower", "[", 
               RowBox[{
                RowBox[{"hoopPower", "[", 
                 RowBox[{"A", ",", 
                  RowBox[{
                   RowBox[{"-", "1"}], "/", "3"}]}], "]"}], ",", 
                RowBox[{"-", "3"}]}], "]"}], "-", "A"}], "]"}], "]"}], "===", 
           
           RowBox[{"{", "0", "}"}]}], ",", 
          RowBox[{
           RowBox[{"no", "=", "\"\<\>\""}], ";", 
           RowBox[{"res", "=", 
            RowBox[{"res", "<>", "\"\<, -ve Powers\>\""}]}]}]}], "]"}]}]}], 
      "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", 
         RowBox[{"tohyPol", "[", 
          RowBox[{"A", ",", "gmn"}], "]"}], "]"}], "===", "List"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"Chop", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"tohyVector", "[", 
               RowBox[{"tohyPolar", "[", "A", "]"}], "]"}], "-", "A"}], ",", 
             "sz"}], "]"}], "]"}], "===", 
          RowBox[{"{", "0", "}"}]}], ",", 
         RowBox[{
          RowBox[{"no", "=", "\"\<\>\""}], ";", 
          RowBox[{"res", "=", 
           RowBox[{"res", "<>", "\"\<, hyPolar\>\""}]}]}]}], "]"}]}], "]"}], 
     ";", 
     RowBox[{"Label", "[", "exit", "]"}], ";", 
     RowBox[{"res", "<>", "no", "<>", "\"\< test(s) passed\>\""}]}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"genQuadratic", "[", 
    RowBox[{
     RowBox[{"A_", "?", "VectorQ"}], ",", 
     RowBox[{"B_", "?", "VectorQ"}], ",", 
     RowBox[{"C_", "?", "VectorQ"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "gp", "]"}], "\[NotEqual]", 
        RowBox[{"Length", "[", "A", "]"}]}], ",", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<Roots unavailable\>\"", "]"}], ";", 
        RowBox[{"Abort", "[", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"a", "=", 
         RowBox[{"hoopInverse", "[", "A", "]"}]}], ";", 
        RowBox[{"b", "=", 
         RowBox[{"hoopRoot", "[", 
          RowBox[{
           RowBox[{"hoopTimes", "[", 
            RowBox[{"B", ",", "B"}], "]"}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"hoopTimes", "[", 
             RowBox[{"A", ",", "C"}], "]"}]}]}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"hoopTimes", "[", 
            RowBox[{"a", ",", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "B"}], "+", "b"}], ")"}]}], "]"}], ",", 
           RowBox[{"hoopTimes", "[", 
            RowBox[{"a", ",", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "B"}], "-", "b"}], ")"}]}], "]"}]}], "}"}], "/", 
         "2"}]}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{
   StyleBox[
    RowBox[{"hoopRoot", "[", 
     RowBox[{"A_", "?", "VectorQ"}], "]"}],
    ShowStringCharacters->True,
    NumberMarks->True], 
   StyleBox[" ",
    ShowStringCharacters->True,
    NumberMarks->True], 
   StyleBox[":=",
    ShowStringCharacters->True,
    NumberMarks->True], 
   RowBox[{
    StyleBox["Module",
     ShowStringCharacters->True,
     NumberMarks->True], 
    StyleBox["[",
     ShowStringCharacters->True,
     NumberMarks->True], 
    RowBox[{
     StyleBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "=", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"l", "=", 
         RowBox[{"toPolar", "[", "A", "]"}]}]}], "}"}],
      ShowStringCharacters->True,
      NumberMarks->True], 
     StyleBox[",",
      ShowStringCharacters->True,
      NumberMarks->True], 
     StyleBox[
      RowBox[{"(*", " ", 
       RowBox[{
       "gp", " ", "shows", " ", "whether", " ", "radius", " ", "or", " ", 
        "angle"}], " ", "*)"}],
      ShowStringCharacters->True,
      NumberMarks->True], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       StyleBox["Do",
        ShowStringCharacters->True,
        NumberMarks->True], 
       StyleBox["[",
        ShowStringCharacters->True,
        NumberMarks->True], 
       RowBox[{
        StyleBox[
         RowBox[{"AppendTo", "[", 
          RowBox[{"a", ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"IntegerQ", "[", 
              RowBox[{"gp", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{
                 StyleBox["l",
                  ShowStringCharacters->True,
                  NumberMarks->True], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], 
               RowBox[{"1", "/", "2"}]], 
              RowBox[{"Sign", "[", 
               RowBox[{"l", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"l", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "/", "2"}]}], "]"}]}], "]"}],
         ShowStringCharacters->True,
         NumberMarks->True], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "gp", "]"}]}], "}"}]}], "]"}], ";", 
      RowBox[{
       StyleBox["Chop",
        ShowStringCharacters->True,
        NumberMarks->True], 
       StyleBox["[",
        ShowStringCharacters->True,
        NumberMarks->True], 
       RowBox[{
        StyleBox["toVector",
         ShowStringCharacters->True,
         NumberMarks->True], 
        StyleBox["[",
         ShowStringCharacters->True,
         NumberMarks->True], "a", 
        StyleBox["]",
         ShowStringCharacters->True,
         NumberMarks->True]}], "]"}]}]}], "]"}]}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"c2simeq", "[", 
    RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], ":=", 
   RowBox[{"c2simeq", "[", 
    RowBox[{
     RowBox[{"a", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"a", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"b", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"b", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"c", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"c", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"a", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"a", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"b", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"b", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"c", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], ",",
      
     RowBox[{"c", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c2simeq", "[", 
   RowBox[{
   "a1_", ",", "a2_", ",", "b1_", ",", "b2_", ",", "c1_", ",", "c2_", ",", 
    "a3_", ",", "a4_", ",", "b3_", ",", "b4_", ",", "c3_", ",", "c4_"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1m2b", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a1", "-", "a2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"b3", "-", "b4"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a3", "-", "a4"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"b1", "-", "b2"}], ")"}]}]}]}], ",", 
      RowBox[{"a1p2b", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a1", "+", "a2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"b3", "+", "b4"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a3", "+", "a4"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"b1", "+", "b2"}], ")"}]}]}]}], ",", 
      RowBox[{"a1m2c", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a1", "-", "a2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"c3", "-", "c4"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a3", "-", "a4"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"c1", "-", "c2"}], ")"}]}]}]}], ",", 
      RowBox[{"a1p2c", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a1", "+", "a2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"c3", "+", "c4"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a3", "+", "a4"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"c1", "+", "c2"}], ")"}]}]}]}], ",", 
      RowBox[{"b1m2", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"b1", "-", "b2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"c3", "-", "c4"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"b3", "-", "b4"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"c1", "-", "c2"}], ")"}]}]}]}], ",", 
      RowBox[{"b1p2", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"b1", "+", "b2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"c3", "+", "c4"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"b3", "+", "b4"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"c1", "+", "c2"}], ")"}]}]}]}], ",", "x4"}], "}"}], ",", 
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"a1p2b", "==", "0"}], "&&", 
        RowBox[{"a1p2c", "==", "0"}]}], "||", 
       RowBox[{"a1m2b", "==", "0"}]}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"c1", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a4", " ", "b2"}], "-", 
                 RowBox[{"a1", " ", "b3"}]}], ")"}]}], "+", 
              RowBox[{"c2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a2", " ", "b3"}], "-", 
                 RowBox[{"a4", " ", "b1"}]}], ")"}]}], "+", 
              RowBox[{"c3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a1", " ", "b1"}], "-", 
                 RowBox[{"a2", " ", "b2"}]}], ")"}]}], "+", 
              RowBox[{"x4", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a4", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["b1", "2"], "-", 
                    SuperscriptBox["b2", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"a1", " ", "b2"}], "-", 
                    RowBox[{"a2", " ", "b1"}]}], ")"}], " ", "b3"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"a2", " ", "b2"}], "-", 
                    RowBox[{"a1", " ", "b1"}]}], ")"}], " ", "b4"}]}], 
                ")"}]}]}], ",", 
             RowBox[{
              RowBox[{"c1", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a2", " ", "b3"}], "-", 
                 RowBox[{"a3", " ", "b2"}]}], ")"}]}], "+", 
              RowBox[{"c2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a3", " ", "b1"}], "-", 
                 RowBox[{"a1", " ", "b3"}]}], ")"}]}], "+", 
              RowBox[{"c3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a1", " ", "b2"}], "-", 
                 RowBox[{"a2", " ", "b1"}]}], ")"}]}], "+", 
              RowBox[{"x4", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["b2", "2"], "-", 
                    SuperscriptBox["b1", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"a1", " ", "b1"}], "-", 
                    RowBox[{"a2", " ", "b2"}]}], ")"}], " ", "b3"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"a2", " ", "b1"}], "-", 
                    RowBox[{"a1", " ", "b2"}]}], ")"}], " ", "b4"}]}], 
                ")"}]}]}], ",", 
             RowBox[{
              FractionBox["1", "a2"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a1"}], " ", "a3"}], "+", 
                   RowBox[{"a2", " ", "a4"}]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"a1", " ", 
                    RowBox[{"(", 
                    RowBox[{"c2", "-", 
                    RowBox[{"b1", " ", "x4"}]}], ")"}]}], "-", 
                   RowBox[{"a2", " ", 
                    RowBox[{"(", 
                    RowBox[{"c1", "-", 
                    RowBox[{"b2", " ", "x4"}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["a1", "2"], "-", 
                   SuperscriptBox["a2", "2"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"a3", " ", "c2"}], "-", 
                   RowBox[{"a2", " ", "c3"}], "-", 
                   RowBox[{"a3", " ", "b1", " ", "x4"}], "+", 
                   RowBox[{"a2", " ", "b4", " ", "x4"}]}], ")"}]}]}], 
               ")"}]}]}], "}"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a1", " ", "a3"}], "-", 
                RowBox[{"a2", " ", "a4"}]}], ")"}], " ", "b1"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a1", " ", "a4"}], "-", 
                RowBox[{"a2", " ", "a3"}]}], ")"}], " ", "b2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["a2", "2"], "-", 
                SuperscriptBox["a1", "2"]}], ")"}], " ", "b3"}]}], ")"}]}], 
          "]"}], ",", 
         RowBox[{"{", "x4", "}"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]",
       
      RowBox[{"a1p2b", "==", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "True", ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "b1m2"}], ",", "b1m2", ",", "a1m2c", ",", 
           RowBox[{"-", "a1m2c"}]}], "}"}], "/", "a1m2b"}], " ", "2"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "b1p2"}], ",", 
           RowBox[{"-", "b1p2"}], ",", "a1p2c", ",", "a1p2c"}], "}"}], "/", 
         "a1p2b"}], " ", "2"}]}]}], "]"}]}], "]"}]}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"simc2", "[", 
   RowBox[{"a_", ",", "b_", ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", "=", 
       RowBox[{"Length", "[", "a", "]"}]}], ",", "ai", ",", "aijp", ",", 
      "aijn", ",", "dp", ",", "dn", ",", 
      RowBox[{"p", "=", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"n", "=", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"at", "=", 
       RowBox[{"Transpose", "[", "a", "]"}]}], ",", 
      RowBox[{"sp", "=", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"sn", "=", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"bp", "=", 
       RowBox[{"{", "}"}]}], ",", "bip", ",", 
      RowBox[{"bn", "=", 
       RowBox[{"{", "}"}]}], ",", "bin", ",", "X", ",", "x"}], "}"}], ",", 
    RowBox[{
     RowBox[{"x", "=", 
      RowBox[{"Unique", "[", "]"}]}], ";", 
     RowBox[{"x", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"x", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "l"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ai", "=", 
         RowBox[{"at", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", 
        RowBox[{"bip", "=", 
         RowBox[{"b", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ";", 
        RowBox[{"bin", "=", 
         RowBox[{"b", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"bp", ",", 
          RowBox[{"bip", "+", "bin"}]}], "]"}], ";", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"bn", ",", 
          RowBox[{"bip", "-", "bin"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"aijp", "=", 
            RowBox[{"ai", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "1"}], "]"}], "]"}]}], ";", 
           RowBox[{"aijn", "=", 
            RowBox[{"ai", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "2"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"p", "=", 
            RowBox[{"{", 
             RowBox[{"p", ",", 
              RowBox[{"aijp", "+", "aijn"}]}], "}"}]}], ";", 
           RowBox[{"n", "=", 
            RowBox[{"{", 
             RowBox[{"n", ",", 
              RowBox[{"aijp", "-", "aijn"}]}], "}"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "l"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "l"}], "}"}]}], "]"}], ";", 
     RowBox[{"p", "=", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", "p", "]"}], ",", "l"}], "]"}]}], ";", 
     RowBox[{"dp", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{"2", " ", 
        RowBox[{"Det", "[", "p", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]",
      
     RowBox[{"n", "=", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", "n", "]"}], ",", "l"}], "]"}]}], ";", 
     RowBox[{"dn", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{"2", " ", 
        RowBox[{"Det", "[", "n", "]"}]}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"o", "===", "2"}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"{", 
         RowBox[{
         "\"\<n\>\"", ",", "n", ",", "dn", ",", "\"\<\\np\>\"", ",", "p", ",",
           "dp"}], "}"}], "]"}]}], "]"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"i", "\[LessEqual]", "l"}], ",", 
       RowBox[{
        RowBox[{"bip", "=", 
         RowBox[{"Det", "[", 
          RowBox[{"Insert", "[", 
           RowBox[{
            RowBox[{"Drop", "[", 
             RowBox[{"p", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], ",", "bp", ",", "i"}], "]"}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"bin", "=", 
         RowBox[{"Det", "[", 
          RowBox[{"Insert", "[", 
           RowBox[{
            RowBox[{"Drop", "[", 
             RowBox[{"n", ",", 
              RowBox[{"{", "i", "}"}]}], "]"}], ",", "bn", ",", "i"}], "]"}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"sp", "=", 
         RowBox[{"{", 
          RowBox[{"sp", ",", "bip", ",", "bip"}], "}"}]}], ";", 
        RowBox[{"sn", "=", 
         RowBox[{"{", 
          RowBox[{"sn", ",", "bin", ",", 
           RowBox[{"-", "bin"}]}], "}"}]}], ";", 
        RowBox[{"i", "+=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"X", "=", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"dp", "===", "0"}], ",", "x", ",", 
         RowBox[{
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", "sp", "]"}], ",", "2"}], "]"}], "/", 
          "dp"}]}], "]"}], "+", "\[IndentingNewLine]", "  ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"dn", "===", "0"}], ",", "x", ",", 
         RowBox[{
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", "sn", "]"}], ",", "2"}], "]"}], "/", 
          "dn"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"o", "===", "1"}], ",", "X", ",", 
       RowBox[{
        RowBox[{"X", "=", 
         RowBox[{"Transpose", "[", "X", "]"}]}], ";", 
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"X", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}]}], "]"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True,
 TextAlignment->Left,
 FontFamily->"Courier New",
 FontSize->12,
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False},
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\
\tRotation using Euler parameters is implemented below for Quaternions, \
Octonions, and Pauli-\[Sigma] algebra. Footnote 16 in Louenesto 2001 \
indicates that it can be generalized via Clifford multiplication. This is \
pursued in CliffordGA.m. Also see History of Algebra, B. L. van der Waerden, \
P192-4. \
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"angls", "[", 
    RowBox[{"r_", ",", "\[Theta]_", ",", 
     RowBox[{"\[Psi]_:", "0"}]}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"r", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"r", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ",", 
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "+", 
          RowBox[{"4", "*", 
           RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ",", 
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ",", 
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "+", 
          RowBox[{"4", "*", 
           RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ",", 
       RowBox[{"r", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "+", 
          RowBox[{"4", "*", 
           RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "r"}], "*", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "r"}], "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Pi", "/", "3"}]}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "r"}], "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "+", 
          RowBox[{"4", "*", 
           RowBox[{"Pi", "/", "3"}]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QPower", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "}"}], ",", 
     RowBox[{"r_:", ".5"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"t", "=", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"a", ",", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"b", "^", "2"}], "+", 
            RowBox[{"c", "^", "2"}], "+", 
            RowBox[{"d", "^", "2"}]}], "]"}]}], "]"}]}], ",", 
       RowBox[{"u", "=", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"b", ",", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"c", "^", "2"}], "+", 
            RowBox[{"d", "^", "2"}]}], "]"}]}], "]"}]}], ",", 
       RowBox[{"v", "=", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"c", ",", "d"}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"s", "=", 
       RowBox[{"Sin", "[", 
        RowBox[{"r", " ", "t"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "^", "2"}], "+", 
          RowBox[{"b", "^", "2"}], "+", 
          RowBox[{"c", "^", "2"}], "+", 
          RowBox[{"d", "^", "2"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"r", "/", "2"}], ")"}]}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"r", " ", "t"}], "]"}], ",", 
         RowBox[{"s", " ", 
          RowBox[{"Cos", "[", "u", "]"}]}], ",", 
         RowBox[{"s", " ", 
          RowBox[{"Sin", "[", "u", "]"}], 
          RowBox[{"Cos", "[", "v", "]"}]}], ",", 
         RowBox[{"s", " ", 
          RowBox[{"Sin", "[", "u", "]"}], 
          RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}]}]}]}], "]"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell["\<\
(*Rotates a set of vectors v0, about an axis n0, both right-padded with \
zeroes and/or truncated, using Qr, Octr or P4. Further developed in \
CliffordGA.m.*)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "rotateQOP", "]"}], ";", 
  RowBox[{
   RowBox[{"rotateQOP", "[", 
    RowBox[{"v0_", ",", "n0_", ",", "\[Theta]_", ",", 
     RowBox[{"g_:", "gmn"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"l", "=", "4"}], ",", "n", ",", 
       RowBox[{"p", "=", "1"}], ",", "pn", ",", "q", ",", "r", ",", "v"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Depth", "[", "v0", "]"}], "\[NotEqual]", "3"}], "||", 
         RowBox[{
          RowBox[{"Depth", "[", "n0", "]"}], "\[NotEqual]", "2"}]}], ",", 
        RowBox[{
         RowBox[{"Print", " ", "[", "\"\<Wrong bracketing\>\"", "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}], ",", 
        RowBox[{"g", "==", "\"\<Qr\>\""}], ",", ",", 
        RowBox[{"g", "==", "\"\<Octr\>\""}], ",", 
        RowBox[{"l", "=", "8"}], ",", 
        RowBox[{"g", "==", "\"\<P4\>\""}], ",", 
        RowBox[{"p", "=", 
         RowBox[{"-", "1"}]}], ",", "\[IndentingNewLine]", "True", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"{", 
           RowBox[{"g", ",", "\"\<Wrong\>\""}], "}"}], "]"}], ";", " ", 
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"gmn", "=", "g"}], ";", 
      RowBox[{"v", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "v0", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
               "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
               "}"}]}], "}"}], "]"}], ",", "l"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", "v0", "]"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"n", "=", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"{", 
           RowBox[{"n0", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}], "]"}], ",", 
         RowBox[{"l", "-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"pn", "=", 
       SqrtBox[
        RowBox[{"p", " ", 
         RowBox[{"Plus", "@@", 
          RowBox[{"(", 
           RowBox[{"n", " ", "n"}], ")"}]}]}]]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"q", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "/", "2"}], "]"}], ",", 
          RowBox[{"n", " ", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "/", "2"}], "]"}], "/", "pn"}]}]}], "}"}], 
        "]"}]}], ";", 
      RowBox[{"r", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "/", "2"}], "]"}], ",", 
          RowBox[{
           RowBox[{"-", "n"}], " ", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "/", "2"}], "]"}], "/", "pn"}]}]}], "}"}], 
        "]"}]}], ";", 
      RowBox[{"Chop", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"hoopTimes", "[", 
          RowBox[{"q", ",", 
           RowBox[{"hoopTimes", "[", 
            RowBox[{
             RowBox[{
             "v", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",",
              "r", ",", "g"}], "]"}], ",", "g"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", "v0", "]"}]}], "}"}]}], "]"}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "13 Substitutions  ",
 StyleBox["fa,  fp, alph, power2, pow2, power3, fromAlph,  linearFactor, s2, \
s3, s4, pr1, pr2 .",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fp", "[", 
     RowBox[{"g_", ",", 
      RowBox[{"p_:", "power2"}]}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Head", "[", "g", "]"}], "===", "TraditionalForm"}]}], ":=", 
   RowBox[{"fp", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "p"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fp", "[", 
    RowBox[{
     RowBox[{"g_", "?", "indexTableQ"}], ",", 
     RowBox[{"p_:", "pow2"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"pp", "=", "p"}], ",", 
       RowBox[{"lg", "=", 
        RowBox[{"Length", "[", "g", "]"}]}], ",", 
       RowBox[{"lp", "=", 
        RowBox[{"Length", "[", "p", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"pp", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"lp", "<", "lg"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"Append", "[", 
           RowBox[{"pp", ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"lg", "-", "lp"}]}], "}"}]}], "]"}]}], "]"}], "]"}], 
         ",", 
         RowBox[{"Take", "[", 
          RowBox[{"pp", ",", "lg"}], "]"}]}], "]"}]}], ";", 
      RowBox[{"pa", "=", 
       RowBox[{"Factor", "[", 
        RowBox[{"Det", "[", 
         RowBox[{"gmap", "[", 
          RowBox[{"g", ",", "pp"}], "]"}], "]"}], "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "fp", "]"}], ">", "1"}], "&&", 
         RowBox[{
          RowBox[{"fp", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
          RowBox[{"-", "1"}]}]}], ",", 
        RowBox[{"-", "pa"}], ",", "pa", ",", "pa"}], "]"}]}]}], "]"}]}], ";", 
  
  RowBox[{
   RowBox[{
    RowBox[{"fa", "[", "g_", "]"}], "/;", 
    RowBox[{
     RowBox[{"Head", "[", "g", "]"}], "===", "TraditionalForm"}]}], ":=", 
   RowBox[{"fa", "[", 
    RowBox[{"g", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fa", "[", 
    RowBox[{"g_", "?", "indexTableQ"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "g", "]"}], "<", "13"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pa", "=", 
            RowBox[{"Factor", "[", 
             RowBox[{"Det", "[", 
              RowBox[{"gmap", "[", 
               RowBox[{"g", ",", "alph"}], "]"}], "]"}], "]"}]}], ")"}], "[", 
          
          RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
         RowBox[{"-", "1"}]}], ",", 
        RowBox[{"-", "pa"}], ",", "pa", ",", "pa"}], "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Print", "[", "\"\<Too Long for fa\>\"", "]"}], ";", 
      RowBox[{"Abort", "[", "]"}]}]}], "]"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"alph", "=", 
   RowBox[{"{", 
    RowBox[{
    "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h",
      ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", "o", 
     ",", "p", ",", "q", ",", "r", ",", "s", ",", "t", ",", "u", ",", "v", 
     ",", "w", ",", "x", ",", "y", ",", "z", ",", "\[AAcute]", ",", 
     "\[EAcute]", ",", "\[OAcute]", ",", "\[UAcute]", ",", "\[AHat]", ",", 
     "\[EHat]", ",", "\[IHat]", ",", "\[OHat]", ",", "\[UHat]", ",", 
     "\[AGrave]", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", 
     "\[Delta]", ",", "\[CurlyEpsilon]", ",", "\[Zeta]", ",", "\[Eta]", ",", 
     "\[Theta]", ",", "\[CapitalTheta]", ",", "\[Iota]", ",", "\[Kappa]", ",",
      "\[Lambda]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Xi]", ",", 
     "\[CapitalXi]", ",", "\[CurlyPi]", ",", "\[CapitalPi]", ",", "\[Rho]", 
     ",", "\[CurlyRho]", ",", "\[Sigma]", ",", "\[CapitalSigma]", ",", 
     "\[Tau]", ",", "\[Upsilon]", ",", "\[CapitalUpsilon]", ",", "\[Phi]", 
     ",", "\[CurlyPhi]", ",", "\[CapitalPhi]", ",", "\[Chi]", ",", "\[Psi]", 
     ",", "\[CapitalPsi]", ",", "\[CapitalOmega]", ",", "\[CapitalKoppa]", 
     ",", "\[Sampi]", ",", "\[CapitalSampi]", ",", "\[Mho]", ",", "a", ",", 
     "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
     "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", "o", ",", 
     "p", ",", "q", ",", "r", ",", "s", ",", "t", ",", "u", ",", "v", ",", 
     "w", ",", "x", ",", "y", ",", "z", ",", "\[AAcute]", ",", "\[EAcute]", 
     ",", "\[OAcute]", ",", "\[UAcute]", ",", "\[AHat]", ",", "\[EHat]", ",", 
     "\[IHat]", ",", "\[OHat]", ",", "\[UHat]", ",", "\[AGrave]", ",", 
     "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]", ",", 
     "\[CurlyEpsilon]", ",", "\[Zeta]", ",", "\[Eta]", ",", "\[Theta]", ",", 
     "\[CapitalTheta]", ",", "\[Iota]", ",", "\[Kappa]", ",", "\[Lambda]", 
     ",", "\[Mu]", ",", "\[Nu]", ",", "\[Xi]", ",", "\[CapitalXi]", ",", 
     "\[CurlyPi]", ",", "\[CapitalPi]", ",", "\[Rho]", ",", "\[CurlyRho]", 
     ",", "\[Sigma]", ",", "\[CapitalSigma]", ",", "\[Tau]", ",", 
     "\[Upsilon]", ",", "\[CapitalUpsilon]", ",", "\[Phi]", ",", 
     "\[CurlyPhi]", ",", "\[CapitalPhi]", ",", "\[Chi]", ",", "\[Psi]", ",", 
     "\[CapitalPsi]", ",", "\[CapitalOmega]", ",", "\[CapitalKoppa]", ",", 
     "\[Sampi]", ",", "\[CapitalSampi]", ",", "\[Mho]", ",", "\[IHat]", ",", 
     "\[OHat]", ",", "\[UHat]", ",", "\[AGrave]", ",", "a", ",", "b", ",", 
     "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
     "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", "o", ",", "p", ",", 
     "q", ",", "r", ",", "s", ",", "t", ",", "u", ",", "v", ",", "w", ",", 
     "x", ",", "y", ",", "z", ",", "\[AAcute]", ",", "\[EAcute]", ",", 
     "\[OAcute]", ",", "\[UAcute]", ",", "\[AHat]", ",", "\[EHat]", ",", 
     "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]", ",", 
     "\[CurlyEpsilon]", ",", "\[Zeta]", ",", "\[Eta]", ",", "\[Theta]", ",", 
     "\[CapitalTheta]", ",", "\[Iota]", ",", "\[Kappa]", ",", "\[Lambda]", 
     ",", "\[Mu]", ",", "\[Nu]", ",", "\[Xi]", ",", "\[CapitalXi]", ",", 
     "\[CurlyPi]", ",", "\[CapitalPi]", ",", "\[Rho]", ",", "\[CurlyRho]", 
     ",", "\[Sigma]", ",", "\[CapitalSigma]", ",", "\[Tau]", ",", 
     "\[Upsilon]", ",", "\[CapitalUpsilon]", ",", "\[Phi]", ",", 
     "\[CurlyPhi]", ",", "\[CapitalPhi]", ",", "\[Chi]", ",", "\[Psi]", ",", 
     "\[CapitalPsi]", ",", "\[CapitalOmega]", ",", "\[CapitalKoppa]", ",", 
     "\[Sampi]", ",", "\[CapitalSampi]", ",", "\[EmptySet]", ",", "\[Mho]", 
     ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", 
     ",", "h", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", 
     ",", "o", ",", "p", ",", "q", ",", "r", ",", "s", ",", "t", ",", "u", 
     ",", "v", ",", "w", ",", "x", ",", "y", ",", "z", ",", "\[AAcute]", ",", 
     "\[EAcute]", ",", "\[OAcute]", ",", "\[UAcute]", ",", "\[AHat]", ",", 
     "\[EHat]", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", 
     "\[Delta]", ",", "\[CurlyEpsilon]", ",", "\[Zeta]", ",", "\[Eta]", ",", 
     "\[Theta]", ",", "\[CapitalTheta]", ",", "\[Iota]", ",", "\[Kappa]", ",",
      "\[Lambda]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Xi]", ",", 
     "\[CapitalXi]", ",", "\[CurlyPi]", ",", "\[CapitalPi]", ",", "\[Rho]", 
     ",", "\[CurlyRho]", ",", "\[Sigma]", ",", "\[CapitalSigma]", ",", 
     "\[Tau]", ",", "\[Upsilon]", ",", "\[CapitalUpsilon]", ",", "\[Phi]", 
     ",", "\[CurlyPhi]", ",", "\[CapitalPhi]", ",", "\[Chi]", ",", "\[Psi]", 
     ",", "\[CapitalPsi]", ",", "\[CapitalOmega]", ",", "\[CapitalKoppa]", 
     ",", "\[Sampi]", ",", "\[CapitalSampi]", ",", "\[Mho]", ",", "\[IHat]", 
     ",", "\[OHat]", ",", "\[UHat]", ",", "\[AGrave]", ",", "a", ",", "b", 
     ",", "c"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"unique", " ", "length", " ", "72"}], ",", " ", 
    RowBox[{"useable", " ", "length", " ", "292"}]}], "*)"}]}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gralph", "=", 
   RowBox[{"{", 
    RowBox[{
    "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]", ",", 
     "\[CurlyEpsilon]", ",", "\[Zeta]", ",", "\[Eta]", ",", "\[Theta]", ",", 
     "\[CapitalTheta]", ",", "\[Iota]", ",", "\[Kappa]", ",", "\[Lambda]", 
     ",", "\[Mu]", ",", "\[Nu]", ",", "\[Xi]", ",", "\[CapitalXi]", ",", 
     "\[CurlyPi]", ",", "\[CapitalPi]", ",", "\[Rho]", ",", "\[CurlyRho]", 
     ",", "\[Sigma]", ",", "\[CapitalSigma]", ",", "\[Tau]", ",", 
     "\[Upsilon]", ",", "\[CapitalUpsilon]", ",", "\[Phi]", ",", 
     "\[CurlyPhi]", ",", "\[CapitalPhi]", ",", "\[Chi]", ",", "\[Psi]", ",", 
     "\[CapitalPsi]", ",", "\[CapitalOmega]", ",", "\[CapitalKoppa]", ",", 
     "\[Sampi]", ",", "\[CapitalSampi]", ",", "\[Mho]", ",", "a", ",", "b", 
     ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", 
     ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", "o", ",", "p", 
     ",", "q", ",", "r", ",", "s", ",", "t", ",", "u", ",", "v", ",", "w", 
     ",", "x", ",", "y", ",", "z", ",", "\[AAcute]", ",", "\[EAcute]", ",", 
     "\[OAcute]", ",", "\[UAcute]", ",", "\[AHat]", ",", "\[EHat]", ",", 
     "\[IHat]", ",", "\[OHat]", ",", "\[UHat]", ",", "\[AGrave]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"unique", " ", "length", " ", "72", " ", "in", " ", "Greek"}], 
     " ", "&"}], " ", "Roman", " ", "sets", " ", "of", " ", "36"}], 
   "*)"}]}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"alpha", "=", 
    RowBox[{"{", 
     RowBox[{
     "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", ",", 
      "\"\<e\>\"", ",", "\"\<f\>\"", ",", "\"\<g\>\"", ",", "\"\<h\>\"", ",", 
      "\"\<i\>\"", ",", "\"\<j\>\"", ",", "\"\<k\>\"", ",", "\"\<l\>\"", ",", 
      "\"\<m\>\"", ",", "\"\<n\>\"", ",", "\"\<o\>\"", ",", "\"\<p\>\"", ",", 
      "\"\<q\>\"", ",", "\"\<r\>\"", ",", "\"\<s\>\"", ",", "\"\<t\>\"", ",", 
      "\"\<u\>\"", ",", "\"\<v\>\"", ",", "\"\<w\>\"", ",", "\"\<x\>\"", ",", 
      "\"\<y\>\"", ",", "\"\<z\>\"", ",", "\"\<\[AAcute]\>\"", ",", 
      "\"\<\[EAcute]\>\"", ",", "\"\<\[OAcute]\>\"", ",", "\"\<\[UAcute]\>\"",
       ",", "\"\<\[AHat]\>\"", ",", "\"\<\[EHat]\>\"", ",", "\"\<\[IHat]\>\"",
       ",", "\"\<\[OHat]\>\"", ",", "\"\<\[UHat]\>\"", ",", 
      "\"\<\[AGrave]\>\"", ",", "\"\<\[Alpha]\>\"", ",", "\"\<\[Beta]\>\"", 
      ",", "\"\<\[Gamma]\>\"", ",", "\"\<\[Delta]\>\"", ",", 
      "\"\<\[CurlyEpsilon]\>\"", ",", "\"\<\[Zeta]\>\"", ",", 
      "\"\<\[Eta]\>\"", ",", "\"\<\[Theta]\>\"", ",", 
      "\"\<\[CapitalTheta]\>\"", ",", "\"\<\[Iota]\>\"", ",", 
      "\"\<\[Kappa]\>\"", ",", "\"\<\[Lambda]\>\"", ",", "\"\<\[Mu]\>\"", 
      ",", "\"\<\[Nu]\>\"", ",", "\"\<\[Xi]\>\"", ",", "\"\<\[CapitalXi]\>\"",
       ",", "\"\<\[CurlyPi]\>\"", ",", "\"\<\[CapitalPi]\>\"", ",", 
      "\"\<\[Rho]\>\"", ",", "\"\<\[CurlyRho]\>\"", ",", "\"\<\[Sigma]\>\"", 
      ",", "\"\<\[CapitalSigma]\>\"", ",", "\"\<\[Tau]\>\"", ",", 
      "\"\<\[Upsilon]\>\"", ",", "\"\<\[CapitalUpsilon]\>\"", ",", 
      "\"\<\[Phi]\>\"", ",", "\"\<\[CurlyPhi]\>\"", ",", 
      "\"\<\[CapitalPhi]\>\"", ",", "\"\<\[Chi]\>\"", ",", "\"\<\[Psi]\>\"", 
      ",", "\"\<\[CapitalPsi]\>\"", ",", "\"\<\[CapitalOmega]\>\"", ",", 
      "\"\<\[CapitalKoppa]\>\"", ",", "\"\<\[Sampi]\>\"", ",", 
      "\"\<\[CapitalSampi]\>\"", ",", "\"\<\[Mho]\>\"", ",", "\"\<a\>\"", 
      ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", ",", "\"\<e\>\"", 
      ",", "\"\<f\>\"", ",", "\"\<g\>\"", ",", "\"\<h\>\"", ",", "\"\<i\>\"", 
      ",", "\"\<j\>\"", ",", "\"\<k\>\"", ",", "\"\<l\>\"", ",", "\"\<m\>\"", 
      ",", "\"\<n\>\"", ",", "\"\<o\>\"", ",", "\"\<p\>\"", ",", "\"\<q\>\"", 
      ",", "\"\<r\>\"", ",", "\"\<s\>\"", ",", "\"\<t\>\"", ",", "\"\<u\>\"", 
      ",", "\"\<v\>\"", ",", "\"\<w\>\"", ",", "\"\<x\>\"", ",", "\"\<y\>\"", 
      ",", "\"\<z\>\"", ",", "\"\<\[AAcute]\>\"", ",", "\"\<\[EAcute]\>\"", 
      ",", "\"\<\[OAcute]\>\"", ",", "\"\<\[UAcute]\>\"", ",", 
      "\"\<\[AHat]\>\"", ",", "\"\<\[EHat]\>\""}], "}"}]}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"unique", " ", "length", " ", "72"}], ",", " ", 
    RowBox[{"useable", " ", "length", " ", "104"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pow2", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        SuperscriptBox["2", "i"], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "50"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", "a", "}"}]}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"power2", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        SuperscriptBox["2", "i"], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "50"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<a\>\"", ",", "3", ",", "7"}], "}"}]}], "]"}], "]"}]}], 
  ";", 
  RowBox[{"power3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        SuperscriptBox["3", "i"], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "32"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<a\>\"", ",", "2", ",", "4"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"fromAlph", "[", "Null", "]"}], ":=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"fromAlph", "[", 
    RowBox[{
     RowBox[{"vec_", "?", "VectorQ"}], ",", 
     RowBox[{"a_:", "alph"}]}], "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"[", "ii", "]"}], "]"}], "\[Rule]", 
      RowBox[{"vec", "[", 
       RowBox[{"[", "ii", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", 
       RowBox[{"Length", "[", "vec", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"linearFactor", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"l_:", "mm"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"res", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"alph", ",", "l"}], "]"}]}], ",", 
      RowBox[{"po", "=", 
       RowBox[{"fromAlph", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"pow2", ",", "l"}], "]"}], "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Plus", "@@", 
            RowBox[{"(", 
             RowBox[{"res", "/.", "po"}], ")"}]}], "-", "f"}], ">=", 
          RowBox[{"2", 
           RowBox[{"pow2", "[", 
            RowBox[{"[", "ii", "]"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"res", "[", 
           RowBox[{"[", "ii", "]"}], "]"}], "*=", 
          RowBox[{"-", "1"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "l", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}], ";", 
     RowBox[{"Plus", "@@", "res"}]}]}], "]"}]}], "\n", 
 RowBox[{
  FormBox[
   RowBox[{"SetAttributes", "[", 
    RowBox[{"linearFactor", ",", "Listable"}], "]"}],
   TraditionalForm], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Permutation", " ", "Lists"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"s3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "}"}]}], ";", 
  RowBox[{"s4", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"s5", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "5", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "5", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "1", ",", "2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4", ",", "3", ",", "5"}], "}"}]}], "}"}]}],
   ";"}]}], "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"vecs", " ", "pr1"}], ",", " ", 
    RowBox[{
    "pr2", " ", "that", " ", "usually", " ", "give", " ", "good", " ", 
     "factorizations"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"pr1", "=", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "5", ",", "7", ",", "11", ",", "13", ",", 
       "17", ",", "19", ",", "23", ",", "29", ",", "37", ",", "41", ",", "43",
        ",", "47", ",", "61", ",", "67", ",", "53", ",", "73", ",", "79", ",",
        "83", ",", "59", ",", "31", ",", "103", ",", "107", ",", "109", ",", 
       "113", ",", "127", ",", "131", ",", "137", ",", "139", ",", "149", ",",
        "151", ",", "157", ",", "163", ",", "167", ",", "173", ",", "179", 
       ",", "181", ",", "191", ",", "193", ",", "197", ",", "199", ",", "211",
        ",", "223", ",", "227", ",", "229", ",", "233", ",", "239", ",", 
       "241", ",", "251", ",", "257", ",", "263", ",", "269", ",", "271", ",",
        "277", ",", "281", ",", "283", ",", "293", ",", "307", ",", "311", 
       ",", "313", ",", "317", ",", "331"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"pr2", "=", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "3", ",", "7", ",", "5", ",", "7", ",", "11", ",", "13", ",", 
       "17", ",", "19", ",", "23", ",", "31", ",", "29", ",", "61", ",", "37",
        ",", "43", ",", "41", ",", "53", ",", "47", ",", "61", ",", "59", ",",
        "73", ",", "67", ",", "79", ",", "71", ",", "83", ",", "89", ",", 
       "97", ",", "101", ",", "103", ",", "107", ",", "109", ",", "113", ",", 
       "127", ",", "131", ",", "137", ",", "139", ",", "149", ",", "151", ",",
        "157", ",", "163", ",", "167", ",", "173", ",", "179", ",", "181", 
       ",", "191", ",", "193", ",", "197", ",", "199", ",", "211", ",", "223",
        ",", "227", ",", "229", ",", "233", ",", "239", ",", "241", ",", 
       "251", ",", "257", ",", "263", ",", "269", ",", "271", ",", "277", ",",
        "281", ",", "283", ",", "293"}], "}"}]}], ";"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "14 Matrix Group Data ",
 StyleBox["u2, u3, u4. ",
  FontSlant->"Italic"],
 StyleBox[" (problems with generalised signs)",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[TextData[{
 "These have been moved from Section 4 to prevent them being included in \
function definitions such as ",
 StyleBox["ms ",
  FontSlant->"Italic"],
 "until they are needed. They are unitary monomial matrices that dot multiply \
to give groups."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"u2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckK]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckK]"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckN]", "4"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckN]", "3"], ",", "0"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckM]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckM]"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalI]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckCapitalI]", "3"], ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalJ]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalY]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalY]", "2"]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[ImaginaryI]"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[ImaginaryI]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalI]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalI]", "3"]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckO]", "3"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckO]", "5"], ",", "0"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckP]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckP]", "4"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckH]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckH]", "5"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckG]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "6"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckO]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckO]", "7"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckN]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckN]", "8"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"\[DoubleStruckCapitalJ]", "^", "2"}]}], ",", "0"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckK]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[DoubleStruckK]"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckL]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[DoubleStruckL]"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckM]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[DoubleStruckM]"}], ",", "0"}], "}"}]}], "}"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckS]"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckS]", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalJ]", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalY]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalI]", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "u2", "]"}]], "Input"],

Cell[BoxData["35"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"u3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckK]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckK]"}], "}"}]}], "}"}], ",",
      
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckK]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[DoubleStruckK]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], ",", "0", ",", "0"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckCapitalJ]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalJ]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalJ]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckCapitalJ]"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[ImaginaryI]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckP]", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckP]", "3"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], ",", "0", ",", "0"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalJ]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "5"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[ImaginaryI]", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckO]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckO]", "7"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckN]", "4"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckN]", "5"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckP]", "2"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckP]", "3"]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckG]", "2"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckG]", "5"]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckN]", "4"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckN]", "5"]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalY]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalY]", "2"]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckN]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckN]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckN]", "7"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckP]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckP]", "3"], ",", "0", ",", "0"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckP]", "2"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[ImaginaryI]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]"}], "}"}]}], "}"}], ",", 
     RowBox[{"-", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "\[ImaginaryI]", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "\[ImaginaryI]"}], "}"}]}], "}"}]}], ",",
      
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[ImaginaryI]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckS]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"u4", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "\[DoubleStruckCapitalJ]"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]", ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]", ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "\[DoubleStruckCapitalJ]"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "\[ImaginaryI]"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckP]", ",", "0", ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckP]", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckP]", "2"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckH]", ",", "0", ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckH]", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckH]", "3"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckG]", ",", "0", ",", "0", ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckG]", ",", "0", ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "3"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "\[ImaginaryI]"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckO]", "3"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckO]", "5"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckN]", ",", "0", ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckN]", "4"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckN]", "4"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckP]", "2"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckP]"}], ",", "0", ",", "0"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckP]", "2"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckP]"}], ",", "0", ",", "0"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckP]", "2"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckP]", "2"]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "\[ImaginaryI]"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckP]", "2"]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[DoubleStruckP]"}], ",", "0", ",", "0"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckP]", "2"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], ",", "0", ",", "0", ",", "0"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]", ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalJ]", ",", "0", ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[DoubleStruckCapitalJ]", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], ",", "0", ",", "0", 
         ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]", ",", "0", ",", "0"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "\[ImaginaryI]", ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[ImaginaryI]", ",", "0", ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckS]", ",", "0", ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"u4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"-", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "u4", "]"}]], "Input"],

Cell[BoxData["45"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The Dirac \[Gamma] matrices are u4[[1]]=",
 Cell[BoxData[
  SuperscriptBox["\[Gamma]", "0"]]],
 ", u4[[29]]=",
 Cell[BoxData[
  SuperscriptBox["\[Gamma]", "1"]]],
 ", u4[[30]]=",
 Cell[BoxData[
  SuperscriptBox["\[Gamma]", "2"]]],
 ", u4[[31]]=",
 Cell[BoxData[
  SuperscriptBox["\[Gamma]", "3"]]],
 ", u4[[40]]=",
 Cell[BoxData[
  SuperscriptBox["\[Gamma]", "5"]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "15 Generalized multi-phase Sinusoids ",
 StyleBox["genCos, genSin.",
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"genCos", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"m_:", "4"}], ",", 
    RowBox[{"j_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"m", "==", "0"}], ",", 
    RowBox[{"j", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", "x"}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ")"}], "/", "2"}]}], ",", 
    RowBox[{"m", "==", "2"}], ",", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "x"], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "j"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", 
          RowBox[{"-", "x"}]}]]}]}], "]"}], "/", "2"}], ",", 
    "\[IndentingNewLine]", "True", ",", 
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"m", "-", "j"}], ")"}], "/", "m"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Im", "[", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genSin", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"m_:", "4"}], ",", 
    RowBox[{"j_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"m", "==", "0"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{" ", "x"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "x"}]]}], ")"}], "/", "2"}], ",", 
    RowBox[{"m", "==", "2"}], ",", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "j"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", "x"}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "x"}]]}], "]"}], "/", "2"}], ",", "\[IndentingNewLine]", 
    "True", ",", 
    RowBox[{"Im", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"m", "-", "j"}], ")"}], "/", "m"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Im", "[", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["9.",
  FontFamily->"Arial"],
 "16 Lie, Jordan & Geometric Algebras",
 StyleBox[". ",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}}],

Cell[TextData[{
 "  All non-abelian groups (and a few non-associative Moufang loops, \
including Octonions, Split-octonions & six 32-element tables) conserve their \
determinant factors as symmetries, but ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " determinant factors include repeated terms that correspond to sets of \
eigenvalues differing by a sign. The following examples use {a,b,c...} as a \
symbolic vector. Quaternions conserve -(a^2+b^2+c^2+d^2)^2; Clifford[2] \
conserves (a^2-b^2+c^2-d^2)^2; D3 conserves a+b+c+d+e+f, a-b+c-d+e-f, and \
(((a-c)^2+(c-e)^2+(e-a)^2-(b-d)^2-(d-e)^2-(e-b)^2)/2)^2; Octonions conserve \
(a^2-b^2+c^2-d^2+f^2-g^2+h^2-i^2)^2. I have formulated \"pseudo-polar\" duals \
for these algebras, but they involve some angles that do not add on \
vector-multiplication. A4 has a triply repeated cubic conserved factor, which \
releases 7 degrees of freedom. Dihedral & Quaternion algebras have one \
positive and one negative quadratic term, so the \"repeated roots\" are a \
\[PlusMinus] pair (I call these \"real-conjugates\"). The A4 triple is a \
terplex-conjugate set that gives a real number on multiplying together.\nLie \
Products.\n   Non-abelian algebras have an extra \"Lie\" product (AB-BA)/2, \
which is zero in the abelian algebras, together with a Jordan product \
(AB+BA)/2. AB=JordanAB+LieAB, BA=JordanAB-LieAB, but these cannot be \
conserved separately. Earlier versions of this package included Lie and Lie0 \
tables, and toJordan, toLie functions; they have been deleted.",
 "\n",
 "  Having developed the splitting of non-commutative algebras into Lie and \
Jordan products, I found references on \"Geometric Algebra\", which is based \
on orthogonal anti-commuting generators (confusingly called \"vectors\" in \
Doran & Lazenby). This is Clifford algebras restricted to the real field. It \
is developed in the CliffordGA.m package, and so is omitted from this \
notebook."
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["10. Protect system symbols, end private context. Unprotect some \
exported symbols, end package context",
  FontFamily->"Arial"],
 StyleBox[".",
  FontFamily->"Arial",
  FontSlant->"Italic"]
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["Protect[Evaluate[protected]];", "Input",
 PageWidth->WindowWidth],

Cell["End[];", "Input",
 PageWidth->WindowWidth,
 InitializationCell->True],

Cell["Protect[Evaluate[$Context <> \"*\"]];", "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", 
   RowBox[{
   "a", ",", " ", "a1", ",", "a2", ",", "a2", ",", "a3", ",", "a4", ",", "ab",
     ",", "aa", ",", "abc", ",", "abef", ",", "agek", ",", "ai", ",", "ap", 
    ",", "ar", ",", "as", ",", "azx", ",", "ayz", ",", "A", ",", "Ai", ",", 
    "AiBA", ",", "AiAB", ",", "Am", ",", "Ap", ",", "b", ",", " ", "b1", ",", 
    "b2", ",", "b3", ",", "b4", ",", "bb", ",", "bc", ",", "B", ",", "AB", 
    ",", "BA", ",", "c", ",", "c1", ",", "c2", ",", "c3", ",", "c4", ",", 
    "cr", ",", "d", ",", "d1", ",", "da", ",", "dab", ",", "db", ",", "de", 
    ",", "e", ",", "e1", ",", "e2", ",", "ef", ",", "f", ",", "f2", ",", "fa",
     ",", "ff", ",", "fi", ",", "fj", ",", "fn", ",", "fp", ",", "g", ",", 
    "G", ",", "g1", ",", "g2", ",", "gf", ",", "gg", ",", "glo", ",", "globa",
     ",", "genel", ",", "gi", ",", "gmn", ",", "gp", ",", "h", ",", "h1", ",",
     "hoopList", ",", "hh", ",", "i", ",", "i1", ",", "i2", ",", "ii", ",", 
    "im", ",", "in", ",", "j", ",", "jj", ",", "k", ",", "kk", ",", "l", ",", 
    "l22a", ",", "l22b", ",", "l3", ",", "l4", ",", "l4p", ",", "l4q", ",", 
    "l4r", ",", "l4s", ",", "la", ",", "ll", ",", "lm", ",", "lp", ",", "lr", 
    ",", "ls", ",", "lt", ",", "m", ",", "m1", ",", "mi", ",", "matel", ",", 
    "mm", ",", "n", ",", "nn", ",", "nb", ",", "no", ",", "np", ",", "nw", 
    ",", "nx", ",", "o", ",", "ok", ",", "o1", ",", "o2", ",", "o3", ",", 
    "o4", ",", "oo", ",", "p", ",", "p1", ",", "p2", ",", "p22", ",", "p23", 
    ",", "p26", ",", "pa", ",", "pb", ",", "pab", ",", "papb", ",", "pba", 
    ",", "pi", ",", "po", ",", "permel", ",", "plex", ",", "pp", ",", "pr", 
    ",", "ps", ",", "q", ",", "q22", ",", "q23", ",", "q24", ",", "q26", ",", 
    "qq", ",", "res", ",", "result", ",", "r", ",", "\[DoubleStruckR]", ",", 
    "R1", ",", "R2", ",", "Rl", ",", "Rr", ",", "r22", ",", "r23", ",", "r26",
     ",", "rhs", ",", "rr", ",", "s", ",", "sab", ",", "sh", ",", "sg", ",", 
    "s1", ",", "s2", ",", "s5", ",", "s22", ",", "s23", ",", "s24", ",", 
    "s26", ",", "si", ",", "sij", ",", "sm", ",", "ss", ",", "strep", ",", 
    "t", ",", "temp", ",", "test", ",", "tes", ",", "tf", ",", "ts", ",", "u",
     ",", "uu", ",", "v", ",", "var", ",", "vec", ",", "vf", ",", "vv", ",", 
    "w", ",", "x", ",", "x2", ",", "x4", ",", "xy", ",", "y", ",", "y2", ",", 
    "z", ",", "L3", ",", "L1a", ",", "L1b", ",", "L1c", ",", "L1d", ",", 
    "L22", ",", "L23a", ",", "L23b", ",", "L23c", ",", "L23d", ",", "L26a", 
    ",", "L26b", ",", "L26c", ",", "L26d", ",", "L4", ",", "L24Q", ",", 
    "L24\[Sigma]", ",", "L4Q", ",", "L4\[Sigma]", ",", "L49", ",", "L49a", 
    ",", "L49b", ",", "L49c", ",", "L4a3", ",", "L4b3", ",", "L4c3", ",", 
    "L4d3", ",", "L4a6", ",", "L4b6", ",", "L4c6", ",", "L4d6", ",", 
    "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]", ",", 
    "\[Epsilon]", ",", "\[Zeta]", ",", "\[Eta]", ",", "\[Theta]", ",", 
    "\[CurlyTheta]", ",", "\[Iota]", ",", "\[Kappa]", ",", "\[CurlyKappa]", 
    ",", "\[Lambda]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Xi]", ",", "\[Rho]",
     ",", "\[Sigma]", ",", "\[Tau]", ",", "\[Phi]", ",", "\[CurlyPhi]", ",", 
    "\[Chi]", ",", "\[Psi]"}], "]"}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True],

Cell["EndPackage[];", "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 InitializationCell->True]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{1008, 756},
WindowMargins->{{53, Automatic}, {Automatic, 8}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], 
   Cell[
    TextData["20/7/6"]], 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}},
PageHeaderLines->{Inherited, False},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 187, 4, 122, "Title"],
Cell[780, 29, 863, 21, 125, "Input",
 InitializationCell->True],
Cell[1646, 52, 77, 2, 43, "Input"],
Cell[CellGroupData[{
Cell[1748, 58, 49, 0, 54, "Subsection"],
Cell[1800, 60, 1198, 28, 188, "Text"],
Cell[3001, 90, 694, 12, 188, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3732, 107, 213, 4, 40, "Subsection"],
Cell[3948, 113, 1090, 31, 188, "Text"],
Cell[5041, 146, 686, 13, 139, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[5764, 164, 197, 4, 40, "Subsection"],
Cell[5964, 170, 3954, 97, 678, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[9955, 272, 195, 4, 40, "Subsection"],
Cell[10153, 278, 692, 12, 115, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[10882, 295, 195, 4, 40, "Subsection"],
Cell[11080, 301, 563, 12, 115, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[11680, 318, 198, 4, 40, "Subsection"],
Cell[11881, 324, 1725, 36, 286, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[13643, 365, 147, 3, 40, "Subsection"],
Cell[13793, 370, 2496, 59, 311, "Text"],
Cell[16292, 431, 1123, 18, 452, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[17452, 454, 135, 2, 40, "Subsection"],
Cell[CellGroupData[{
Cell[17612, 460, 140, 6, 42, "Subsubsection"],
Cell[17755, 468, 104, 2, 43, "Input",
 InitializationCell->True],
Cell[17862, 472, 1032, 19, 201, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[18931, 496, 110, 2, 31, "Subsubsection"],
Cell[19044, 500, 5697, 155, 395, "Input",
 InitializationCell->True],
Cell[24744, 657, 4258, 94, 1205, "Input",
 InitializationCell->True],
Cell[29005, 753, 1588, 30, 503, "Input",
 InitializationCell->True],
Cell[30596, 785, 1525, 24, 503, "Input",
 InitializationCell->True],
Cell[32124, 811, 2163, 44, 638, "Input",
 InitializationCell->True],
Cell[34290, 857, 2402, 46, 719, "Input",
 InitializationCell->True],
Cell[36695, 905, 1147, 21, 341, "Input",
 InitializationCell->True],
Cell[37845, 928, 1766, 38, 557, "Input",
 InitializationCell->True],
Cell[39614, 968, 1325, 27, 368, "Input",
 InitializationCell->True],
Cell[40942, 997, 2801, 52, 827, "Input",
 InitializationCell->True],
Cell[43746, 1051, 1025, 23, 341, "Input",
 InitializationCell->True],
Cell[44774, 1076, 1350, 28, 476, "Input",
 InitializationCell->True],
Cell[46127, 1106, 750, 17, 260, "Input",
 InitializationCell->True],
Cell[46880, 1125, 1420, 23, 449, "Input",
 InitializationCell->True],
Cell[48303, 1150, 2418, 50, 692, "Input",
 InitializationCell->True],
Cell[50724, 1202, 2800, 81, 503, "Input",
 InitializationCell->True],
Cell[53527, 1285, 1449, 32, 449, "Input",
 InitializationCell->True],
Cell[54979, 1319, 1240, 22, 368, "Input",
 InitializationCell->True],
Cell[56222, 1343, 426, 9, 125, "Input",
 InitializationCell->True],
Cell[56651, 1354, 1825, 31, 719, "Input",
 InitializationCell->True],
Cell[58479, 1387, 2970, 62, 1286, "Input",
 InitializationCell->True],
Cell[61452, 1451, 2137, 46, 773, "Input",
 InitializationCell->True],
Cell[63592, 1499, 1218, 31, 314, "Input",
 InitializationCell->True],
Cell[64813, 1532, 2266, 50, 665, "Input",
 InitializationCell->True],
Cell[67082, 1584, 327, 8, 98, "Input",
 InitializationCell->True],
Cell[67412, 1594, 2448, 55, 692, "Input",
 InitializationCell->True],
Cell[69863, 1651, 1871, 42, 719, "Input",
 InitializationCell->True],
Cell[71737, 1695, 2809, 66, 287, "Input",
 InitializationCell->True],
Cell[74549, 1763, 1190, 27, 422, "Input",
 InitializationCell->True],
Cell[75742, 1792, 1322, 24, 557, "Input",
 InitializationCell->True],
Cell[77067, 1818, 1886, 43, 746, "Input",
 InitializationCell->True],
Cell[78956, 1863, 1190, 26, 476, "Input",
 InitializationCell->True],
Cell[80149, 1891, 719, 17, 287, "Input",
 InitializationCell->True],
Cell[80871, 1910, 2799, 58, 647, "Input",
 InitializationCell->True],
Cell[83673, 1970, 1126, 28, 368, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[84836, 2003, 97, 1, 31, "Subsubsection"],
Cell[84936, 2006, 3523, 89, 692, "Input",
 InitializationCell->True],
Cell[88462, 2097, 2172, 58, 422, "Input",
 InitializationCell->True],
Cell[90637, 2157, 1193, 34, 206, "Input",
 InitializationCell->True],
Cell[91833, 2193, 3850, 108, 665, "Input",
 InitializationCell->True],
Cell[95686, 2303, 3023, 78, 557, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[98758, 2387, 163, 3, 54, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[98946, 2394, 182, 6, 42, "Subsubsection"],
Cell[99131, 2402, 287, 8, 66, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[99455, 2415, 276, 9, 31, "Subsubsection"],
Cell[99734, 2426, 163, 4, 41, "Text"],
Cell[99900, 2432, 1723, 53, 172, "Input",
 InitializationCell->True],
Cell[101626, 2487, 2352, 78, 154, "Input",
 InitializationCell->True],
Cell[103981, 2567, 8764, 226, 476, "Input",
 InitializationCell->True],
Cell[112748, 2795, 7480, 194, 343, "Input",
 Evaluatable->False],
Cell[120231, 2991, 3323, 100, 233, "Input",
 InitializationCell->True],
Cell[123557, 3093, 5248, 157, 395, "Input",
 InitializationCell->True],
Cell[128808, 3252, 451, 12, 71, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[129296, 3269, 259, 8, 31, "Subsubsection"],
Cell[129558, 3279, 1617, 33, 262, "Text"],
Cell[131178, 3314, 217, 6, 43, "Input",
 InitializationCell->True],
Cell[131398, 3322, 3968, 105, 183, "Input",
 InitializationCell->True],
Cell[135369, 3429, 4290, 121, 395, "Input",
 InitializationCell->True],
Cell[139662, 3552, 6728, 196, 368, "Input",
 InitializationCell->True],
Cell[146393, 3750, 1528, 45, 152, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[147958, 3800, 196, 6, 31, "Subsubsection"],
Cell[148157, 3808, 217, 5, 45, "Text"],
Cell[148377, 3815, 2321, 38, 138, "Input",
 InitializationCell->True],
Cell[150701, 3855, 6462, 196, 204, "Input",
 InitializationCell->True],
Cell[157166, 4053, 1226, 37, 78, "Input",
 InitializationCell->True],
Cell[158395, 4092, 6279, 180, 228, "Input",
 InitializationCell->True],
Cell[164677, 4274, 1128, 35, 46, "Input",
 InitializationCell->True],
Cell[165808, 4311, 5546, 137, 214, "Input",
 InitializationCell->True],
Cell[171357, 4450, 20044, 532, 522, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[191426, 4986, 22397, 577, 618, InheritFromParent,
 InitializationCell->True],
Cell[213826, 5565, 5449, 146, 70, "Output"],
Cell[219278, 5713, 5433, 142, 70, "Output"],
Cell[224714, 5857, 5433, 142, 70, "Output"],
Cell[230150, 6001, 5433, 142, 70, "Output"]
}, Open  ]],
Cell[235598, 6146, 22824, 421, 520, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[258459, 6572, 277, 10, 31, "Subsubsection"],
Cell[258739, 6584, 269, 8, 71, "Input"],
Cell[259011, 6594, 312, 10, 43, "Input",
 InitializationCell->True],
Cell[259326, 6606, 5951, 173, 368, "Input",
 InitializationCell->True],
Cell[265280, 6781, 6837, 198, 449, "Input",
 InitializationCell->True],
Cell[272120, 6981, 3015, 86, 260, "Input",
 InitializationCell->True],
Cell[275138, 7069, 7935, 227, 503, "Input",
 InitializationCell->True],
Cell[283076, 7298, 15511, 431, 1205, "Input",
 InitializationCell->True],
Cell[298590, 7731, 4644, 138, 368, "Input",
 InitializationCell->True],
Cell[303237, 7871, 16091, 453, 1205, "Input",
 InitializationCell->True],
Cell[319331, 8326, 17088, 463, 1265, "Input",
 InitializationCell->True],
Cell[336422, 8791, 4041, 119, 314, "Input",
 InitializationCell->True],
Cell[340466, 8912, 5857, 175, 449, "Input",
 InitializationCell->True],
Cell[346326, 9089, 12565, 333, 1070, "Input",
 InitializationCell->True],
Cell[358894, 9424, 6850, 203, 449, "Input",
 InitializationCell->True],
Cell[365747, 9629, 3409, 101, 260, "Input",
 InitializationCell->True],
Cell[369159, 9732, 37896, 946, 3203, "Input",
 InitializationCell->True],
Cell[407058, 10680, 2210, 69, 152, "Input",
 InitializationCell->True],
Cell[409271, 10751, 8908, 243, 746, "Input",
 InitializationCell->True],
Cell[418182, 10996, 2564, 79, 152, "Input",
 InitializationCell->True],
Cell[420749, 11077, 8448, 226, 692, "Input",
 InitializationCell->True],
Cell[429200, 11305, 9125, 267, 665, "Input",
 InitializationCell->True],
Cell[438328, 11574, 36515, 921, 3149, "Input",
 InitializationCell->True],
Cell[474846, 12497, 6898, 205, 449, "Input",
 InitializationCell->True],
Cell[481747, 12704, 10647, 280, 854, "Input",
 InitializationCell->True],
Cell[492397, 12986, 8124, 214, 665, "Input",
 InitializationCell->True],
Cell[500524, 13202, 2592, 79, 152, "Input",
 InitializationCell->True],
Cell[503119, 13283, 7446, 204, 584, "Input",
 InitializationCell->True],
Cell[510568, 13489, 3856, 112, 287, "Input",
 InitializationCell->True],
Cell[514427, 13603, 138933, 3556, 6947, "Input",
 InitializationCell->True],
Cell[653363, 17161, 8476, 252, 530, "Input",
 InitializationCell->True],
Cell[661842, 17415, 30749, 795, 2469, "Input",
 InitializationCell->True],
Cell[692594, 18212, 9193, 272, 746, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[701824, 18489, 208, 6, 31, "Subsubsection"],
Cell[702035, 18497, 4044, 144, 399, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[706116, 18646, 304, 9, 57, "Subsubsection"],
Cell[706423, 18657, 2143, 74, 166, "Input",
 InitializationCell->True],
Cell[708569, 18733, 1588, 55, 116, "Input",
 InitializationCell->True],
Cell[710160, 18790, 3544, 109, 206, "Input",
 InitializationCell->True],
Cell[713707, 18901, 14013, 431, 793, "Input",
 InitializationCell->True],
Cell[727723, 19334, 3526, 105, 135, "Input",
 InitializationCell->True],
Cell[731252, 19441, 5705, 172, 460, "Input",
 InitializationCell->True],
Cell[736960, 19615, 4763, 145, 373, "Input",
 InitializationCell->True],
Cell[741726, 19762, 5308, 173, 340, "Input",
 InitializationCell->True],
Cell[747037, 19937, 6357, 209, 448, "Input",
 InitializationCell->True],
Cell[753397, 20148, 5419, 180, 269, "Input",
 InitializationCell->True],
Cell[758819, 20330, 4999, 168, 296, "Input",
 InitializationCell->True],
Cell[763821, 20500, 6386, 188, 447, "Input",
 InitializationCell->True],
Cell[770210, 20690, 924, 27, 75, "Input",
 InitializationCell->True],
Cell[771137, 20719, 3478, 118, 170, "Input",
 InitializationCell->True],
Cell[774618, 20839, 10370, 327, 643, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[785025, 21171, 300, 9, 57, "Subsubsection"],
Cell[785328, 21182, 4306, 123, 229, "Input",
 InitializationCell->True],
Cell[789637, 21307, 13263, 369, 759, "Input",
 InitializationCell->True],
Cell[802903, 21678, 10467, 304, 566, "Input",
 InitializationCell->True],
Cell[813373, 21984, 2915, 80, 179, "Input",
 InitializationCell->True],
Cell[816291, 22066, 2643, 77, 131, "Input",
 InitializationCell->True],
Cell[818937, 22145, 7406, 200, 486, "Input",
 InitializationCell->True],
Cell[826346, 22347, 7161, 213, 455, "Input",
 InitializationCell->True],
Cell[833510, 22562, 7262, 220, 455, "Input",
 InitializationCell->True],
Cell[840775, 22784, 653, 14, 201, "Input",
 InitializationCell->True],
Cell[841431, 22800, 546, 11, 133, "Input",
 InitializationCell->True],
Cell[841980, 22813, 2270, 68, 134, "Input"],
Cell[844253, 22883, 2478, 73, 131, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[846768, 22961, 300, 9, 57, "Subsubsection"],
Cell[847071, 22972, 3885, 118, 162, "Input",
 InitializationCell->True],
Cell[850959, 23092, 18333, 547, 962, "Input",
 InitializationCell->True],
Cell[869295, 23641, 5928, 177, 249, "Input",
 InitializationCell->True],
Cell[875226, 23820, 8150, 217, 513, "Input",
 InitializationCell->True],
Cell[883379, 24039, 6685, 178, 455, "Input",
 InitializationCell->True],
Cell[890067, 24219, 10845, 300, 620, "Input",
 InitializationCell->True],
Cell[900915, 24521, 10769, 300, 680, "Input",
 InitializationCell->True],
Cell[911687, 24823, 4102, 123, 291, "Input",
 InitializationCell->True],
Cell[915792, 24948, 8347, 245, 536, "Input",
 InitializationCell->True],
Cell[924142, 25195, 8993, 250, 461, "Input",
 InitializationCell->True],
Cell[933138, 25447, 4333, 124, 245, "Input",
 InitializationCell->True],
Cell[937474, 25573, 7940, 221, 374, "Input",
 InitializationCell->True],
Cell[945417, 25796, 2109, 60, 131, "Input",
 InitializationCell->True],
Cell[947529, 25858, 5896, 165, 310, "Input",
 InitializationCell->True],
Cell[953428, 26025, 6782, 200, 399, "Input",
 InitializationCell->True],
Cell[960213, 26227, 6508, 193, 376, "Input",
 InitializationCell->True],
Cell[966724, 26422, 3841, 113, 239, "Input",
 InitializationCell->True],
Cell[970568, 26537, 2233, 64, 158, "Input",
 InitializationCell->True],
Cell[972804, 26603, 3475, 94, 191, "Input",
 InitializationCell->True],
Cell[976282, 26699, 11880, 316, 563, "Input",
 InitializationCell->True],
Cell[988165, 27017, 7051, 194, 363, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[995253, 27216, 303, 9, 57, "Subsubsection"],
Cell[995559, 27227, 4932, 129, 232, "Input",
 InitializationCell->True],
Cell[1000494, 27358, 9910, 224, 309, "Input",
 InitializationCell->True],
Cell[1010407, 27584, 277, 5, 66, "Text"],
Cell[1010687, 27591, 3132, 81, 99, "Input"],
Cell[1013822, 27674, 139, 3, 41, "Text"],
Cell[1013964, 27679, 1923, 52, 79, "Input"],
Cell[1015890, 27733, 6363, 170, 333, "Input",
 InitializationCell->True],
Cell[1022256, 27905, 10236, 266, 480, "Input",
 InitializationCell->True],
Cell[1032495, 28173, 8092, 197, 309, "Input",
 InitializationCell->True],
Cell[1040590, 28372, 292, 5, 66, "Text"],
Cell[1040885, 28379, 6225, 163, 198, "Input"],
Cell[1047113, 28544, 8964, 239, 433, "Input",
 InitializationCell->True],
Cell[1056080, 28785, 6235, 148, 289, "Input",
 InitializationCell->True],
Cell[1062318, 28935, 3700, 97, 209, "Input",
 InitializationCell->True],
Cell[1066021, 29034, 5087, 135, 270, "Input",
 InitializationCell->True],
Cell[1071111, 29171, 5510, 134, 309, "Input",
 InitializationCell->True],
Cell[1076624, 29307, 3504, 89, 154, "Input",
 InitializationCell->True],
Cell[1080131, 29398, 5875, 157, 209, "Input",
 InitializationCell->True],
Cell[1086009, 29557, 5549, 148, 189, "Input",
 InitializationCell->True],
Cell[1091561, 29707, 4586, 118, 209, "Input",
 InitializationCell->True],
Cell[1096150, 29827, 8021, 209, 344, "Input",
 InitializationCell->True],
Cell[1104174, 30038, 1545, 39, 139, "Input",
 Evaluatable->False,
 InitializationCell->True],
Cell[1105722, 30079, 36797, 984, 1093, "Input",
 PageBreakWithin->Automatic,
 InitializationCell->True],
Cell[1142522, 31065, 1035, 20, 79, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1143594, 31090, 287, 9, 31, "Subsubsection"],
Cell[1143884, 31101, 3661, 97, 206, "Input",
 InitializationCell->True],
Cell[1147548, 31200, 18690, 505, 404, "Input",
 InitializationCell->True],
Cell[1166241, 31707, 7374, 180, 271, "Input",
 InitializationCell->True],
Cell[1173618, 31889, 11472, 242, 499, "Input",
 InitializationCell->True],
Cell[1185093, 32133, 18741, 470, 889, "Input",
 InitializationCell->True],
Cell[1203837, 32605, 6848, 170, 254, "Input",
 InitializationCell->True],
Cell[1210688, 32777, 7473, 182, 262, "Input",
 InitializationCell->True],
Cell[1218164, 32961, 3467, 83, 155, "Input",
 InitializationCell->True],
Cell[1221634, 33046, 12207, 319, 377, "Input",
 InitializationCell->True],
Cell[1233844, 33367, 13668, 338, 406, "Input",
 InitializationCell->True],
Cell[1247515, 33707, 21983, 589, 742, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1269535, 34301, 189, 6, 31, "Subsubsection"],
Cell[1269727, 34309, 11216, 275, 513, "Input",
 InitializationCell->True],
Cell[1280946, 34586, 19553, 421, 392, "Input"],
Cell[1300502, 35009, 18592, 412, 392, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1319143, 35427, 194, 4, 54, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1319362, 35435, 322, 9, 68, "Subsubsection"],
Cell[1319687, 35446, 1817, 55, 125, "Input",
 InitializationCell->True],
Cell[1321507, 35503, 5641, 165, 314, "Input",
 InitializationCell->True],
Cell[1327151, 35670, 8862, 255, 665, "Input",
 InitializationCell->True],
Cell[1336016, 35927, 3489, 103, 179, "Input",
 InitializationCell->True],
Cell[1339508, 36032, 16849, 422, 943, "Input",
 InitializationCell->True],
Cell[1356360, 36456, 1075, 29, 141, "Text"],
Cell[1357438, 36487, 5571, 157, 341, "Input",
 InitializationCell->True],
Cell[1363012, 36646, 11034, 285, 716, "Input",
 InitializationCell->True],
Cell[1374049, 36933, 7701, 202, 601, "Input"],
Cell[1381753, 37137, 1442, 43, 98, "Input",
 InitializationCell->True],
Cell[1383198, 37182, 445, 12, 43, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1383680, 37199, 254, 9, 31, "Subsubsection"],
Cell[1383937, 37210, 2691, 82, 179, "Input",
 InitializationCell->True],
Cell[1386631, 37294, 14510, 347, 746, "Input",
 InitializationCell->True],
Cell[1401144, 37643, 3780, 110, 206, "Input",
 InitializationCell->True],
Cell[1404927, 37755, 260, 7, 88, "Input",
 InitializationCell->True],
Cell[1405190, 37764, 121, 3, 43, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1405348, 37772, 280, 10, 31, "Subsubsection",
 InitializationCell->True],
Cell[1405631, 37784, 3432, 108, 206, "Input",
 InitializationCell->True],
Cell[1409066, 37894, 2547, 79, 179, "Input",
 InitializationCell->True],
Cell[1411616, 37975, 4533, 134, 341, "Input",
 InitializationCell->True],
Cell[1416152, 38111, 4067, 111, 233, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1420256, 38227, 246, 9, 31, "Subsubsection"],
Cell[1420505, 38238, 363, 11, 66, "Text"],
Cell[1420871, 38251, 5860, 146, 476, "Input",
 InitializationCell->True],
Cell[1426734, 38399, 2900, 72, 206, "Input",
 InitializationCell->True],
Cell[1429637, 38473, 4189, 103, 260, "Input",
 InitializationCell->True],
Cell[1433829, 38578, 3685, 94, 260, "Input",
 InitializationCell->True],
Cell[1437517, 38674, 5953, 144, 341, "Input",
 InitializationCell->True],
Cell[1443473, 38820, 3472, 89, 233, "Input",
 InitializationCell->True],
Cell[1446948, 38911, 4919, 141, 406, "Input",
 InitializationCell->True],
Cell[1451870, 39054, 3423, 88, 260, "Input",
 InitializationCell->True],
Cell[1455296, 39144, 3576, 92, 233, "Input",
 InitializationCell->True],
Cell[1458875, 39238, 4303, 103, 260, "Input",
 InitializationCell->True],
Cell[1463181, 39343, 2507, 68, 179, "Input",
 InitializationCell->True],
Cell[1465691, 39413, 887, 27, 98, "Input",
 InitializationCell->True],
Cell[1466581, 39442, 2093, 58, 125, "Input",
 InitializationCell->True],
Cell[1468677, 39502, 3728, 93, 260, "Input",
 InitializationCell->True],
Cell[1472408, 39597, 1998, 59, 206, "Input",
 InitializationCell->True],
Cell[1474409, 39658, 4500, 106, 260, "Input",
 InitializationCell->True],
Cell[1478912, 39766, 4317, 102, 260, "Input",
 InitializationCell->True],
Cell[1483232, 39870, 3454, 84, 233, "Input",
 InitializationCell->True],
Cell[1486689, 39956, 3454, 84, 233, "Input",
 InitializationCell->True],
Cell[1490146, 40042, 3294, 91, 179, "Input",
 InitializationCell->True],
Cell[1493443, 40135, 3692, 98, 233, "Input",
 InitializationCell->True],
Cell[1497138, 40235, 621, 18, 43, "Input",
 InitializationCell->True],
Cell[1497762, 40255, 925, 32, 71, "Input",
 InitializationCell->True],
Cell[1498690, 40289, 4157, 103, 260, "Input",
 InitializationCell->True],
Cell[1502850, 40394, 3739, 89, 287, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1506626, 40488, 285, 10, 31, "Subsubsection"],
Cell[1506914, 40500, 2387, 69, 152, "Input",
 InitializationCell->True],
Cell[1509304, 40571, 3828, 117, 233, "Input",
 InitializationCell->True],
Cell[1513135, 40690, 2829, 85, 125, "Input",
 InitializationCell->True],
Cell[1515967, 40777, 3312, 98, 206, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1519316, 40880, 419, 17, 57, "Subsubsection"],
Cell[1519738, 40899, 2925, 90, 233, "Input",
 InitializationCell->True],
Cell[1522666, 40991, 2985, 77, 233, "Input",
 InitializationCell->True],
Cell[1525654, 41070, 19632, 491, 1097, "Input",
 InitializationCell->True],
Cell[1545289, 41563, 8815, 236, 592, "Input",
 InitializationCell->True],
Cell[1554107, 41801, 11569, 337, 692, "Input",
 InitializationCell->True],
Cell[1565679, 42140, 3709, 69, 531, "Text"],
Cell[1569391, 42211, 3850, 109, 212, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1573278, 42325, 280, 9, 31, "Subsubsection"],
Cell[1573561, 42336, 4667, 134, 233, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1578265, 42475, 406, 14, 31, "Subsubsection"],
Cell[1578674, 42491, 3666, 104, 287, "Input",
 InitializationCell->True],
Cell[1582343, 42597, 13188, 374, 1016, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1595568, 42976, 242, 8, 31, "Subsubsection"],
Cell[1595813, 42986, 10448, 301, 800, "Input",
 InitializationCell->True],
Cell[1606264, 43289, 3070, 95, 233, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1609371, 43389, 235, 9, 31, "Subsubsection"],
Cell[1609609, 43400, 354, 11, 71, "Input"],
Cell[1609966, 43413, 64518, 1585, 6011, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1674521, 45003, 264, 8, 31, "Subsubsection"],
Cell[1674788, 45013, 6795, 179, 557, "Input",
 InitializationCell->True],
Cell[1681586, 45194, 2608, 80, 179, "Input",
 InitializationCell->True],
Cell[1684197, 45276, 6034, 176, 374, "Input",
 InitializationCell->True],
Cell[1690234, 45454, 2083, 62, 179, "Input",
 InitializationCell->True],
Cell[1692320, 45518, 4680, 135, 287, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1697037, 45658, 314, 10, 57, "Subsubsection"],
Cell[1697354, 45670, 234, 7, 111, "Input",
 InitializationCell->True],
Cell[1697591, 45679, 7703, 211, 611, "Input",
 InitializationCell->True],
Cell[1705297, 45892, 3171, 88, 260, "Input",
 InitializationCell->True],
Cell[1708471, 45982, 1966, 83, 188, "Text"],
Cell[1710440, 46067, 2389, 66, 152, "Input",
 InitializationCell->True],
Cell[1712832, 46135, 412, 10, 90, "Text"],
Cell[1713247, 46147, 14056, 387, 1286, "Input",
 InitializationCell->True],
Cell[1727306, 46536, 4478, 139, 295, "Input",
 InitializationCell->True],
Cell[1731787, 46677, 9754, 271, 740, "Input",
 InitializationCell->True],
Cell[1741544, 46950, 5956, 173, 476, "Input",
 InitializationCell->True],
Cell[1747503, 47125, 357, 7, 90, "Text"],
Cell[1747863, 47134, 2565, 76, 152, "Input",
 InitializationCell->True],
Cell[1750431, 47212, 1910, 58, 152, "Input",
 InitializationCell->True],
Cell[1752344, 47272, 183, 4, 66, "Text"],
Cell[1752530, 47278, 3915, 109, 340, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1756482, 47392, 303, 9, 57, "Subsubsection"],
Cell[1756788, 47403, 3111, 96, 260, "Input",
 InitializationCell->True],
Cell[1759902, 47501, 5164, 76, 341, "Input",
 InitializationCell->True],
Cell[1765069, 47579, 1584, 30, 125, "Input",
 InitializationCell->True],
Cell[1766656, 47611, 7527, 190, 536, "Input",
 InitializationCell->True],
Cell[1774186, 47803, 2207, 41, 233, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1776430, 47849, 336, 11, 31, "Subsubsection"],
Cell[1776769, 47862, 297, 8, 66, "Text"],
Cell[1777069, 47872, 8548, 268, 301, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1785642, 48144, 60, 1, 43, "Input"],
Cell[1785705, 48147, 29, 0, 42, "Output"]
}, Open  ]],
Cell[1785749, 48150, 16322, 469, 689, "Input",
 InitializationCell->True],
Cell[1802074, 48621, 21832, 590, 1287, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1823931, 49215, 615, 18, 48, "Input"],
Cell[1824549, 49235, 45, 1, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1824631, 49241, 60, 1, 43, "Input"],
Cell[1824694, 49244, 29, 0, 42, "Output"]
}, Open  ]],
Cell[1824738, 49247, 401, 17, 43, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1825176, 49269, 257, 9, 31, "Subsubsection"],
Cell[1825436, 49280, 2896, 94, 174, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1828369, 49379, 236, 8, 31, "Subsubsection"],
Cell[1828608, 49389, 1950, 30, 384, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1830607, 49425, 292, 9, 80, "Subsection"],
Cell[1830902, 49436, 71, 1, 43, "Input"],
Cell[1830976, 49439, 75, 2, 43, "Input",
 InitializationCell->True],
Cell[1831054, 49443, 162, 3, 43, "Input",
 InitializationCell->True],
Cell[1831219, 49448, 3375, 48, 341, "Input",
 InitializationCell->True],
Cell[1834597, 49498, 138, 3, 43, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
