(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1572689,      51827]
NotebookOptionsPosition[   1516826,      50120]
NotebookOutlinePosition[   1520496,      50234]
CellTagsIndexPosition[   1519926,      50217]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Small finite Groups, Loops, Hoops & Geometric Algebras for non-",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " users."
}], "Title",
 PageWidth->WindowWidth,
 CellMargins->{{4, -16}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Small Groups, Moufang Loops, Hoop and Geometric Algebras;",
 StyleBox[" ", "DisplayFormula"],
 "Demonstrations."
}], "Subtitle",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["R.H.Beresford. 2004. Latest Revision 21/8/2008", "Subsubtitle",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[{
 "Non-",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " readers",
 StyleBox[" ",
  FontSlant->"Italic"],
 "vs ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " users."
}], "Section",
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThe examples in this notebook are intended to be comprehensible by non-",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " users via ",
 StyleBox["MathPlayer",
  FontColor->GrayLevel[0]],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " users can install the ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " package and activate it with the following instruction, so they can test \
the examples with other data, or carry out other investigations."
}], "Text",
 PageWidth->WindowWidth],

Cell["Quit[]", "Input"],

Cell[BoxData[
 RowBox[{"<<", "GroupLoopHoop6`"}]], "Input",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New foundations for physical mathematics? Symmetry-conserving \
partial-fraction-division \"Hoop\" Algebras.\
\>", "Section",
 FontFamily->"Times New Roman"],

Cell["\<\
\"To see what is in front of your nose needs a constant struggle.\" (George \
Orwell.)\
\>", "Text",
 PageWidth->WindowWidth,
 TextJustification->0.25],

Cell[TextData[StyleBox["Summary. Symmetry-conserving partial-fraction \
vector-division \"Hoop\" algebras arise from algebraic loops, which multiply \
\"vecs\" (sets of  elements, used because \"vector\" is ambiguous) via \
quasi-group Cayley multiplication tables. Loop symmetries are used to \
introduce generalised signs (orthogonal r'th roots of unity) by \"r-folding\" \
the table and the vec, which becomes a vec over a field.  All associative \
(group) tables, and a few octonionic non-associative Moufang loops, have the \
Frobenius property, Det[A] Det[B] =\[PlusMinus] Det[AB]. Det is the \
determinant of the inverse table, mapped with the vec. The determinant \
factors are conserved symmetries, or \"sizes\", that provide numerators for a \
partial-fraction formulation of the multiplicative inverse of any vec. (The \
Moufang property ensures that multiplicative inverses exist). Whenever a size \
is zero, conservation  \"projects\" everything into a constrained \
sub-algebra, eliminating the infinity. Multiplying or dividing vecs with \
disparate zero-sizes  maintains conservation by ejecting \"remainders\". By \
Noether's theorem, the symmetries lead to particles and forces; so remainders \
may correspond to particle interactions or decay.\nReal and complex algebras \
are degenerate mono-sized hoops that impose 2-fold symmetry. Commutative \
hoops have multi-phase polar-dual orbits; the quadratic sizes become squared \
radii, phase angles are hidden variables. Non-commutative hoop multiplication \
splits ino a commutative Jordan product and a non-commutative Lie product, \
i.e. the inner and wedge products of Grassmann's Geometric algebra. Clifford \
(Geometric) algebras are ant-commutative Hoops that generalise geometry, \
analysis, etc., to any number of dimensions. Their distinctive properties are \
developed in a separate package.",
 FontSlant->"Italic"]], "Text"],

Cell[TextData[{
 "\tRecognising that integers and reals are equivalence relationships on \
pairs of unsigned numbers suggests a new formulation of physical mathematics. \
All groups, and a few non-associative Moufang loops, provide \
multiplication/division tables with a symmetry-conserving property for \
unsigned vecs. (This term is introduced for lists of elements because ",
 StyleBox["\"vector\" ",
  FontSlant->"Italic"],
 "is ambiguous.) Tables with r-fold symmetry \"fold\" to algebras that have \
",
 StyleBox["r",
  FontSlant->"Italic"],
 "-th roots of unity as orthogonal \"generalized signs\". Real and complex \
numbers correspond to ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = 2 or 4, whilst ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = 3 gives a complete \"Terplex\" algebra relevant to quarks. (This is \
distorted if it is projected onto a complex plane.)  The factors of table \
determinants (mapped with a general vector {",
 StyleBox["a,b,..,m",
  FontSlant->"Italic"],
 "}) are conserved symmetries (or \"sizes\") that, by Noether's law, relate \
to particles and forces; vector multiplication may be related particle \
interactions. Vecs with some zero-sizes correspond to objects lacking some \
symmetries. Their conservative multiplication has to generate \"remainders\" \
carrying sizes that would otherwise be lost, as in particle interaction and \
decay. Different tables (different forces?) conserve different (but \
overlapping) sets of symmetries.\n\tThe Moufang division property ensures \
that every vec has a multiplicative inverse that splits into partial \
fractions with each size as a denominator (mono-sized algebras are degenerate \
cases). Zero-sizes constrain operations to sub-algebras that cannot create \
infinities because these sizes are eliminated. Commutative (Abelian) tables \
have polar-dual formulations with quadratic sizes defining squared radii that \
multiply and angles and add on vec multiplication, together with linear sizes \
defining \"offsets\" as additive conserved properties. Multi-phase sinusoidal \
\"orbits\" occur; but I have failed to find differential equations describing \
multi-phase solitonic wave-packets. Stable orbits appear to be restricted to \
table dimensions ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["2", "p"], 
   SuperscriptBox["3", "q"]}]]],
 ".\n\t12-element \"Dozal\" and 6-element \"Hexal\" algebras look promising \
as fermionic and bosonic models. Four groups conserve overlapping sets of  3, \
4, 6 and 12-phase systems that have symmetries resembling those of stable \
particles. The bosons are \"supersymmetric\" to, but fewer in number than, \
the fermions. Outstanding problems are the interpretation of the Lie products \
of non-commutative algebras, and the formulation of the sizes of groups with \
more than 16 elements.\n\tOther operations are related to Hoop \
multiplication. Vec can be raised to powers, exponentiated & differentiated. \
Non-abelian algebras split into a Jordan (commutative, inner, Dot) product \
(ab+ba)/2 and a Lie (non-commutative,outer, wedge) product (ab-ba)/2. \
Clifford (Geometric) algebras are a subset that specialize the to a graded \
algebra with products that separate into a scalar and pseudoscalar grade, and \
different multivector grades. This generalizes the scalar, dot and cross \
products (which are limited to 2,3, & 7 dimensions), and complex analysis, to \
any number of dimensions. "
}], "Text"],

Cell[TextData[{
 "\"Primal\" Mathematics.\n\tMost mathematicians assume (without any attempt \
at justification) that integers \[DoubleStruckCapitalZ] are fundamental, \
instead of being equivalence relationships on pairs of unsigned (natural) \
numbers \[DoubleStruckCapitalN]",
 Cell[BoxData[
  SubscriptBox["", "0"]]],
 ". Equivalencing destroys information, whilst introducing and conflating \
unary negation ",
 StyleBox["-a ",
  FontSlant->"Italic"],
 "and binary subtraction ",
 StyleBox["a-b",
  FontSlant->"Italic"],
 "; it also makes the real number \"-1\" unique. A few authors justify this \
by \"it is so much easier to work in fields!\" The result is \"too much \
reality\"."
}], "Text"],

Cell[TextData[{
 "\tA better approach is to postpone the introduction of real numbers and the \
signs -1=",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"+", "1"}]]]],
 " and \[ImaginaryI]=",
 Cell[BoxData[
  RadicalBox[
   RowBox[{"+", "1"}], "4"]]],
 ". Unsigned numbers  \[DoubleStruckCapitalN]",
 Cell[BoxData[
  SubscriptBox["", "0"]]],
 " = {0,1,..} arise from set theory as labels for the sets { {}, {{}}, ...} \
and have several emergent properties. If ",
 StyleBox["a,b,c,d,,m,p,q,r,s,t",
  FontSlant->"Italic"],
 " are members of \[DoubleStruckCapitalN]",
 Cell[BoxData[
  SubscriptBox["", "0"]]],
 ", then:-\n1) The exclusive possibilites ",
 StyleBox["a<b, a=b, ",
  FontSlant->"Italic"],
 "or",
 StyleBox[" a>b",
  FontSlant->"Italic"],
 " define trichotomous order.\n2) The operations ",
 StyleBox["a+b = s",
  FontSlant->"Italic"],
 " (sum), ",
 StyleBox["a*b = t",
  FontSlant->"Italic"],
 " (times), ",
 StyleBox["a^b = p",
  FontSlant->"Italic"],
 " (power) are universal;\n3) Instead of subtraction there is a symmetric \
difference ",
 StyleBox["m=|a,b|",
  FontSlant->"Italic"],
 " with Min(",
 StyleBox["a,b",
  FontSlant->"Italic"],
 ")+",
 StyleBox["m ",
  FontSlant->"Italic"],
 "= Max(",
 StyleBox["a,b",
  FontSlant->"Italic"],
 ")\n4) Division gives a remainder ",
 StyleBox["a/d",
  FontSlant->"Italic"],
 "(divisor) = ",
 StyleBox["q",
  FontSlant->"Italic"],
 " (quotient) +",
 StyleBox["r",
  FontSlant->"Italic"],
 " (remainder), with ",
 StyleBox["q*d+r",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 " (so if ",
 StyleBox["d",
  FontSlant->"Italic"],
 "=0, ",
 StyleBox["q",
  FontSlant->"Italic"],
 " is undefined but ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 " ).\n5) If ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=0, ",
 StyleBox["d",
  FontSlant->"Italic"],
 " is called a factor of ",
 StyleBox["a",
  FontSlant->"Italic"],
 "; ",
 StyleBox["a",
  FontSlant->"Italic"],
 " is prime if it itis>1 and only has factors 1 and ",
 StyleBox["a",
  FontSlant->"Italic"],
 ".\n6) Every ",
 StyleBox["a>",
  FontSlant->"Italic"],
 "1 has a unique prime factorisation."
}], "Text"],

Cell[TextData[{
 "\tLandau developed unsigned rationals \[DoubleStruckCapitalQ]",
 Cell[BoxData[
  SubscriptBox["", "+"]]],
 " as equivalence relationships on unsigned ordered pairs of natural numbers, \
",
 StyleBox["c~{a*d,b*d},",
  FontSlant->"Italic"],
 " but started natural numbers at 1. Starting with 0 gives non-negative \
rationals \[DoubleStruckCapitalQ]",
 Cell[BoxData[
  SubscriptBox["", 
   RowBox[{"0", "+"}]]]],
 ". Rational infinity is ",
 StyleBox["\[Infinity]~{a>0,0}",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["{0,0}",
  FontSlant->"Italic"],
 " is undefined. Rational division no longer creates remainders.\n\tA \
continuity axiom can now be used to convert \[DoubleStruckCapitalQ]",
 Cell[BoxData[
  SubscriptBox["", 
   RowBox[{"0", "+"}]]]],
 " into the unsigned continuous numbers (the half line), for which I propose \
the name \"Primal\" numbers with symbol \[DoubleStruckCapitalA] (Absolute, as \
\[DoubleStruckCapitalP] is already in use). These introduce unique roots, as \
the inverse of exponentiation."
}], "Text"],

Cell[TextData[{
 "\t\"Indexed sets\" of primal numbers A={",
 Cell[BoxData[
  SubscriptBox["a", "1"]]],
 ",",
 Cell[BoxData[
  SubscriptBox["a", "2"]]],
 ",...",
 Cell[BoxData[
  SubscriptBox["a", "m"]]],
 "} (etc) are introduced; they differ from ordered sets by having properties \
that are not affected by re-ordering. Multiplication can now be defined, for \
indexed sets, as a binary operation A*B\[ShortRightArrow]P, ",
 Cell[BoxData[
  SubscriptBox["p", "ij"]]],
 "=",
 Cell[BoxData[
  SubscriptBox["a", "i"]]],
 Cell[BoxData[
  SubscriptBox["b", "j"]]],
 ", with ",
 StyleBox["ij ",
  FontSlant->"Italic"],
 "being defined by a Cayley table M=[",
 Cell[BoxData[
  SubscriptBox["M", "ij"]]],
 "]. If this is a (square, m\[Times]m) quasi-group with identity, the result \
is an \"algebraic loop\". Important subsets are ",
 StyleBox["Moufang (division) loops",
  FontSlant->"Italic"],
 " with ",
 StyleBox["ca.bc=(c.ab).c,",
  FontSlant->"Italic"],
 " their associative subset of ",
 StyleBox["groups",
  FontSlant->"Italic"],
 " with ",
 StyleBox["a(bc)=(ab)c",
  FontSlant->"Italic"],
 ", and their commutative subset ",
 StyleBox["Abelian groups",
  FontSlant->"Italic"],
 " with ",
 StyleBox["ab=ba.\n\t",
  FontSlant->"Italic"],
 "The Moufang property ensures that every vec A has a multiplicative inverse. \
If the table has ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry, it is possible to introduce generalized signs ",
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckS]", 
   RowBox[{"i", "<", "r"}]]]],
 " with ",
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckS]", "r"]]],
 "=1 by \"folding\" the Cayley table to define a division algebra. The C2, \
C4, Klein and Quaternion groups, and the non-associtive Octonion and \
split-octonion tables have {2,4,4,8,16,16} elements and fold to real, \
complex, double, quaternion, octonion and split-octonion algebras with \
ordinary negation (and {1,2,2,4,8,8} real elements). C6 and C12 (etc) can be \
3-folded to ternary algebras; these have \"associative triality\"."
}], "Text"],

Cell[TextData[{
 "\tAll groups, and a few non-associative Moufang loops, have another \
property that is important in mathematical physics - \"Frobenius determinant \
conservation\". The symbolic determinants of their inverse Cayley tables \
(mapped with {a,b,...} for compactness) factorise into \"symmetries\" that \
are conserved on multiplication and division. Thus C4, K, and quaternions \
conserve ",
 Cell[BoxData[
  SuperscriptBox["a", "2"]]],
 "+",
 Cell[BoxData[
  SuperscriptBox["b", "2"]]],
 "(C4), ",
 Cell[BoxData[
  SuperscriptBox["a", "2"]]],
 "-",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["b", "2"], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}]}]}]]],
 "(K), ",
 Cell[BoxData[
  SuperscriptBox["a", "2"]]],
 "+",
 Cell[BoxData[
  SuperscriptBox["b", "2"]]],
 "+",
 Cell[BoxData[
  SuperscriptBox["c", "2"]]],
 "+",
 Cell[BoxData[
  SuperscriptBox["d", "2"]]],
 "(\[DoubleStruckCapitalH]).  Noether's laws mean that symmetries imply \
conserved forces and matching particles. Consequently, these algebras provide \
an approach to particle physics that uses finite Cayley multiplication tables \
to define particle physics. Do not confuse this with the \"standard model\", \
which uses matrix multiplication (and infinite groups) in transformations of \
space-time."
}], "Text"],

Cell["\<\
\tI call these symmetry-conserving division algebras \"hoops\". All Abelian \
hoops have duals with 1 to 1 mappings between the Cartesian-vector \
description and a description as multi-phase \"orbits\" with \"offsets\". \
Each hoop symmetry has a Cartesian and (at least for Abelian hoops) a polar \
formulation. The angles of the polar form are \"hidden variables\" of the \
cartesian form. Every \"vec\" (generalized vector, so named because \
\"vector\" is ambiguous) has a \"shape\" (set of conserved symmetries or \
\"sizes\") in a given hoop. Vecs with all offsets and radii being either 0 or \
1 are \"stable\" under hoop multiplication. Hoop multiplication/division of \
vecs re-introduces \"remainders\", those sizes that are zero in one \
multiplicand but not in the other. This is needed to maintain symmetry \
conservation, the fundamental property of hoop algebras and of physics. Two \
vecs (with different symmetries) interact to create a product and a remainder \
with different sets of symmetries, but the symmetries are conserved. I \
suggest that this relates vecs to particles and forces, with hoop \
multiplication defining their interactions. Vecs can be multiplied by \
different hoops, and I suggest that these correspond to different forces that \
conserve (and break) different sets of symmetries.
\tThe abelian Dozal (12 element) algebras (C3K & C3C4) have Abelian products \
that conserve linear offsets for 3-phase, 4-phase, and 6-phase sinusoidal \
orbits in 12-direction formulations that have analogies with 4-phase leptons, \
3, 6, and possibly 12 phase hadrons. These fold to Hexal (6 elements)  \
products with analogies to the bosons. The non-Abelian D3C2, Q12, and A4 \
Dozal algebras share some of these orbits, but may introduce uncertainty.
\tFour interesting observations -
1) The different sets of sizes resemble the different sets of properties of \
fundamental particles. Different multiplications conserve different sets of \
symmetries,.
2) Pairs of vecs with disparate sizes create a vec with the common sizes and \
remainder vecs carrying the overlapping sizes.
3) As folding means that Hexal is an equivalence relation, it may account for \
bosons being free from Pauli's exclusion principle.
4) Folding destroys some symmetries. Consequently, bosons may be the \
sub-symmetric partners of fermions, with fermions being the (one to many) \
supersymmetric partners of bosons.\
\>", "Text"],

Cell[TextData[{
 "\tThis notebook demonstrates the material on small groups, Moufang loops, \
and \"Hoop Algebras\" supplied in the",
 StyleBox[" GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " package in ",
 ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://library.wolfram.com/infocenter/MathSource/4894/"], None}],
 ". Another notebook, ",
 StyleBox["HoopDemo.nb",
  FontSlant->"Italic"],
 ", deals solely with Hoop Algebras; another, on Geometric Algebras, is in \
preparation. A shorter and simpler account of Hoop Algebras (using a much \
smaller package, and omitting all the material specific to groups and loops) \
is available as ",
 StyleBox["HoopFundamentals.nb",
  FontSlant->"Italic"],
 " in ",
 ButtonBox["http://library.wolfram.com/infocenter/MathSource/6198/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://library.wolfram.com/infocenter/MathSource/6198/"], None}],
 StyleBox[" \n",
  FontSlant->"Italic"],
 "This development version (2008) uses",
 StyleBox[" GroupLoopHoop6.m\n\t",
  FontSlant->"Italic"],
 "If you are a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " user and wish to check the examples, to test them with changed data, or to \
investigate any other aspects of groups, loops, or hoops, activate the ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " notebook. This provides a database of over 800 Cayley tables, including \
all groups with up to 73 elements, together with the relevant procedures.\n\t\
Please inform me by e-mail to ",
 StyleBox["rhberesford@btinternet.com",
  FontSlant->"Italic"],
 " of any errors or infelicities."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["1. Preamble",
  FontFamily->"Times New Roman"],
 "."
}], "Section",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["1.1 Summary. ", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\t\"Primal\" (unsigned continuous) numbers, \"Generalized Signs\" \
(orthogonal roots of unity) and \"Hoops\" (Symmetry-conserving \
Partial-fraction vector-division Algebras) re-write much of mathematics. \
Hoops multiply, divide, add and split sets of operators or primal \
coefficients. They are defined by having Cayley multiplication tables with \
Frobenius determinant-factor conservation. They also have the Moufang \
properties [2, p92] , ",
 StyleBox["including ",
  FontWeight->"Plain"],
 StyleBox["zx.yz=(z.xy)z,",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontWeight->"Plain"],
 "left & right units, & multiplicative inverses for \"vecs\" (sets of \
operators or coefficients, generalized vectors). They conserve symmetries or \
\"sizes\" (factors of the symbolic conjugate table determinant) on \
multiplication and division. The existence of multiplicative inverses makes \
vec division the same operation as vec multiplication; this creates \
\"remainders\" to maintain size conservation when the operands have disparate \
sizes.\n\tRoots of unity provide generalized signs that \"fold\" groups and \
many Moufang loops to \"Hoop algebras\" with vec multiplication and \
generalized negation. Simple negation \"-\" is an equivalence relation on ",
 StyleBox["pairs",
  FontSlant->"Italic"],
 " of unsigned numbers. Generalized signs ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "r"], TraditionalForm]]],
 " involve equivalence relations on indexed ",
 StyleBox["sets ",
  FontSlant->"Italic"],
 "of ",
 StyleBox["r",
  FontSlant->"Italic"],
 " unsigned numbers, and extend many aspects of standard mathematics - they \
generate groups and multi-phase sinusoids; complex & quaternion algebras are \
degenerate mono-sized hoop algebras, minus one is not unique, etc.\n\tMany \
commutative hoops have quadratic sizes that lead to polar or hyperbolic \
duals, generalized powers and roots, and deBroglie-wave-like continuous \
\"orbits\" (polar duals with unit magnitude). A few orbits have stable \
Planck-area-like squared amplitudes, possibly related to stable particles. \
Elements in these algebras act as unit-spin and half-spin quantum operators. \
Indirect composition of \"supersymmetric\" commutative algebras creates \
\"subsymmetric\" non-commutative algebras with more symmetries. (Physicists \
originated this nomenclature, wrongly assuming it to be one-to-one.)\n\t\
\"Zero-sized vecs\" have some sizes equal to zero. Multiplication and \
division by them \"projects\" the result into a sub-algebra with these sizes \
zeroed, whilst \"ejecting\" size-conserving \"remainders\". Thus A*B = \
T(times) + Rl + Rr (remainders) and T/B + Rl = A,  T/A + Rr = B. The sizes of \
Rl & Rr are those that are zero in B & A respectively. This generalizes \
integer division, where A/B gives Q (quotient) + R (remainder) with R\
\[LessSlantEqual]B and Q*B+R=A. Remainders provide \"renormalization\" and \
eliminate vector division-by-zero.\n\tNon-commutative hoops have repeated \
sizes. These release degrees of freedom. Multiplication splits ino a \
commutative Jordan product and a non-commutative Lie product, i.e. inner and \
wedge products. Clifford (Geometric) algebra is the anti-commutative subset \
that generalises many aspects of geometry, analysis, and physics to any \
number of dimensions.\n\tThe ",
 StyleBox["GroupLoopHoop.m",
  FontSlant->"Italic"],
 " package provides a database of over 800 loops including over 80 hoops, all \
groups with up to 73 elements, and the 12 smallest non-associative Moufang \
loops. It also includes procedures to create, test, identify and manipulate \
groups, loops & hoops."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
1.2 New and Neglected Mathematical Concepts Related to Hoops.\
\>", "Subsection",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0.625}, {Inherited, Inherited}},
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tMany new, and some neglected, mathematical concepts are developed below, \
in ",
 StyleBox["bold",
  FontWeight->"Bold"],
 " when first mentioned; they are related to hoop algebras (and summarized in \
the companion notebook ",
 StyleBox["HoopGlossary.nb",
  FontSlant->"Italic"],
 ").\n\tAlgebraic loops are closed binary operations with a unit. If they are \
finite, they can be expressed as indexed Cayley tables, with the first row \
and column being {1,2,...,m} (the unit) and with every row and column \
containing each index once. A ",
 StyleBox["Protoloop",
  FontWeight->"Bold"],
 " has been chosen for each loop, and put in the database; this is a \
preferred isomorph that is related to the protoloops of similar loops.\n\t\
Loops that are associative, with x(yz) = (xy)z (for all elements x,y,z in the \
table), are Groups. If they have the slightly less restrictive Moufang \
division property zx.yz = (z.xy)z they are \"Moufang Loops\" [2, p92] . \
(Other Moufang properties are equivalent to this division property.) All \
groups are Moufang Loops, and all non-associative Moufang Loops are \"square \
associative\" or \"alternative\", with xx.y = x(xy).\n\tFrobenius showed that \
all groups have ",
 StyleBox["Frobenius conservation,",
  FontWeight->"Bold"],
 " Det[A] Det[B] = \[PlusMinus] Det[AB]. Here, A = {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], ","}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "2"], TraditionalForm]]],
 ", ..",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "m"], TraditionalForm]]],
 "} and B = {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "2"], TraditionalForm]]],
 ", ..",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "m"], TraditionalForm]]],
 "} are ",
 StyleBox["vecs",
  FontWeight->"Bold"],
 " (generalized vectors), sets of unsigned operators or coefficients (loops \
can be defined without recourse to negation) and AB is the product {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "2"], TraditionalForm]]],
 ",.., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "m"], TraditionalForm]]],
 "} obtained by ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "k"], TraditionalForm]]],
 "=\[Sum]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "j"], TraditionalForm]]],
 ", where ",
 StyleBox["i.j=k",
  FontSlant->"Italic"],
 " in the table. Det[A] is that of the protoloop table mapped with the ",
 StyleBox["generalized conjugate",
  FontWeight->"Bold"],
 " of A. All groups, Octonions and a few other non-associative Moufang Loops \
have this ",
 StyleBox["conservative ",
  FontWeight->"Bold"],
 "property (most loops do not). The division property guarantees that ",
 StyleBox["every vec A has an inverse",
  FontWeight->"Bold"],
 ", Ai = {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "2"], TraditionalForm]]],
 ",..",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "m"], TraditionalForm]]],
 "} /Det[A] with Ai.A={1,0,...}. Hence multiplication is invertible, and \
division is defined for Moufang Loops. The inverse can be calculated by \
Cramer's rule. An important feature of Moufang Loops is that ",
 StyleBox["the inverse splits into partial fractions",
  FontWeight->"Bold"],
 " because Det[A] always factorises (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "2"], TraditionalForm]]],
 "+..+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "m"], TraditionalForm]]],
 " must be a first factor of a quasigroup determinant). Note that the \
multiplication operation involves two vectors; it is not matrix \
multiplication, which transforms a single vector to a different coordinate \
system."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tConservative loops have two operations, multiplication and division; they \
become algebras when ",
 StyleBox["generalized signs",
  FontWeight->"Bold"],
 " (and generalized subtraction) are defined. The traditional signs {+,\
\[ImaginaryI],-,-\[ImaginaryI]} are created by equivalence relations on ",
 StyleBox["sets",
  FontSlant->"Italic"],
 " of unsigned numbers. Integers are created [8, p20 et seq] when ",
 StyleBox["pairs",
  FontSlant->"Italic"],
 " of Natural (unsigned) numbers {",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 "} & {",
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 "} are equivalenced to a single integer ",
 StyleBox["x ",
  FontSlant->"Italic"],
 "if ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 "+",
 StyleBox["d=b+c",
  FontSlant->"Italic"],
 ". Unsigned continuous numbers (I call them \"Primal Numbers\") can be \
created via an axiom of continuity on unsigned rational numbers. If the \
cyclic group of 2 elements, C2, is used as a multiplication table for ordered \
pairs of primals, {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "2"], TraditionalForm]]],
 "} and {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "2"], TraditionalForm]]],
 "}, the result is the ordered pair {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "2"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]]],
 "}. Equivalencing then gives the rules of Real Algebra, {\"+\"\[Times]\"+\" \
= \"+\", \"-\"\[Times]\"-\" = \"+\", \"+\"\[Times]\"-\" = \"-\", \
\"-\"\[Times]\"+\" = \"-\"}, and these rules give a division algebra because \
C2 is conservative. I use the term \"folding\" for equivalencing from ",
 StyleBox["m",
  FontSlant->"Italic"],
 " elements to ",
 StyleBox["m/r",
  FontSlant->"Italic"],
 " elements for loops with ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry.\n\tUsing the C4 multiplication table to multiply sets of \
four unsigned numbers give Complex algebra after folding to a pair of \
\"real\" coefficients, the real and imaginary parts. (These are \"real\" \
because they can be positive, zero, or negative.) The rules of Complex \
arithmetic include those of real algebra, together with \"\[ImaginaryI]\"\
\[Times]\"\[ImaginaryI]\" = \"-\", \"-\"\[Times]\"\[ImaginaryI]\" = \"-\
\[ImaginaryI]\", etc.; they originate in the conservative property of C4. \
Four unsigned coefficients have been folded to one complex number.\n\tFolding \
the Klein 4-group K gives \"Study numbers\", \"Cayley-Klein numbers\" or \
\"double algebra\" [3, p24]. These describe the hyperbolic plane instead of \
the complex plane. K has three elements that square to +1, i.e. \"j\", \"k\" \
and \"jk\"; so \"minus one is not unique\".\n\tSimilarly, the eight-element \
Quaternion group provides the rules for Quaternion algebra, with four \
\"real\" coefficients that are folded from the eight unsigned elements. \
\"+1\" has three different fourth roots in Quaternion algebra.\n\tOctonion \
algebra involves eight \"real\" coefficients and seven fourth roots of +1, \
but there is no group to provide the multiplication table for the 16 \
un-equivalenced elements. The relevant multiplication table \"Oct\" is not a \
group (it is only square-associative), but it is folded from a \
\"non-associative Moufang Loop\".\n\tHamilton noted the two-to-one \
relationships between the quaternion and octonion tables and their \
multiplication tables. (?? in Lectures on Quaternions, Dublin 1853.??) He \
distinguished between the (unsigned) \"",
 StyleBox["directions",
  FontWeight->"Bold"],
 "\" of the larger tables and the (signed) \"",
 StyleBox["dimensions",
  FontWeight->"Bold"],
 "\" of the smaller tables. He also introduced \"vector\" for the imaginary \
part of these algebras.\n\t Sets of ",
 StyleBox["m ",
  FontSlant->"Italic"],
 "unsigned coefficients are folded to ",
 StyleBox["vecs",
  FontWeight->"Bold"],
 " (generalized vectors in the modern sense of a list of elements) with ",
 StyleBox["m/2",
  FontSlant->"Italic"],
 " signed coefficients by 2-fold equivalencing. Conservative ",
 StyleBox["m\[Times]m",
  FontSlant->"Italic"],
 " loops, with 2-fold symmetry, are folded to algebras with multiplication \
tables of size ",
 StyleBox["(m/2)\[Times](m/2)",
  FontSlant->"Italic"],
 ". The Frobenius determinant-conservation property Det[A] Det[B] = Det[AB] \
and the Moufang division property zx.yz = (z.xy)z (relaxed to \"up to a \
sign\") survive the folding process, and so are shared by all Hoop \
algebras.",
 StyleBox[" ",
  FontWeight->"Bold"],
 "The conservation property makes them relevant to physics, via Noether's \
law. (Non-Moufang algebras, and most non-associative Moufang algebras, do not \
provide consistent conservation laws.) The division property ensures that",
 StyleBox[" every vec has a multiplicative inverse",
  FontWeight->"Bold"],
 " (making multiplication and division a single operation). In most cases, \
the inverse splits into partial fractions with the determinant factors as \
denominators.\n\t I propose the name ",
 StyleBox["Hoops",
  FontWeight->"Bold"],
 " for these ",
 StyleBox["symmetry-conserving partial-fraction division algebras.",
  FontWeight->"Bold"],
 " (Hoops are rings or loops that conserve their shape, and come between \
groups and loops.) A single procedure ",
 StyleBox["hoopTimes[A,B,table]",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " performs multiplication of the vecs A & B according to the specified \
table, and makes ",
 StyleBox["table",
  FontSlant->"Italic"],
 " the ",
 StyleBox["Target algebra",
  FontWeight->"Bold"],
 ". Another procedure ",
 StyleBox["hoopInverse[A]",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " calculates the inverse of A in the target algebra\n\tFolding can be \
generalized to use other symmetries. As all groups are hoops, ",
 StyleBox["every group with r-fold symmetry can be folded to an r-signed \
algebra",
  FontWeight->"Bold"],
 ". Figure 1 shows protoloops for three Moufang Loops (the C4C2, quaternion, \
and C9 groups). The top left corner is repeated in the tables; it also occurs \
with offsets of 3, 4, or 6, showing the symmetry. It is then shown as folded \
tables, with the indices replaced by the usual complex or quaternion symbols, \
or (in the C9j algebra) by signed indices, with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], TraditionalForm]]],
 "=1 providing a new sign \[DoubleStruckCapitalJ] so that indices 4 & 5 \
becoming \[DoubleStruckCapitalJ]1 and \[DoubleStruckCapitalJ]2. The last \
table has {a,b,c} mapped onto {1,2,3}, to give the symbolic table, with the \
determinant ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["c", "3"]}], "-", 
   RowBox[{
    SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "+", 
   RowBox[{
   "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], "-", 
   RowBox[{
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]],
 ". Note also that the C4C2 table can be folded a second time, to give the \
Complex multiplication table \"C4c\" with \[ImaginaryI].\[ImaginaryI]=-1. "
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 1.",
  FontWeight->"Bold"],
 " Two-fold and three-fold ",
 "Folding",
 StyleBox[" ",
  FontWeight->"Bold"],
 "of Moufang Loops\n            and the resulting signed algebras."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 " C4C2 group  Quaternion group   C9 Group\n\n",
 Cell[BoxData[
  TagBox[
   FormBox[
    RowBox[{GridBox[{
       {
        StyleBox["1",
         FontWeight->"Bold"], 
        StyleBox["2",
         FontWeight->"Bold"], 
        StyleBox["3",
         FontWeight->"Bold"], 
        StyleBox["4",
         FontWeight->"Bold"], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["2",
         FontWeight->"Bold"], 
        StyleBox["3",
         FontWeight->"Bold"], 
        StyleBox["4",
         FontWeight->"Bold"], 
        StyleBox["1",
         FontWeight->"Bold"], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["3",
         FontWeight->"Bold"], 
        StyleBox["4",
         FontWeight->"Bold"], 
        StyleBox["1",
         FontWeight->"Bold"], 
        StyleBox["2",
         FontWeight->"Bold"], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["4",
         FontWeight->"Bold"], 
        StyleBox["1",
         FontWeight->"Bold"], 
        StyleBox["2",
         FontWeight->"Bold"], 
        StyleBox["3",
         FontWeight->"Bold"], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Bold",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]"}],
    TraditionalForm],
   TraditionalForm,
   Editable->True]],
  PageWidth->PaperWidth,
  Evaluatable->False,
  FontSize->9],
 ", ",
 Cell[BoxData[
  RowBox[{
   TagBox[
    FormBox[
     RowBox[{"\[NoBreak]", GridBox[{
        {
         StyleBox["1",
          FontWeight->"Bold"], 
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["3",
          FontWeight->"Bold"], 
         StyleBox["4",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"], 
         StyleBox["8",
          FontWeight->"Bold"], 
         StyleBox["3",
          FontWeight->"Bold"], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["3",
          FontWeight->"Bold"], 
         StyleBox["4",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"], 
         StyleBox["6",
          FontWeight->"Bold"], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["4",
          FontWeight->"Bold"], 
         StyleBox["7",
          FontWeight->"Bold"], 
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["5",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["5",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["5",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["5",
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak] "}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ","}]],
  PageWidth->PaperWidth,
  Evaluatable->False,
  FontSize->9],
 " ",
 Cell[BoxData[
  RowBox[{GridBox[{
     {
      StyleBox["1",
       FontWeight->"Bold"], 
      StyleBox["2",
       FontWeight->"Bold"], 
      StyleBox["3",
       FontWeight->"Bold"], 
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["2",
       FontWeight->"Bold"], 
      StyleBox["3",
       FontWeight->"Bold"], 
      StyleBox["4",
       FontWeight->"Bold"], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["3",
       FontWeight->"Bold"], 
      StyleBox["4",
       FontWeight->"Bold"], 
      StyleBox["5",
       FontWeight->"Bold"], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Bold",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], 
   TagBox[
    FormBox["\[NoBreak]",
     TraditionalForm],
    TraditionalForm,
    Editable->True], " "}]]],
 "\n\nC4 & Complex  Quaternion     C9J      Symbolic\n  algebra      algebra  \
   algebra     C9J  \n",
 Cell[BoxData[{
  RowBox[{
   TagBox[
    FormBox[
     RowBox[{"\[NoBreak]", GridBox[{
        {
         StyleBox["1",
          FontWeight->"Bold"], 
         StyleBox["\[ImaginaryI]",
          FontWeight->"Bold"], 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "\[ImaginaryI]"}]},
        {
         StyleBox["\[ImaginaryI]",
          FontWeight->"Bold"], 
         StyleBox[
          RowBox[{"-", "1"}],
          FontWeight->"Bold"], 
         RowBox[{"-", "\[ImaginaryI]"}], "1"},
        {
         RowBox[{"-", "1"}], 
         RowBox[{"-", "\[ImaginaryI]"}], "1", "\[ImaginaryI]"},
        {
         RowBox[{"-", "\[ImaginaryI]"}], "1", "\[ImaginaryI]", 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", " ", 
   TagBox[
    FormBox[
     RowBox[{"\[NoBreak]", GridBox[{
        {"1", 
         StyleBox["i",
          FontSlant->"Plain"], 
         StyleBox["j",
          FontSlant->"Plain"], "ij"},
        {
         StyleBox["i",
          FontSlant->"Plain"], 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "ij"}], 
         StyleBox["j",
          FontSlant->"Plain"]},
        {
         StyleBox["j",
          FontSlant->"Plain"], "ij", 
         RowBox[{"-", "1"}], 
         RowBox[{"-", 
          StyleBox["i",
           FontSlant->"Plain"]}]},
        {"ij", 
         RowBox[{"-", 
          StyleBox["j",
           FontSlant->"Plain"]}], 
         StyleBox["i",
          FontSlant->"Plain"], 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "     ", 
   RowBox[{
    TagBox[
     FormBox[
      RowBox[{"\[NoBreak]", 
       RowBox[{GridBox[{
          {"1", "2", "3"},
          {"2", 
           RowBox[{"3", " "}], "\[DoubleStruckCapitalJ]1"},
          {"3", "\[DoubleStruckCapitalJ]1", "\[DoubleStruckCapitalJ]2"}
         }], ",", "\[NoBreak]"}]}],
      TraditionalForm],
     TraditionalForm,
     Editable->True], GridBox[{
      {"a", "b", "c"},
      {"b", "c", 
       RowBox[{"\[DoubleStruckCapitalJ]a", " "}]},
      {"c", "\[DoubleStruckCapitalJ]a", "\[DoubleStruckCapitalJ]b"}
     }]}]}], "\[IndentingNewLine]", 
  RowBox[{"   "}]}], "Input",
  PageWidth->PaperWidth,
  FontSize->9,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Courier New",
 FontSize->9],

Cell[TextData[{
 "\tI call the symbolic determinant factors ",
 StyleBox["sizes",
  FontWeight->"Bold"],
 ", and the list of sizes are the ",
 StyleBox["shape",
  FontWeight->"Bold"],
 ". (Hoops conserve their shape.)  ",
 StyleBox["One or more determinant factor is destroyed on folding",
  FontWeight->"Bold"],
 ". C4C2 has 6 sizes, C4 has 3, and C4c a single factor. The quaternion group \
has four linear and one (repeated) quadratic factor whilst the quaternion \
algebra loses the linear factors. C9 has 3 factors, C9J only one. \n\tAs each \
factor is a symmetry, each signed algebra is super-symmetric (sic, by an \
accident of nomenclature) to the (larger) parent Moufang loop. A",
 StyleBox[" ",
  FontWeight->"Bold"],
 "few Hoops (including \[DoubleStruckCapitalR], \[DoubleStruckCapitalC], \
\[DoubleStruckCapitalH] & \[DoubleStruckCapitalO]) are ",
 StyleBox["degenerate",
  FontWeight->"Bold"],
 " because they have lost all but one factor and so the inverses cannot split \
into partial fractions. Sizes can be zero, and division by a vec with a zero \
size would appear to give an infinite result. This is eliminated by the \
convention that a zero-sized vector ",
 StyleBox["projects",
  FontWeight->"Bold"],
 " vecs into a ",
 StyleBox["sub-algebra",
  FontWeight->"Bold"],
 " in which this size is constrained to be zero. Consequently, the inverse is \
also in the sub-algebra. Conic sections provide an analogy - their distance \
from a plane is zero and the 3D cone is reduced to a 2D figure of reduced \
symmetry. (Projection reduces symmetry.) To maintain the key conservative \
property, ",
 StyleBox["remainders",
  FontWeight->"Bold"],
 " have to be introduced. If multiplication (or division, which is \
multiplication by an inverse) would give a result which has lost some sizes, \
these sizes are ",
 StyleBox["ejected",
  FontWeight->"Bold"],
 " as remainders. This has physical analogies. When \"particles\" decay or \
interact, various symmetries are conserved by ejecting other \"particles\". \
In the case of ",
 StyleBox["Dozal",
  FontWeight->"Bold"],
 " algebra, different 12-element groups provide different (but overlapping) \
sets of symmetries resembling those of fundamental particles; this may \
correspond to different \"forces\" with different conservation laws.\n\tSome \
hoops conserve quadratic sizes (complex-conjugate factors are not conserved) \
that lead to ",
 StyleBox["polar or hyperbolic duals",
  FontWeight->"Bold"],
 ", and provide ",
 StyleBox["generalized powers and roots",
  FontWeight->"Bold"],
 ", with deBroglie-like continuous ",
 StyleBox["orbits",
  FontWeight->"Bold"],
 " and Planck-area-like squared radii or ",
 StyleBox["ulnae",
  FontWeight->"Bold"],
 ".\n\tHoops are fundamental to mathematical physics because they alone \
possess the conservation properties that lead (via Noether's theorem) to \
particles and forces. Groups are relevant because they are conservative, not \
because they are associative. The mathematical physicist's emphasis on \
symmetries as transformations using continuous groups (often based on complex \
matrices) appears to be unduly restrictive. Hoop symmetries act via \
operations, as well as transformations."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tHoop Algebras unify many traditional algebras. Some mathematical \
\"facts\" (such as \"minus one is unique\", which is proved by a circular \
argument using a rarely acknowledged axiom) are only true in the restricted \
context of the degenerate hoops \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], \[DoubleStruckCapitalO]. ",
 StyleBox["Primal numbers",
  FontWeight->"Bold"],
 " (unsigned continuous numbers, the half-line) can be developed from set \
theory via Natural numbers \[DoubleStruckCapitalN], unsigned Rational numbers \
",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalQ]", 
   RowBox[{"0", "+"}]]]],
 " and a continuity axiom. Negation, subtraction, signed integers \
\[DoubleStruckCapitalZ], and signed continuous Reals \[DoubleStruckCapitalR] \
should NOT be introduced until indexed sets have been developed. As \
mathematics is widely thought of as operations on rings & fields (because \
they are easy to handle) integers and reals are (implicitly or explicitly) \
assumed to exist on page 1 of most mathematical texts. Negation and \
subtraction constitute a \"blind spot\" for many mathematicians; few texts \
even index the topics and only a handful consider their axiomatic definition. \
However, they are the special first case of ",
 StyleBox["generalized negation",
  FontWeight->"Bold"],
 " which uses equivalence relations on indexed ",
 StyleBox["sets",
  FontSlant->"Italic"],
 " to create ",
 StyleBox["generalized signs",
  FontWeight->"Bold"],
 ", orthogonal roots of unity. \[DoubleStruckCapitalZ] & \
\[DoubleStruckCapitalR] are the simplest examples, being equivalence \
relations on indexed ",
 StyleBox["pairs",
  FontSlant->"Italic"],
 " of natural or primal numbers; the C2 group provides the multiplication \
table. \[DoubleStruckCapitalC] is one equivalence relation on indexed ",
 StyleBox["quads",
  FontSlant->"Italic"],
 " of primal numbers; the C4 group provides the multiplication table. The C3 \
group provides (chiral) ",
 StyleBox["Terplex numbers",
  FontWeight->"Bold"],
 "; the Klein 4-group provides \"Study numbers\" aka \"Double numbers\"; the \
8-element Quaternion group provides the 4-element quaternion algebra, etc. \
Every \"real\" number is obtained from a pair of primal numbers; every \
\"terplex\" number is obtained from a triple of primal numbers, etc."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " package provides a database of over 800 entries - all the groups with up \
to 73 elements, some larger groups, octonions, and a number of other tables. \
Procedures are provided to create, identify, and investigate small groups, \
loops, and hoops. Key properties are provided for the hoop algebras for which \
compact symbolic inverses have been found. ",
 StyleBox["GroupLoopTest.nb",
  FontSlant->"Italic"],
 " contains general test procedures that confirm the correctness of the \
database and procedures.\n\tThe database entries relate to ordered quasigroup \
\"indexTables\" i.e. ",
 StyleBox["m\[Times]m",
  FontSlant->"Italic"],
 " Cayley multiplication tables with the first row and column containing the \
element indices {1,2,..,m} and with each (possibly signed) index occuring \
once in each row and column. Note that \"Cayley table multiplication\" is not \
\"Matrix Multiplication\", which transforms a single vector. It is \
implemented by the ",
 StyleBox["hoopTimes",
  FontSlant->"Italic"],
 " procedure and operates on two vecs to create another vec and two (possibly \
null) remainders. \n\tMost loops in the database have at least one compact \
\"incantation\" that generates the Cayley table as a ",
 StyleBox["protoloop",
  FontWeight->"Bold"],
 " (a preferred isomorph). Different incantations use formulae, relators, \
permutations, matrix multiplication, and generalized Cayley-Dickson or \
Clifford procedures to create the tables. Apart from a few counter-examples \
with names ending in ",
 StyleBox["n",
  FontSlant->"Italic"],
 ", all the entries have the conservation property, making them Hoops. Many \
are loops, unsigned tables that multiply and divide sets of primal numbers; \
negation is not initially defined for them. They become Hoop Algebras when a \
second operation introduces some form of negation via generalized signs such \
as \"-\" , \"\[DoubleStruckCapitalJ]\" and \"\[ImaginaryI]\" (second, third \
and fourth roots of unity that create real, terplex and complex numbers). ",
 StyleBox["m\[Times]m",
  FontSlant->"Italic"],
 " loops can be folded to ",
 StyleBox["m/r\[Times]m/r",
  FontSlant->"Italic"],
 " multiplication tables under r-fold negation if the loop has r-fold \
symmetry. This often creates ",
 StyleBox["signed tables",
  FontWeight->"Bold"],
 " such as Complex algebra C4c, in which \[ImaginaryI].\[ImaginaryI] = -1, \
and the Quaternion Algebra Qr, in which i.j = k but j.i = -k. Many signed \
tables, with names ending in ",
 StyleBox["r, c,",
  FontSlant->"Italic"],
 " or ",
 StyleBox["J",
  FontSlant->"Italic"],
 ", are included. Every (unsigned) group ",
 StyleBox["G",
  FontSlant->"Italic"],
 " also defines algebras over the fields \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC] etc. because the compositions ",
 StyleBox["GC2",
  FontSlant->"Italic"],
 ", ",
 StyleBox["GC4",
  FontSlant->"Italic"],
 ", etc are also groups that fold to ",
 StyleBox["G",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tGeneralized signs \[DoubleStruckS] are distinct orthogonal ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'th roots of unity. Projecting them onto the complex unit circle (as \
\"cyclotomic numbers\") distorts their properties and loses information. They \
occur as loop generators, as elements of generator matrices, in the bodies of \
\"signed tables\", in the definition of multi-phase sinusoids, and in ",
 StyleBox["generalizations of many functions that involve \[ImaginaryI] ",
  FontWeight->"Bold"],
 "in traditional mathematics. Some algebras involve more than one instance of \
an ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'th root; in particular, \"-1\" is not the only square root of unity in \
many algebras and it is absent from some others. Clifford (geometric) \
algebras ",
 "clf[",
 "p,q] have ",
 StyleBox["p",
  FontSlant->"Italic"],
 " generators that square to +1 and ",
 StyleBox["q",
  FontSlant->"Italic"],
 " that square to -1; their ",
 StyleBox["pseudoscalar",
  FontSlant->"Italic"],
 " elements generalise \[ImaginaryI] to square roots of -1 that do not \
commute with other elements."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe database includes some small group, loop, and signed tables that are \
pre-defined for use in prescriptions for larger loops. Procedures are \
supplied to generate tables, using several descriptions:- (1) an explicit \
table, (2) the GAP Group Atlas [6] identifier ",
 StyleBox["g",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["mmnn",
  FontSlant->"Italic"],
 " corresponding to ",
 StyleBox["GAP>SmallGroups(mm,nn) ",
  FontSlant->"Italic"],
 "(this Atlas is extended in the database to include many non-groups), (3) a \
mnemonic such as \"D3\", (4) incantations ca[], cd[], ",
 "clf[",
 "], co[], ge[], ma[], md[],mg[], mp[], & ms[] that create index tables in \
different ways. (These two-letter abbreviations are used to reduce clutter in \
the database.)"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tProcedures are supplied to identify, characterise and manipulate Cayley \
tables. Any isomorphic Cayley table can be identified for most of the \
database tables. Group and subgroup properties can be tested. Functions that \
are conserved on multiplication (which I call ",
 StyleBox["sizes",
  FontWeight->"Bold"],
 "; the list of sizes is the ",
 StyleBox["shape",
  FontWeight->"Bold"],
 " of a vector in a specific hoop) are identified for over 80 small tables. \
They are the factors of a symbolic table determinant; sizes have not been \
found for larger tables because of computational limitations. Generalised \
multiplication and inversion procedures ",
 StyleBox["hoopTi",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["mes, ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["hoopIn",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["verse",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " are defined for algebras with conservative multiplication tables."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tWherever one or more sizes are zero (to within an arbitrary ",
 StyleBox["hmin",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 "), ",
 StyleBox["hoopTi",
  FontSlant->"Italic"],
 StyleBox["mes",
  FontSlant->"Italic"],
 " implements ",
 StyleBox["conservative multiplication & division",
  FontWeight->"Bold"],
 "; results are constrained to a sub-space or sub-algebra and remainders are \
created to maintain conservation. The result is ",
 StyleBox["projected",
  FontWeight->"Bold"],
 " onto a sub-algebra with these sizes zeroed, and the lost sizes are ",
 StyleBox["ejected",
  FontWeight->"Bold"],
 " as ",
 StyleBox["remainders",
  FontWeight->"Bold"],
 " to maintain conservation. ",
 StyleBox["Division-by-zero is eliminated",
  FontWeight->"Bold"],
 " by this process; when one or more zero size of the denominator is non-zero \
in the numerator the result of division is a dividend (with the same zeroes) \
together with remainders containing the sizes that would otherwise be lost. \
This appears to be related to particle interactions and decays, where \
properties are similarly conserved."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tSome hoops have ",
 StyleBox["sinusoidal and/or hyperbolic dual forms",
  FontWeight->"Bold"],
 " that lead to generalized powers and generalized roots. Polar-duals \
generalize the polar description of the complex plane. Hoops with polar-dual \
forms have ",
 StyleBox["continuous orbits",
  FontWeight->"Bold"],
 " related to the \"discrete orbits\" of groups. Quadratic sizes become \
squared radii (releasing a degree of freedom); linear sizes displace the \
centre of rotation from zero. Orbit angle-parameters are \"hidden variables\" \
for the cartesian (vector-like) form; in the polar form they take up the \
degrees of freedom released by the squared radii. Constraining the \
determinants (ignoring any zero sizes) to be 1 defines ",
 StyleBox["unital sub-algebras",
  FontWeight->"Bold"],
 ". Their orbits resemble multi-phase deBroglie waves. A few hoops appear to \
have orbits with ",
 StyleBox["stable squared radii",
  FontWeight->"Bold"],
 " that resemble Planck areas. I conjecture that this relates to the limited \
number of stable particles. The ",
 StyleBox["Hexal and Dozal",
  FontWeight->"Bold"],
 " algebras (having 6 and 12 elements) are in a \"super/subsymmetric\" \
relationship; they have elements that act as unit spin and half-spin quantum \
operators that are neither real nor complex. Their Planck-scale orbits may \
correspond to lepton wave packets with 4 phases and quark wave packets with \
3, 6, & 12 phases, giving a non-point-like description of particles. A ",
 StyleBox["unit-velocity equation",
  FontWeight->"Bold"],
 " may lead to stable wave-packet formulations for particles; mass \
corresponds to orbital velocities (zitterbewung?) in Kaluza-Klein dimensions \
(rather than spatial velocities). Indirect composition of commutative loops \
such as C2, C3, & K gives non-commutative hoops such as D3C2, which ",
 StyleBox["pseudo-powers",
  FontWeight->"Bold"],
 " and introduce uncertainty because the angles do not add on multiplication. \
The \"law of large numbers\" may arise from a ",
 StyleBox["reciprocal relationship",
  FontWeight->"Bold"],
 " between sizes of three sets of squared radii, that of the universe and \
that of the \"point-like\" particles (electrons), with other particles at \
their geometric mean near the Planck size."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tHoops unify and generalize many standard algebras and their conservation \
properties make them relevant to physics. I claim that primal numbers & hoop \
algebras provide new foundations for mathematical physics, transcending (but \
not discrediting) the approach based on complex numbers. They could not have \
been developed without computer-aided maths. Their conserved properties \
provide the mathematics for half-spin, renormalization, supersymmetry, \
polarized and chiral waves, mass, hidden variables, the \"law of large \
numbers\" etc, and the limited number of fundamental particles. \
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3 Note on Nomenclature.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThe GAP Atlas [6] instruction ",
 StyleBox["SmallGroup(mm,nn)",
  FontSlant->"Italic"],
 " has been adapted to provide an unambiguous identifier ",
 StyleBox["g",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["mmnn",
  FontSlant->"Italic"],
 " for any loop in the database, by inserting non-groups of size ",
 StyleBox["mm",
  FontSlant->"Italic"],
 " after the groups of the same size. (The GAP numbering is not followed for \
",
 StyleBox["mm",
  FontSlant->"Italic"],
 ">73). E.g. ",
 StyleBox["g0201",
  FontSlant->"Italic"],
 " is the C2 group and ",
 StyleBox["g0202",
  FontSlant->"Italic"],
 " is the complex algebra multiplication table with elements ",
 StyleBox["r",
  FontSlant->"Italic"],
 " & \[ImaginaryI] and with \[ImaginaryI]\[CenterDot]\[ImaginaryI] = -",
 StyleBox["r",
  FontSlant->"Italic"],
 ". \"Protoloops\" (preferred isomorphic Cayley tables) are defined for most \
database entries. Where possible, these are defined in terms of \"relators\", \
usually ordered by decreasing complexity. Thus the 12-element groups have \
relators ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "3"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b", "2"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "2"], TraditionalForm]]],
 "=1 or ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "3"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b", "4"], TraditionalForm]]],
 "=1. Wherever a \"loop structure\" has been identified the loop has been \
given a specific mnemonic such as Q8 & Q12 for the 8- & 12-element \
quaternionic group tables. (Q12 is called T in Mathworld, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Dic", "3"], TraditionalForm]]],
 " in Wikipedia). Some loops have been predefined as Cayley Tables \
(identified by their mnemonic) because they lack an incantation or are needed \
as building blocks for larger tables. The majority of protoloops can be \
created by ",
 StyleBox["makeProtoloop[mm,nn,o]",
  FontSlant->"Italic"],
 " (with abbreviation ",
 StyleBox["mp[mm,nn,o]",
  FontSlant->"Italic"],
 ") where the option ",
 StyleBox["o",
  FontSlant->"Italic"],
 " selects between different creation procedures if more than one has been \
defined. The procedure ",
 StyleBox["idc[L]",
  FontSlant->"Italic"],
 " will identify any conservative isomorphic loop table ",
 StyleBox["L",
  FontSlant->"Italic"],
 " for most of the entries in the database (the faster & more general ",
 StyleBox["id[L]",
  FontSlant->"Italic"],
 " does not test for conservation). ",
 StyleBox["loop[[mm]]",
  FontSlant->"Italic"],
 " lists the data entries for all the tables with ",
 StyleBox["mm",
  FontSlant->"Italic"],
 " elements; ",
 StyleBox["gd[mnemonic] ",
  FontSlant->"Italic"],
 "and ",
 StyleBox["gd[mm,nn]",
  FontSlant->"Italic"],
 " (or ",
 StyleBox["gd[] ",
  FontSlant->"Italic"],
 "after ",
 StyleBox["id",
  FontSlant->"Italic"],
 " or ",
 StyleBox["idc ",
  FontSlant->"Italic"],
 "has been used) will provide ",
 StyleBox["mm,nn",
  FontSlant->"Italic"],
 " followed by the specific loop entry.\n\tCyclic groups are called C",
 StyleBox["n ",
  FontSlant->"Italic"],
 "rather than \[DoubleStruckCapitalZ]",
 StyleBox["n",
  FontSlant->"Italic"],
 " because \[DoubleStruckCapitalZ]",
 StyleBox["n",
  FontSlant->"Italic"],
 " implies a ring with subtraction. ",
 StyleBox["\n\t",
  FontSlant->"Italic"],
 "\tMnemonics: C",
 StyleBox["n",
  FontSlant->"Italic"],
 ", D",
 StyleBox["n/2",
  FontSlant->"Italic"],
 ", and Q",
 StyleBox["n",
  FontSlant->"Italic"],
 " are cyclic, ",
 "generalized",
 " Dihedral, and Quaternion groups with ",
 StyleBox["n",
  FontSlant->"Italic"],
 " elements. A",
 StyleBox["n",
  FontSlant->"Italic"],
 " & S",
 StyleBox["n",
  FontSlant->"Italic"],
 " have ",
 StyleBox["n",
  FontSlant->"Italic"],
 " generators. Alt12n, Oct, D3M2 & D3M1n, etc., are \"alternative\" or \
\"square-associative, aa.b=a.ab\" loops. The M indicates that the loop is a \
\"Moufang double\" of D3 (etc.). Compound names XY, XiY, XpY are the direct \
or indirect compositions of X & Y. Xa, Xb, are second & third isomorphs of X. \
 Xr, XJ & Xc are conservative signed tables obtained from X that also provide \
conservative tables on expanding with C2 (r), C3 (J), or both C2 & C4 (c). \
Names ending with \"n\" (Q4n, C5n, C6n, C8n, Q8n, Alt12n,  etc.) are \
non-conservative loops."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Loops, Groups, & Hoops. ", "Section",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
 TextJustification->0.25,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Summary. ",
 StyleBox["Algebraic Loops are multiplication tables for sets of unsigned \
elements. Groups are associative loops; Moufang loops are loops with division \
and (in all commutative and some noncommutative cases) symmetry conservation. \
Introducing another operation via \"generalized signs\" ",
  FontSlant->"Italic"],
 StyleBox["fold",
  FontSlant->"Italic"],
 StyleBox["s conservative loops to \"Hoop algebras\" over generalized fields. \
Unlike the use of groups in mathematical physics (as matrices to transform a \
single vector) hoops multiply or divide two vectors to give a product and \
two, possibly null, remainder vectors.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " package is concerned with \"Finite Algebraic Loops\", with their subsets \
\"Moufang Loops\" and \"Groups\", and with the related symmetry-conserving \
partial-fraction division algebras or \"Hoops\". ",
 StyleBox["GroupLoopDemo6.nb",
  FontSlant->"Italic"],
 " & ",
 StyleBox["HoopDemo.nb",
  FontSlant->"Italic"],
 " explain and demonstrate the concepts. They handle algebraic loops as \
normalized quasi-group Cayley index-tables with left and right units, i.e. as \
square tables with every index occurring once in each row and column, and \
with the first row and column defining the unit or neutral element. These \
tables define closed binary operations on unsigned elements, a.b=c.  The test \
routines abelianQ",
 StyleBox[", ",
  FontSlant->"Italic"],
 "associativeQ",
 StyleBox[",",
  FontSlant->"Italic"],
 " abelGrassmanQ, alternativeQ, amQ, cQ, conservativeQ,  entropicQ, flexQ, \
flexibleQ, hamiltonianQ, indexTableQ, jordanQ, jacobiQ, MoufangQ, negatableQ, \
quasigroupQ, reductiveQ, riffQ, & signedTableQ are provided, and test whether \
tables possess specific properties. Appendix A demonstrates these tests. The \
\"conservativeQ\" test uses the table to multiply two vecs A & B. It then \
tests whether Det[A].Det[B] = \[PlusMinus] Det[AB], where Det is the \
determinant of the loop inverse table mapped with the vec elements. A & B are \
random, but must not have zero determinants."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tTables with the associative property, (xy)z = x(yz) are \"groups\". \
Tables with the slightly less restrictive Moufang property zx.yz=(z.xy)z are \
Moufang loops. This covers all tables with a division property. I conjectured \
that all Moufang loops have another key property, conservation of the \
symbolic inverse determinant, but the D3Mn table disproves this conjecture. \
Frobenius established that all groups are conservative. This ",
 StyleBox["Frobenius conservation",
  FontWeight->"Bold"],
 " property is significant because Noether's law links symmetry conservation \
to particles and forces. Extensive searching suggests that a few \
\"Moufang-doubled\" loops (Octonions, split-octonions, D4M2, and a few \
others, together with their direct compositions with Abelian groups) are the \
only non-associative conservative tables. Moufang loops are \
\"square-associative\", a(ab) = (a(ab) (also called alternative). Other \
square-associative tables lack both the conservation and the division \
properties. References to groups in much of mathematical physics should \
perhaps be to hoops; the key properties are division and conservation; \
associativity is not relevant."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tMoufang loops are defined in terms of multiplication. Division is \
multiplication by a multiplicative inverse, whose existence is guaranteed by \
the Moufang properties. Negation and subtraction are not involved in their \
definition, so elements of Moufang loops are unsigned. Describing Abelian \
Moufang loops in terms of an invertible addition operation is abuse of \
nomenclature.\n\tA second operation is needed to convert a loop into an \
algebra with addition and (generalized) subtraction. This is provided by \
equivalence relationships that \"fold\" an ",
 StyleBox["m\[Times]m",
  FontSlant->"Italic"],
 " loop that multiplies sets of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " unsigned elements to an (",
 StyleBox["m/r)\[Times](m/r)",
  FontSlant->"Italic"],
 " algebraic multiplication table that multiplies vecs of ",
 StyleBox["m/r",
  FontSlant->"Italic"],
 " signed elements. ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = 2 or 4 gives real and complex vectors and algebras over the \
corresponding fields. Other ",
 StyleBox["r",
  FontSlant->"Italic"],
 " values provide generalized signs and define new \"rigs\" (rings without \
negation). The second operation often introduces signed products that are not \
included in the set of defining elements, so these tables are not loops. \
Hoops are algebras that pass the conservativeQ test; they are only introduced \
briefly here; ",
 StyleBox["HoopDemo.nb,",
  FontSlant->"Italic"],
 " ",
 StyleBox["Hoops.nb",
  FontSlant->"Italic"],
 " and ",
 StyleBox["CliffordG.m",
  FontSlant->"Italic"],
 " deal with them in greater detail. "
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Loop Properties, Loop & Signed Table creation.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". GroupLoopHoop6.m provides a database of groups, loops & hoops, together \
with procedures to create, identify & manipulate them. This section \
demonstrates the creation & identification of loops & signed tables. Index \
Tables represent loops, m\[Times]m Cayley multiplication tables. Introducing \
r-fold negation converts loops into hoop algebras with tables of size m/r\
\[Times]m/r. These are often \"signed tables\" with some signed products. Ten \
table-creating procedures are described and demonstrated."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["3.1. Index & Cayley Tables, Loops, Table Identification. ", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThe ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " package includes a database of index tables. These are normalized \
quasi-group arrays with indices as elements. They describe a loop operation \
(usually called vector multiplication) for indexed sets of coefficients, \
A={",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "2"], TraditionalForm]]],
 ",..}, which can be written ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], 
    SubscriptBox["d", "1"]}], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "2"], TraditionalForm]]],
 "+... where ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["d", "i"]}], TraditionalForm]]],
 " is a (loop) direction or (hoop) dimension. Multiplication AB gives C={",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "2"], TraditionalForm]]],
 ",...} where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "k"], "=", 
    RowBox[{"\[Sum]", 
     RowBox[{
      SubscriptBox["a", "i"], 
      SubscriptBox["b", "j"]}]}]}], TraditionalForm]]],
 ", with ",
 StyleBox["k=i.j",
  FontSlant->"Italic"],
 " in the loop. In Moufang Loops this operation has a (left & right) \"unit\" \
or \"1\" and multiplication of sets of coefficients is invertible, making \
division identical to multiplication. All groups are associative Moufang \
loops; all non-associative Moufang loops are square-associative (aka \
alternative). Negation is not defined for loops, so they do not represent \
algebras until they have been \"folded\" via a second operation, introducing \
negation and additive elimination (generalized subtraction). This may give a \
\"signed table\" (Section 3.7) in which some products are signed indices. \
E.g. the 2-element complex algebra has elements {1, \[ImaginaryI]} with the \
signed product \[ImaginaryI].\[ImaginaryI] = -1; it is folded from the \
4-element C4 group; the 4-element Quaternion algebra {1, i, j, k} has i.j = k \
but j.i = -k, and is folded from the 8-element quaternion group. \
\"Symmetry-conserving\" tables (I call them \"Hoops\") are discussed in \
Section 4.3. They define partial-fraction-division algebras; tables folded \
from loops with this property are also conservative.\n\tCayley tables include \
index tables, but may also have symbols or coefficients mapped onto the \
indices, to give symbolic or general Cayley tables. The ",
 StyleBox["caylindex",
  FontSlant->"Italic"],
 " procedure converts a table to an index table, whilst ",
 StyleBox["gmap",
  FontSlant->"Italic"],
 " reverses the process, mapping a ",
 StyleBox["vec",
  FontSlant->"Italic"],
 " (an indexed list of symbols and/or coefficients, one interpretation of \
\"vector\") onto an index table, respecting signs.\n\tThe identification ",
 StyleBox["g",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["mmnn",
  FontSlant->"Italic"],
 " (based on ",
 StyleBox["SmallGroup( mm, nn)",
  FontSlant->"Italic"],
 " in the GAP Atlas, and extended to include all the non-groups in the \
database) can be found for most conservative (Group, Moufang Loop, & Hoop) \
table isomorphs with up to 73 elements and for some non-associative and \
larger tables. ",
 StyleBox["nn",
  FontSlant->"Italic"],
 " is the position in the sub-list of loops with ",
 StyleBox["mm",
  FontSlant->"Italic"],
 " elements",
 StyleBox[".",
  FontSlant->"Italic"],
 " The ",
 StyleBox["id",
  FontSlant->"Italic"],
 " procedure uses a diagnostic property ",
 StyleBox["dico ",
  FontSlant->"Italic"],
 "(diagonal count), together with specific tests where this is not unique. \
Some database tables can only be provisionally identified because there may \
be non-isomorphic non-conservative tables with the same ",
 StyleBox["dico",
  FontSlant->"Italic"],
 ". \n\t",
 StyleBox["loop[[mm,nn]]",
  FontSlant->"Italic"],
 ",",
 StyleBox[" gd[\"mnemonic\"], gd[mm,nn] ",
  FontSlant->"Italic"],
 "or ",
 StyleBox["gd[]",
  FontSlant->"Italic"],
 " all supply the database entry. The first two entries in ",
 StyleBox["gd[]",
  FontSlant->"Italic"],
 " are ",
 StyleBox["mm,nn",
  FontSlant->"Italic"],
 " for the \"target loop\", i.e. the one currently in use",
 StyleBox[".",
  FontSlant->"Italic"],
 " The database also includes information about the ",
 StyleBox["shape",
  FontSlant->"Italic"],
 ", ",
 StyleBox["polar form",
  FontSlant->"Italic"],
 " and ",
 StyleBox["plex",
  FontSlant->"Italic"],
 " (Sections 4.3, 6.2, 7.) of many small groups.\n\tExample 1 demonstrates \
tables and mappings, and shows that the ",
 StyleBox["id",
  FontSlant->"Italic"],
 " procedure identifies a table whatever its form, provided that it is in the \
database. (As the input may be incomprehensible to non-",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " users, input is hidden in \"closed cells\"; it can be revealed by \
un-checking the ",
 StyleBox["Cell<Cell Properties<Cell open",
  FontSlant->"Italic"],
 " box. The frequent",
 StyleBox[" \\n",
  FontSlant->"Italic"],
 " entries in the input are new-line symbols, used to organise the output.)"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 1. Groups C3 & C4", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{\"The group {{a,b,c},{b,c,a},{c,a,b}} is \", \
id[caylindex[{{a,b,c},{b,c,a},{c,a,b}}]],
\"\\nwith {mm,nn} = \",{mm,nn},
\"\\nand index Table \",C3//tf,
\"\\n{3.,2.+\[ImaginaryI], -4.} mapped onto C3 gives\", gmap[C3,{3.,2.+\
\[ImaginaryI], -4.}]//tf,
\"\\nListForm C4 is \",C4,\"\\nTraditional form C4 is\",C4//tf,\"\\nMapping \
{a,b,c,d} onto C4 gives a symbolic table\",gmap[C4,{a,b,c,d}]//tf}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"The group {{a,b,c},{b,c,a},{c,a,b}} is \"\>", 
   ",", "\<\"C3\"\>", ",", "\<\"\\nwith {mm,nn} = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", "\<\"\\nand index Table \"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", "3", "1"},
        {"3", "1", "2"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\n{3.,2.+\[ImaginaryI], -4.} mapped onto C3 gives\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"3.`", 
         RowBox[{"2.`", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}], 
         RowBox[{"-", "4.`"}]},
        {
         RowBox[{"2.`", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}], 
         RowBox[{"-", "4.`"}], "3.`"},
        {
         RowBox[{"-", "4.`"}], "3.`", 
         RowBox[{"2.`", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nListForm C4 is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1", ",", "2", ",", "3"}], "}"}]}], "}"}], 
   ",", "\<\"\\nTraditional form C4 is\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", "3", "4", "1"},
        {"3", "4", "1", "2"},
        {"4", "1", "2", "3"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\nMapping {a,b,c,d} onto C4 gives a symbolic table\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"a", "b", "c", "d"},
        {"b", "c", "d", "a"},
        {"c", "d", "a", "b"},
        {"d", "a", "b", "c"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tMost  ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " procedures accept ",
 StyleBox["TraditionalForm",
  FontSlant->"Italic"],
 " array as well as ",
 StyleBox["ListForm",
  FontSlant->"Italic"],
 " as input. Example 2 shows this for the Klein 4-group \"K\"",
 StyleBox[".",
  FontSlant->"Italic"],
 " The different ways of accessing the data about a loop are demonstrated:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 2. TraditionalForm input, Loop Data Access.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{\"TraditionalForm input such \
as\",tst={{1,2,3,4},{2,1,4,3},{3,4,1,2},{4,3,2,1}}//tf,\" is accepted.\\nThis \
group is\",
  id[tst],\"\\nLoop data can be accessed in different ways:-\\nloop[[4,1]] \
gives\",loop[[4,1]],\"\\ngd[4,1] gives\",gd[4,1],\"\\ngd[\\\"K\\\"] \
gives\",gd[\"K\"],\"\\ngd[]    gives\",gd[]}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"TraditionalForm input such as\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", "1", "4", "3"},
        {"3", "4", "1", "2"},
        {"4", "3", "2", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\" is accepted.\\nThis group is\"\>", 
   ",", "\<\"K\"\>", 
   ",", "\<\"\\nLoop data can be accessed in different ways:-\\nloop[[4,1]] \
gives\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"K\"\>", ",", 
     RowBox[{"{", "4.`", "}"}], ",", "0", ",", "\<\"co[C2,C2]\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}], 
   ",", "\<\"\\ngd[4,1] gives\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"K\"\>", ",", 
       RowBox[{"{", "4.`", "}"}], ",", "0", ",", "\<\"co[C2,C2]\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], "}"}], 
   ",", "\<\"\\ngd[\\\"K\\\"] gives\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"K\"\>", ",", 
       RowBox[{"{", "4.`", "}"}], ",", "0", ",", "\<\"co[C2,C2]\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], "}"}], 
   ",", "\<\"\\ngd[]    gives\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"K\"\>", ",", 
       RowBox[{"{", "4.`", "}"}], ",", "0", ",", "\<\"co[C2,C2]\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tInformation about the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " procedures (",
 StyleBox["Usage",
  FontSlant->"Italic"],
 ") can always be found by the \"?\" help system, and the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " implementation by \"??\". \"Usage\" for the ",
 StyleBox["GroupLoopHoop.m",
  FontSlant->"Italic"],
 " package can be seen in Section 2.7 of that package; Example 3 gives it for \
",
 StyleBox["id & dico",
  FontSlant->"Italic"],
 ", which should be read carefully as the information is not repeated in this \
notebook (Warning! ",
 StyleBox["??id",
  FontSlant->"Italic"],
 " generates several pages of irrelevant output!):-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 3a. Help system, ?id.", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman",
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["?id", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 StyleBox["\<\"id[G_,L_:{}] uses a range of tests to identify 'G', which may \
be a name, or \\!\\(\\*\\nStyleBox[\\\"{\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"mm\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"\
nn\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"}\\\",\\\
nFontSlant->\\\"Italic\\\"]\\), or an indexTable; if an index-list 'L' is \
specified, the corresponding subgroup of 'G' is identified. Associativity is \
not tested (for speed of execution) so unknown groupoids may be wrongly \
identified. Names: C\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\
\"]\\), D\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\)/2 & \
Qn are cyclic or generalised Dihedral and Quaternion groups with \
\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\) elements.\\n  \
  \\*\\nStyleBox[\\(A\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\)] & \\*\\nStyleBox[\\(S\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\)] have n generators. Alt12n, Oct, D4Mn etc  are 'Square \
associative' or 'alternative aa.b=a.ab' groupoids. XY, XiY, XpY are the \
direct or indirect compositions of X & Y. Xa is a second isomorph of X. Xr & \
Xc are conservative signed tables obtained from X that also provide \
conservative algebras on expanding with C2 or (C2 & C4). Loops with names \
ending in \\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\) \
(the letter, not a number) are not conservative. Loops with M in the name are \
non-associative Moufang loops. \
\\!\\(\\*\\nStyleBox[\\\"gnnmm\\\",\\nFontSlant->\\\"Italic\\\"]\\) is GAP \
SmallGroups(mm,nn). If the name contains ? identification is provisional \
because all groups of that size have not been distinguished. The global \
variables \
\\!\\(\\*\\nStyleBox[\\\"glo\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"gmn\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"mm\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"&\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"nn\\\",\\nFontSlant->\\\"Italic\\\"]\
\\) are set by id. \
\\!\\(\\*\\nStyleBox[\\\"gmn\\\",\\nFontSlant->\\\"Italic\\\"]\\) is returned \
and \\!\\(\\*\\nStyleBox[\\\"gd\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\
\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) will provide more details.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3426322660-2087744"]
}, Open  ]],

Cell[TextData[{
 "\tIdentification employs a variety of \"table invariants\" to distinguish \
between different conservative tables. These are functions that are \
unaffected by re-ordering a table. The most important is ",
 StyleBox["dico",
  FontSlant->"Italic"],
 ", the \"diagonal count\", which is a generalized signature for a hoop \
table:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 3b. Help system,  ?dico, ?abbr.", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman",
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[{
 "\n{\"",
 StyleBox["dico[g3207] =\",",
  FontSlant->"Italic"],
 "dico[makeProtoloop[\"g3207\"]]}\n?dico\n?abbr"
}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"dico[g3207] =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", 
     SubscriptBox["4", "5"], ",", "15"}], "}"}]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"dico[g_:glo] is the 'diagonal count' i.e. the count of \
elements of 'g' in the table diagonal, compressed via 'abbr' (q.v.). The \
first entry is the number of square roots of unity, and is signed if 'g' is \
signed, and is real if 'g' is abelian.  A specific extra diagnostic integer \
is added for tables with m = 32, 48, 54, 64 or 72. For example \
{12,\\!\\(\\*SubscriptBox[\\\"4\\\", \\\"5\\\"]\\),15} is \
dico[makeProtoloop['g3207']]. There are 12 occurences of the unit; 5 other \
elements occur 4 times (total=32), and there are 15 subgroups of 4 \
elements.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3426322661-8039262"],

Cell[BoxData[
 StyleBox["\<\"abbr[t_,o_:1] is used by 'dico' & 'trico' to create an \
abbreviation such as {12,\\!\\(\\*SubscriptBox[\\\"4\\\", \\\"5\\\"]\\),15} \
in which subscripts indicate numbers of appearances of elements in a table \
diagonal, with the first element real for abelian and negated for signed \
tables.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3426322661-4802284"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "\tNote that ",
 StyleBox["dico",
  FontSlant->"Italic"],
 " is the second element of ",
 " ",
 StyleBox["loop[[mm,nn]]",
  FontSlant->"Italic"],
 ", following the table mnemonic."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tMost of the procedures require that the argument is a quasigroup, so they \
apply ",
 StyleBox["gpd",
  FontSlant->"Italic"],
 " to ensure that arrays have the required properties. Example 4 tests a \
variation on the C3 example. The quasigroup property is so fundamental to the \
package that operations are aborted if it is absent."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example 4. Alter one element of C3 and the result is rejected as it is not a \
quasigroup.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold",
 FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell["\<\
gpd[{{a,b,c},{b,d,a},{d,a,b}}]
?gpd\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "d", ",", "a"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", "a", ",", "b"}], "}"}]}], "}"}],
    Short], "\[InvisibleSpace]", "\<\" is not a groupoid\"\>"}],
  SequenceForm[
   Short[{{GroupLoopHoop6`a, GroupLoopHoop6`b, GroupLoopHoop6`c}, {
     GroupLoopHoop6`b, GroupLoopHoop6`d, GroupLoopHoop6`a}, {
     GroupLoopHoop6`d, GroupLoopHoop6`a, GroupLoopHoop6`b}}], 
   " is not a groupoid"],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"pr", "<", "3"}], ",", 
   RowBox[{"Abort", "[", "]"}]}], "]"}]], "Output"],

Cell[BoxData[
 StyleBox["\<\"gpd[gg_] is used on function arguments that should be \
groupoids (i.e. magmas, loops, quasigroups). It removes any TraditionalForm \
wrapper and rejects non-groupoids by 'Abort[] unless pr>3'. The first row \
must contain the elements, which may be matrices; signed elements are \
permitted in the body of the table.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3426322661-3580866"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2. Creating Cayley Tables.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tProcedures are supplied to construct loops as indexTables from formulae, \
compositions, relators, cycles, permutations, \"unitary monomial matrices\", \
and \"monovectors\". Each construction is demonstrated in the following \
subsections. Some skeleton routines are shown, to allow programmers to see \
what is going on. They are non-executable because they omit all checks and \
special cases.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[{
 "3.2.1. Creating Cayley Tables with ",
 StyleBox["ca",
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tExample 5 uses the procedure ",
 StyleBox["ca",
  FontSlant->"Italic"],
 " to create the 6-element tables for the groups C6 (\[TildeEqual] C3C2) and \
D3. ",
 StyleBox["ca",
  FontSlant->"Italic"],
 " employs a fast formula:-  i*j \[RightArrow]Mod[i+j,m] for even i,  i*j \
\[RightArrow] Mod[i+j*k,m] for odd ",
 StyleBox["i",
  FontSlant->"Italic"],
 ". It uses an optional parameter ",
 StyleBox["k",
  FontSlant->"Italic"],
 " to create non-abelian groups; ",
 StyleBox["m",
  FontSlant->"Italic"],
 " is the number of elements. A skeleton implementation is given below. (The \
programmed formula is complicated by the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " indices being {1,..,m} rather than {0,...,m-1})."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ca", "[", 
    RowBox[{"m_", ",", 
     RowBox[{"k_:", "0"}]}], "]"}], ":=", 
   RowBox[{"(*", 
    StyleBox[
     RowBox[{
      RowBox[{"skeleton", ".", " ", "non"}], "-", "executable"}],
     FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{
       RowBox[{"i", "+", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"EvenQ", "[", "i", "]"}], ",", 
          RowBox[{
           RowBox[{"j", " ", "k"}], "-", "k", "+", "1"}], ",", "j"}], "]"}], 
        "-", "1"}], ",", "m", ",", "1"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"i", ",", "m"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "m"}], "}"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[TextData[{
 "Example 5. Create and identify two 6-element Tables using ",
 StyleBox["ca",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<ca[6] \!\(\*
StyleBox[\"creates\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{
    RowBox[{"c6", "=", 
     RowBox[{"ca", "[", "6", "]"}]}], ";", 
    RowBox[{"id", " ", "[", "c6", "]"}]}], ",", 
   RowBox[{"c6", "//", "tf"}], ",", "\"\<ca[6,5] \!\(\*
StyleBox[\"creates\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{
    RowBox[{"d3", "=", 
     RowBox[{"ca", "[", 
      RowBox[{"6", ",", "5"}], "]"}]}], ";", 
    RowBox[{"id", " ", "[", "d3", "]"}]}], ",", 
   RowBox[{"d3", "//", "tf"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ca[6] \
\\!\\(\\*\\nStyleBox[\\\"creates\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", "\<\"C3C2\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6"},
        {"2", "3", "4", "5", "6", "1"},
        {"3", "4", "5", "6", "1", "2"},
        {"4", "5", "6", "1", "2", "3"},
        {"5", "6", "1", "2", "3", "4"},
        {"6", "1", "2", "3", "4", "5"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"ca[6,5] \
\\!\\(\\*\\nStyleBox[\\\"creates\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", "\<\"D3\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6"},
        {"2", "1", "6", "5", "4", "3"},
        {"3", "4", "5", "6", "1", "2"},
        {"4", "3", "2", "1", "6", "5"},
        {"5", "6", "1", "2", "3", "4"},
        {"6", "5", "4", "3", "2", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tNote that Dihedral groups such as D3 are given by ",
 StyleBox["ca[2n,2n-1]",
  FontSlant->"Italic"],
 " and generalized quaternion groups by ",
 StyleBox["ca[2n,n-1].",
  FontSlant->"Italic"],
 " In general",
 StyleBox[" ca[i,j]",
  FontSlant->"Italic"],
 " often generates groupoids that are not Moufang loops."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.2.2. Composing Cayley Tables with ",
 StyleBox["co",
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tA skeleton implementation of the composition procedure, ",
 StyleBox["co[g,h,o]",
  FontSlant->"Italic"],
 ", is given below. It puts the elements of the second array, ",
 StyleBox["h",
  FontSlant->"Italic"],
 ", suitably offset, in the place of each element of the first array ",
 StyleBox["g",
  FontSlant->"Italic"],
 ". The composition is \"indirect\" if the parameter ",
 StyleBox["a",
  FontSlant->"Italic"],
 "=2. The full procedure handles some other values of ",
 StyleBox["a",
  FontSlant->"Italic"],
 ". (The expression mod[t,m,1] gives indices in the range 1 to m; ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 5 implements this directly.)"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"co", "[", 
    RowBox[{"g_", ",", "h_", ",", 
     RowBox[{"a_:", "0"}]}], "]"}], ":=", 
   RowBox[{"(*", 
    StyleBox[
     RowBox[{
      RowBox[{"Skeleton", ".", " ", "Shortened"}], ",", " ", 
      RowBox[{"non", "-", "executable"}]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["*)",
     FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g1", "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", "g", "]"}], "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"h1", "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", "h", "]"}], "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}]}], ",", "im", ",", "lm", ",", 
       RowBox[{"result", "=", 
        RowBox[{"{", "}"}]}], ",", "t", ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"g1", " ", "h1"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"lm", "=", 
          RowBox[{"l", "-", "1"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"t", "=", 
             RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"Do", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Do", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"a", "\[Equal]", "2"}], ",", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"EvenQ", "[", "l", "]"}], "&&", 
                    RowBox[{"i", ">", "1"}]}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"g1", "+", "2", "-", "i"}], ",", "j"}], 
                    "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                    "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"t", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"k", ",", "l"}], "\[RightDoubleBracket]"}], "-", 
                    "1"}], ")"}], "g1"}], "+", 
                    RowBox[{"g", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}]}], 
                   "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "g1"}], "}"}]}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"k", ",", "h1"}], "}"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"result", ",", 
              RowBox[{"Mod", "[", 
               RowBox[{"t", ",", "m", ",", "1"}], "]"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"j", ",", "g1"}], "}"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"l", ",", "h1"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]",
       "result"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[TextData[{
 "\tExample 6a uses ",
 StyleBox["co ",
  FontSlant->"Italic"],
 "to compose the ",
 StyleBox["C3 ",
  FontSlant->"Italic"],
 "table with ",
 StyleBox["C4",
  FontSlant->"Italic"],
 ", both directly and indirectly. The results are groups ",
 StyleBox["C3C4",
  FontSlant->"Italic"],
 " & ",
 StyleBox["Q12",
  FontSlant->"Italic"],
 ".  Their tables are shown. Direct composition of abelian loops gives an \
abelian loop; indirect compositions gives non-abelian loops."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 6a. Direct & Indirect Composition of C3 & C4 using ",
 StyleBox["co",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<\!\(\*
StyleBox[\"Composing\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C3\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"with\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C4\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)co[C3,C4], \!\(\*
StyleBox[\"gives\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"abelian\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"table\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"tst", "=", 
     RowBox[{"co", "[", 
      RowBox[{"C3", ",", "C4"}], "]"}]}], "]"}], ",", 
   RowBox[{"gd", "[", "]"}], ",", "\"\<\\n\>\"", ",", 
   RowBox[{"tst", "//", "tf"}], ",", "\"\<\!\(\*
StyleBox[\"Indirect\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"composition\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C3\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"with\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C4\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)co[C3,C4,2],\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gives\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"non\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"abelian\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"table\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"tst1", "=", 
     RowBox[{"co", "[", 
      RowBox[{"C3", ",", "C4", ",", "2"}], "]"}]}], "]"}], ",", "\"\<\\n\>\"",
    ",", 
   RowBox[{"gd", "[", "]"}], ",", "\"\<\\n \>\"", ",", "\[IndentingNewLine]", 
   
   RowBox[{"tst1", "//", "tf"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"Composing\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"C3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"with\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"C4\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)co[C3,C4], \
\\!\\(\\*\\nStyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"abelian\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\
\\*\\nStyleBox[\\\"table\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", "\<\"C3C4\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "2", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"C3C4\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2.`", ",", 
         SubscriptBox["2", "5"]}], "}"}], ",", "0", ",", "\<\"co[C3,C4]\"\>", 
       ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "15"}], "}"}], ",", 
       RowBox[{"{", "26", "}"}]}], "}"}]}], "}"}], ",", "\<\"\\n\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"},
        {"2", "3", "1", "5", "6", "4", "8", "9", "7", "11", "12", "10"},
        {"3", "1", "2", "6", "4", "5", "9", "7", "8", "12", "10", "11"},
        {"4", "5", "6", "7", "8", "9", "10", "11", "12", "1", "2", "3"},
        {"5", "6", "4", "8", "9", "7", "11", "12", "10", "2", "3", "1"},
        {"6", "4", "5", "9", "7", "8", "12", "10", "11", "3", "1", "2"},
        {"7", "8", "9", "10", "11", "12", "1", "2", "3", "4", "5", "6"},
        {"8", "9", "7", "11", "12", "10", "2", "3", "1", "5", "6", "4"},
        {"9", "7", "8", "12", "10", "11", "3", "1", "2", "6", "4", "5"},
        {"10", "11", "12", "1", "2", "3", "4", "5", "6", "7", "8", "9"},
        {"11", "12", "10", "2", "3", "1", "5", "6", "4", "8", "9", "7"},
        {"12", "10", "11", "3", "1", "2", "6", "4", "5", "9", "7", "8"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"Indirect\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"composition\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"C3\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"C4\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)co[C3,C4,2],\\!\\(\\*\\nStyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"gives\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"non\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"-\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"abelian\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\
\\*\\nStyleBox[\\\"table\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", "\<\"Q12\"\>", ",", "\<\"\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "1", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"Q12\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", "6"}], "}"}], ",", "0", 
       ",", "\<\"co[C3,C4,2]\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\<\"ba\"\>", "\[Rule]", "\<\"a2b\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "36"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "16"}], "}"}]}], "}"}]}], "}"}], 
   ",", "\<\"\\n \"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"},
        {"2", "3", "1", "5", "6", "4", "8", "9", "7", "11", "12", "10"},
        {"3", "1", "2", "6", "4", "5", "9", "7", "8", "12", "10", "11"},
        {"4", "6", "5", "7", "9", "8", "10", "12", "11", "1", "3", "2"},
        {"5", "4", "6", "8", "7", "9", "11", "10", "12", "2", "1", "3"},
        {"6", "5", "4", "9", "8", "7", "12", "11", "10", "3", "2", "1"},
        {"7", "8", "9", "10", "11", "12", "1", "2", "3", "4", "5", "6"},
        {"8", "9", "7", "11", "12", "10", "2", "3", "1", "5", "6", "4"},
        {"9", "7", "8", "12", "10", "11", "3", "1", "2", "6", "4", "5"},
        {"10", "12", "11", "1", "3", "2", "4", "6", "5", "7", "9", "8"},
        {"11", "10", "12", "2", "1", "3", "5", "4", "6", "8", "7", "9"},
        {"12", "11", "10", "3", "2", "1", "6", "5", "4", "9", "8", "7"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Example 6b shows that three different 48-element groups can be created by \
direct or indirect composition of D3 & Q8.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 6b. Direct & Indirect Composition of D3 & Q8 using ",
 StyleBox["co",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{"\"\<\!\(\*
StyleBox[\"Composing\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"D3\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"with\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Q8\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)co[D3,Q8], \!\(\*
StyleBox[\"gives\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"non\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"abelian\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"table\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{
    RowBox[{"tst", "=", 
     RowBox[{"co", "[", 
      RowBox[{"D3", ",", "Q8"}], "]"}]}], ";", 
    RowBox[{"idc", "[", "tst", "]"}]}], ",", 
   RowBox[{"gd", "[", "]"}], ",", "\"\<\\n\>\"", ",", "\"\<\!\(\*
StyleBox[\"Indirect\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"composition\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"D3\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"with\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Q8\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)co[Q8,D3,2] &\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)co[Q8,D3,4],\!\(\*
StyleBox[\"gives\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"two\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"non\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"abelian\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"tables\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{
    RowBox[{"tst1", "=", 
     RowBox[{"co", "[", 
      RowBox[{"Q8", ",", "D3", ",", "2"}], "]"}]}], ";", "\"\<\\n\>\""}], ",",
    
   RowBox[{"idc", "[", "tst1", "]"}], ",", 
   RowBox[{"gd", "[", "]"}], ",", 
   RowBox[{
    RowBox[{"tst1", "=", 
     RowBox[{"co", "[", 
      RowBox[{"Q8", ",", "D3", ",", "4"}], "]"}]}], ";", "\"\<\\nand\>\""}], 
   ",", 
   RowBox[{"idc", "[", "tst1", "]"}], ",", "\"\<\\n\>\"", ",", 
   RowBox[{"gd", "[", "]"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tst1", "=."}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"Composing\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"D3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"with\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Q8\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)co[D3,Q8], \
\\!\\(\\*\\nStyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"non\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"abelian\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"table\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", "\<\"Q8D3\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", "40", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"Q8D3\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "2"], ",", "24"}], "}"}], ",", "0", 
       ",", "\<\"co[Q8,D3]\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\<\"aa\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
         RowBox[{"\<\"bb\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
         RowBox[{"\<\"ba\"\>", "\[Rule]", "\<\"abc\"\>"}], ",", 
         RowBox[{"\<\"abab\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
         RowBox[{"\<\"ed\"\>", "\[Rule]", "\<\"dde\"\>"}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", "27", ",", "30"}], "}"}]}], "}"}]}], "}"}], 
   ",", "\<\"\\n\"\>", 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"Indirect\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"composition\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"D3\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Q8\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)co[Q8,D3,2] &\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)co[Q8,D3,4],\\!\\(\\*\\nStyleBox[\\\"\
gives\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"two\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"non\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"abelian\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"tables\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", "\<\"\\n\"\>", ",", "\<\"Q8iD3\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", "17", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"Q8iD3\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"14", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "5"]}], "}"}], ",", "0", 
       ",", "\<\"co[Q8,ca[6,5],2]\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\<\"bb\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
         RowBox[{"\<\"cc\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
         RowBox[{"\<\"ba\"\>", "\[Rule]", "\<\"abc\"\>"}], ",", 
         RowBox[{"\<\"ca\"\>", "\[Rule]", "\<\"acd\"\>"}], ",", 
         RowBox[{"\<\"ea\"\>", "\[Rule]", "\<\"aee\"\>"}], ",", 
         RowBox[{"\<\"cb\"\>", "\[Rule]", "\<\"bcd\"\>"}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}], ",", "\<\"\\nand\"\>", 
   ",", "\<\"Q8pD3\"\>", ",", "\<\"\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", "41", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"Q8pD3\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", 
         SubscriptBox["2", "2"], ",", 
         SubscriptBox["6", "2"], ",", "12"}], "}"}], ",", "0", 
       ",", "\<\"co[Q8,D3,4]\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\<\"bb\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
         RowBox[{"\<\"cc\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
         RowBox[{"\<\"ca\"\>", "\[Rule]", "\<\"acd\"\>"}], ",", 
         RowBox[{"\<\"ea\"\>", "\[Rule]", "\<\"aee\"\>"}], ",", 
         RowBox[{"\<\"cb\"\>", "\[Rule]", "\<\"bcd\"\>"}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tDirect and indirect compositions create larger tables, with more \
symmetries. The reverse procedure, \"folding\" from larger to smaller tables, \
creates \"supersymmetry\" (",
 StyleBox["sic",
  FontSlant->"Italic"],
 " because of the way that physicists have defined supersymmetry); some \
symmetries are lost. The indirect compositions are all non-commutative, and \
so this may be a paradigm for boson-fermion supersymmetry, where the bosons \
commute and the fermions anti-commute. The ",
 StyleBox["ts",
  FontSlant->"Italic"],
 " procedure reverses direct composition. I have not looked for a \
corresponding indirect composition reversal. "
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.2.3. Creating Matrix Cayley Tables with ",
 StyleBox["ma",
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tMost groups can be represented (in many isomorphic ways) by elements that \
are square matrices, using dot-multiplication as the group operation. The \
procedure ",
 StyleBox["ma",
  FontSlant->"Italic"],
 " inverts this, finding the group generated by dot-multiplication of a given \
set of square matrices. Whenever a dot-product gives a new matrix it is added \
to the list of elements, until the group closes or the size limit is \
exceeded. A skeleton version is supplied. Defining matrices are specified in \
the database for many loops. ",
 StyleBox["st",
  FontSlant->"Italic"],
 " is conversion table that converts the matrices to indices."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"ma", "[", 
   RowBox[{
    RowBox[{"{", "mm__", "}"}], ",", 
    RowBox[{"maxel_:", "73"}], ",", 
    RowBox[{"o_:", "0"}]}], "]"}], ":=", 
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{"Skeleton", ".", " ", "Short"}], ",", " ", 
     RowBox[{"non", "-", "executable"}]}],
    FontColor->RGBColor[1, 0, 0]], " ", "*)"}], 
  StyleBox["\[IndentingNewLine]",
   FontColor->RGBColor[1, 0, 0]], 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"{", "mm", "}"}]}], ",", "g", ",", 
      RowBox[{"j", "=", "2"}], ",", 
      RowBox[{"k", "=", "1"}], ",", "lg", ",", 
      RowBox[{"mx", "=", "2"}], ",", "n", ",", 
      RowBox[{"rs", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           StyleBox["\[DoubleStruckCapitalJ]",
            FontWeight->"Plain"], "any_"], "\[Rule]", 
          SuperscriptBox[
           StyleBox["\[DoubleStruckCapitalJ]",
            FontWeight->"Plain"], 
           RowBox[{"Mod", "[", 
            RowBox[{"any", ",", "3"}], "]"}]]}], ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckK]", "any_"], "\[Rule]", 
          SuperscriptBox["\[DoubleStruckK]", 
           RowBox[{"Mod", "[", 
            RowBox[{"any", ",", "2"}], "]"}]]}]}], "}"}]}], ",", "st"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{"g", "=", 
      RowBox[{"Insert", "[", 
       RowBox[{"m", ",", 
        RowBox[{"IdentityMatrix", "[", 
         RowBox[{"Length", "[", 
          RowBox[{"m", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}], "]"}], ",", "1"}], 
       "]"}]}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"lg", "=", 
         RowBox[{"Length", "[", "g", "]"}]}], ";", 
        RowBox[{"j", "\[LessEqual]", "lg"}]}], ",", 
       RowBox[{
        RowBox[{"k", "++"}], ";", 
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{
           RowBox[{
           "g", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ".", 
           RowBox[{
           "g", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}]}], "/.",
           "\[InvisibleSpace]", "rs"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"MemberQ", "[", 
            RowBox[{"g", ",", "n"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"g", ",", "n"}], "]"}], ";", 
           RowBox[{"mx", "++"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"mx", ">", "maxel"}], ",", 
             RowBox[{
              RowBox[{"k", "=", "9999"}], ";", 
              RowBox[{"j", "=", "mx"}]}]}], "]"}]}]}], "]"}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"k", "\[GreaterEqual]", "lg"}], ",", 
          RowBox[{
           RowBox[{"k", "=", "1"}], ";", 
           RowBox[{"j", "++"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"j", ">", "maxel"}], ",", 
             RowBox[{
              RowBox[{"g", "=", 
               RowBox[{"{", 
                RowBox[{"{", "}"}], "}"}]}], ";", 
              RowBox[{"Goto", "[", "tag", "]"}]}]}], "]"}]}]}], "]"}]}]}], 
      "]"}], ";", 
     RowBox[{"g", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"g", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
           ".", 
          RowBox[{
          "g", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}], "/.",
          "rs"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "lg"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "lg"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"Label", "[", "tag", "]"}], ";", 
     RowBox[{"st", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "\[LeftDoubleBracket]", 
          RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], "->", "j"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "lg", ",", "1", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"g", "/.", "st"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[TextData[{
 "\tExample 7 sets up the three Pauli-\[Sigma] matrices [3, p51] and uses ",
 StyleBox["ma",
  FontSlant->"Italic"],
 " to dot-multiply them to give a 16-element group; the 16 matrix elements \
are shown. The result is an isomorph of the ",
 StyleBox["P16",
  FontSlant->"Italic"],
 " protoloop, which is also shown. These tables have physical significance \
(discussed elsewhere) because they possess the Riemann metric."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Ex. 7. Using ",
 StyleBox["ma",
  FontSlant->"Italic"],
 " to generate a group from Pauli Matrices."
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<The 3 \[Sigma] matrices are \>\"", 
   StyleBox[",",
    FontSlant->"Italic"], 
   StyleBox[" ",
    FontSlant->"Italic"], 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], ";", 
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], "//", "tf"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "2"], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[ImaginaryI]", ",", "0"}], "}"}]}], "}"}]}], ";", 
    RowBox[{
     SubscriptBox["\[Sigma]", "2"], "//", "tf"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "3"], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ";", 
    RowBox[{
     SubscriptBox["\[Sigma]", "3"], "//", "tf"}]}], ",", 
   "\"\<\\nma[{\!\(\*SubscriptBox[\(\[Sigma]\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Sigma]\), \(2\)]\),\!\(\*SubscriptBox[\(\
\[Sigma]\), \(3\)]\)}] generates\>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"ma", "[", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], ",", 
       SubscriptBox["\[Sigma]", "2"], ",", 
       SubscriptBox["\[Sigma]", "3"]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\nThe elements are stored in matel as\>\"", ",", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"matel", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "//", "tf"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "16"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   "\"\<\\nWith protoloop P16:-\\n\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"P16", "//", "tf"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"The 3 \[Sigma] matrices are \"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0", "1"},
        {"1", "0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0", 
         RowBox[{"-", "\[ImaginaryI]"}]},
        {"\[ImaginaryI]", "0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "0"},
        {"0", 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\nma[{\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \
\\(1\\)]\\),\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \
\\(2\\)]\\),\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(3\\)]\\)}] \
generates\"\>", ",", "\<\"P16\"\>", 
   ",", "\<\"\\nThe elements are stored in matel as\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "0"},
          {"0", "1"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", "1"},
          {"1", "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", 
           RowBox[{"-", "\[ImaginaryI]"}]},
          {"\[ImaginaryI]", "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "0"},
          {"0", 
           RowBox[{"-", "1"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"\[ImaginaryI]", "0"},
          {"0", 
           RowBox[{"-", "\[ImaginaryI]"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", 
           RowBox[{"-", "1"}]},
          {"1", "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {
           RowBox[{"-", "\[ImaginaryI]"}], "0"},
          {"0", "\[ImaginaryI]"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", "\[ImaginaryI]"},
          {"\[ImaginaryI]", "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", 
           RowBox[{"-", "1"}]},
          {
           RowBox[{"-", "1"}], "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {
           RowBox[{"-", "\[ImaginaryI]"}], "0"},
          {"0", 
           RowBox[{"-", "\[ImaginaryI]"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", "1"},
          {
           RowBox[{"-", "1"}], "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", 
           RowBox[{"-", "\[ImaginaryI]"}]},
          {
           RowBox[{"-", "\[ImaginaryI]"}], "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"\[ImaginaryI]", "0"},
          {"0", "\[ImaginaryI]"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", "\[ImaginaryI]"},
          {
           RowBox[{"-", "\[ImaginaryI]"}], "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {
           RowBox[{"-", "1"}], "0"},
          {"0", 
           RowBox[{"-", "1"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {
           RowBox[{"-", "1"}], "0"},
          {"0", "1"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True]}], "}"}], ",", "\<\"\\nWith protoloop P16:-\\n\"\>", 
   ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
         "14", "15", "16"},
        {"2", "1", "8", "15", "6", "5", "12", "3", "10", "9", "16", "7", "14",
          "13", "4", "11"},
        {"3", "16", "1", "6", "7", "4", "5", "10", "11", "8", "9", "14", "15",
          "12", "13", "2"},
        {"4", "7", "14", "1", "8", "11", "2", "5", "12", "15", "6", "9", "16",
          "3", "10", "13"},
        {"5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", 
         "1", "2", "3", "4"},
        {"6", "5", "12", "3", "10", "9", "16", "7", "14", "13", "4", "11", 
         "2", "1", "8", "15"},
        {"7", "4", "5", "10", "11", "8", "9", "14", "15", "12", "13", "2", 
         "3", "16", "1", "6"},
        {"8", "11", "2", "5", "12", "15", "6", "9", "16", "3", "10", "13", 
         "4", "7", "14", "1"},
        {"9", "10", "11", "12", "13", "14", "15", "16", "1", "2", "3", "4", 
         "5", "6", "7", "8"},
        {"10", "9", "16", "7", "14", "13", "4", "11", "2", "1", "8", "15", 
         "6", "5", "12", "3"},
        {"11", "8", "9", "14", "15", "12", "13", "2", "3", "16", "1", "6", 
         "7", "4", "5", "10"},
        {"12", "15", "6", "9", "16", "3", "10", "13", "4", "7", "14", "1", 
         "8", "11", "2", "5"},
        {"13", "14", "15", "16", "1", "2", "3", "4", "5", "6", "7", "8", "9", 
         "10", "11", "12"},
        {"14", "13", "4", "11", "2", "1", "8", "15", "6", "5", "12", "3", 
         "10", "9", "16", "7"},
        {"15", "12", "13", "2", "3", "16", "1", "6", "7", "4", "5", "10", 
         "11", "8", "9", "14"},
        {"16", "3", "10", "13", "4", "7", "14", "1", "8", "11", "2", "5", 
         "12", "15", "6", "9"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.2.4. Generating Cayley Tables with ",
 StyleBox["ge",
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tAnother way to create a group is to specify a list of relators (aka \
generators, monovectors, gammas) ",
 StyleBox["a, b,... ",
  FontSlant->"Italic"],
 "and some relations (substitution rules such as ",
 StyleBox["ba\[RightArrow]aab) ",
  FontSlant->"Italic"],
 "between them. The relators act as the letters to be used in names of the \
group element. ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " creates group elements by concatenation of relator strings. Non-abelian \
rules can be specified, leading to non-abelian groups. The relations are used \
to give lexicographic order in individual element names. Each relator acts as \
a root of unity; the ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " procedure uses strings \"",
 StyleBox["a",
  FontSlant->"Italic"],
 "\", \"",
 StyleBox["b",
  FontSlant->"Italic"],
 "\", etc. as relators. Thus if ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "3"], TraditionalForm]]],
 "\[RightArrow]1, there will be string elements \"",
 StyleBox["a",
  FontSlant->"Italic"],
 "\" and \"",
 StyleBox["aa",
  FontSlant->"Italic"],
 "\" whilst \"",
 StyleBox["aaa",
  FontSlant->"Italic"],
 "\" becomes the unit or empty string \"\".  ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " was originally written to use symbolic variables ",
 StyleBox["a, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 ",  etc. (and called ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " because I originally thought that they were \"generators\"), these were \
converted to strings to reduce interference with other calculations. A final \
parameter ",
 StyleBox["o",
  FontSlant->"Italic"],
 " can be set to \[PlusMinus]1; this results in the creation of global \
variables ",
 StyleBox["genel, matel",
  FontSlant->"Italic"],
 " that record the elements and the loop, with the elements as strings. An \
experimental feature is the creation of a string replacement rule ",
 StyleBox["strep",
  FontSlant->"Italic"],
 " if ",
 StyleBox["o",
  FontSlant->"Italic"],
 "=-1, to allow investigation of noncommutative loop properties. These \
features are not demonstrated."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ge", "[", 
    RowBox[{"gp_", ",", 
     RowBox[{"post_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      StyleBox["skeleton",
       FontColor->RGBColor[1, 0, 0]], " ", "version", " ", "of", " ", "ge"}], 
     ",", " ", 
     RowBox[{"for", " ", "groups", " ", "only"}]}], " ", "*)"}], 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "=", 
        RowBox[{"{", "}"}]}], ",", "cr", ",", "j", ",", 
       RowBox[{"l", "=", 
        RowBox[{
         RowBox[{"Plus", "@@", "gp"}], "+", "2"}]}], ",", 
       RowBox[{"le", "=", 
        RowBox[{"Length", "[", "gp", "]"}]}], ",", 
       RowBox[{"ln", "=", "1"}], ",", "lh", ",", 
       RowBox[{"n", "=", 
        RowBox[{"{", "\"\<\>\"", "}"}]}], ",", "new", ",", "p", ",", "st", 
       ",", "rhs", ",", "si", ",", "sij", ",", 
       RowBox[{"t", "=", "post"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"cr", "=", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", 
           ",", "\"\<e\>\"", ",", "\"\<f\>\"", ",", "\"\<g\>\""}], "}"}], ",",
          "le"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{"(*", 
        RowBox[{"i", " ", 
         RowBox[{"loop", ".", " ", "Rules"}], " ", "to", " ", "reduce", " ", 
         "repetitions"}], "*)"}], 
       RowBox[{
        RowBox[{
         RowBox[{"st", "=", 
          RowBox[{"cr", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"t", ",", 
           RowBox[{
            RowBox[{"Do", "[", 
             RowBox[{
              RowBox[{"st", "=", 
               RowBox[{"st", "<>", 
                RowBox[{"cr", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"gp", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "-", "1"}], "}"}]}], "]"}], 
            ";", 
            RowBox[{"Rule", "[", 
             RowBox[{"st", ",", "\"\<\>\""}], "]"}]}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "le"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]",
       
      RowBox[{"Do", "[", 
       RowBox[{"(*", 
        RowBox[{"i", ",", 
         RowBox[{"j", " ", 
          RowBox[{"loops", ".", " ", "Add"}], " ", "abelian", " ", 
          "rules"}]}], "*)"}], 
       RowBox[{
        RowBox[{
         RowBox[{"new", "=", 
          RowBox[{"Rule", "[", 
           RowBox[{
            RowBox[{"lh", "=", 
             RowBox[{
              RowBox[{"cr", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "<>", 
              RowBox[{"cr", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{"cr", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "<>", 
             RowBox[{"cr", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{"(*", 
           RowBox[{"k", " ", 
            RowBox[{"loop", ".", "Omit"}], " ", "redundant", " ", "rules"}], 
           "*)"}], 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"lh", "\[Equal]", 
              RowBox[{"t", "[", 
               RowBox[{"[", 
                RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ",", 
             RowBox[{"new", "=", "\"\<\>\""}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{
              RowBox[{"Length", "[", "t", "]"}], "-", "1"}]}], "}"}]}], "]"}],
          ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "new", "]"}], "\[Equal]", "2"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"t", ",", "new"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"le", "-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"i", "+", "1"}], ",", "le"}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{"(*", 
        RowBox[{"i", " ", 
         RowBox[{"loop", ".", " ", "Build"}], " ", "the", " ", "element", " ",
          "list"}], "*)"}], 
       RowBox[{
        RowBox[{
         RowBox[{"si", "=", 
          RowBox[{"cr", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", 
         RowBox[{"sij", "=", "si"}], ";", 
         RowBox[{"p", "=", 
          RowBox[{
           RowBox[{"gp", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", "1"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{"(*", 
           RowBox[{"j", " ", 
            RowBox[{"loop", ".", "Repetitions"}]}], "*)"}], 
          RowBox[{
           RowBox[{
            RowBox[{"Do", "[", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"k", " ", 
                RowBox[{"loop", ".", " ", "New"}], " ", "element"}], "=", 
               RowBox[{"j", " ", "repeats", " ", "of", " ", 
                RowBox[{"k", "'"}], "th", " ", "existing", " ", "element"}]}],
               "*)"}], 
             RowBox[{
              RowBox[{"AppendTo", "[", 
               RowBox[{"n", ",", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"k", "\[Equal]", "1"}], ",", "sij", ",", 
                  RowBox[{
                   RowBox[{"n", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], "<>", "sij"}]}], "]"}]}], 
               "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "ln"}], "}"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"sij", "=", 
             RowBox[{"sij", "<>", "si"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "p"}], "}"}]}], "]"}], ";", 
         RowBox[{"ln", "=", 
          RowBox[{"Length", "[", "n", "]"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "le"}], "}"}]}], "]"}], ";", 
      RowBox[{"(*", 
       RowBox[{"element", " ", "list", " ", 
        RowBox[{"completed", "."}]}], "*)"}], 
      RowBox[{"Do", "[", 
       RowBox[{"(*", 
        RowBox[{"i", " ", 
         RowBox[{"loop", ".", "Build"}], " ", "table", " ", "by", " ", 
         RowBox[{"concatenation", "."}]}], "*)"}], 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"g", ",", 
          RowBox[{"(*", 
           RowBox[{"add", " ", "successive", " ", 
            RowBox[{
             RowBox[{"n", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "<>", "n"}], " ", "rows", " ", 
            "to", " ", "g"}], "*)"}], 
          RowBox[{"MapThread", "[", 
           RowBox[{"StringJoin", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"n", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "ln"}], "}"}]}], "]"}], ",", "n"}], 
             "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "ln"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]",
       
      RowBox[{"g", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"l", "=", "0"}], ";", 
          RowBox[{"s1", "=", 
           RowBox[{"g", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}], ";", 
          RowBox[{"s1", "=", 
           RowBox[{"While", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"s2", "=", 
                 RowBox[{"StringReplace", "[", 
                  RowBox[{"s1", ",", "t"}], "]"}]}], ")"}], "\[NotEqual]", 
               "s1"}], "&&", 
              RowBox[{"l", "<", "99"}]}], ",", 
             RowBox[{
              RowBox[{"l", "++"}], ";", 
              RowBox[{"s1", "=", "s2"}]}]}], "]"}]}], ";", "s2"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "ln"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "ln"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Conversion", " ", "to", " ", 
        RowBox[{"indices", "."}]}], "*)"}], 
      RowBox[{"st", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g", "\[LeftDoubleBracket]", 
           RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], "\[Rule]", 
          "j"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "ln", ",", "1", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]",
       
      RowBox[{"g", "/.", "st"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[TextData[{
 "\tExample 8 creates ",
 StyleBox["A4",
  FontSlant->"Italic"],
 " by setting up relators",
 StyleBox[" a, b, & c,",
  FontSlant->"Italic"],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["a", "3"], "\[RightArrow]", "1"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["b", "2"], "\[RightArrow]", "1"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["c", "2"], "\[RightArrow]", "1"}], TraditionalForm]]],
 ". This is specified by the ",
 StyleBox["{3,2,2}",
  FontSlant->"Italic"],
 " entry. The elements ",
 StyleBox["{\"\", \"a\", \"aa\", \"b\", \"ab\", \"aab\", \"c\", \"ac\", \"aac\
\", \"bc\", \"abc\", \"aabc\"}",
  FontSlant->"Italic"],
 " are created. These are put into ",
 StyleBox["genel",
  FontSlant->"Italic"],
 " if the last parameter is \[PlusMinus]1, as in this example. A loop is then \
created by concatenation. The non-abelian rules ",
 StyleBox["ba\[RightArrow]abc ",
  FontSlant->"Italic"],
 "&",
 StyleBox[" ca\[RightArrow]ab",
  FontSlant->"Italic"],
 " are applied, followed by the (implicit) abelian rule ",
 StyleBox["cb\[RightArrow]bc",
  FontSlant->"Italic"],
 ", until all strings are reduced to elements. The Index table is created and \
identified.\n\tThe corresponding traditional formulation of relators is \
discussed in Section 5.2. I have not investigated the creation of either \
signed tables or non-associative Moufang loops from relators. "
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example 8. Group creation from relators and non-abelian rules.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold",
 FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<On generating \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"a4", "=", 
     RowBox[{"ge", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
         RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}], ",", "2"}],
       "]"}]}], "]"}], ",", 
   "\"\<by ge[{3,2,2},{ba\[Rule]abc,ca\[Rule]ab},1]]\\nthe string elements \
are\>\"", ",", "genel", ",", "\"\<\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"first\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"element\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"empty\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"string\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",
FontSlant->\"Italic\"]\)\\nThe Index table is\!\(\*
StyleBox[\":\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"a4", "//", "tf"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"On generating \"\>", ",", "\<\"A4\"\>", 
   ",", "\<\"by ge[{3,2,2},{ba\[Rule]abc,ca\[Rule]ab},1]]\\nthe string \
elements are\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "\<\"a\"\>", ",", "\<\"aa\"\>", ",", "\<\"b\"\>", 
     ",", "\<\"ab\"\>", ",", "\<\"aab\"\>", ",", "\<\"c\"\>", 
     ",", "\<\"ac\"\>", ",", "\<\"aac\"\>", ",", "\<\"bc\"\>", 
     ",", "\<\"abc\"\>", ",", "\<\"aabc\"\>"}], "}"}], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\\
!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"first\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"element\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\
\\*\\nStyleBox[\\\"is\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"empty\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"string\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\nThe Index table \
is\\!\\(\\*\\nStyleBox[\\\":\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"},
        {"2", "3", "1", "5", "6", "4", "8", "9", "7", "11", "12", "10"},
        {"3", "1", "2", "6", "4", "5", "9", "7", "8", "12", "10", "11"},
        {"4", "11", "9", "1", "8", "12", "10", "5", "3", "7", "2", "6"},
        {"5", "12", "7", "2", "9", "10", "11", "6", "1", "8", "3", "4"},
        {"6", "10", "8", "3", "7", "11", "12", "4", "2", "9", "1", "5"},
        {"7", "5", "12", "10", "2", "9", "1", "11", "6", "4", "8", "3"},
        {"8", "6", "10", "11", "3", "7", "2", "12", "4", "5", "9", "1"},
        {"9", "4", "11", "12", "1", "8", "3", "10", "5", "6", "7", "2"},
        {"10", "8", "6", "7", "11", "3", "4", "2", "12", "1", "5", "9"},
        {"11", "9", "4", "8", "12", "1", "5", "3", "10", "2", "6", "7"},
        {"12", "7", "5", "9", "10", "2", "6", "1", "11", "3", "4", "8"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "genel"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"Global. The string elements of the last generator group to \
have been created with 'o'=1\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3426322665-2472452"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.2.5. Generating Cayley Tables with ",
 StyleBox["pe",
  FontSlant->"Italic"],
 "."
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tEvery group can be generated from permutations and cycles; this is of \
limited value for small groups, but suitable procedures (not shown here) are \
implemented and the database includes 34 examples derived from GAP data or by \
search. The incantations tend to be voluminous in comparison with the other \
incantations for the same group.\n\tExample 8a generates groups from \
permutations, using examples from the basic permutations that have been set \
up as arrays s3, s4, and s5. Note that 120-element S5 group needs the \
permissible size to be increased from the default value of 72. Then some \
small groups are created from 6-member permutations. In Example 8b the \
120-element ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["SL", "2"], 
   RowBox[{"(", "5", ")"}]}]],
  FontWeight->"Bold"],
 " group is created from the two permutations specified in a tutorial in the \
GAP manual."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 8a Generation from pre-defined permutations.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<\!\(\*
StyleBox[\"Permutations\",
FontSlant->\"Italic\"]\) s3 =\>\"", ",", "s3", ",", "\"\<\!\(\*
StyleBox[\"generate\",
FontSlant->\"Italic\"]\)\\n\>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s3", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C2", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s3", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C3", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s3", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s3", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "D3", "*)"}], ",", "\"\<\\n\!\(\*
StyleBox[\"Permutations\",
FontSlant->\"Italic\"]\) s4 =\>\"", ",", "s4", ",", "\"\<\!\(\*
StyleBox[\"generate\",
FontSlant->\"Italic\"]\)\\n\>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s4", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C2", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s4", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C3", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s4", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s4", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s4", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "K", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s4", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s4", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "D4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s4", "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{"s4", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "A4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s4", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s4", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "S4", "*)"}], ",", "\"\<\\n\!\(\*
StyleBox[\"Permutations\",
FontSlant->\"Italic\"]\) s5 =\>\"", ",", "s5", ",", "\"\<\!\(\*
StyleBox[\"generate\",
FontSlant->\"Italic\"]\)\\n\>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s5", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C2", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s5", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C3", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s5", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s5", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "8", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "K", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"s5", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C5", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s5", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C6", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s5", "[", 
        RowBox[{"[", "4", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "D3", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s5", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "D4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s5", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "8", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "D3C2", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s5", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "A4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s5", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "S4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s5", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"s5", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "A5", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s5", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{"s5", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", "120"}], "]"}], "]"}], 
   
   RowBox[{"(*", "S5", "*)"}], ",", "\"\<\\n\!\(\*
StyleBox[\"Some\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"groups\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"from\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"6\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"member\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"permutations\",
FontSlant->\"Italic\"]\) -\>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "6", ",", "5"}], "}"}],
       "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C2", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "6", ",", "4", ",", "5"}], "}"}],
       "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C3", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "6", ",", "3", ",", "4", ",", "5"}], "}"}],
       "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "6", ",", "5"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "4", ",", "3", ",", "5", ",", "6"}], 
        "}"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "K", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "4", ",", "6", ",", "2", ",", "5"}], "}"}],
       "}"}], "]"}], "]"}], 
   RowBox[{"(*", "C5", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "2", ",", "6", ",", "4", ",", "5"}], "}"}],
       "}"}], "]"}], "]"}], 
   RowBox[{"(*", 
    RowBox[{"C3C2", " ", "or", " ", "C6"}], "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "6", ",", "5"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "5", ",", "4", ",", "6"}], 
        "}"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "D3", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "4", ",", "3", ",", "6", ",", "5"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "6", ",", "5", ",", "4"}], 
        "}"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "D4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "4", ",", "3", ",", "6", ",", "5"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "6", ",", "4", ",", "5"}], 
        "}"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "A4", "*)"}], ",", "\[IndentingNewLine]", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "2", ",", "4", ",", "6", ",", "5"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3", ",", "2", ",", "5", ",", "6", ",", "4"}], 
        "}"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "D3C2", "*)"}], ",", "\[IndentingNewLine]", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "6", ",", "5"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "6", ",", "3", ",", "4", ",", "5"}], 
        "}"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "S4", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "4", ",", "2", ",", "6", ",", "3", ",", "5"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "5", ",", "6", ",", "3", ",", "4"}], 
        "}"}]}], "}"}], "]"}], "]"}], 
   RowBox[{"(*", "A5", "*)"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"pe", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "6", ",", "3", ",", "5", ",", "4"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", "5", ",", "3", ",", "4", ",", "6"}], 
        "}"}]}], "}"}], "]"}], "]"}]}], 
  RowBox[{"(*", "A4C2", "*)"}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"Permutations\\\",\\nFontSlant->\\\"\
Italic\\\"]\\) s3 =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "}"}], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"generate\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\n\"\>", ",", "\<\"C2\"\>", ",", "\<\"C3\"\>", ",", "\<\"D3\"\>", 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Permutations\\\",\\nFontSlant->\\\"\
Italic\\\"]\\) s4 =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "1"}], "}"}]}], "}"}], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"generate\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\n\"\>", ",", "\<\"C2\"\>", ",", "\<\"C3\"\>", ",", "\<\"C4\"\>", 
   ",", "\<\"K\"\>", ",", "\<\"D4\"\>", ",", "\<\"A4\"\>", ",", "\<\"S4\"\>", 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Permutations\\\",\\nFontSlant->\\\"\
Italic\\\"]\\) s5 =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "5", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "5", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "1", ",", "2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4", ",", "3", ",", "5"}], "}"}]}], "}"}], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"generate\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\n\"\>", ",", "\<\"C2\"\>", ",", "\<\"C3\"\>", ",", "\<\"C4\"\>", 
   ",", "\<\"K\"\>", ",", "\<\"C5\"\>", ",", "\<\"C3C2\"\>", 
   ",", "\<\"D3\"\>", ",", "\<\"D4\"\>", ",", "\<\"D3C2\"\>", 
   ",", "\<\"A4\"\>", ",", "\<\"S4\"\>", ",", "\<\"A5\"\>", ",", "\<\"S5\"\>",
    ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Some\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"groups\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"from\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"6\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"-\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"member\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"permutations\\\"\
,\\nFontSlant->\\\"Italic\\\"]\\) -\"\>", ",", "\<\"C2\"\>", 
   ",", "\<\"C3\"\>", ",", "\<\"C4\"\>", ",", "\<\"K\"\>", ",", "\<\"C5\"\>", 
   ",", "\<\"C3C2\"\>", ",", "\<\"D3\"\>", ",", "\<\"D4\"\>", 
   ",", "\<\"A4\"\>", ",", "\<\"D3C2\"\>", ",", "\<\"S4\"\>", 
   ",", "\<\"A5\"\>", ",", "\<\"A4C2\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Example", " ", "8", 
  RowBox[{"b", ".", " ", "Generation"}], " ", "of", " ", 
  SubscriptBox["SL", "2"], 
  RowBox[{"(", "5", ")"}], " ", "from", " ", "GAP", " ", "tutorial", " ", 
  "Ch", ".2", " "}]], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman",
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<\!\(\*
StyleBox[\"Permutations\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{"perm1", "=", 
    RowBox[{"fromCycles", "[", 
     StyleBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "1", "}"}], ",", 
        RowBox[{"{", " ", 
         RowBox[{
         "2", ",", " ", "3", ",", " ", "5", ",", " ", "9", ",", "15"}], "}"}],
         ",", 
        RowBox[{"{", " ", 
         RowBox[{"4", ",", " ", "7", ",", "12", ",", " ", "8", ",", "14"}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"10", ",", "17", ",", "23", ",", "20", ",", "24"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"11", ",", "19", ",", "22", ",", "16", ",", "13"}], "}"}]}], 
       "}"}],
      FormatType->StandardForm], 
     StyleBox["]",
      FormatType->StandardForm]}]}], 
   StyleBox[",",
    FormatType->StandardForm], "\n", 
   RowBox[{"perm2", "=", 
    RowBox[{"fromCycles", "[", 
     RowBox[{"{", 
      RowBox[{
       StyleBox[
        RowBox[{"{", 
         RowBox[{
         "1", ",", "2", ",", "4", ",", "8", ",", "3", ",", "6", ",", "11", 
          ",", "20", ",", "17", ",", "19"}], "}"}],
        FormatType->StandardForm], 
       StyleBox[",",
        FormatType->StandardForm], 
       StyleBox["\[IndentingNewLine]",
        FormatType->StandardForm], 
       RowBox[{
        StyleBox["{",
         FormatType->StandardForm], 
        StyleBox[
         RowBox[{
         "5", ",", "10", ",", "18", ",", "7", ",", "13", ",", "22", ",", "12",
           ",", "21", ",", "24", ",", "15"}],
         FormatType->StandardForm], "}"}], ",", 
       RowBox[{"{", 
        StyleBox[
         RowBox[{"9", ",", "16"}],
         FormatType->StandardForm], "}"}], ",", 
       RowBox[{"{", 
        StyleBox[
         RowBox[{"14", ",", "23"}],
         FormatType->StandardForm], 
        StyleBox["}",
         FormatType->StandardForm]}]}], 
      StyleBox["}",
       FormatType->StandardForm]}], 
     StyleBox["]",
      FormatType->StandardForm]}]}], 
   StyleBox[",",
    FormatType->StandardForm], "\n", 
   RowBox[{
    RowBox[{"SL25", "=", 
     RowBox[{"pe", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"perm1", ",", "perm2"}], "}"}], ",", "120"}], "]"}]}], ";", 
    "\"\<\!\(\*
StyleBox[\"Create\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Group\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"SL25\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Length\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",
FontSlant->\"Italic\"]\) \>\""}], ",", 
   RowBox[{"Length", "[", "SL25", "]"}], ",", "\n", "\"\<\\ndico = \>\"", ",",
    
   RowBox[{"dico", "[", "SL25", "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"Permutations\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "3", ",", "5", ",", "7", ",", "9", ",", "6", ",", "12", ",", 
     "14", ",", "15", ",", "17", ",", "19", ",", "8", ",", "11", ",", "4", 
     ",", "2", ",", "13", ",", "23", ",", "18", ",", "22", ",", "24", ",", 
     "21", ",", "16", ",", "20", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "4", ",", "6", ",", "8", ",", "10", ",", "11", ",", "13", ",", 
     "3", ",", "16", ",", "18", ",", "20", ",", "21", ",", "22", ",", "23", 
     ",", "5", ",", "9", ",", "19", ",", "7", ",", "1", ",", "17", ",", "24", 
     ",", "12", ",", "14", ",", "15"}], "}"}], 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"Create\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Group\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"SL25\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"=\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", "120", ",", "\<\"\\ndico = \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     SubscriptBox["2", "44"], ",", "30"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["Example 8c. Systematic Generation from permutations.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[TextData[{
 "The following routine searches permutation incantations & reports those \
giving groups without ",
 StyleBox["pe",
  FontSlant->"Italic"],
 " formulations in the database. Many of the known incantations were found \
this way, by varying the range and the number of  permutations. New results \
unlikely! The cells have been made non-evaluatable."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pn", "=", 
   RowBox[{"Permutations", "[", 
    RowBox[{"Range", "[", "5", "]"}], "]"}]}], ";", 
  RowBox[{"lp", "=", 
   RowBox[{"Length", "[", "pn", "]"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"id", "[", 
          RowBox[{"pe", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"pn", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"pn", "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{"pn", "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "}"}], "]"}], "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"gd", "[", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"3", ",", "1"}], "]"}], "]"}], "\[NotEqual]", 
             "\"\<Unrecognised\>\""}], "&&", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{
               RowBox[{"gd", "[", "]"}], "[", 
               RowBox[{"[", "3", "]"}], "]"}], "]"}], "<", "10"}]}], ",", 
           RowBox[{"Print", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"gd", "[", "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"pn", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"pn", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"pn", "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], "}"}], "]"}]}], "]"}]}], ",",
         
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"j", "+", "1"}], ",", 
          RowBox[{"lp", "-", "2"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"i", "+", "1"}], ",", 
        RowBox[{"lp", "-", "1"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2", ",", "lp"}], "}"}]}], "]"}], ";"}]], "Input",
 Evaluatable->False],

Cell[TextData[{
 "Attempts to find a ",
 StyleBox["pe",
  FontSlant->"Italic"],
 " for ",
 StyleBox["C3K",
  FontSlant->"Italic"],
 " (or other small group) are speeded up by limiting the length (final ",
 StyleBox["pe",
  FontSlant->"Italic"],
 " argument) and testing for the name:-"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pn", "=", 
   RowBox[{"Permutations", "[", 
    RowBox[{"Range", "[", "8", "]"}], "]"}]}], ";", 
  RowBox[{"lp", "=", 
   RowBox[{"Length", "[", "pn", "]"}]}], ";", " ", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"id", "[", 
      RowBox[{"pe", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"pn", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "}"}], ",", "13"}], "]"}], "]"}], 
     ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<C3K\>\"", ",", "\"\<Q12\>\""}], "}"}], ",", 
         RowBox[{
          RowBox[{"gd", "[", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"gd", "[", "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"pn", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}], ";", 
        RowBox[{"Abort", "[", "]"}]}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2", ",", "lp"}], "}"}]}], "]"}], ";"}]], "Input",
 Evaluatable->False],

Cell["No match Range[8].", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pn", "=", 
   RowBox[{"Permutations", "[", 
    RowBox[{"Range", "[", "6", "]"}], "]"}]}], ";", 
  RowBox[{"lp", "=", 
   RowBox[{"Length", "[", "pn", "]"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"id", "[", 
        RowBox[{"pe", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"pn", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"pn", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", "13"}], "]"}], 
        "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"MemberQ", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<C3K\>\"", ",", "\"\<Q12\>\"", ",", "\"\<C3C4\>\""}], 
            "}"}], ",", 
           RowBox[{
            RowBox[{"gd", "[", "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"gd", "[", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"pn", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"pn", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "}"}], "]"}], ";", 
          RowBox[{"Abort", "[", "]"}]}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"i", "+", "1"}], ",", 
        RowBox[{"lp", "-", "1"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2", ",", "lp"}], "}"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData["$Aborted"], "Output"]
}, Open  ]],

Cell["No match with Range[5]. Range[6] abandoned after 3 hrs..", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pn", "=", 
   RowBox[{"Permutations", "[", 
    RowBox[{"Range", "[", "4", "]"}], "]"}]}], ";", 
  RowBox[{"lp", "=", 
   RowBox[{"Length", "[", "pn", "]"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"id", "[", 
          RowBox[{"pe", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"pn", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"pn", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"pn", "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], "}"}], ",", "13"}], "]"}], 
          "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"\"\<C3K\>\"", ",", "\"\<Q12\>\""}], "}"}], ",", 
             RowBox[{
              RowBox[{"gd", "[", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "]"}], ",", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"gd", "[", "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", 
               RowBox[{"pn", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{"pn", "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{"pn", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "}"}], "]"}], ";", 
            RowBox[{"Abort", "[", "]"}]}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"j", "+", "1"}], ",", 
          RowBox[{"lp", "-", "2"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"i", "+", "1"}], ",", 
        RowBox[{"lp", "-", "1"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2", ",", "lp"}], "}"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData["$Aborted"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.2.6. Creating Signed Tables with ",
 StyleBox["ms & ts.",
  FontSlant->"Italic"]
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tThe database of over 800 loops includes many non-associative tables \
(octonions etc.) and \"signed-tables\". The signed tables have unsigned \
elements (as in \"C4c\", complex algebra, & \"Qr\", quaternion algebra, and \
in the tables in the following examples) but they include signed products \
such as \[ImaginaryI] \[ImaginaryI] = - 1  and j i = - k. They are not \
groups, because the signed products are not in the list of elements; however \
composing them with one of {C2,C3,C4} usually creates an (unsigned) Moufang \
loop. The definitions of loop properties have been extended to signed tables \
by defining tests that allow for signed elements.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tSome signed tables can be created from matrices, by using ",
 StyleBox["ms",
  FontSlant->"Italic"],
 ". This dot-multiplies the matrices (as in ",
 StyleBox["ma",
  FontSlant->"Italic"],
 ", Section 3.2.3), but does not add a new matrix to the element list if it \
only differs from an existing element by a sign. In Example 9, two matrices \
generate the Clifford(2) algebra [3,p10]; the generating matrices are the \
second and third in the ",
 StyleBox["matel",
  FontSlant->"Italic"],
 " list, after the unit matrix. The unit matrix and one new matrix have been \
added; all four negated matrices are present in the signed table. "
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example 9. CL2 signed table from two 2\[Times]2 matrices.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
tst=ms[{2,13}];{\"ms[{2,13}] uses two 2\[Times]2 \
matrices\",{u2[[2]]//tf,u2[[13]]//tf},\"\\nto create\",id[tst],tst//tf,\"\\n \
The matrices stored in matel are the \
elements\",{matel[[1]]//tf,matel[[2]]//tf,matel[[3]]//tf,matel[[4]]//tf}}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ms[{2,13}] uses two 2\[Times]2 matrices\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "0"},
          {"0", 
           RowBox[{"-", "1"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", "\[ImaginaryI]"},
          {"\[ImaginaryI]", "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True]}], "}"}], ",", "\<\"\\nto create\"\>", 
   ",", "\<\"CL2\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", "1", "4", "3"},
        {"3", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "1"}], "2"},
        {"4", 
         RowBox[{"-", "3"}], 
         RowBox[{"-", "2"}], "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\n The matrices stored in matel are the elements\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "0"},
          {"0", "1"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "0"},
          {"0", 
           RowBox[{"-", "1"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", "\[ImaginaryI]"},
          {"\[ImaginaryI]", "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ",", 
     TagBox[
      FormBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0", "\[ImaginaryI]"},
          {
           RowBox[{"-", "\[ImaginaryI]"}], "0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A problem with the ",
 StyleBox["ms",
  FontSlant->"Italic"],
 " procedure is the identification of the result, because only a few signed \
tables are stored and different matrix orders give different numbers of \
negated elements. Ian C.G. Bell quotes Lounesto on matrices that generate ",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalR]", 
   RowBox[{"3", ",", "1"}]]]],
 "& ",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalR]", 
   RowBox[{"4", ",", "1"}]]]],
 ". These are:-"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"u4", "[", 
     RowBox[{"[", "6", "]"}], "]"}], "//", "tf"}], ",", 
   RowBox[{
    RowBox[{"u4", "[", 
     RowBox[{"[", "4", "]"}], "]"}], "//", "tf"}], " ", ",", 
   RowBox[{
    RowBox[{"u4", "[", 
     RowBox[{"[", "7", "]"}], "]"}], "//", "tf"}], ",", 
   RowBox[{
    RowBox[{"u4", "[", 
     RowBox[{"[", "15", "]"}], "]"}], "//", "tf"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "0", "0", "0"},
        {"0", 
         RowBox[{"-", "1"}], "0", "0"},
        {"0", "0", 
         RowBox[{"-", "1"}], "0"},
        {"0", "0", "0", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0", "1", "0", "0"},
        {"1", "0", "0", "0"},
        {"0", "0", "0", "1"},
        {"0", "0", "1", "0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0", "0", "1", "0"},
        {"0", "0", "0", 
         RowBox[{"-", "1"}]},
        {"1", "0", "0", "0"},
        {"0", 
         RowBox[{"-", "1"}], "0", "0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0", "0", 
         RowBox[{"-", "1"}], "0"},
        {"0", "0", "0", "1"},
        {"1", "0", "0", "0"},
        {"0", 
         RowBox[{"-", "1"}], "0", "0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"ms", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "7", ",", "15"}], "}"}], ",", "u4"}], 
    "]"}]}], ";", 
  RowBox[{"idc", "[", "tst", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"id", "[", 
  RowBox[{"co", "[", 
   RowBox[{"tst", ",", "C2"}], "]"}], "]"}]}], "Input"],

Cell[BoxData["\<\"Unrecognised\"\>"], "Output"],

Cell[BoxData["\<\"CL31C2\"\>"], "Output"]
}, Open  ]],

Cell[TextData[{
 "An example has been scrapped because of problems with generalised sign \
matrices in Version 6\nIt generated the parent group with ",
 StyleBox["mg",
  FontSlant->"Italic"],
 ", but ",
 StyleBox["ms",
  FontSlant->"Italic"],
 " gave a shuffled signed table that is not identified. The following set \
create the table called R3 by Bell:-"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mm", "=", "32"}], ";", 
  RowBox[{"tst", "=", 
   RowBox[{"ms", "[", 
    RowBox[{"{", 
     RowBox[{"14", ",", "4", ",", "3"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", "tst", "]"}], ",", 
   RowBox[{"dico", "[", "tst", "]"}], ",", 
   RowBox[{"id", "[", 
    RowBox[{"co", "[", 
     RowBox[{"tst", ",", "C2"}], "]"}], "]"}]}], "}"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Unrecognised\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "4", ",", "22"}], "}"}], ",", "\<\"P16\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tOther signed tables can be made by folding a table that has a suitable \
symmetric structure, using the ",
 StyleBox["ts",
  FontSlant->"Italic"],
 " (toSignedTable) procedure; this creates single signed elements as \
equivalence relations on ",
 StyleBox["r",
  FontSlant->"Italic"],
 " unsigned elements. ",
 StyleBox["P16",
  FontSlant->"Italic"],
 " (shown in Example 7) splits into four 8\[Times]8 tables or into sixteen 4\
\[Times]4 tables that repeat the structure of the top left corner with \
offsets mod 8 or 4. In Example 10, ",
 StyleBox["ts",
  FontSlant->"Italic"],
 " finds the signed tables corresponding to these structures. The 8-element \
case (",
 StyleBox["r",
  FontSlant->"Italic"],
 " =2) is not in the database; the 4-element case (",
 StyleBox["r=",
  FontSlant->"Italic"],
 "4) is the algebra that I call the Pauli-\[Sigma] algebra, P4:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 10. Collapsing P16.", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman",
 FontSize->12,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"ts", "[", "P16", "]"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
   "\"\<Collapse of P16 by ts[P16,2]. \\nIs the result conservative?\>\"", 
    ",", 
    RowBox[{"conservativeQ", "[", "tst", "]"}], ",", 
    "\"\<\\nThe table is\>\"", ",", 
    RowBox[{"tst", "//", "tf"}], ",", 
    "\"\<\\nC4 Collapse of P16 by ts[P16,4] gives\>\"", ",", 
    RowBox[{
     RowBox[{"tst4", "=", 
      RowBox[{"ts", "[", 
       RowBox[{"P16", ",", "4"}], "]"}]}], ";", 
     RowBox[{"tst4", "//", "tf"}], ";", 
     RowBox[{"id", "[", "tst4", "]"}]}], ",", 
    RowBox[{"tst4", "//", "tf"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Collapse of P16 by ts[P16,2]. \\nIs the result conservative?\"\
\>", ",", "True", ",", "\<\"\\nThe table is\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8"},
        {"2", "1", 
         RowBox[{"-", "8"}], "7", "6", "5", "4", 
         RowBox[{"-", "3"}]},
        {"3", "8", "1", 
         RowBox[{"-", "6"}], "7", 
         RowBox[{"-", "4"}], "5", "2"},
        {"4", 
         RowBox[{"-", "7"}], "6", "1", "8", "3", 
         RowBox[{"-", "2"}], "5"},
        {"5", "6", "7", "8", 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "2"}], 
         RowBox[{"-", "3"}], 
         RowBox[{"-", "4"}]},
        {"6", "5", "4", 
         RowBox[{"-", "3"}], 
         RowBox[{"-", "2"}], 
         RowBox[{"-", "1"}], "8", 
         RowBox[{"-", "7"}]},
        {"7", 
         RowBox[{"-", "4"}], "5", "2", 
         RowBox[{"-", "3"}], 
         RowBox[{"-", "8"}], 
         RowBox[{"-", "1"}], "6"},
        {"8", "3", 
         RowBox[{"-", "2"}], "5", 
         RowBox[{"-", "4"}], "7", 
         RowBox[{"-", "6"}], 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nC4 Collapse of P16 by ts[P16,4] gives\"\>", 
   ",", "\<\"P4\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", "1", 
         RowBox[{
          RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}], 
         RowBox[{"3", " ", "\[ImaginaryI]"}]},
        {"3", 
         RowBox[{"4", " ", "\[ImaginaryI]"}], "1", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}]},
        {"4", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], 
         RowBox[{"2", " ", "\[ImaginaryI]"}], "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.2.7. Generalized Cayley-Dickson and Clifford Algebras, Moufang doubling.\
\>", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tExample 11 uses generalizations (",
 StyleBox["cd",
  FontSlant->"Italic"],
 " & ",
 StyleBox["cl",
  FontSlant->"Italic"],
 ") of the Cayley-Dickson [3, p285] and Clifford [3, p284] procedures to \
create the Octonion and Clifford(2,1) algebra signed tables from \"gammas\" \
or \"basisvectors\". Composing them with C2 \"expands\" or \"unfolds\" them \
to ",
 StyleBox["Oct & D4C2",
  FontSlant->"Italic"],
 " respectively. (Note that non-associative hoops such Octr and Octi cannot \
be created by the dot-multiplication of matrices and are not members of \
GL[n].) I call the generators of these tables \"monovectors\" - some authors \
confusingly call them either \"vectors\" or \"scalars\"; I contend that \
\"scalar\" should be reserved for the unit element, and \"vector\" should be \
reserved for sets of elements. Bivectors and trivectors are products of two \
or three monovectors, etc. Geometric algebras and the original ",
 StyleBox["cd",
  FontSlant->"Italic"],
 " procedure only allow monovectors that square to \[PlusMinus]1."
}], "Text",
 PageWidth->WindowWidth],

Cell[" Ex. 11. Signed table hoops from monovectors.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<cd[{-1,-1,-1}]  creates \>\"", ",", "\n", 
   RowBox[{"idc", "[", 
    RowBox[{"tst", "=", 
     RowBox[{"cd", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "}"}], "]"}]}], "]"}], ",", 
   RowBox[{"tst", "//", "tf"}], ",", "\"\<\\nIs this alternative?\>\"", ",", 
   RowBox[{"alternativeQ", "[", "tst", "]"}], ",", 
   "\"\<\\nIt expands to \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"co", "[", 
     RowBox[{"tst", ",", "C2"}], "]"}], "]"}], ",", 
   "\"\<\\n\\nclf[2,1] creates\\n\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"idc", "[", 
    RowBox[{"tst2", "=", 
     RowBox[{"clf", "[", 
      RowBox[{"2", ",", "1"}], "]"}]}], "]"}], ",", 
   RowBox[{"tst2", "//", "tf"}], ",", "\"\<\\nIs this conservative?\>\"", ",",
    
   RowBox[{"alternativeQ", "[", "tst2", "]"}], ",", 
   "\"\<\\nIt expands to \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"co", "[", 
     RowBox[{"tst2", ",", "C2"}], "]"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"cd[{-1,-1,-1}]  creates \"\>", ",", "\<\"Octr\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8"},
        {"2", 
         RowBox[{"-", "1"}], "4", 
         RowBox[{"-", "3"}], "6", 
         RowBox[{"-", "5"}], 
         RowBox[{"-", "8"}], "7"},
        {"3", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "1"}], "2", "7", "8", 
         RowBox[{"-", "5"}], 
         RowBox[{"-", "6"}]},
        {"4", "3", 
         RowBox[{"-", "2"}], 
         RowBox[{"-", "1"}], "8", 
         RowBox[{"-", "7"}], "6", 
         RowBox[{"-", "5"}]},
        {"5", 
         RowBox[{"-", "6"}], 
         RowBox[{"-", "7"}], 
         RowBox[{"-", "8"}], 
         RowBox[{"-", "1"}], "2", "3", "4"},
        {"6", "5", 
         RowBox[{"-", "8"}], "7", 
         RowBox[{"-", "2"}], 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "4"}], "3"},
        {"7", "8", "5", 
         RowBox[{"-", "6"}], 
         RowBox[{"-", "3"}], "4", 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "2"}]},
        {"8", 
         RowBox[{"-", "7"}], "6", "5", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "3"}], "2", 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nIs this alternative?\"\>", ",", "True", 
   ",", "\<\"\\nIt expands to \"\>", ",", "\<\"Oct\"\>", 
   ",", "\<\"\\n\\nclf[2,1] creates\\n\"\>", ",", "\<\"CL21\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8"},
        {"2", "1", "4", "3", "6", "5", "8", "7"},
        {"3", 
         RowBox[{"-", "4"}], "1", 
         RowBox[{"-", "2"}], "7", 
         RowBox[{"-", "8"}], "5", 
         RowBox[{"-", "6"}]},
        {"4", 
         RowBox[{"-", "3"}], "2", 
         RowBox[{"-", "1"}], "8", 
         RowBox[{"-", "7"}], "6", 
         RowBox[{"-", "5"}]},
        {"5", 
         RowBox[{"-", "6"}], 
         RowBox[{"-", "7"}], "8", 
         RowBox[{"-", "1"}], "2", "3", 
         RowBox[{"-", "4"}]},
        {"6", 
         RowBox[{"-", "5"}], 
         RowBox[{"-", "8"}], "7", 
         RowBox[{"-", "2"}], "1", "4", 
         RowBox[{"-", "3"}]},
        {"7", "8", 
         RowBox[{"-", "5"}], 
         RowBox[{"-", "6"}], 
         RowBox[{"-", "3"}], 
         RowBox[{"-", "4"}], "1", "2"},
        {"8", "7", 
         RowBox[{"-", "6"}], 
         RowBox[{"-", "5"}], 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "3"}], "2", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nIs this conservative?\"\>", ",", "True", 
   ",", "\<\"\\nIt expands to \"\>", ",", "\<\"D4C2\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe original Cayley-Dickson process corresponds to cd[{-1,-1...}] with \
each new \[Gamma] being -1. Schafer generalized this to \
\[Gamma]=\[PlusMinus]1. Using some \[Gamma]=+1 creates some new conservative \
signed tables. I generalized further, introducing a list as an optional final \
\[Gamma]; this composes the signed table with an abelian group to create a \
\"parent\" unsigned table. I also introduced some variations and some new \
starting tables in place of C2. Test 4 in ",
 StyleBox["GroupLoopTest",
  FontSlant->"Italic"],
 " listed 45 tables with ",
 StyleBox["cd",
  FontSlant->"Italic"],
 " incantations; only 4 of the many non-conservative cases have been \
included. The following is a (non-exhaustive) list of conservative signed \
tables followed by the groups from which they are 2-folded :-"
}], "Text",
 PageWidth->WindowWidth],

Cell[" Ex. 11a. Generalized Cayley-Dickson process.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<cd[{1,-1}]        creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<   which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{-1,-1.}]       creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1."}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<   which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1."}], ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<\\ncd[{-1,-1,-1}]     creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<  which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{-2,1,1}]       creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "1", ",", "1"}], "}"}], "]"}], "]"}], ",", 
   "\"\<   which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "1", ",", "1", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<\\ncd[{-2,1,-1.}]     creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "1", ",", 
       RowBox[{"-", "1."}]}], "}"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\< which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "1", ",", 
       RowBox[{"-", "1."}], ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<\\ncd[{3,-1.,-1.}]    creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1."}], ",", 
       RowBox[{"-", "1."}]}], "}"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\< which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1."}], ",", 
       RowBox[{"-", "1."}], ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<\\ncd[{3.,1,1}]       creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"3.", ",", "1", ",", "1"}], "}"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<  which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"3.", ",", "1", ",", "1", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<\\ncd[{1,-1,-1}]      creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<  which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{-2,1}]         creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "1"}], "}"}], "]"}], "]"}], ",", 
   "\"\< which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "1", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{3.,1.}]        creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"3.", ",", "1."}], "}"}], "]"}], "]"}], ",", 
   "\"\<  which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"3.", ",", "1.", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{4.,1.}]        creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"4.", ",", "1."}], "}"}], "]"}], "]"}], ",", 
   "\"\<   which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{"4.", ",", "1.", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{-1,1}]         creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}], "]"}], ",", 
   "\"\<    which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{-1,1,1}]       creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], "]"}], "]"}], ",", 
   "\"\<    which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{-1,1,1,1}]     creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1"}], "}"}], "]"}], 
    "]"}], ",", "\"\<    which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}], ",", 
   "\"\<\\ncd[{-1,1,1,1,1}]   creates \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], 
     "]"}], "]"}], ",", "\"\<   which doubles to \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", 
       RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"cd[{1,-1}]        creates \"\>", ",", "\<\"CL2\"\>", 
   ",", "\<\"   which doubles to \"\>", ",", "\<\"D4\"\>", 
   ",", "\<\"\\ncd[{-1,-1.}]       creates \"\>", ",", "\<\"Dav\"\>", 
   ",", "\<\"   which doubles to \"\>", ",", "\<\"C4C2\"\>", 
   ",", "\<\"\\ncd[{-1,-1,-1}]     creates \"\>", ",", "\<\"Octr\"\>", 
   ",", "\<\"  which doubles to \"\>", ",", "\<\"Oct\"\>", 
   ",", "\<\"\\ncd[{-2,1,1}]       creates \"\>", ",", "\<\"O4k\"\>", 
   ",", "\<\"   which doubles to \"\>", ",", "\<\"C4K\"\>", 
   ",", "\<\"\\ncd[{-2,1,-1.}]     creates \"\>", ",", "\<\"C4C4r\"\>", 
   ",", "\<\" which doubles to \"\>", ",", "\<\"C4C4\"\>", 
   ",", "\<\"\\ncd[{3,-1.,-1.}]    creates \"\>", ",", "\<\"C3Dav\"\>", 
   ",", "\<\" which doubles to \"\>", ",", "\<\"C3C4C2\"\>", 
   ",", "\<\"\\ncd[{3.,1,1}]       creates \"\>", ",", "\<\"C6Kc\"\>", 
   ",", "\<\"  which doubles to \"\>", ",", "\<\"C3KC2\"\>", 
   ",", "\<\"\\ncd[{1,-1,-1}]      creates \"\>", ",", "\<\"Octs\"\>", 
   ",", "\<\"  which doubles to \"\>", ",", "\<\"Q8M2\"\>", 
   ",", "\<\"\\ncd[{-2,1}]         creates \"\>", ",", "\<\"C3C4j\"\>", 
   ",", "\<\" which doubles to \"\>", ",", "\<\"C4C2\"\>", 
   ",", "\<\"\\ncd[{3.,1.}]        creates \"\>", ",", "\<\"KC3c\"\>", 
   ",", "\<\"  which doubles to \"\>", ",", "\<\"C3K\"\>", 
   ",", "\<\"\\ncd[{4.,1.}]        creates \"\>", ",", "\<\"KKr\"\>", 
   ",", "\<\"   which doubles to \"\>", ",", "\<\"KK\"\>", 
   ",", "\<\"\\ncd[{-1,1}]         creates \"\>", ",", "\<\"O2\"\>", 
   ",", "\<\"    which doubles to \"\>", ",", "\<\"C4C2\"\>", 
   ",", "\<\"\\ncd[{-1,1,1}]       creates \"\>", ",", "\<\"O4\"\>", 
   ",", "\<\"    which doubles to \"\>", ",", "\<\"C4K\"\>", 
   ",", "\<\"\\ncd[{-1,1,1,1}]     creates \"\>", ",", "\<\"O8\"\>", 
   ",", "\<\"    which doubles to \"\>", ",", "\<\"C4KC2\"\>", 
   ",", "\<\"\\ncd[{-1,1,1,1,1}]   creates \"\>", ",", "\<\"O16\"\>", 
   ",", "\<\"   which doubles to \"\>", ",", "\<\"g64260\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tNote that Dav, C3C4j, & O2 are all folded from C4C2 isomorphs. The O2, \
O4,...  series have 2, 4,... quadratic sizes and so describe that number of \
copies of the complex plane, with the origin as the only common point. Dav is \
an O2 isomorph.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tThe non-associative Moufang loops (Loops package, Gabor P. Nagy & Petr \
Vojtechovsky, in  www.GAP-system.org) are obtained by \"Chein doubling\" or \
by \"Moufang modification\" of non-abelian groups. M1201 (GAP name) = D3Mn \
(my name) is the smallest non-associative Moufang loop (doubled D3), but does \
not conserve its non-linear factors. Neither do M1601 (doubled D4), M1604 \
(modified from D4), nor M1605 (modified from Q8). The only other 16 element \
non-associative Moufang loops are M1602 (doubled Q8, Q8C2M, \
\"split-Octonions) & M1603 (the Octonion table); they conserve sums of 8 \
squares (with 4 negated in the M1602 case). Of the 71 32-element cases, only \
6 (M3202 = Q8C2M; M3216 = OctC2; M3221 = P16M; M3235 = C8pC2M; M3254 = KiC4M \
& M3265 = C4iC4M) are conservative. Example 11b. creates all those in the \
database, together with the group E18, which is doubled C3C3.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[" Ex. 11b. Moufang Doubling processes.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<md[D3]                  creates \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", "D3", "]"}], "]"}], ",", 
   "\"\<\\nmd[ca[8,7]]              creates \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", 
     RowBox[{"ca", "[", 
      RowBox[{"8", ",", "7"}], "]"}], "]"}], "]"}], ",", 
   "\"\<\\nmd[Q8]      creates conservative \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"md", "[", "Q8", "]"}], "]"}], ",", "\[IndentingNewLine]", 
   "\"\<\\nmd[C3C3]    creates conservative \>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"md", "[", "C3C3", "]"}], "]"}], ",", 
   "\"\<\\nmd[D4,{1,2,3,8,5,6,7,4}] creates \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", 
     RowBox[{"D4", ",", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "8", ",", "5", ",", "6", ",", "7", ",", 
        "4"}], "}"}]}], "]"}], "]"}], ",", 
   "\"\<\\nmd[Q8,{1,2,3,8,5,6,7,4}] creates \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", 
     RowBox[{"Q8", ",", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "8", ",", "5", ",", "6", ",", "7", ",", 
        "4"}], "}"}]}], "]"}], "]"}], ",", 
   "\"\<\\nmd[ca[10,9]              creates \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", 
     RowBox[{"ca", "[", 
      RowBox[{"10", ",", "9"}], "]"}], "]"}], "]"}], ",", 
   "\"\<\\nmd[D3C2]                 creates \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", "D3C2", "]"}], "]"}], ",", "\[IndentingNewLine]", 
   "\"\<\\nmd[co[Q8,C2]] creates conservative\>\"", ",", 
   RowBox[{"idc", "[", 
    RowBox[{"md", "[", 
     RowBox[{"co", "[", 
      RowBox[{"Q8", ",", "C2"}], "]"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   "\"\<\\nmd[co[P4,C4],{1,10,11,12,5,14,15,16,9,2,3,4,13,6,7,8}] \\n creates \
conservative \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", 
     RowBox[{
      RowBox[{"co", "[", 
       RowBox[{"P4", ",", "C4"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "10", ",", "11", ",", "12", ",", "5", ",", "14", ",", "15", 
        ",", "16", ",", "9", ",", "2", ",", "3", ",", "4", ",", "13", ",", 
        "6", ",", "7", ",", "8"}], "}"}]}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   "\"\<\\nmd[md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\\n \
creates conservative\>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", 
     RowBox[{
      RowBox[{"co", "[", 
       RowBox[{
        RowBox[{"ca", "[", "8", "]"}], ",", "C2", ",", "4"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "6", ",", "3", ",", "8", ",", "5", ",", "2", ",", "7", ",", 
        "4", ",", "13", ",", "14", ",", "15", ",", "16", ",", "9", ",", "10", 
        ",", "11", ",", "12"}], "}"}]}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   "\"\<\\nmd[md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\\n \
creates conservative\>\"", ",", "                         ", 
   RowBox[{"id", "[", 
    RowBox[{"md", "[", 
     RowBox[{
      RowBox[{"co", "[", 
       RowBox[{"K", ",", "C4", ",", "2"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "4", ",", "3", ",", "2", ",", "7", ",", "8", ",", "5", ",", 
        "6", ",", "9", ",", "12", ",", "11", ",", "10", ",", "15", ",", "16", 
        ",", "13", ",", "14"}], "}"}]}], "]"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"md[D3]                  creates \"\>", ",", "\<\"D3Mn\"\>", 
   ",", "\<\"\\nmd[ca[8,7]]              creates \"\>", ",", "\<\"D4M1n\"\>", 
   ",", "\<\"\\nmd[Q8]      creates conservative \"\>", ",", "\<\"Q8M2\"\>", 
   ",", "\<\"\\nmd[C3C3]    creates conservative \"\>", ",", "\<\"E18\"\>", 
   ",", "\<\"\\nmd[D4,{1,2,3,8,5,6,7,4}] creates \"\>", ",", "\<\"D4M4n\"\>", 
   ",", "\<\"\\nmd[Q8,{1,2,3,8,5,6,7,4}] creates \"\>", ",", "\<\"D4M5n\"\>", 
   ",", "\<\"\\nmd[ca[10,9]              creates \"\>", ",", "\<\"D5Mn\"\>", 
   ",", "\<\"\\nmd[D3C2]                 creates \"\>", ",", "\<\"D3C2Mn\"\>",
    ",", "\<\"\\nmd[co[Q8,C2]] creates conservative\"\>", 
   ",", "\<\"Q8C2M\"\>", 
   ",", "\<\"\\nmd[co[P4,C4],{1,10,11,12,5,14,15,16,9,2,3,4,13,6,7,8}] \\n \
creates conservative \"\>", ",", "\<\"P16M\"\>", 
   ",", "\<\"\\nmd[md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\
\\n creates conservative\"\>", ",", "\<\"C8pC2M\"\>", 
   ",", "\<\"\\nmd[md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\
\\n creates conservative\"\>", ",", "\<\"KiC4M\"\>"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3. Database rules for loop creation.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThe ",
 StyleBox["loop[[mm,nn]]",
  FontSlant->"Italic"],
 " data includes information that allows the creation of the loop ",
 StyleBox["g",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["mmnn",
  FontSlant->"Italic"],
 ", usually in several ways. The 4th entry is a prescription such as \
\"co[C3,C4,2]\" (used to create ",
 StyleBox["Q12",
  FontSlant->"Italic"],
 " in Example 6); the next two are relators and non-abelian rules such as \
{3,2,2}, {\"ba\"\[Rule] \"abc\",\"ca\"\[Rule] \"ab\"} (used to create A4 in \
Example 8). Entries 7, 8, & 9  are lists pointing to 2\[Times]2, 3\[Times]3, \
& 4\[Times]4 matrices that generate the loop via ",
 StyleBox["ma",
  FontSlant->"Italic"],
 " or the signed table via ",
 StyleBox["ms ",
  FontSlant->"Italic"],
 "(where such generating matrix sets are known to the author). Example 13 \
first gives ",
 StyleBox["gd[\"P16\"] ",
  FontSlant->"Italic"],
 "and then demonstrates the different creation processes for ",
 StyleBox["P16",
  FontSlant->"Italic"],
 ". Entry 7 is {2,3,4} because the Pauli-\[Sigma] matrices (as used in \
Example 7) are stored as ",
 StyleBox["u2[[2]], u2[[3]], u2[[4]]",
  FontSlant->"Italic"],
 ".  Entry 9 is {1,7,16} because the Dirac-\[Gamma] matrices are stored as ",
 StyleBox["u4[[2]], u4[[7]], u4[[16]]",
  FontSlant->"Italic"],
 ". 34 entries have permutation incantations (including ",
 StyleBox["A4, A5, S4, S5, P72, SL23, SL25, g2003, g3609",
  FontSlant->"Italic"],
 "). In a few cases (including ",
 StyleBox["P16 & A5",
  FontSlant->"Italic"],
 ") extra entries provide additional prescriptions. Thus ",
 StyleBox["makeProtoloop[\"P16\",o]",
  FontSlant->"Italic"],
 " creates ",
 StyleBox["P16",
  FontSlant->"Italic"],
 " in six different ways:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 13. Loop generation rules demonstrated.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[{
 "{\"P16 Data\",gd[\"P16\"],\n\"\\n\\nEffect of makeProtoloop[16,13,o] or mp[\
\\\"P16\\\",o] etc.",
 StyleBox["\\n",
  FontSlant->"Italic"],
 "o=0 uses co[P4,C4] to create       \",id[co[P4,C4]],\n\"\\no=1 uses \
ge[{2,2,2,2},{dd\[Rule]c,ba\[Rule]abc}] to create\",\nid[ge[{2,2,2,2},{dd\
\[Rule]c,ba\[Rule]abc}]],\n\"\\no=2 uses mg[{2,3,4},u2] to create  \
\",id[mg[{2,3,4},u2]],\n\"\\no=4 uses mg[{1,7,16},u4] to create \
\",id[mg[{1,7,16},u4]],\n\"\\no=5 uses co[Q8,C2,4] to create     \
\",id[co[Q8,C2,4]],\n\"\\no=6 uses co[clf[3],C2] to create   \
\",id[co[clf[3],C2]]}"
}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"P16 Data\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"16", ",", "13", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"P16\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "8"}], "}"}], ",", "0", ",", "\<\"co[P4,C4]\"\>", 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\<\"dd\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
         RowBox[{"\<\"ba\"\>", "\[Rule]", "\<\"abc\"\>"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "7", ",", "16"}], "}"}], ",", "\<\"co[Q8,C2,4]\"\>",
        ",", "\<\"co[cl[3],C2]\"\>"}], "}"}]}], "}"}], 
   ",", "\<\"\\n\\nEffect of makeProtoloop[16,13,o] or mp[\\\"P16\\\",o] etc.\
\\no=0 uses co[P4,C4] to create       \"\>", ",", "\<\"P16\"\>", 
   ",", "\<\"\\no=1 uses ge[{2,2,2,2},{dd\[Rule]c,ba\[Rule]abc}] to \
create\"\>", ",", "\<\"P16\"\>", 
   ",", "\<\"\\no=2 uses mg[{2,3,4},u2] to create  \"\>", ",", "\<\"P16\"\>", 
   ",", "\<\"\\no=4 uses mg[{1,7,16},u4] to create \"\>", ",", "\<\"P16\"\>", 
   ",", "\<\"\\no=5 uses co[Q8,C2,4] to create     \"\>", ",", "\<\"P16\"\>", 
   ",", "\<\"\\no=6 uses co[clf[3],C2] to create   \"\>", 
   ",", "\<\"P16\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tExample 14 tabulates abbreviated data entries for 43 of the smallest \
non-abelian groups (",
 StyleBox["mg",
  FontSlant->"Italic"],
 " & ",
 StyleBox["ms",
  FontSlant->"Italic"],
 " rules are omitted). The non-abelian rules are in compressed form, \"a4b\" \
being equivalent to \"aaaab\". The fastest prescription is usually supplied, \
",
 StyleBox["ca[mm,o]",
  FontSlant->"Italic"],
 " being preferred to \"",
 StyleBox["co[g,h,o]",
  FontSlant->"Italic"],
 "\". Note that prescriptions have not been found for \"A4\", \
\"g2003\",\"SL23\", \"P27\", and \"g2704\"; their prescription entries are ",
 StyleBox["ca[]",
  FontSlant->"Italic"],
 ". Every group appears to have generators (called \"relators\" here and in \
GAP) whose powers multiply to give the group size; John Conway assures me \
(private communication) that this is likely. The GAP system can provide a \
(not necessarily minimal) set of relators; this is demonstrated later (in \
Example 22)."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 14. Small non-abelian groups.", "Text",
 PageWidth->WindowWidth,
 Evaluatable->False,
 FontWeight->"Bold"],

Cell[BoxData[
 FormBox[GridBox[{
    {"\"\<Name\>\"", "\"\<Length\>\"", "\"\<GAP\>\"", "\"\<Prescription\>\"", 
     "\"\<Gens\>\"", "\"\<non-Abelian\>\""},
    {"\"\<D3\>\"", "6", "1", "\"\<ca[6,5]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}]},
    {"\"\<D4\>\"", "8", "3", "\"\<ca[8,7]\>\"", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}]},
    {"\"\<Q8\>\"", "8", "4", "\"\<ca[8,3]\>\"", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}]},
    {"\"\<D5\>\"", "10", "1", "\"\<ca[10,9]\>\"", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}]},
    {"\"\<Q12\>\"", "12", "1", "\"\<co[C3,C4,2]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}]},
    {"\"\<A4\>\"", "12", "3", "\"\<ca[]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
       RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}]},
    {"\"\<D3C2\>\"", "12", "4", "\"\<co[C3,K,2]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}]},
    {"\"\<D7\>\"", "14", "2", "\"\<ca[14,13]\>\"", 
     RowBox[{"{", 
      RowBox[{"7", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a6b\>\""}], "}"}]},
    {"\"\<KiC4\>\"", "16", "3", "\"\<co[K,C4,2]\>\"", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}]},
    {"\"\<C4iC4\>\"", "16", "4", "\"\<co[C4,C4,2]\>\"", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}]},
    {"\"\<C8pC2\>\"", "16", "6", "\"\<co[ca[8],C2,4]\>\"", 
     RowBox[{"{", 
      RowBox[{"8", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}]},
    {"\"\<D8\>\"", "16", "7", "\"\<ca[16,15]\>\"", 
     RowBox[{"{", 
      RowBox[{"8", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a7b\>\""}], "}"}]},
    {"\"\<Q8iC2\>\"", "16", "8", "\"\<co[Q8,C2,2]\>\"", 
     RowBox[{"{", 
      RowBox[{"8", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}]},
    {"\"\<Q16\>\"", "16", "9", "\"\<ca[16,7]\>\"", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
       RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}]},
    {"\"\<D4C2\>\"", "16", "11", "\"\<co[D4,C2]\>\"", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}]},
    {"\"\<Q8C2\>\"", "16", "12", "\"\<co[Q8,C2]\>\"", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}]},
    {"\"\<P16\>\"", "16", "13", "\"\<co[P4,C4]\>\"", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}]},
    {"\"\<D9\>\"", "18", "1", "\"\<ca[18,17]\>\"", 
     RowBox[{"{", 
      RowBox[{"9", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a8b\>\""}], "}"}]},
    {"\"\<D3C3\>\"", "18", "3", "\"\<co[D3,C3]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}]},
    {"\"\<E18\>\"", "18", "4", "\"\<co[C3,ca[6,5],2]\>\"", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "3"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abb\>\""}], ",", 
       RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<acc\>\""}]}], "}"}]},
    {"\"\<Q20\>\"", "20", "1", "\"\<ca[20,9]\>\"", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}]},
    {"\"\<g2003\>\"", "20", "3", "\"\<ca[]\>\"", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}]},
    {"\"\<D10\>\"", "20", "4", "\"\<ca[20,19]\>\"", 
     RowBox[{"{", 
      RowBox[{"10", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a9b\>\""}], "}"}]},
    {"\"\<g2101\>\"", "21", "1", "\"\<co[ca[7],C3,7]\>\"", 
     RowBox[{"{", 
      RowBox[{"7", ",", "3"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}]},
    {"\"\<D11\>\"", "22", "1", "\"\<ca[22,21]\>\"", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a10b\>\""}], "}"}]},
    {"\"\<C3iC8\>\"", "24", "1", "\"\<co[C3,C8,2]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}]},
    {"\"\<SL23\>\"", "24", "3", "\"\<ca[]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
       RowBox[{"\"\<cc\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abcd\>\""}], ",", 
       RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<abd\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<cb\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}]},
    {"\"\<Q24\>\"", "24", "4", "\"\<ca[24,11]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], ",", 
       RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<dd\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<bcd\>\""}]}], "}"}]},
    {"\"\<D3C4\>\"", "24", "5", "\"\<co[D3,C4]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "4"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a2b\>\""}], "}"}]},
    {"\"\<D12\>\"", "24", "6", "\"\<ca[24,23]\>\"", 
     RowBox[{"{", 
      RowBox[{"12", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a11b\>\""}], "}"}]},
    {"\"\<Q12C2\>\"", "24", "7", "\"\<co[ca[12,5],C2]\>\"", 
     RowBox[{"{", 
      RowBox[{"6", ",", "4"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}]},
    {"\"\<C3iC4iC2\>\"", "24", "8", "\"\<co[C3,C4,C2,2,2]\>\"", 
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5bc\>\""}], "}"}]},
    {"\"\<D4C3\>\"", "24", "10", "\"\<co[D4,C3]\>\"", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "3"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a3b\>\""}], "}"}]},
    {"\"\<Q8C3\>\"", "24", "11", "\"\<co[Q8,C3]\>\"", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2", ",", "3"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<aa\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"\"\<bb\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}]}], "}"}]},
    {"\"\<S4\>\"", "24", "12", "\"\<sgroup[4]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
       RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<da\>\"", "\[Rule]", "\"\<a2d\>\""}], ",", 
       RowBox[{"\"\<db\>\"", "\[Rule]", "\"\<cd\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<dc\>\"", "\[Rule]", "\"\<bd\>\""}]}], "}"}]},
    {"\"\<A4C2\>\"", "24", "13", "\"\<co[A4a,C2]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], ",", 
       RowBox[{"\"\<ca\>\"", "\[Rule]", "\"\<ab\>\""}]}], "}"}]},
    {"\"\<D6C2\>\"", "24", "14", "\"\<co[ca[12,11],C2]\>\"", 
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a5b\>\""}], "}"}]},
    {"\"\<D13\>\"", "26", "1", "\"\<ca[26,25]\>\"", 
     RowBox[{"{", 
      RowBox[{"13", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a12b\>\""}], "}"}]},
    {"\"\<P27\>\"", "27", "3", "\"\<ca[]\>\"", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<abc\>\""}], "}"}]},
    {"\"\<g2704\>\"", "27", "4", "\"\<ca[]\>\"", 
     RowBox[{"{", 
      RowBox[{"9", ",", "3"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a4b\>\""}], "}"}]},
    {"\"\<Q28\>\"", "28", "1", "\"\<ca[28,13]\>\"", 
     RowBox[{"{", 
      RowBox[{"7", ",", "4"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a6b\>\""}], "}"}]},
    {"\"\<D14\>\"", "28", "3", "\"\<ca[28,27]\>\"", 
     RowBox[{"{", 
      RowBox[{"14", ",", "2"}], "}"}], 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "\[Rule]", "\"\<a13b\>\""}], "}"}]}
   }], TraditionalForm]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False,
 FontSize->9]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Moufang Loops, Conserved \"sizes\" and \"shapes\".", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". Moufang loops have invertible multiplication, so vector division and \
multiplication are one operation; associative (and a few non-associative) \
Moufang loops \"conserve\" functions (\"sizes\") related to the determinant \
of the inverse symbolic table. Most loops lack this \"Frobenius property\". \
The division and conservation properties are fundamental requirements for \
mathematical physics. Sizes are generalized norms for which the triangle \
inequality becomes an equality. Non-linear sizes are symmetric polynomials; \
compact expression have been found for many, often as sums of powers or \
products of simpler polynomials that I call \"fragments\"."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["4.1. Moufang Loops, Division. ", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tMoufang loops are \"loops with units & division\", i.e. quasigroup \
multiplication tables with the indices in order in the first row and column \
(left & right units) and with ",
 StyleBox["zx.yz=(z.xy)z",
  FontSlant->"Italic"],
 " for all ",
 StyleBox["xyz",
  FontSlant->"Italic"],
 ". (There are other, related, Moufang properties. [2, p93]) They are groups \
if the multiplication is associative. Every finite group (and every Octonion) \
can be expressed as a Moufang loop index table (often in many isomorphic \
forms). A specific isomorph or \"protoloop\" (chosen because it demonstrates \
the structure of the loop and its similarities with other loops) is defined \
for every loop in my database. It is a convenient definition of the loop as \
an index table; ",
 StyleBox["shape & toPol",
  FontSlant->"Italic"],
 " (etc.) definitions employ it."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tExample 15 uses ",
 StyleBox["makeProtoloop[\"Qr\"] ",
  FontSlant->"Italic"],
 "to create a copy (called ",
 StyleBox["qr",
  FontSlant->"Italic"],
 " here) of the Quaternion algebra signed multiplication table. This is shown \
both as a signed table and in the usual form with the univectors ",
 StyleBox["i",
  FontSlant->"Italic"],
 " & ",
 StyleBox["j",
  FontSlant->"Italic"],
 " (i.e. the Cayley-Dickson generators [3, p285] that are fourth roots of \
unity). Tests then shows that the table is non-abelian but has the \
associative and extended moufangQ properties. (The strict MoufangQ test fails \
because at least one product changes sign.)"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 15. Quaternion algebra tables & properties.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"qr", "=", 
   RowBox[{"makeProtoloop", "[", "\"\<Qr\>\"", "]"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
   "\"\<Quaternion Index Table & Univector multiplication table\>\"", ",", 
    RowBox[{"qr", "//", "tf"}], ",", 
    RowBox[{
     RowBox[{"gmap", "[", 
      RowBox[{"qr", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "i", ",", "j", ",", 
         RowBox[{"i", "\[VeryThinSpace]", "j"}]}], "}"}]}], "]"}], "//", 
     "tf"}], ",", "\"\<\\nAbelian    \>\"", ",", 
    RowBox[{"abelianQ", "[", "qr", "]"}], ",", "\"\<\\nAssociative\>\"", ",", 
    
    RowBox[{"associativeQ", "[", "qr", "]"}], ",", "\"\<\\nmoufang    \>\"", 
    ",", 
    RowBox[{"moufangQ", "[", "qr", "]"}], ",", "\"\<\\nMoufang    \>\"", " ", 
    ",", 
    RowBox[{"MoufangQ", "[", "qr", "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Quaternion Index Table & Univector multiplication table\"\>", 
   ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", 
         RowBox[{"-", "1"}], "4", 
         RowBox[{"-", "3"}]},
        {"3", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "1"}], "2"},
        {"4", "3", 
         RowBox[{"-", "2"}], 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "i", "j", 
         RowBox[{"i", " ", "j"}]},
        {"i", 
         RowBox[{"-", "1"}], 
         RowBox[{"i", " ", "j"}], 
         RowBox[{"-", "j"}]},
        {"j", 
         RowBox[{
          RowBox[{"-", "i"}], " ", "j"}], 
         RowBox[{"-", "1"}], "i"},
        {
         RowBox[{"i", " ", "j"}], "j", 
         RowBox[{"-", "i"}], 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nAbelian    \"\>", ",", "False", 
   ",", "\<\"\\nAssociative\"\>", ",", "True", ",", "\<\"\\nmoufang    \"\>", 
   ",", "True", ",", "\<\"\\nMoufang    \"\>", ",", "False"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?MoufangQ", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 StyleBox["\<\"MoufangQ tests if zx.yz=(z.xy)z, the 3rd Moufang Identity. See \
PMA p92. As this fails for many conservative signed tables such as Qr, \
unsigned tests can be performed by moufangQ.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellTags->"Info3426325327-2735175"]
}, Open  ]],

Cell[TextData[{
 "\tThe Moufang division property means that multiplicative inverses exist \
for vectors (and not just for table elements). I do noy know of a proof for \
this empirical discovery. The unit of a loop multiplication is the vec \
{1,0,...}, and so the inverse of a vec such as {a,b,...} can be found (for \
small loops) by solving for the vec {p,q,...} that gives the unit as a \
product, {p,q,...}{a,b,...} = {1,0,...}. This defines a left inverse iff the \
loop is conservative. (A right inverse could be found similarly; abelian \
tables give a single inverse.)  The table determinant is a denominator for \
each element of the inverse, as Cramer's method has been used in its \
calculation. Each numerator is a derivation, so division and differentiation \
are linked.\n\tExample 16 finds left inverses for ",
 StyleBox["C4",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Qr, CL2, P4, Dav",
  FontSlant->"Italic"],
 " [7], & C9j & C9J (which are both \"\[DoubleStruckCapitalJ]-signed\"), \
finding the expressions for ",
 StyleBox["p,q",
  FontSlant->"Italic"],
 ", etc. The",
 StyleBox[" C4",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Dav",
  FontSlant->"Italic"],
 " inverses are shown to split into partial fractions, because their \
determinants factorise. "
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 16. Solving for Multiplicative Inverses.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
(*16a C4*)
C4inv=Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"C4\"]=={1,0,0,0},{p,q,r,s}]
Apart[{p,q,r,s}/.C4inv]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"2", " ", "a", " ", "b", " ", "d"}], "-", 
         RowBox[{"c", " ", 
          SuperscriptBox["d", "2"]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "4"], "-", 
         SuperscriptBox["b", "4"], "+", 
         RowBox[{"4", " ", "a", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         SuperscriptBox["c", "4"], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "2"], " ", "b", " ", "d"}], "-", 
         RowBox[{"4", " ", "b", " ", 
          SuperscriptBox["c", "2"], " ", "d"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"4", " ", "a", " ", "c", " ", 
          SuperscriptBox["d", "2"]}], "-", 
         SuperscriptBox["d", "4"]}], ")"}]}]}]}], ",", 
    RowBox[{"q", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
         RowBox[{"b", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "d"}], "+", 
         RowBox[{"2", " ", "a", " ", "c", " ", "d"}], "-", 
         SuperscriptBox["d", "3"]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], "+", 
         SuperscriptBox["b", "4"], "-", 
         RowBox[{"4", " ", "a", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["c", "4"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "2"], " ", "b", " ", "d"}], "+", 
         RowBox[{"4", " ", "b", " ", 
          SuperscriptBox["c", "2"], " ", "d"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["d", "2"]}], "-", 
         RowBox[{"4", " ", "a", " ", "c", " ", 
          SuperscriptBox["d", "2"]}], "+", 
         SuperscriptBox["d", "4"]}], ")"}]}]}]}], ",", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "c"}], "+", 
         SuperscriptBox["c", "3"], "-", 
         RowBox[{"2", " ", "b", " ", "c", " ", "d"}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["d", "2"]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], "+", 
         SuperscriptBox["b", "4"], "-", 
         RowBox[{"4", " ", "a", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["c", "4"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "2"], " ", "b", " ", "d"}], "+", 
         RowBox[{"4", " ", "b", " ", 
          SuperscriptBox["c", "2"], " ", "d"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["d", "2"]}], "-", 
         RowBox[{"4", " ", "a", " ", "c", " ", 
          SuperscriptBox["d", "2"]}], "+", 
         SuperscriptBox["d", "4"]}], ")"}]}]}]}], ",", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["b", "3"]}], "+", 
         RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "d"}], "-", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", "d"}], "+", 
         RowBox[{"b", " ", 
          SuperscriptBox["d", "2"]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], "+", 
         SuperscriptBox["b", "4"], "-", 
         RowBox[{"4", " ", "a", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["c", "4"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "2"], " ", "b", " ", "d"}], "+", 
         RowBox[{"4", " ", "b", " ", 
          SuperscriptBox["c", "2"], " ", "d"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["d", "2"]}], "-", 
         RowBox[{"4", " ", "a", " ", "c", " ", 
          SuperscriptBox["d", "2"]}], "+", 
         SuperscriptBox["d", "4"]}], ")"}]}]}]}]}], "}"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "-", "c", "+", "d"}], ")"}]}]]}], "+",
      
     FractionBox["1", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"a", "-", "c"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]]}], ",", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "-", "c", "+", "d"}], ")"}]}]], "+", 
     FractionBox["1", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "b"}], "+", "d"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]]}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "-", "c", "+", "d"}], ")"}]}]]}], "+",
      
     FractionBox["1", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "a"}], "+", "c"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]]}], ",", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "-", "c", "+", "d"}], ")"}]}]], "+", 
     FractionBox["1", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"b", "-", "d"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]]}]}], "}"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16b Quaternion*)
Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"Qr\"]=={1,0,0,0},{p,q,r,s}]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     FractionBox["a", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}]]}], ",", 
    RowBox[{"q", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["b", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["d", "2"]}]]}]}], ",", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["c", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["d", "2"]}]]}]}], ",", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["d", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["d", "2"]}]]}]}]}], "}"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16c Clifford(2)*)
Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"CL2\"]=={1,0,0,0},{p,q,r,s}]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     FractionBox["a", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["d", "2"]}]]}], ",", 
    RowBox[{"q", "\[Rule]", 
     FractionBox["b", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}]]}], ",", 
    RowBox[{"r", "\[Rule]", 
     FractionBox["c", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}]]}], ",", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["d", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "-", 
        SuperscriptBox["d", "2"]}]]}]}]}], "}"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16d Pauli-\[Sigma]*)
Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"P4\"]=={1,0,0,0},{p,q,r,s}]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     FractionBox["a", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["d", "2"]}]]}], ",", 
    RowBox[{"q", "\[Rule]", 
     FractionBox["b", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}]]}], ",", 
    RowBox[{"r", "\[Rule]", 
     FractionBox["c", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}]]}], ",", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["d", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"], "-", 
        SuperscriptBox["d", "2"]}]]}]}]}], "}"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16e Davenport Algebra*)
Davinv=Solve[hoopTimes[{p,q,r,s},{a,b,c,d},\"Dav\"]=={1,0,0,0},{p,q,r,s}]
Apart[{p,q,r,s}/.Davinv]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         RowBox[{"2", " ", "b", " ", "c", " ", "d"}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["d", "2"]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         SuperscriptBox["b", "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         SuperscriptBox["c", "4"], "+", 
         RowBox[{"8", " ", "a", " ", "b", " ", "c", " ", "d"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         SuperscriptBox["d", "4"]}], ")"}]}]}]}], ",", 
    RowBox[{"q", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b"}], "+", 
         SuperscriptBox["b", "3"], "-", 
         RowBox[{"b", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"2", " ", "a", " ", "c", " ", "d"}], "+", 
         RowBox[{"b", " ", 
          SuperscriptBox["d", "2"]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         SuperscriptBox["b", "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         SuperscriptBox["c", "4"], "+", 
         RowBox[{"8", " ", "a", " ", "b", " ", "c", " ", "d"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         SuperscriptBox["d", "4"]}], ")"}]}]}]}], ",", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", "c"}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         SuperscriptBox["c", "3"], "+", 
         RowBox[{"2", " ", "a", " ", "b", " ", "d"}], "+", 
         RowBox[{"c", " ", 
          SuperscriptBox["d", "2"]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         SuperscriptBox["b", "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         SuperscriptBox["c", "4"], "+", 
         RowBox[{"8", " ", "a", " ", "b", " ", "c", " ", "d"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         SuperscriptBox["d", "4"]}], ")"}]}]}]}], ",", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "a", " ", "b", " ", "c"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "d"}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "d"}], "-", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", "d"}], "-", 
         SuperscriptBox["d", "3"]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         SuperscriptBox["b", "4"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         SuperscriptBox["c", "4"], "+", 
         RowBox[{"8", " ", "a", " ", "b", " ", "c", " ", "d"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox["d", "2"]}], "+", 
         SuperscriptBox["d", "4"]}], ")"}]}]}]}]}], "}"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"a", "-", "d"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"a", "+", "d"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "+", 
         RowBox[{"2", " ", "a", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]]}], ",", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "b"}], "-", "c"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "b"}], "+", "c"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "+", 
         RowBox[{"2", " ", "a", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]]}], ",", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "b"}], "-", "c"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"b", "-", "c"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "+", 
         RowBox[{"2", " ", "a", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]]}], ",", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "a"}], "+", "d"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"a", "+", "d"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "+", 
         RowBox[{"2", " ", "a", " ", "d"}], "+", 
         SuperscriptBox["d", "2"]}], ")"}]}]]}]}], "}"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16f C9j*)
C9jinv=Solve[(hoopTimes[{p,q,r},{a,b,c},\"C9j\"]/.\[DoubleStruckCapitalJ]^3 \
\[Rule] 1)=={1,0,0},{p,q,r}]/.\[DoubleStruckCapitalJ]^3 \[Rule] 1\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}], ",", 
    RowBox[{"q", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["c", "2"], " ", "\[DoubleStruckCapitalJ]"}]}], 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}], ",", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}]}], "}"}], 
  "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(*16g C9J*)
C9Jinv=Solve[(hoopTimes[{p,q,r},{a,b,c},\"C9J\"]/.\[DoubleStruckCapitalJ]^3 \
\[Rule] 1)=={1,0,0},{p,q,r}]/.\[DoubleStruckCapitalJ]^3 \[Rule] 1\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}]}], 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
        RowBox[{
        "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
        "+", 
        RowBox[{
         SuperscriptBox["c", "3"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}], ",", 
    RowBox[{"q", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["c", "2"], " ", "\[DoubleStruckCapitalJ]"}]}], 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
        RowBox[{
        "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
        "+", 
        RowBox[{
         SuperscriptBox["c", "3"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}], ",", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
        RowBox[{
        "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
        "+", 
        RowBox[{
         SuperscriptBox["c", "3"], " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}]}], "}"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe procedure ",
 StyleBox["hoopIn",
  FontSlant->"Italic"],
 StyleBox["verse",
  FontSlant->"Italic"],
 " calculates the inverse of a vec in a conservative algebra. It is discussed \
in detail in Section 6.3, but is demonstrated in Example 17. The ",
 StyleBox["Qr",
  FontSlant->"Italic"],
 " inverse Ai of an arbitrary vec A={4.,1.,2.,3} is calculated, and Ai\
\[CenterDot]A is shown to be {1,0,0,0}. Then A is multiplied by B={5., 2., \
1., 7.}, giving AB= {-5., 24., 13., 40.}. Finally, AB is divided by A (by \
pre-multiplying by Ai), and B is recovered."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 17. Multiplicative Inverse, Division.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{id[\"Qr\"];\"A is\",A={4.,1.,2.,3},\"\\nQuaternion Inverse of A \
is\",Ai=hoopInverse[A],\"\\nAi\[CenterDot]A is the \
unit\",Chop[hoopTimes[Ai,A]],\"\\nB is            \",B={5.,2.,1.,7.},\"\\nAB \
is           \",AB=hoopTimes[A,B],\"\\nAi\[CenterDot]AB recovers \
B\",hoopTimes[Ai,AB]}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", "1.`", ",", "2.`", ",", "3"}], "}"}], 
   ",", "\<\"\\nQuaternion Inverse of A is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0.13333333333333333`", ",", 
     RowBox[{"-", "0.03333333333333333`"}], ",", 
     RowBox[{"-", "0.06666666666666667`"}], ",", 
     RowBox[{"-", "0.1`"}]}], "}"}], 
   ",", "\<\"\\nAi\[CenterDot]A is the unit\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", "\<\"\\nB is            \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"5.`", ",", "2.`", ",", "1.`", ",", "7.`"}], "}"}], 
   ",", "\<\"\\nAB is           \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.`"}], ",", "24.`", ",", "13.`", ",", "40.`"}], "}"}], 
   ",", "\<\"\\nAi\[CenterDot]AB recovers B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"5.`", ",", "2.`", ",", "0.9999999999999996`", ",", "7.`"}], 
    "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tHoops are central to mathematical physics because of their conservation and \
division properties.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2. Size Conservation.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tIf the multiplication table is a loop, the determinant has at least two \
factors. (It is a quasigroup with each element occuring once in each row and \
column. Add all the other rows to the first row; the sum of elements is then \
seen to be a determinant factor.) This is not true for signed tables; some \
factors (including the sum of the elements) are destroyed when a Moufang loop \
is folded to a signed table.\n\tMoufang Loop inverses split into partial \
fractions with their factors as denominators (Example 16a). A few small \
signed tables have a single factor or one repeated factor (Examples 16 b-d); \
most have a number of different factors (Example 16 e). I call the symbolic \
protoloop factors \"sizes\", and the list of sizes the \"shape\" of a loop or \
hoop. Section 4.3 goes into more detail of sizes & shapes. The \
complex-conjugate factor-pairs of quadratic factors are not conserved. \
(Though some Clifford algebras have factors that are repeated four times, and \
have complex conserved factors.)\n\tI first inverted signed tables involving \
\[ImaginaryI] or \[DoubleStruckCapitalJ] (Example 16f) in September 2003 and \
found that sizes are actually \"generalized conjugates\" of the signed \
determinant factors. This is related to Frobenius's discovery (Section 4.4) \
that it is the determinant of the ",
 StyleBox["inverted",
  FontSlant->"Italic"],
 " associative table that is conserved. As the factors are identical where \
negation is the only sign, many sizes can be found from the direct table.\n\t\
Conservative hoops conserve all their \"sizes\" on multiplication - they are \
defined by that property. They also (trivially) conserve linear sizes on \
addition and splitting. Example 18 demonstrates conservation for two \
6-element groups by adding and multiplying two symbolic vecs. The linear size \
of the sum is subtracted from the linear sizes of the summands, giving {0,0} \
to show that it is conserved on addition. Then all the sizes of the product \
are shown to match the product of the multiplicand sizes."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 18. Conservation of C3C2 & D3 Sizes", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"a4", "=."}], ";", 
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6"}], 
    "}"}]}], ";", 
  RowBox[{"B", "=", 
   RowBox[{"{", 
    RowBox[{"b1", ",", "b2", ",", "b3", ",", "b4", ",", "b5", ",", "b6"}], 
    "}"}]}], ";", 
  RowBox[{"{", 
   RowBox[{"\"\<Set Target Loop to\>\"", ",", 
    RowBox[{"id", "[", "\"\<C3C2\>\"", "]"}], ",", 
    RowBox[{"C3C2", "//", "tf"}], ",", "\"\<\\nSet  A =\>\"", ",", 
    RowBox[{"A", "=", 
     RowBox[{"{", 
      RowBox[{"a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6"}], 
      "}"}]}], ",", "\"\<\\nSet  B =\>\"", ",", 
    RowBox[{"B", "=", 
     RowBox[{"{", 
      RowBox[{"b1", ",", "b2", ",", "b3", ",", "b4", ",", "b5", ",", "b6"}], 
      "}"}]}], ",", "\"\<\\nThen AB=\>\"", ",", 
    RowBox[{"AB", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"A", ",", "B"}], "]"}]}], ",", 
    StyleBox["\"\<\\nShape of A is  \>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sa", "=", 
      RowBox[{"shape", "[", "A", "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nShape of B is  \>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sb", "=", 
      RowBox[{"shape", "[", "B", "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nShape of A+B is \>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sapb", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"shape", "[", 
        RowBox[{"A", "+", "B"}], "]"}], "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\n'+' conserves linear factors\>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sapb", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"sa", "+", "sb", "-", "sapb"}], ",", "2"}], "]"}], "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nShape of AB is \>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sab", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"shape", "[", "AB", "]"}], "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nProduct of shapes A & B = shape of product AB\>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"sa", " ", "sb"}], "==", "sab"}], "]"}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], "\[IndentingNewLine]", 
    "\"\<\\n\\nChange Target Loop to\>\"", ",", 
    RowBox[{"id", "[", "\"\<D3\>\"", "]"}], ",", 
    RowBox[{"D3", "//", "tf"}], ",", "\"\<\\nAB=\>\"", ",", 
    RowBox[{"AB", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"A", ",", "B"}], "]"}]}], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nShape of A is  \>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sa", "=", 
      RowBox[{"shape", "[", "A", "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nShape of B is  \>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sb", "=", 
      RowBox[{"shape", "[", "B", "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nShape of A+B is \>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sapb", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"shape", "[", 
        RowBox[{"A", "+", "B"}], "]"}], "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\n'+' conserves linear factors\>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sapb", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"sa", "+", "sb", "-", "sapb"}], ",", "2"}], "]"}], "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nShape of AB is \>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"sab", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"shape", "[", "AB", "]"}], "]"}]}],
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox["\"\<\\nProduct of shapes A & B = shape of product AB\>\"",
     FontSlant->"Plain"], 
    StyleBox[",",
     FontSlant->"Plain"], 
    StyleBox[
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"sa", " ", "sb"}], "==", "sab"}], "]"}],
     FontSlant->"Plain"]}], 
   StyleBox["}",
    FontSlant->"Plain"]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Set Target Loop to\"\>", ",", "\<\"C3C2\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6"},
        {"2", "3", "1", "5", "6", "4"},
        {"3", "1", "2", "6", "4", "5"},
        {"4", "5", "6", "1", "2", "3"},
        {"5", "6", "4", "2", "3", "1"},
        {"6", "4", "5", "3", "1", "2"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nSet  A =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6"}], 
    "}"}], ",", "\<\"\\nSet  B =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"b1", ",", "b2", ",", "b3", ",", "b4", ",", "b5", ",", "b6"}], 
    "}"}], ",", "\<\"\\nThen AB=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a1", " ", "b1"}], "+", 
      RowBox[{"a3", " ", "b2"}], "+", 
      RowBox[{"a2", " ", "b3"}], "+", 
      RowBox[{"a4", " ", "b4"}], "+", 
      RowBox[{"a6", " ", "b5"}], "+", 
      RowBox[{"a5", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a2", " ", "b1"}], "+", 
      RowBox[{"a1", " ", "b2"}], "+", 
      RowBox[{"a3", " ", "b3"}], "+", 
      RowBox[{"a5", " ", "b4"}], "+", 
      RowBox[{"a4", " ", "b5"}], "+", 
      RowBox[{"a6", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a3", " ", "b1"}], "+", 
      RowBox[{"a2", " ", "b2"}], "+", 
      RowBox[{"a1", " ", "b3"}], "+", 
      RowBox[{"a6", " ", "b4"}], "+", 
      RowBox[{"a5", " ", "b5"}], "+", 
      RowBox[{"a4", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a4", " ", "b1"}], "+", 
      RowBox[{"a6", " ", "b2"}], "+", 
      RowBox[{"a5", " ", "b3"}], "+", 
      RowBox[{"a1", " ", "b4"}], "+", 
      RowBox[{"a3", " ", "b5"}], "+", 
      RowBox[{"a2", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a5", " ", "b1"}], "+", 
      RowBox[{"a4", " ", "b2"}], "+", 
      RowBox[{"a6", " ", "b3"}], "+", 
      RowBox[{"a2", " ", "b4"}], "+", 
      RowBox[{"a1", " ", "b5"}], "+", 
      RowBox[{"a3", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a6", " ", "b1"}], "+", 
      RowBox[{"a5", " ", "b2"}], "+", 
      RowBox[{"a4", " ", "b3"}], "+", 
      RowBox[{"a3", " ", "b4"}], "+", 
      RowBox[{"a2", " ", "b5"}], "+", 
      RowBox[{"a1", " ", "b6"}]}]}], "}"}], ",", "\<\"\\nShape of A is  \"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "+", "a2", "+", "a3", "+", "a4", "+", "a5", "+", "a6"}], 
     ",", 
     RowBox[{"a1", "+", "a2", "+", "a3", "-", "a4", "-", "a5", "-", "a6"}], 
     ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a1", "-", "a2", "+", "a4", "-", "a5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a1", "-", "a3", "+", "a4", "-", "a6"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a2", "-", "a3", "+", "a5", "-", "a6"}], ")"}], "2"]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a1", "-", "a2", "-", "a4", "+", "a5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a1", "-", "a3", "-", "a4", "+", "a6"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a2", "-", "a3", "-", "a5", "+", "a6"}], ")"}], "2"]}], 
       ")"}]}]}], "}"}], ",", "\<\"\\nShape of B is  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b1", "+", "b2", "+", "b3", "+", "b4", "+", "b5", "+", "b6"}], 
     ",", 
     RowBox[{"b1", "+", "b2", "+", "b3", "-", "b4", "-", "b5", "-", "b6"}], 
     ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b1", "-", "b2", "+", "b4", "-", "b5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b1", "-", "b3", "+", "b4", "-", "b6"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b2", "-", "b3", "+", "b5", "-", "b6"}], ")"}], "2"]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b1", "-", "b2", "-", "b4", "+", "b5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b1", "-", "b3", "-", "b4", "+", "b6"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b2", "-", "b3", "-", "b5", "+", "b6"}], ")"}], "2"]}], 
       ")"}]}]}], "}"}], ",", "\<\"\\nShape of A+B is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a1", "+", "a2", "+", "a3", "+", "a4", "+", "a5", "+", "a6", "+", "b1", 
      "+", "b2", "+", "b3", "+", "b4", "+", "b5", "+", "b6"}], ",", 
     RowBox[{
     "a1", "+", "a2", "+", "a3", "-", "a4", "-", "a5", "-", "a6", "+", "b1", 
      "+", "b2", "+", "b3", "-", "b4", "-", "b5", "-", "b6"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "a1", "-", "a2", "+", "a4", "-", "a5", "+", "b1", "-", "b2", "+", 
           "b4", "-", "b5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "a1", "-", "a3", "+", "a4", "-", "a6", "+", "b1", "-", "b3", "+", 
           "b4", "-", "b6"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "a2", "-", "a3", "+", "a5", "-", "a6", "+", "b2", "-", "b3", "+", 
           "b5", "-", "b6"}], ")"}], "2"]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "a1", "-", "a2", "-", "a4", "+", "a5", "+", "b1", "-", "b2", "-", 
           "b4", "+", "b5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "a1", "-", "a3", "-", "a4", "+", "a6", "+", "b1", "-", "b3", "-", 
           "b4", "+", "b6"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
          "a2", "-", "a3", "-", "a5", "+", "a6", "+", "b2", "-", "b3", "-", 
           "b5", "+", "b6"}], ")"}], "2"]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\n'+' conserves linear factors\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "\<\"\\nShape of AB is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a1", "+", "a2", "+", "a3", "+", "a4", "+", "a5", "+", "a6"}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b1", "+", "b2", "+", "b3", "+", "b4", "+", "b5", "+", "b6"}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a1", "+", "a2", "+", "a3", "-", "a4", "-", "a5", "-", "a6"}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b1", "+", "b2", "+", "b3", "-", "b4", "-", "b5", "-", "b6"}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "+", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"], "-", 
        RowBox[{"a3", " ", "a4"}], "+", 
        SuperscriptBox["a4", "2"], "-", 
        RowBox[{"a3", " ", "a5"}], "-", 
        RowBox[{"a4", " ", "a5"}], "+", 
        SuperscriptBox["a5", "2"], "+", 
        RowBox[{"2", " ", "a3", " ", "a6"}], "-", 
        RowBox[{"a4", " ", "a6"}], "-", 
        RowBox[{"a5", " ", "a6"}], "+", 
        SuperscriptBox["a6", "2"], "-", 
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{"a3", "+", "a4", "-", 
           RowBox[{"2", " ", "a5"}], "+", "a6"}], ")"}]}], "-", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"a2", "+", "a3", "-", 
           RowBox[{"2", " ", "a4"}], "+", "a5", "+", "a6"}], ")"}]}]}], ")"}],
       " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b1", "2"], "+", 
        SuperscriptBox["b2", "2"], "+", 
        SuperscriptBox["b3", "2"], "-", 
        RowBox[{"b3", " ", "b4"}], "+", 
        SuperscriptBox["b4", "2"], "-", 
        RowBox[{"b3", " ", "b5"}], "-", 
        RowBox[{"b4", " ", "b5"}], "+", 
        SuperscriptBox["b5", "2"], "+", 
        RowBox[{"2", " ", "b3", " ", "b6"}], "-", 
        RowBox[{"b4", " ", "b6"}], "-", 
        RowBox[{"b5", " ", "b6"}], "+", 
        SuperscriptBox["b6", "2"], "-", 
        RowBox[{"b2", " ", 
         RowBox[{"(", 
          RowBox[{"b3", "+", "b4", "-", 
           RowBox[{"2", " ", "b5"}], "+", "b6"}], ")"}]}], "-", 
        RowBox[{"b1", " ", 
         RowBox[{"(", 
          RowBox[{"b2", "+", "b3", "-", 
           RowBox[{"2", " ", "b4"}], "+", "b5", "+", "b6"}], ")"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "+", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"], "+", 
        RowBox[{"a3", " ", "a4"}], "+", 
        SuperscriptBox["a4", "2"], "+", 
        RowBox[{"a3", " ", "a5"}], "-", 
        RowBox[{"a4", " ", "a5"}], "+", 
        SuperscriptBox["a5", "2"], "-", 
        RowBox[{"2", " ", "a3", " ", "a6"}], "-", 
        RowBox[{"a4", " ", "a6"}], "-", 
        RowBox[{"a5", " ", "a6"}], "+", 
        SuperscriptBox["a6", "2"], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a3"}], "+", "a4", "-", 
           RowBox[{"2", " ", "a5"}], "+", "a6"}], ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a2"}], "-", "a3", "-", 
           RowBox[{"2", " ", "a4"}], "+", "a5", "+", "a6"}], ")"}]}]}], ")"}],
       " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b1", "2"], "+", 
        SuperscriptBox["b2", "2"], "+", 
        SuperscriptBox["b3", "2"], "+", 
        RowBox[{"b3", " ", "b4"}], "+", 
        SuperscriptBox["b4", "2"], "+", 
        RowBox[{"b3", " ", "b5"}], "-", 
        RowBox[{"b4", " ", "b5"}], "+", 
        SuperscriptBox["b5", "2"], "-", 
        RowBox[{"2", " ", "b3", " ", "b6"}], "-", 
        RowBox[{"b4", " ", "b6"}], "-", 
        RowBox[{"b5", " ", "b6"}], "+", 
        SuperscriptBox["b6", "2"], "+", 
        RowBox[{"b2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "b3"}], "+", "b4", "-", 
           RowBox[{"2", " ", "b5"}], "+", "b6"}], ")"}]}], "+", 
        RowBox[{"b1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "b2"}], "-", "b3", "-", 
           RowBox[{"2", " ", "b4"}], "+", "b5", "+", "b6"}], ")"}]}]}], 
       ")"}]}]}], "}"}], 
   ",", "\<\"\\nProduct of shapes A & B = shape of product AB\"\>", ",", 
   "True", ",", "\<\"\\n\\nChange Target Loop to\"\>", ",", "\<\"D3\"\>", ",",
    
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6"},
        {"2", "1", "6", "5", "4", "3"},
        {"3", "4", "5", "6", "1", "2"},
        {"4", "3", "2", "1", "6", "5"},
        {"5", "6", "1", "2", "3", "4"},
        {"6", "5", "4", "3", "2", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nAB=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a1", " ", "b1"}], "+", 
      RowBox[{"a2", " ", "b2"}], "+", 
      RowBox[{"a5", " ", "b3"}], "+", 
      RowBox[{"a4", " ", "b4"}], "+", 
      RowBox[{"a3", " ", "b5"}], "+", 
      RowBox[{"a6", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a2", " ", "b1"}], "+", 
      RowBox[{"a1", " ", "b2"}], "+", 
      RowBox[{"a4", " ", "b3"}], "+", 
      RowBox[{"a5", " ", "b4"}], "+", 
      RowBox[{"a6", " ", "b5"}], "+", 
      RowBox[{"a3", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a3", " ", "b1"}], "+", 
      RowBox[{"a4", " ", "b2"}], "+", 
      RowBox[{"a1", " ", "b3"}], "+", 
      RowBox[{"a6", " ", "b4"}], "+", 
      RowBox[{"a5", " ", "b5"}], "+", 
      RowBox[{"a2", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a4", " ", "b1"}], "+", 
      RowBox[{"a3", " ", "b2"}], "+", 
      RowBox[{"a6", " ", "b3"}], "+", 
      RowBox[{"a1", " ", "b4"}], "+", 
      RowBox[{"a2", " ", "b5"}], "+", 
      RowBox[{"a5", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a5", " ", "b1"}], "+", 
      RowBox[{"a6", " ", "b2"}], "+", 
      RowBox[{"a3", " ", "b3"}], "+", 
      RowBox[{"a2", " ", "b4"}], "+", 
      RowBox[{"a1", " ", "b5"}], "+", 
      RowBox[{"a4", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a6", " ", "b1"}], "+", 
      RowBox[{"a5", " ", "b2"}], "+", 
      RowBox[{"a2", " ", "b3"}], "+", 
      RowBox[{"a3", " ", "b4"}], "+", 
      RowBox[{"a4", " ", "b5"}], "+", 
      RowBox[{"a1", " ", "b6"}]}]}], "}"}], ",", "\<\"\\nShape of A is  \"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "+", "a2", "+", "a3", "+", "a4", "+", "a5", "+", "a6"}], 
     ",", 
     RowBox[{"a1", "-", "a2", "+", "a3", "-", "a4", "+", "a5", "-", "a6"}], 
     ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a1", "-", "a3"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a2", "-", "a4"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a3", "-", "a5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a1"}], "+", "a5"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a4", "-", "a6"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a2"}], "+", "a6"}], ")"}], "2"]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nShape of B is  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b1", "+", "b2", "+", "b3", "+", "b4", "+", "b5", "+", "b6"}], 
     ",", 
     RowBox[{"b1", "-", "b2", "+", "b3", "-", "b4", "+", "b5", "-", "b6"}], 
     ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b1", "-", "b3"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b2", "-", "b4"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b3", "-", "b5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "b1"}], "+", "b5"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b4", "-", "b6"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "b2"}], "+", "b6"}], ")"}], "2"]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nShape of A+B is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a1", "+", "a2", "+", "a3", "+", "a4", "+", "a5", "+", "a6", "+", "b1", 
      "+", "b2", "+", "b3", "+", "b4", "+", "b5", "+", "b6"}], ",", 
     RowBox[{
     "a1", "-", "a2", "+", "a3", "-", "a4", "+", "a5", "-", "a6", "+", "b1", 
      "-", "b2", "+", "b3", "-", "b4", "+", "b5", "-", "b6"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a1", "-", "a3", "+", "b1", "-", "b3"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a2", "-", "a4", "+", "b2", "-", "b4"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a1", "-", "a5", "+", "b1", "-", "b5"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a3", "-", "a5", "+", "b3", "-", "b5"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a2", "-", "a6", "+", "b2", "-", "b6"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a4", "-", "a6", "+", "b4", "-", "b6"}], ")"}], "2"]}], 
       ")"}]}]}], "}"}], ",", "\<\"\\n'+' conserves linear factors\"\>", ",", 
   
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "\<\"\\nShape of AB is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a1", "+", "a2", "+", "a3", "+", "a4", "+", "a5", "+", "a6"}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b1", "+", "b2", "+", "b3", "+", "b4", "+", "b5", "+", "b6"}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a1", "-", "a2", "+", "a3", "-", "a4", "+", "a5", "-", "a6"}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b1", "-", "b2", "+", "b3", "-", "b4", "+", "b5", "-", "b6"}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "-", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"], "-", 
        SuperscriptBox["a4", "2"], "-", 
        RowBox[{"a3", " ", "a5"}], "+", 
        SuperscriptBox["a5", "2"], "-", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"a3", "+", "a5"}], ")"}]}], "+", 
        RowBox[{"a4", " ", "a6"}], "-", 
        SuperscriptBox["a6", "2"], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{"a4", "+", "a6"}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b1", "2"], "-", 
        SuperscriptBox["b2", "2"], "+", 
        SuperscriptBox["b3", "2"], "-", 
        SuperscriptBox["b4", "2"], "-", 
        RowBox[{"b3", " ", "b5"}], "+", 
        SuperscriptBox["b5", "2"], "-", 
        RowBox[{"b1", " ", 
         RowBox[{"(", 
          RowBox[{"b3", "+", "b5"}], ")"}]}], "+", 
        RowBox[{"b4", " ", "b6"}], "-", 
        SuperscriptBox["b6", "2"], "+", 
        RowBox[{"b2", " ", 
         RowBox[{"(", 
          RowBox[{"b4", "+", "b6"}], ")"}]}]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nProduct of shapes A & B = shape of product AB\"\>", ",", 
   "True"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tSizes are a generalization of metrics and norms. The triangle inequality \
becomes exact, but sizes may be negative for non-abelian hoops, and may be \
linear, quadratic, cubic (rare), quartic etc. A4 is the smallest group with a \
conserved volume (cubic size); quartic sizes are very common (and some \
factorise over Gaussian Integers).\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.3. Algebras, Determinant Factors, \"",
 StyleBox["sizes",
  FontSlant->"Italic"],
 "\" & \"",
 StyleBox["shapes",
  FontSlant->"Italic"],
 "\"."
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tWhilst general algebras allow very general entries (structure constants) \
in each cell of the Cayley multiplication table, many algebras of physical \
significance have single entries in each cell. The most relevant of these are \
related to Moufang Loops, and in particular to those tables that have \"",
 StyleBox["Frobenius-conservation",
  FontSlant->"Italic"],
 "\" for functions related to the factors of the multiplication table \
determinant. (I conjectured this to be a consequence of the Moufang \
properties until finding many exceptions amongst the non-associative Moufang \
loops in [8].) This is discussed and demonstrated in the next section, after \
introducing the determinant and its factors."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe database is restricted to tables with single elements in each cell; \
the elements are indices (or signed indices), and so vecs can be mapped \
(using ",
 StyleBox["gmap",
  FontSlant->"Italic"],
 ") onto the table by putting the signed i'th component of the vec wherever \
the index \"i\" appears in the protoloop."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tLoop determinants can be calculated after mapping symbolic or numeric vec \
elements onto the index table. Frobenius [4] showed that the group property, \
associativity, was a sufficient condition for the determinant of a product to \
be the product of the multiplicand determinants (up to a minus sign). \
Octonions, a few other nonassociative Moufang loops, and many signed tables \
share this property with groups. I use it as the defining property for hoop \
algebras.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tConservative loops are found to conserve (up to a sign) the real factors of \
the determinant on multiplication - complex linear factors obtained by \
splitting quadratic factors into complex-conjugate pairs are not generally \
conserved. Real linear factors are trivially conserved on addition. I call \
each determinant factor a \"size\", and the list of sizes the \"shape\" of a \
vec in a particular algebra. Each size is a group \"ideal\". It is also a \
symmetric polynomial related to a table eigenvector.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\t\tFrobenius worked with the inverse of the group table, whilst I usually \
work with the table itself. This is significant for signed tables, where the \
conserved properties appear to be \"plex-conjugates\" of the determinant \
factors of the non-inverted table (Section 6.3). If the table is unsigned, or \
only involves \"-\", the group table and the inverse table have the same \
factors, and sizes have been found from the group table determinant; \
conjugation does not alter them. With signed tables involving \[ImaginaryI] \
or \[DoubleStruckCapitalJ], etc, (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], TraditionalForm]]],
 "=1, see Section 5.1) the group table factors have to be modified in a way \
that is not yet fully understood; several such signed tables have been found \
to conserve their modified shapes. Appendix D goes into more detail."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tAs computer-mathematics systems such as ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are needed in all but the smallest cases, ",
 StyleBox["GroupLoopHoop6.nb ",
  FontSlant->"Italic"],
 "provides procedures to factorize table determinants, and to find compact \
expressions for these factors. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can only factorise full symbolic tables up to 10\[Times]10 on my PC, and a \
number of techniques have been developed for larger tables (Appendix D). The \
shapes of many small loops have been found and are included in the database; \
the largest are for 32-element loops."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tMany non-linear sizes can be expressed in compact forms as the sums of \
smaller polynomials (which I call \"fragments\"). These are often sums of \
squares.  Some progress (Appendix D2)",
 StyleBox[" ",
  FontSlant->"Italic"],
 "has been made with the automatic calculation of these compact forms by the \
heuristic procedure ",
 StyleBox["frag",
  FontSlant->"Italic"],
 ".\n(Technical note. Negation is undefined for loops, but \"-\" always \
occurs in determinants as the \"symmetric differences\" of numbers. Squaring \
a symmetric difference gives a positive result; conservation \"up to a sign\" \
copes with negation in linear terms.)"
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4. Loop Determinant Factor Conservation, Hoops.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tExample 19 multiplies two symbolic 4-vecs A & B using ",
 StyleBox["Qr ",
  FontSlant->"Italic"],
 "as the multiplication rule; this sets ",
 StyleBox["glo",
  FontSlant->"Italic"],
 " (the \"target\" loop) to ",
 StyleBox["Qr ",
  FontSlant->"Italic"],
 "so that it can be omitted from later instructions. (",
 StyleBox["hoopShape[\"Qr\"] ",
  FontSlant->"Italic"],
 " could be used to set the target loop.)",
 " The shape (the list of factors of the determinant) is available in the \
database, and so the shapes of A, B, & AB can be found. It is shown that the \
product of the sizes of A & B equals the sizes of the product AB. This is \
\"size conservation on multiplication\", the defining property for a hoop \
algebra."
}], "Text",
 PageWidth->WindowWidth],

Cell[" Example 19. Conservation of sizes.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<Symbolic shape for\>\"", ",", 
   RowBox[{
    RowBox[{"a4", "=."}], ";", 
    RowBox[{"qr", "=", 
     RowBox[{"id", "[", "\"\<Qr\>\"", "]"}]}]}], ",", 
   RowBox[{"sh", "[", "\"\<Qr\>\"", "]"}], ",", 
   "\"\<\\nThe table is stored as \!\(\*
StyleBox[\"glo\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{"glo", "//", "tf"}], ",", "\"\<\\nA=\>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{"a1", ",", "a2", ",", "a3", ",", "a4"}], "}"}]}], ",", 
   "\"\<B=\>\"", ",", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{"b1", ",", "b2", ",", "b3", ",", "b4"}], "}"}]}], ",", 
   "\"\<\\n\!\(\*
StyleBox[\"AB\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B", ",", "qr"}], "]"}]}], ",", "\"\<\\n\!\(\*
StyleBox[\"Shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",
FontSlant->\"Italic\"]\)\>\"", 
   StyleBox[",",
    FontSlant->"Italic"], 
   RowBox[{"sa", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], 
   StyleBox[",",
    FontSlant->"Italic"], "\"\<\\n\!\(\*
StyleBox[\"Shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"B\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",
FontSlant->\"Italic\"]\)\>\"", 
   StyleBox[",",
    FontSlant->"Italic"], 
   RowBox[{"sb", "=", 
    RowBox[{"shape", "[", "B", "]"}]}], 
   StyleBox[",",
    FontSlant->"Italic"], "\"\<\\n\!\(\*
StyleBox[\"Shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"AB\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",
FontSlant->\"Italic\"]\)\>\"", 
   StyleBox[",",
    FontSlant->"Italic"], 
   RowBox[{"sab", "=", 
    RowBox[{"shape", "[", "AB", "]"}]}], 
   StyleBox[",",
    FontSlant->"Italic"], "\"\<\\n\!\(\*
StyleBox[\"Product\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shapes\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"&\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"B\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"equals\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"AB\",
FontSlant->\"Italic\"]\)\>\"", 
   StyleBox[",",
    FontSlant->"Italic"], 
   StyleBox[" ",
    FontSlant->"Italic"], 
   RowBox[{
    StyleBox["Simplify",
     FontSlant->"Plain"], 
    StyleBox["[",
     FontSlant->"Plain"], 
    RowBox[{
     RowBox[{"sa", " ", "sb"}], " ", "==", "sab"}], 
    StyleBox["]",
     FontSlant->"Italic"]}]}], 
  StyleBox["}",
   FontSlant->"Plain"]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Symbolic shape for\"\>", ",", "\<\"Qr\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"]}], "}"}], 
   ",", "\<\"\\nThe table is stored as \
\\!\\(\\*\\nStyleBox[\\\"glo\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"=\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", 
         RowBox[{"-", "1"}], "4", 
         RowBox[{"-", "3"}]},
        {"3", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "1"}], "2"},
        {"4", "3", 
         RowBox[{"-", "2"}], 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nA=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "a3", ",", "a4"}], "}"}], ",", "\<\"B=\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"b1", ",", "b2", ",", "b3", ",", "b4"}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"AB\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a1", " ", "b1"}], "-", 
      RowBox[{"a2", " ", "b2"}], "-", 
      RowBox[{"a3", " ", "b3"}], "-", 
      RowBox[{"a4", " ", "b4"}]}], ",", 
     RowBox[{
      RowBox[{"a2", " ", "b1"}], "+", 
      RowBox[{"a1", " ", "b2"}], "-", 
      RowBox[{"a4", " ", "b3"}], "+", 
      RowBox[{"a3", " ", "b4"}]}], ",", 
     RowBox[{
      RowBox[{"a3", " ", "b1"}], "+", 
      RowBox[{"a4", " ", "b2"}], "+", 
      RowBox[{"a1", " ", "b3"}], "-", 
      RowBox[{"a2", " ", "b4"}]}], ",", 
     RowBox[{
      RowBox[{"a4", " ", "b1"}], "-", 
      RowBox[{"a3", " ", "b2"}], "+", 
      RowBox[{"a2", " ", "b3"}], "+", 
      RowBox[{"a1", " ", "b4"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"is\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a1", "2"], "+", 
     SuperscriptBox["a2", "2"], "+", 
     SuperscriptBox["a3", "2"], "+", 
     SuperscriptBox["a4", "2"]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"B\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"is\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["b1", "2"], "+", 
     SuperscriptBox["b2", "2"], "+", 
     SuperscriptBox["b3", "2"], "+", 
     SuperscriptBox["b4", "2"]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"AB\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"is\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a4", " ", "b1"}], "-", 
        RowBox[{"a3", " ", "b2"}], "+", 
        RowBox[{"a2", " ", "b3"}], "+", 
        RowBox[{"a1", " ", "b4"}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a3", " ", "b1"}], "+", 
        RowBox[{"a4", " ", "b2"}], "+", 
        RowBox[{"a1", " ", "b3"}], "-", 
        RowBox[{"a2", " ", "b4"}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a2", " ", "b1"}], "+", 
        RowBox[{"a1", " ", "b2"}], "-", 
        RowBox[{"a4", " ", "b3"}], "+", 
        RowBox[{"a3", " ", "b4"}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "b1"}], "-", 
        RowBox[{"a2", " ", "b2"}], "-", 
        RowBox[{"a3", " ", "b3"}], "-", 
        RowBox[{"a4", " ", "b4"}]}], ")"}], "2"]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Product\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\
\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"shapes\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"A\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"&\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"B\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"equals\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"AB\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tWhilst Frobenius showed that all groups conserve their determinants, this \
property is also possessed by the larger class that I call \"Hoops\" (because \
they are shape-conserving loops or rings). Octonions [3, pp97,303] and a few \
other non-associative Moufang Loops are included; they (and their direct \
compositions with abelian groups) appear to be the only \"alternative\" \
(square-associative, xx.y=x.xy but xy.z\[NotEqual]x.yz) tables that are \
conservative. The database contains many conservative tables. Most loops \
(even if they have a unit) are non-conservative but only a few such \
(identified by mnemonics ending in ",
 StyleBox["n",
  FontSlant->"Italic"],
 ") are included in the database. The table ",
 StyleBox["C6n ",
  FontSlant->"Italic"],
 "is tested in Example 20; it also has a shape, with two linear and two \
quadratic sizes, in the databank. Simplifying the product of the shapes minus \
the shape of the product gives {0,0, two long expressions}, showing that the \
last two sizes are NOT conserved. ",
 StyleBox["C6n",
  FontSlant->"Italic"],
 " is not a division algebra; the result of Ai= hoopInverse[ A,\"C6n\"] is \
NOT an inverse; neither is the solution to Ai\[CenterDot]A={1,0,0,0,0,0}."
}], "Text",
 PageWidth->WindowWidth],

Cell[" Example 20. Non-conservation of sizes with C6n.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[{
 "{\"",
 StyleBox["Target Loop is",
  FontSlant->"Italic"],
 "\",tst=C6n;id[tst],tst//tf,\"\\nMoufang \
Property\",MoufangQ[tst],A={a1,a2,a3,a4,a5,a6};B={b1,b2,b3,b4,b5,b6};\"\\nAB=\
\",AB=",
 "hoopTi",
 "mes[A,B],sa=shape[A];sb=shape[B];\"\\nShape[AB]-Shape[A]*Shape[B]\",sab=\
Simplify[shape[AB]-sa sb]}"
}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Target Loop is\"\>", ",", "\<\"C6n\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6"},
        {"2", "3", "1", "6", "4", "5"},
        {"3", "1", "2", "5", "6", "4"},
        {"4", "5", "6", "2", "1", "3"},
        {"5", "6", "4", "1", "3", "2"},
        {"6", "4", "5", "3", "2", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nMoufang Property\"\>", ",", "False", 
   ",", "\<\"\\nAB=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a1", " ", "b1"}], "+", 
      RowBox[{"a3", " ", "b2"}], "+", 
      RowBox[{"a2", " ", "b3"}], "+", 
      RowBox[{"a5", " ", "b4"}], "+", 
      RowBox[{"a4", " ", "b5"}], "+", 
      RowBox[{"a6", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a2", " ", "b1"}], "+", 
      RowBox[{"a1", " ", "b2"}], "+", 
      RowBox[{"a3", " ", "b3"}], "+", 
      RowBox[{"a4", " ", "b4"}], "+", 
      RowBox[{"a6", " ", "b5"}], "+", 
      RowBox[{"a5", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a3", " ", "b1"}], "+", 
      RowBox[{"a2", " ", "b2"}], "+", 
      RowBox[{"a1", " ", "b3"}], "+", 
      RowBox[{"a6", " ", "b4"}], "+", 
      RowBox[{"a5", " ", "b5"}], "+", 
      RowBox[{"a4", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a4", " ", "b1"}], "+", 
      RowBox[{"a6", " ", "b2"}], "+", 
      RowBox[{"a5", " ", "b3"}], "+", 
      RowBox[{"a1", " ", "b4"}], "+", 
      RowBox[{"a2", " ", "b5"}], "+", 
      RowBox[{"a3", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a5", " ", "b1"}], "+", 
      RowBox[{"a4", " ", "b2"}], "+", 
      RowBox[{"a6", " ", "b3"}], "+", 
      RowBox[{"a3", " ", "b4"}], "+", 
      RowBox[{"a1", " ", "b5"}], "+", 
      RowBox[{"a2", " ", "b6"}]}], ",", 
     RowBox[{
      RowBox[{"a6", " ", "b1"}], "+", 
      RowBox[{"a5", " ", "b2"}], "+", 
      RowBox[{"a4", " ", "b3"}], "+", 
      RowBox[{"a2", " ", "b4"}], "+", 
      RowBox[{"a3", " ", "b5"}], "+", 
      RowBox[{"a1", " ", "b6"}]}]}], "}"}], 
   ",", "\<\"\\nShape[AB]-Shape[A]*Shape[B]\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "a4"}], " ", "b1"}], "+", 
           RowBox[{"a6", " ", "b1"}], "+", 
           RowBox[{"a5", " ", "b2"}], "-", 
           RowBox[{"a6", " ", "b2"}], "+", 
           RowBox[{"a4", " ", "b3"}], "-", 
           RowBox[{"a5", " ", "b3"}]}], ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "a5"}], " ", "b1"}], "+", 
           RowBox[{"a4", " ", 
            RowBox[{"(", 
             RowBox[{"b1", "-", "b2"}], ")"}]}], "+", 
           RowBox[{"a6", " ", "b2"}], "+", 
           RowBox[{"a5", " ", "b3"}], "-", 
           RowBox[{"a6", " ", "b3"}]}], ")"}]}], "+", 
        RowBox[{"a3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a5", " ", "b1"}], "-", 
           RowBox[{"a6", " ", "b1"}], "+", 
           RowBox[{"a4", " ", "b2"}], "-", 
           RowBox[{"a5", " ", "b2"}], "-", 
           RowBox[{"a4", " ", "b3"}], "+", 
           RowBox[{"a6", " ", "b3"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b4", "-", "b5"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a5", " ", 
            RowBox[{"(", 
             RowBox[{"b1", "+", "b2", "-", 
              RowBox[{"2", " ", "b3"}]}], ")"}]}], "+", 
           RowBox[{"a6", " ", 
            RowBox[{"(", 
             RowBox[{"b1", "-", 
              RowBox[{"2", " ", "b2"}], "+", "b3"}], ")"}]}], "+", 
           RowBox[{"a4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "b1"}], "+", "b2", "+", "b3"}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a6", " ", 
            RowBox[{"(", 
             RowBox[{"b1", "+", "b2", "-", 
              RowBox[{"2", " ", "b3"}]}], ")"}]}], "+", 
           RowBox[{"a4", " ", 
            RowBox[{"(", 
             RowBox[{"b1", "-", 
              RowBox[{"2", " ", "b2"}], "+", "b3"}], ")"}]}], "+", 
           RowBox[{"a5", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "b1"}], "+", "b2", "+", "b3"}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a4", " ", 
            RowBox[{"(", 
             RowBox[{"b1", "+", "b2", "-", 
              RowBox[{"2", " ", "b3"}]}], ")"}]}], "+", 
           RowBox[{"a5", " ", 
            RowBox[{"(", 
             RowBox[{"b1", "-", 
              RowBox[{"2", " ", "b2"}], "+", "b3"}], ")"}]}], "+", 
           RowBox[{"a6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "b1"}], "+", "b2", "+", "b3"}], 
             ")"}]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b4", "+", "b5", "-", 
        RowBox[{"2", " ", "b6"}]}], ")"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThe database contains the direct compositions of Oct with C2, C3, C4, K, \
C5, & Oct (all conservative), the same indirect compositions and the \
composition with C5n (none conservative). Several alternative tables are also \
included apart from these; apart from Q8M2, Q8pC2M, P16M, C8pC2M and C4iC4M \
they lack the Frobenius property.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tNoether's laws show that the particles and forces of physics are related to \
symmetries and conserved properties; and Stephen Adler argues that division \
algebras are needed to describe physics. Consequently these algebras should \
be relevant to particle physics. \
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Generalized Signs.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Summary. ",
 StyleBox["Roots of unity are generalized signs, which I write as \
\[DoubleStruckS] : ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["\[DoubleStruckS]",
     FontSlant->"Italic"], "r"], TraditionalForm]]],
 StyleBox["=1; I propose a set of double struck characters for specific \
generalized signs. \"-\" is one of the square roots, and \"\[ImaginaryI]\" is \
one of the fourth roots, of unity. Many algebras employ several different \
square roots, cube roots, etc. Algebraic expressions involving \"-\" & \"\
\[ImaginaryI]\" are special cases of more general expressions involving \
generalized signs; e.g ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     StyleBox["\[DoubleStruckS]",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], "\[Theta]"}]], TraditionalForm]]],
 StyleBox[" defines multi-phase sinusoids with r phases (",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], TraditionalForm]]],
 StyleBox[" defines a 4-phase sinusoid that folds to Cos[\[Theta]]+\
\[ImaginaryI] Sin[\[Theta]]); ordinary negation is an equivalence relation on \
indexed pairs of numbers and generalizes to rotations of indexed sets. \
Geometric Algebra introduces \"pseudovectors\" that provide non-commutative \
analogues of \[ImaginaryI].",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["5.1. Roots of Unity provide Generalized Signs.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThe \"ordinary signs\" are \"+\" & \"-\"; the latter is a square root of \
+1 (or \"unity\"). The imaginary numbers \"\[ImaginaryI]\" & \"-\[ImaginaryI]\
\" also behave as signs; they are fourth roots of +1. As many algebras have \
more than one entity that squares to unity, \"-\" is ambiguous, and so it is \
misleading to call \[ImaginaryI] \"the\" square root of -1. \n\tGeneralized \
signs are distinct primitive roots of unity. There are \"terplex\" algebras \
using \[DoubleStruckCapitalJ], with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], TraditionalForm]]],
 "=1; \"Study numbers\" have two entities that square to unity; Quaternions \
have three entities (i, j, ij in Example 15) that are fourth roots of unity.\n\
\tExample 21 shows my proposed standard nomenclature for ",
 "generalized",
 " signs, with ",
 Cell[BoxData["\[DoubleStruckS]"]],
 " : ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[DoubleStruckS]", 
    StyleBox["\[DoubleStruckR]",
     FontSlant->"Italic"]], "\[Rule]", "1"}]]],
 " as a general case, the  \[DoubleStruckR]'th root of unity. Example 21 also \
shows the substitution rules that make \[DoubleStruckD], \[DoubleStruckG], \
\[DoubleStruckH], \[DoubleStruckCapitalI], \[DoubleStruckCapitalJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM], \[DoubleStruckN], \
\[DoubleStruckO], \[DoubleStruckS], \[DoubleStruckP] & \
\[DoubleStruckCapitalY] into generalized signs akin to \[ImaginaryI]. Various \
properties have to be specified; these are shown for \[DoubleStruckCapitalJ].\
\n\tWhilst roots of unity are commonly called \"cyclotomic roots of unity\", \
because they can be projected onto the unit circle in the complex plane, as \
generalized signs they are independent orthogonal mathematical entities. \
Expressing them as complex numbers puts them on a Procrustean bed and \
conceals their orthogonality. Generalised signs (and their powers, until \
reaching unity) act as orthogonal directions, and several distinct \
\[DoubleStruckR]'th roots occur in many algebras - impossibilities for \
\"cyclotomic roots of unity\". In general, these signs are not converted to \
complex cyclotomic numbers; the properties shown in Example 21 are sufficient \
to define them. Section 5.5 is an exception; it is convenient to use the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " procedures for the standard Cos, Sin, etc functions there."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 21. Generalized Signs.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<Proposed nomenclature for \!\(\*
StyleBox[\"Generalized\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Signs\",
FontSlant->\"Italic\"]\) \>\"", ",", "unitSigns", ",", 
   "\"\<\\nVarious properties are imposed to ensure correct behaviour \
e.g.:-\\nNumber \[DoubleStruckCapitalJ] =\>\"", ",", 
   RowBox[{"NumberQ", "[", "\[DoubleStruckCapitalJ]", "]"}], ",", 
   "\"\<\\nSign[\[DoubleStruckCapitalJ]] =\>\"", ",", 
   RowBox[{"Sign", "[", "\[DoubleStruckCapitalJ]", "]"}], ",", 
   "\"\<\\nAbs[\[DoubleStruckCapitalJ]] =\>\"", ",", 
   RowBox[{"Abs", "[", "\[DoubleStruckCapitalJ]", "]"}], ",", 
   "\"\<\\nAbs[-\[DoubleStruckCapitalJ]] =\>\"", ",", 
   RowBox[{"Abs", "[", 
    RowBox[{"-", "\[DoubleStruckCapitalJ]"}], "]"}], ",", 
   "\"\<\\nPositive \[DoubleStruckCapitalJ] =\>\"", ",", 
   RowBox[{"Positive", "[", "\[DoubleStruckCapitalJ]", "]"}], ",", 
   "\"\<\\nPositive -\[DoubleStruckCapitalJ] =\>\"", ",", 
   RowBox[{"Positive", "[", 
    RowBox[{"-", "\[DoubleStruckCapitalJ]"}], "]"}], " ", ",", 
   "\"\<\\nRe[\[DoubleStruckCapitalJ]] =\>\"", ",", 
   RowBox[{"Re", "[", "\[DoubleStruckCapitalJ]", "]"}], ",", 
   "\"\<\\nRe[a_\[DoubleStruckCapitalJ]] =\>\"", ",", 
   RowBox[{"Re", "[", 
    RowBox[{"a_", " ", "\[DoubleStruckCapitalJ]"}], "]"}], ",", 
   "\"\<\\nImaginary[\[DoubleStruckCapitalJ]] =\>\"", ",", 
   RowBox[{"Im", "[", "\[DoubleStruckCapitalJ]", "]"}], ",", 
   "\"\<\\nImaginary[a_\[DoubleStruckCapitalJ]] =\>\"", ",", 
   RowBox[{"Im", "[", 
    RowBox[{"a_", " ", "\[DoubleStruckCapitalJ]"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Proposed nomenclature for \\!\\(\\*\\nStyleBox[\\\"Generalized\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Signs\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubleStruckD]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckD]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "12"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckG]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckG]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "7"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckH]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckH]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "6"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckCapitalI]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckCapitalI]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "4"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckCapitalJ]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckCapitalJ]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "3"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckK]", 
       RowBox[{"any_", "?", "OddQ"}]], "\[Rule]", "\[DoubleStruckK]"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckK]", 
       RowBox[{"any_", "?", "EvenQ"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckL]", 
       RowBox[{"any_", "?", "OddQ"}]], "\[Rule]", "\[DoubleStruckL]"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckL]", 
       RowBox[{"any_", "?", "EvenQ"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckM]", 
       RowBox[{"any_", "?", "OddQ"}]], "\[Rule]", "\[DoubleStruckM]"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckM]", 
       RowBox[{"any_", "?", "EvenQ"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckN]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckN]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "9"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckO]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckO]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "8"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckP]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckP]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "5"}], "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckS]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckS]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "GroupLoopHoop6`Private`\[DoubleStruckR]"}], 
        "]"}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckCapitalY]", "any_"], "\[Rule]", 
      SuperscriptBox["\[DoubleStruckCapitalY]", 
       RowBox[{"Mod", "[", 
        RowBox[{"any", ",", "3"}], "]"}]]}]}], "}"}], 
   ",", "\<\"\\nVarious properties are imposed to ensure correct behaviour \
e.g.:-\\nNumber \[DoubleStruckCapitalJ] =\"\>", ",", "True", 
   ",", "\<\"\\nSign[\[DoubleStruckCapitalJ]] =\"\>", ",", 
   "\[DoubleStruckCapitalJ]", 
   ",", "\<\"\\nAbs[\[DoubleStruckCapitalJ]] =\"\>", ",", "1", 
   ",", "\<\"\\nAbs[-\[DoubleStruckCapitalJ]] =\"\>", ",", "1", 
   ",", "\<\"\\nPositive \[DoubleStruckCapitalJ] =\"\>", ",", "False", 
   ",", "\<\"\\nPositive -\[DoubleStruckCapitalJ] =\"\>", ",", "False", 
   ",", "\<\"\\nRe[\[DoubleStruckCapitalJ]] =\"\>", ",", "0", 
   ",", "\<\"\\nRe[a_\[DoubleStruckCapitalJ]] =\"\>", ",", "0", 
   ",", "\<\"\\nImaginary[\[DoubleStruckCapitalJ]] =\"\>", ",", "0", 
   ",", "\<\"\\nImaginary[a_\[DoubleStruckCapitalJ]] =\"\>", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe following sections show how generalized signs are used as (1) group \
relators, (2) in 2\[Times]2 (\[Sigma]), 3\[Times]3 (\[Tau]) and 4\[Times]4 (\
\[Gamma]) unitary monomial matrices, to generate groups with second negation \
(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckK]", "2"], TraditionalForm]]],
 "=+1), ternary (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], TraditionalForm]]],
 "=+1), and other symmetries, (3) as signs in tables such as ",
 StyleBox["C9J",
  FontSlant->"Italic"],
 ", and (4) to define generalized \"polyhelix\" sinusoids."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2. Generalized Signs as group relators.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tExample 8 (Section 3.2.5) demonstrated the use of generalized signs to \
create the group A4 via the ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " procedure. This required one cube root and two distinct square roots of \
unity (called \"",
 StyleBox["a",
  FontSlant->"Italic"],
 "\", \"",
 StyleBox["b",
  FontSlant->"Italic"],
 "\" & \"",
 StyleBox["c",
  FontSlant->"Italic"],
 "\" rather than \[DoubleStruckCapitalJ], \[DoubleStruckK] & \[DoubleStruckL] \
because ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " needs lex ordering of relators). Prime groups have a single (prime root) \
relator. Every group probably has relators whose powers multiply to the group \
length; e.g. ",
 StyleBox["g3251",
  FontSlant->"Italic"],
 " needs 5 relators that are different square roots of unity, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "5"], TraditionalForm]]],
 "=32. The database includes a few groups for which I have not found such \
relators."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tMost ",
 "rela",
 "tor rules were discovered empirically, retaining the shortest wherever more \
than one gave a particular group. I later learned that most could have been \
found by using the GAP instruction ",
 StyleBox["gap> RelatorsOfFpGroup( Image( IsomorphismFpGroup( SmallGroup( \
mm,nn))))",
  FontSlant->"Italic"],
 ". See Section 13.2. "
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3. Generalized Signs in Unitary Monomial Matrices.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
 \tExample 22  shows two \"unitary monomial matrices\" employing the \
generalized signs \[DoubleStruckCapitalJ]  & \[DoubleStruckG]. The \
determinant of these matrices is 1 (unitary) and they have exactly one \
non-zero element in each row and column (monomial); together they generate \
the group C21.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["Example 22. Generalized Signs in Unitary Monomial Matrices.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<\!\(\*
StyleBox[\"Two\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"\[Times]\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"unitary\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"matrices\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"using\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"generalized\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"signs\",
FontSlant->\"Italic\"]\) \>\"", ",", 
   RowBox[{
    RowBox[{"u2", "[", 
     RowBox[{"[", "10", "]"}], "]"}], "//", "tf"}], ",", 
   RowBox[{
    RowBox[{"u2", "[", 
     RowBox[{"[", "21", "]"}], "]"}], "//", "tf"}], ",", "\"\<\\n\!\(\*
StyleBox[\"They\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"generate\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"isomorph\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) \>\"", ",", 
   RowBox[{
    RowBox[{"mm", "=."}], ";", 
    RowBox[{"id", "[", 
     RowBox[{"test", "=", 
      RowBox[{"mg", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"21", ",", "10"}], "}"}], ",", "u2"}], "]"}]}], "]"}]}], 
   ",", "\"\<\!\(\*
StyleBox[\"which\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"has\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"matrix\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"elements\",
FontSlant->\"Italic\"]\) \>\"", ",", "matel", ",", "\"\<\\n\!\(\*
StyleBox[\"and\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"dimensions\",
FontSlant->\"Italic\"]\) \>\"", ",", 
   RowBox[{"Dimensions", "[", "test", "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"Two\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"\[Times]\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"unitary\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"matrices\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"using\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"generalized\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"signs\\\",\\nFontSlant->\\\"Italic\
\\\"]\\) \"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"\[DoubleStruckCapitalJ]", "0"},
        {"0", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"\[DoubleStruckG]", "0"},
        {"0", 
         SuperscriptBox["\[DoubleStruckG]", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"They\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"generate\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"isomorph\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\
\\) \"\>", ",", "\<\"C21\"\>", 
   ",", "\<\"\\!\\(\\*\\nStyleBox[\\\"which\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"has\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"matrix\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"elements\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckG]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "6"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[DoubleStruckCapitalJ]", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckG]", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "5"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[DoubleStruckG]", " ", "\[DoubleStruckCapitalJ]"}], ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "6"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckG]", "3"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "4"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "2"], " ", 
          "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "5"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckG]", "4"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "3"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "3"], " ", 
          "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "4"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckG]", "5"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox["\[DoubleStruckG]", "2"]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "4"], " ", 
          "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "3"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckG]", "6"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckG]"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "5"], " ", 
          "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "2"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "6"], " ", 
          "\[DoubleStruckCapitalJ]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"\[DoubleStruckG]", " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], ",", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[DoubleStruckCapitalJ]"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[DoubleStruckG]", " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", "0"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "6"], " ", 
          "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "2"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", "0"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "5"], " ", 
          "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "3"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", "0"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "4"], " ", 
          "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "4"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", "0"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "3"], " ", 
          "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "5"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", "0"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "2"], " ", 
          "\[DoubleStruckCapitalJ]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubleStruckG]", "6"], " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], ",", "0"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"\[DoubleStruckG]", " ", "\[DoubleStruckCapitalJ]"}]}], 
        "}"}]}], "}"}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"and\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"dimensions\\\",\
\\nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"21", ",", "21"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4. Generalized Signs in Signed Tables.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tAll groups are hoops, because they can be considered to be folded from \
the composition of the group with C2 or C4, and this allows them to be \
algebras over the real and complex fields, as well as being loop \
multiplication tables for sets of primal coefficients. If they have the \
appropriate structure, as in Example 10, they can be folded to versions with \
some negated indices or, as in ",
 StyleBox["P4,",
  FontSlant->"Italic"],
 " some complex indices. Others fold to \[DoubleStruckCapitalJ]-signed \
algebras, such as those in Example 23. The ",
 StyleBox["ts",
  FontSlant->"Italic"],
 " procedure is sufficiently general to handle signs \[ImaginaryI] & \
\[DoubleStruckCapitalJ]. "
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 23. Generalized Sign \[DoubleStruckCapitalJ] \
in Signed Tables.",
 FontFamily->"Times New Roman"]], "Subsubsection",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<The C9 group isomorph\>\"", ",", 
   RowBox[{
    RowBox[{"tstJ", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "2", ",", "9", ",", "1", ",", "5", ",", "3", ",", "4", ",", "8", ",", 
         "6", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3", ",", "1", ",", "5", ",", "6", ",", "4", ",", "8", ",", "9", ",", 
         "7", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "4", ",", "5", ",", "6", ",", "7", ",", "8", ",", "9", ",", "1", ",", 
         "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "5", ",", "3", ",", "4", ",", "8", ",", "6", ",", "7", ",", "2", ",", 
         "9", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "6", ",", "4", ",", "8", ",", "9", ",", "7", ",", "2", ",", "3", ",", 
         "1", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "7", ",", "8", ",", "9", ",", "1", ",", "2", ",", "3", ",", "4", ",", 
         "5", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "8", ",", "6", ",", "7", ",", "2", ",", "9", ",", "1", ",", "5", ",", 
         "3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "9", ",", "7", ",", "2", ",", "3", ",", "1", ",", "5", ",", "6", ",", 
         "4", ",", "8"}], "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"tstJ", "//", "tf"}]}], ",", 
   "\"\<\[DoubleStruckCapitalJ]-folds to\>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"tstj", "=", 
     RowBox[{"ts", "[", 
      RowBox[{"tstJ", ",", "3"}], "]"}]}], "]"}], ",", 
   RowBox[{"tstj", "//", "tf"}], ",", "\"\<The C3C3 group isomorph\>\"", ",", 
   
   RowBox[{
    RowBox[{"tstJJ", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "2", ",", "9", ",", "4", ",", "5", ",", "3", ",", "7", ",", "8", ",", 
         "6", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3", ",", "4", ",", "8", ",", "6", ",", "7", ",", "2", ",", "9", ",", 
         "1", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "4", ",", "5", ",", "6", ",", "7", ",", "8", ",", "9", ",", "1", ",", 
         "2", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "5", ",", "3", ",", "7", ",", "8", ",", "6", ",", "1", ",", "2", ",", 
         "9", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "6", ",", "7", ",", "2", ",", "9", ",", "1", ",", "5", ",", "3", ",", 
         "4", ",", "8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "7", ",", "8", ",", "9", ",", "1", ",", "2", ",", "3", ",", "4", ",", 
         "5", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "8", ",", "6", ",", "1", ",", "2", ",", "9", ",", "4", ",", "5", ",", 
         "3", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "9", ",", "1", ",", "5", ",", "3", ",", "4", ",", "8", ",", "6", ",", 
         "7", ",", "2"}], "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"tstJJ", "//", "tf"}]}], ",", 
   "\"\<\[DoubleStruckCapitalJ]-folds to\>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"tstjj", "=", 
     RowBox[{"ts", "[", 
      RowBox[{"tstJJ", ",", "3"}], "]"}]}], "]"}], ",", 
   RowBox[{"tstjj", "//", "tf"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"The C9 group isomorph\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8", "9"},
        {"2", "9", "1", "5", "3", "4", "8", "6", "7"},
        {"3", "1", "5", "6", "4", "8", "9", "7", "2"},
        {"4", "5", "6", "7", "8", "9", "1", "2", "3"},
        {"5", "3", "4", "8", "6", "7", "2", "9", "1"},
        {"6", "4", "8", "9", "7", "2", "3", "1", "5"},
        {"7", "8", "9", "1", "2", "3", "4", "5", "6"},
        {"8", "6", "7", "2", "9", "1", "5", "3", "4"},
        {"9", "7", "2", "3", "1", "5", "6", "4", "8"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\[DoubleStruckCapitalJ]-folds to\"\>", 
   ",", "\<\"C9j\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "1"},
        {"3", "1", 
         RowBox[{"2", " ", "\[DoubleStruckCapitalJ]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"The C3C3 group isomorph\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8", "9"},
        {"2", "9", "4", "5", "3", "7", "8", "6", "1"},
        {"3", "4", "8", "6", "7", "2", "9", "1", "5"},
        {"4", "5", "6", "7", "8", "9", "1", "2", "3"},
        {"5", "3", "7", "8", "6", "1", "2", "9", "4"},
        {"6", "7", "2", "9", "1", "5", "3", "4", "8"},
        {"7", "8", "9", "1", "2", "3", "4", "5", "6"},
        {"8", "6", "1", "2", "9", "4", "5", "3", "7"},
        {"9", "1", "5", "3", "4", "8", "6", "7", "2"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\[DoubleStruckCapitalJ]-folds to\"\>", 
   ",", "\<\"C3C3j\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], 
         "\[DoubleStruckCapitalJ]"},
        {"3", "\[DoubleStruckCapitalJ]", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.5. Exponent of Generalised Signs, PolyHelix Identity.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tExtended signs, \[DoubleStruckS] : ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "r"], TraditionalForm]]],
 "=1, generalize the sinusoids Cos[x] = Re[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
 "], Sin[x] = Im[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
 "] to multi-phase sinusoids ",
 StyleBox["genCos[x,m] ",
  FontSlant->"Italic"],
 "= Re[",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[ExponentialE]", "m", 
    RowBox[{"\[DoubleStruckS]", " ", "x"}]], TraditionalForm]]],
 "] where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "m"], TraditionalForm]]],
 " is a (normalizing) modification of \[ExponentialE] that depends on ",
 StyleBox["m",
  FontSlant->"Italic"],
 ", the number of phases. The normalising element is easily shown to be Re[",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[ExponentialE]", "m", 
    RowBox[{"Im", "[", "\[DoubleStruckS]", "]"}]], TraditionalForm]]],
 "] = Re[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"Im", "[", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"2", "/", "m"}]], "]"}]], TraditionalForm]]],
 "], where the second expression is the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " implementation of the first. (This gives ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "3"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "6"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SqrtBox["3"], "/", "2"}]], TraditionalForm]]],
 "\[TildeEqual]2.3774, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "12"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SqrtBox["\[ExponentialE]"], TraditionalForm]]],
 "\[TildeEqual]1.6487). The generation of these sinusoids as solutions to \
banded differential equations is described in Appendix E.\n\tMulti-phase \
sinusoids have an exponential series formulation that simplifies, when ",
 StyleBox["m",
  FontSlant->"Italic"],
 " = 4, to half the standard Cos and Sin series, with half the terms becoming \
zero. This is traditionally folded and mis-interpreted as two asymmetrical \
phases, {Cos[x], Sin[x]} instead of four symmetrical phases ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
 " = {Cos[x], Sin[x], -Cos[x], -Sin[x]}/2. \n\tIt is convenient to include a \
phase parameter \"j\" in the ",
 "generalized",
 " sinusoid procedures ",
 StyleBox["genCos[x,m,j]",
  FontSlant->"Italic"],
 " & ",
 StyleBox["genSin[x,m,j],",
  FontSlant->"Italic"],
 " and to normalize the amplitude to 1.  I also include phases between \
+Cosh[x] and -Cosh[x] if ",
 StyleBox["m",
  FontSlant->"Italic"],
 "=0, and between Cosh[x] and Sinh[x] if ",
 StyleBox["m",
  FontSlant->"Italic"],
 "=2."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell["Example  24.  genCos, genSin.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "genCos"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"genCos[x_,m_:4,j_:0] creates the j'th phase of the generalized \
antisymmetric sinusoid or helix with m phases; generalised Cosh and Sinh \
functions are generated if m=0 or 2.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3426326367-7958013"],

Cell[BoxData["\<\"genCos[x_,m_:4,j_:0] creates the j'th phase of the \
generalized antisymmetric sinusoid or helix with m phases; generalized Cosh \
and Sinh functions are generated if m=0 or 2.\"\>"], "Print",
 PageWidth->WindowWidth,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellTags->"Info3362457282-3716175"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "genSin"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"genSin[x_,m_:4,j_:0] creates the j'th phase of the generalized \
symmetric sinusoid or helix with m phases; generalised Cosh and Sinh \
functions are generated if m=0 or 2.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3426326367-8704009"],

Cell[BoxData["\<\"genSin[x_,m_:4,j_:0] creates the j'th phase of the \
generalized symmetric sinusoid or helix with m phases; generalized Cosh and \
Sinh functions are generated if m=0 or 2.\"\>"], "Print",
 PageWidth->WindowWidth,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellTags->"Info3362457286-9933190"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "\tExamples 25 & 26 demonstrate ",
 StyleBox["genCos",
  FontSlant->"Italic"],
 " & ",
 StyleBox["genSin ",
  FontSlant->"Italic"],
 "by plotting three phases of the 3-phase & 12-phase sinusoids over their \
periods 2\[Pi]/Sin[2\[Pi]/3] = ",
 Cell[BoxData[
  SqrtBox["3"]]],
 "\[Pi] = 7.2552 & 4\[Pi]=12.5664. "
}], "Text",
 PageWidth->WindowWidth],

Cell["Example  25.  3-phase Sinusoids.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", "3"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "r", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "phase", "]"}], "]"}], "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["s", 
          RowBox[{"phase", "-", "1"}]], "  ", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", " ", "x", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"phase", ",", "3"}], "}"}]}], "]"}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Ex.25\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"3\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"phases\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"0\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"l\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"4\",
FontSize->9]\)\!\(\*
StyleBox[\"\[Pi]\",
FontSize->9]\)\!\(\*
StyleBox[\"/\",
FontSize->9]\)\!\(\*
StyleBox[SqrtBox[\"3\"],
FontSize->9]\)\>\""}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk4FM7/AHA6nLuuFNklHTqkVEqlY97Up5tSQo5EKYlKd1IhJEeudFCU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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4lF8bB3BbpcgyM7JlyxKVUtpI3af8olBkX0OF0iLaVMiSQkT2Nkl7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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4VN8bAPAxYyyJLMPcsZSikCVtKqrzaiORpYWkrEmhKEl9EWmhVLZE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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
   "\"Ex.25\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"3\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"phases\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"0\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\\
*\\nStyleBox[\\\"l\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"4\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"\[Pi]\\\",\\nFontSize->9]\\)\\!\
\\(\\*\\nStyleBox[\\\"/\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[SqrtBox[\\\
\"3\\\"],\\nFontSize->9]\\)\"", TraditionalForm],
  PlotRange->
   NCache[{{0, (4 3^Rational[-1, 2]) Pi}, {-0.9999998830731719, 
     0.9999999999999918}}, {{0, 7.255197456936872}, {-0.9999998830731719, 
     0.9999999999999918}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"genCos", "[", 
       RowBox[{"x", ",", "3"}], "]"}], ",", 
      RowBox[{"genCos", "[", 
       RowBox[{"x", ",", "3", ",", "1"}], "]"}], ",", 
      RowBox[{"genCos", "[", 
       RowBox[{"x", ",", "3", ",", "2"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"2", 
       RowBox[{"\[Pi]", "/", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", 
          RowBox[{"\[Pi]", "/", "3"}]}], "]"}]}]}]}], "}"}], ",", 
    RowBox[{
    "PlotLabel", "->", "\"\<Fig.4. genCos. Phases 0,1,2 for m = 3\>\""}]}], 
   "]"}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell["Example  26. 12-phase Half-Spin Sinusoids.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", "12"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "r", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "phase", "]"}], "]"}], "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["s", 
          RowBox[{"phase", "-", "1"}]], "  ", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", " ", "x", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"phase", ",", "3"}], "}"}]}], "]"}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"p", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"p", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"p", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "  ", ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<\!\(\*
StyleBox[\"6\",
FontSize->9]\)\!\(\*
StyleBox[\"Ex\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"26.\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"12\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"phases\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"0\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"l\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"4\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"\[Pi]\",
FontSize->9]\)\>\""}]}], "]"}]}], "\n"}], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk81Nv/B3DUzZY224wtZBmSFluFzjsVSYkWylYpS1KhpCstKtEmS1S6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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13dczf8XB/AWEpr3Nkj73tuiCKF4HwkJaVuhoVBp0EAlGQ36piESbU2z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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VO8XB3Ah+zIzhlSyzR2yhDYl6jlFkkqlTSGyJVS0IFEqX2khW5Y2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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
   "\"\\!\\(\\*\\nStyleBox[\\\"6\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\
\"Ex\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontSize->9]\\)\\\
!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"26.\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"12\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"phases\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"0\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\\
*\\nStyleBox[\\\"l\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"4\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"\[Pi]\\\",\\nFontSize->9]\\)\"\
", TraditionalForm],
  PlotRange->
   NCache[{{0, 4 Pi}, {-0.9999998830731719, 0.9999999999999918}}, {{
     0, 12.566370614359172`}, {-0.9999998830731719, 0.9999999999999918}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tNote that neither the phasality ",
 StyleBox["m",
  FontSlant->"Italic"],
 " nor the phase ",
 StyleBox["j",
  FontSlant->"Italic"],
 " need be an integer. Also ",
 StyleBox["genCos[x,m,m/4]\[Congruent]genSin[x,m]",
  FontSlant->"Italic"],
 ", so one of the series is redundant. Both are included for compatibility \
with normal mathematics, with ",
 StyleBox["genSin",
  FontSlant->"Italic"],
 " as the antisymmetric sinusoid. ",
 StyleBox["genSin",
  FontSlant->"Italic"],
 " is preferable to ",
 StyleBox["genCos",
  FontSlant->"Italic"],
 " in some situations such as Direction Sines, as ",
 StyleBox["genSin[x,m,0]~x",
  FontSlant->"Italic"],
 " for small ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and the value tends to zero with ",
 StyleBox["x",
  FontSlant->"Italic"],
 ". When x = 0, terms involving ",
 StyleBox["genSin[x,m,0]",
  FontSlant->"Italic"],
 " drop out of expressions, making them compatible with renormalization."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.6. Generalized Signs & Generalized negation.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tOrdinary negation \"-\" is a first member of the \"generalized \
negations\". It corresponds to a binary equivalence relation, with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "i"], TraditionalForm]]],
 "~{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "}, -",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "i"], TraditionalForm]]],
 "~{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "}, 0~{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "} in a group with ",
 StyleBox["m",
  FontSlant->"Italic"],
 " elements. This is the rotation of the elements by ",
 StyleBox["m/2",
  FontSlant->"Italic"],
 ", either to the left or the right. It fails for odd ",
 StyleBox["m",
  FontSlant->"Italic"],
 " groups and for some even-",
 StyleBox["m",
  FontSlant->"Italic"],
 " groups such as ",
 StyleBox["D3",
  FontSlant->"Italic"],
 " that lack a C2 symmetry,",
 StyleBox[" ",
  FontSlant->"Italic"],
 "but it can be extended to rotation by factors of ",
 StyleBox["m",
  FontSlant->"Italic"],
 ". Extra negations are introduced in this way. Thus C3 has two (left and \
right) negations ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["A", "\[LeftArrow]"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["A", "\[RightArrow]"], TraditionalForm]]],
 ". The real (C2) axiom that ",
 StyleBox["A",
  FontSlant->"Italic"],
 "+ ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["A", "\[LeftRightArrow]"], TraditionalForm]]],
 "~0 is {a,b}+{b,a} = {a+b,a+b} \[Tilde] 0. In the C3 case this becomes ",
 StyleBox["A",
  FontSlant->"Italic"],
 "+",
 Cell[BoxData[
  FormBox[
   OverscriptBox["A", "\[LeftArrow]"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["A", "\[RightArrow]"], " "}], TraditionalForm]]],
 "~ 0, {a,b,c} + {b,c,a} + {c,a,b} = {a+b+c, a+b+c, a+b+c} \[Tilde] 0. As \
{a+b+...+",
 StyleBox["m",
  FontSlant->"Italic"],
 "} is always a factor of a quasigroup determinant, ",
 StyleBox["r-",
  FontSlant->"Italic"],
 "fold negation corresponds to equivalencing that factor to zero. \
Renormalization makes it (and usually some other factors) explicitly zero. \
Subtraction is \"additive elimination\", adding one or more terms to give a \
result that equivalences to zero."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 " \tThe standard development of numbers from sets [8, p46] is defective, \
prematurely introducing ordinary negation as an equivalence relation (ER) on \
a two-element indexed set; {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], ",", 
    SubscriptBox["a", "2"]}], TraditionalForm]]],
 "} is arbitrarily given the \"+\" sign and {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], ",", 
    SubscriptBox["a", "1"]}], TraditionalForm]]],
 "} the \"-\" sign. Negation is not needed in the development of unsigned \
rational and continuous numbers from set theory and a continuum axiom. The \
unsigned Rationals, \[DoubleStruckCapitalQ]",
 Cell[BoxData[
  SubscriptBox["", 
   RowBox[{"0", "+"}]]]],
 ", are an ER on a two-element ",
 StyleBox["ordered",
  FontSlant->"Italic"],
 " set of natural numbers; a continuity axiom extends them to the unsigned \
continuous numbers (the half-line) that I call \"Primal\" numbers. The \
development and multiplication of indexed sets of primal coefficients then \
leads to loops, and to generalized negation as ER's on rotated multi-element \
indexed sets. Ordinary negation then arises in many, but not all, algebras.\n\
\tSome physical entities appear to be primal - they can be expressed using \
non-negative coefficients. There is no evidence for negative time, so it is \
always positive, i.e. Time is a Direction. Other entities, such as \
derivatives, are Real, being ER's on pairs of primal coefficients. \
Accelerations are ambiguous; are they ER's on three coefficients (terplex \
numbers), or on two derivatives (Study numbers)? Complex numbers are ER's on \
quads of primal numbers, Quaternions are ER's on sets of eight primal \
numbers."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Hoop Algebras.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Summary.",
 StyleBox[" Conservative m\[Times]m loops become m/r\[Times]m/r \"Hoop \
Algebras\" after imposing r-fold negation to provide generalized signs, \
addition & generalized subtraction. Polar & Hyperbolic dual forms exist for \
Abelian hoops, and provide generalized powers, roots, and rotations. When \
sizes approach zero, multiplication & division \"renormalize\" by working in \
a constrained sub-algebra and splitting-off  \"remainders\" of appropriate \
shape. Multiplication or division by a vec with some zero sizes \"projects\" \
the result into a constrained sub-algebra and \"ejects\" one or two \
remainder(s).",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[{
 "6.1. \"",
 StyleBox["Hoops",
  FontSlant->"Italic"],
 "\" - Generalized Partial-fraction Division Algebras."
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tI coined the name \"Hoops\" for all algebras obtained by folding \
conservative loops because they are rings or loops that conserve their shape, \
and fit between groups and loops. Many of the algebras relevant to \
mathematical physics are hoops or specializations of particular hoops. This \
is discussed in Section 7, but complex algebra is treated  here.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tExample 27 shows the relationship of C4 to \[DoubleStruckCapitalC], by \
mapping {\"+1\", \"\[ImaginaryI]\", \"-1\", \"-\[ImaginaryI]\"} onto the C4 \
index table and then isolating the quarter-table, which can be seen to be the \
complex algebra multiplication table; this is a C2 fold. The 4-vecs \
{a,b,-a,-b} & {d,e,-d,-e} (which fold to {2a,2b} & {2d,2e}) are then \
multiplied; the product matches the complex product of \
(2a+2\[ImaginaryI]b)*(2d+2\[ImaginaryI]e).\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example 27. The C4 group \"equivalences\" to \[DoubleStruckCapitalC].\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<\!\(\*
StyleBox[\"Full\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"C4\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Table\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",
FontSlant->\"Italic\"]\) \>\"", ",", 
     RowBox[{"c4", "=", 
      RowBox[{"gmap", "[", 
       RowBox[{"C4", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<+1\>\"", ",", "\"\<\[ImaginaryI]\>\"", ",", "\"\<-1\>\"", ",", 
          "\"\<-\[ImaginaryI]\>\""}], "}"}]}], "]"}]}], ",", "\"\< \!\(\*
StyleBox[\"Signed\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"quarter\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"table\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"is\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\[DoubleStruckCapitalC]\>\"", ",", 
     RowBox[{"c4c", "=", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"Take", "[", 
          RowBox[{"c4", ",", "2"}], "]"}], "]"}], ",", "2"}], "]"}]}]}], 
    "}"}], "//", "TraditionalForm"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"Full\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"C4\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Table\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"=\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"+1\"\>", "\<\"\[ImaginaryI]\"\>", "\<\"-1\"\>", "\<\"-\
\[ImaginaryI]\"\>"},
       {"\<\"\[ImaginaryI]\"\>", "\<\"-1\"\>", "\<\"-\[ImaginaryI]\"\>", \
"\<\"+1\"\>"},
       {"\<\"-1\"\>", "\<\"-\[ImaginaryI]\"\>", "\<\"+1\"\>", "\<\"\
\[ImaginaryI]\"\>"},
       {"\<\"-\[ImaginaryI]\"\>", "\<\"+1\"\>", "\<\"\[ImaginaryI]\"\>", \
"\<\"-1\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
    ",", "\<\" \\!\\(\\*\\nStyleBox[\\\"Signed\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"quarter\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"table\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"is\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\[DoubleStruckCapitalC]\"\>", ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"+1\"\>", "\<\"\[ImaginaryI]\"\>"},
       {"\<\"\[ImaginaryI]\"\>", "\<\"-1\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], "}"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<C4 \!\(\*
StyleBox[\"product\",
FontSlant->\"Italic\"]\) {a,b,-a,-b}*{d,e,-d,-e}= \>\"", ",", 
   RowBox[{"abef", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", 
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"e", ",", "f", ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}]}], "}"}], ",", "C4"}], "]"}]}], ",", 
   "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"This\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"equivalences\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"to\",
FontSlant->\"Italic\"]\) \>\"", ",", 
   RowBox[{
    RowBox[{"abef", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "-", 
    RowBox[{"abef", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"abef", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "-", 
    RowBox[{"abef", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], ",", "\n", 
   "\"\<\\n &  to (a+\[ImaginaryI] b)*(e+\[ImaginaryI] f) =\>\"", ",", 
   RowBox[{"ComplexExpand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "a"}], "+", 
       RowBox[{"2", "\[ImaginaryI]", " ", "b"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "e"}], "+", 
       RowBox[{"2", "\[ImaginaryI]", " ", "f"}]}], ")"}]}], "]"}], ",", 
   "\"\<\\nC4 \!\(\*
StyleBox[\"determinant\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
   RowBox[{"frag", "[", 
    RowBox[{"Factor", "[", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"b", ",", "c", ",", "d", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"c", ",", "d", ",", "a", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"d", ",", "a", ",", "b", ",", "c"}], "}"}]}], "}"}], "]"}], 
     "]"}], "]"}], ",", "\"\<\\nC4c \!\(\*
StyleBox[\"determinant\",
FontSlant->\"Italic\"]\)       \>\"", ",", 
   RowBox[{"Factor", "[", 
    RowBox[{"Det", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", 
         RowBox[{"-", "a"}]}], "}"}]}], "}"}], "]"}], "]"}]}], "}"}]], "Input",\

 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C4 \
\\!\\(\\*\\nStyleBox[\\\"product\\\",\\nFontSlant->\\\"Italic\\\"]\\) \
{a,b,-a,-b}*{d,e,-d,-e}= \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "-", 
      RowBox[{"2", " ", "b", " ", "f"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "b", " ", "e"}], "+", 
      RowBox[{"2", " ", "a", " ", "f"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a", " ", "e"}], "+", 
      RowBox[{"2", " ", "b", " ", "f"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "b", " ", "e"}], "-", 
      RowBox[{"2", " ", "a", " ", "f"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"This\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"equivalences\\\"\
,\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"to\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
   RowBox[{
    RowBox[{"4", " ", "a", " ", "e"}], "-", 
    RowBox[{"4", " ", "b", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", "b", " ", "e"}], "+", 
    RowBox[{"4", " ", "a", " ", "f"}]}], 
   ",", "\<\"\\n &  to (a+\[ImaginaryI] b)*(e+\[ImaginaryI] f) =\"\>", ",", 
   RowBox[{
    RowBox[{"4", " ", "a", " ", "e"}], "-", 
    RowBox[{"4", " ", "b", " ", "f"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "b", " ", "e"}], "+", 
       RowBox[{"4", " ", "a", " ", "f"}]}], ")"}]}]}], 
   ",", "\<\"\\nC4 \
\\!\\(\\*\\nStyleBox[\\\"determinant\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\\
(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
     RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "d"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nC4c \\!\\(\\*\\nStyleBox[\\\"determinant\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)       \"\>", ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "-", 
    SuperscriptBox["b", "2"]}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "6.2. Polar and Hyperbolic \"",
 StyleBox["Duals",
  FontSlant->"Italic"],
 "\", Powers & Roots."
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThe polyhelix identity (Appendix E) ensures that some hoop algebras have \
polar \"duals\" with conserved radii and offsets, together with angles that \
are added (in abelian algebras) when the ",
 StyleBox["vecs",
  FontSlant->"Italic"],
 " are multiplied. The shapes of these hoops include conserved signed sums of \
squares. If a size can be expressed as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["y", "2"], " "}], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "2"], TraditionalForm]]],
 ", x, y and r can be interpreted as sides of a right angled triangle with \
\[Theta]=Arctan[x,y]; if  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["z", "2"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "2"], TraditionalForm]]],
 "; \[Theta]=ArcTan[2x-y-z,",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "(z-y)]. Polar duals are generalizations of the Cartesian {x,y} \
\[LeftRightArrow] Polar {r,\[Theta]} duality of the complex plane. ",
 StyleBox["hoopP",
  FontSlant->"Italic"],
 "o",
 StyleBox["wer",
  FontSlant->"Italic"],
 " uses the additivity of angles in duals to calculate ",
 StyleBox["vec",
  FontSlant->"Italic"],
 " powers and roots. Hoops are not restricted to infinitesimal rotations.\n \t\
Example 28 demonstrates the sinusoidal dual for the Terplex hoop (which uses \
the C3 group as the multiplication table and conserves (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], "2"], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"b", "-", "c"}], ")"}], "2"], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"c", "-", "a"}], ")"}], "2"], TraditionalForm]]],
 ")/2 ). The 3-vec ",
 StyleBox["A",
  FontSlant->"Italic"],
 " has been chosen to have a simple polar form, so that the relation between \
the polar form of the cube root ",
 StyleBox["r3A",
  FontSlant->"Italic"],
 " and that of ",
 StyleBox["A",
  FontSlant->"Italic"],
 " can be seen",
 StyleBox[".",
  FontSlant->"Italic"],
 " The original value is recovered on cubing ",
 StyleBox["r3A",
  FontSlant->"Italic"],
 ". Note that roots of powers will recover a \"rotated\" version of the \
original vec if the angle of the power exceeds 2\[Pi]. The result will have \
the same sizes as the original vec, but the angle may be different. Raising a \
root to the corresponding power does not have this problem as 2\[Pi] is not \
exceeded."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["6.2.1 Terplex Powers and Roots.", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
Example 28. \"Terplex\" vecs have polar duals that provide powers and roots.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"id", "[", "C3", "]"}], ";", "\"\<Terplex A = \>\""}], ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{"1.", ",", "5", ",", "5"}], "}"}]}], ",", 
   "\"\<\\nPolar form   \>\"", ",", 
   RowBox[{"toPolar", "[", 
    RowBox[{"A", ",", "\"\<C3\>\""}], "]"}], ",", "\"\<\\nCube Root r3A\>\"", 
   ",", 
   RowBox[{"r3A", "=", 
    RowBox[{"hoopPower", "[", 
     RowBox[{"A", ",", 
      RowBox[{"1", "/", "3"}]}], "]"}]}], ",", "\"\<\\nPolar form   \>\"", 
   ",", 
   RowBox[{"toPolar", "[", "r3A", "]"}], ",", 
   "\"\<\\n\!\(\*RadicalBox[\(11\), \(3\)]\),\!\(\*RadicalBox[\(16\), \
\(3\)]\),\[Pi]/3\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RadicalBox["11.", "3"], ",", 
     RadicalBox["16.", "3"], ",", 
     RowBox[{"\[Pi]", "/", "3."}]}], "}"}], ",", 
   "\"\<\\n\!\(\*SuperscriptBox[\(r3A\), \(3\)]\)=A       \>\"", ",", 
   RowBox[{"hoopPower", "[", 
    RowBox[{"r3A", ",", "3"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Terplex A = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", "5"}], "}"}], 
   ",", "\<\"\\nPolar form   \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"11.`", ",", "16.`", ",", "\[Pi]"}], "}"}], 
   ",", "\<\"\\nCube Root r3A\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.2704603808458383`", ",", 
     RowBox[{"-", "0.3169406711223613`"}], ",", "1.2704603808458383`"}], 
    "}"}], ",", "\<\"\\nPolar form   \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "2.2239800905693157`", ",", "2.519842099789747`", ",", 
     "1.0471975511965976`"}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*RadicalBox[\\(11\\), \
\\(3\\)]\\),\\!\\(\\*RadicalBox[\\(16\\), \\(3\\)]\\),\[Pi]/3\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "2.2239800905693152`", ",", "2.5198420997897464`", ",", 
     "1.0471975511965976`"}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*SuperscriptBox[\\(r3A\\), \\(3\\)]\\)=A       \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "0.9999999999999993`", ",", "4.999999999999999`", ",", 
     "5.000000000000001`"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tWhilst A has components from the real field in the above examples, hoop \
algebras are valid over the complex field (because any G can be considered to \
be folded from GC4). This is demonstrated in the next example; hyperbolic \
functions are inherently complex, even for real arguments.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2.2 Hypolar Powers and Roots.", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tWhen a size involves the difference of two squares, or (as in C4 & K) two \
linear sizes can combine to conserve a difference of two squares, a \
hyperbolic dual polar (\"hypolar\") form exists. This is based on ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["Cosh", "2"],
    FontSlant->"Italic"], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["Sinh", "2"],
    FontSlant->"Italic"], TraditionalForm]]],
 " = 1, and I write ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["u", "2"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 "; ",
 StyleBox["x & y",
  FontSlant->"Italic"],
 " are coordinates on the \"hyperbolic plane\" rather than the complex plane \
and ",
 StyleBox["u",
  FontSlant->"Italic"],
 " is (by analogy with the bones of the forearm) an \"ulna\". These are \
\"Study numbers\", the hyperbolic analogue of complex numbers. The ",
 StyleBox["arcTanh[adj,opp]",
  FontSlant->"Italic"],
 " function (defined in section 2.8.2 and discussed in Appendix C) is an \
extension of ArcTanh that gives results for complex or real arguments by \
taking the quadrant of the real ",
 StyleBox["adj,opp",
  FontSlant->"Italic"],
 " components into account. The \"hyperangle\" is a complex number that \
becomes infinite whenever ",
 StyleBox["adj ",
  FontSlant->"Italic"],
 "= \[PlusMinus] ",
 StyleBox["opp",
  FontSlant->"Italic"],
 ", i.e. on the 45\[Degree] lines in the \"hypercomplex plane\".",
 StyleBox[" tohyVec",
  FontSlant->"Italic"],
 " recovers the signed adjacent-opposite components, unlike ",
 StyleBox["Tanh",
  FontSlant->"Italic"],
 ", which only provides their ratio. The database contains nine hypolar \
examples. The hypolar form may have both hypolar and polar components as in \
C4. Example 29 shows the same vecs A={3.-2\[ImaginaryI], 5., -2, 2.+\
\[ImaginaryI]} & B={5.+\[ImaginaryI], 3.-2\[ImaginaryI], -2. -3\[ImaginaryI], \
4.} being multiplied by both C4 & the Klein group K, which has two hypolar \
angles (the first matching that of C4). The hypolar coordinates are \
\"synthetic\" in both examples, as they are obtained from pairs of linear \
sizes. "
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example 29. Hypolar sizes multiply & angles add on multiplication.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\"\<Target group is\>\"", ",", 
    RowBox[{"id", "[", "C4", "]"}], ",", "\"\<with hypolar form\>\"", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"tohyPolar", "[", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], "]"}]}], "}"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3.", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ",", "5.", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"2.", "+", "\[ImaginaryI]"}]}], "}"}]}], ",", 
    RowBox[{"hA", "=", 
     RowBox[{"tohyPolar", "[", 
      RowBox[{"A", ",", "\"\<C4\>\""}], "]"}]}], ",", 
    RowBox[{"Chop", "[", 
     RowBox[{
      RowBox[{"tohyVector", "[", "hA", "]"}], "-", "A"}], "]"}], ",", 
    RowBox[{"B", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"5.", "+", "\[ImaginaryI]"}], ",", 
       RowBox[{"3.", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "2."}], "-", 
        RowBox[{"3", "\[ImaginaryI]"}]}], ",", "4."}], "}"}]}], ",", 
    RowBox[{"hB", "=", 
     RowBox[{"tohyPolar", "[", "B", "]"}]}], ",", 
    RowBox[{"AB", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"A", ",", "B"}], "]"}]}], ",", 
    RowBox[{"hAB", "=", 
     RowBox[{"tohyPolar", "[", "AB", "]"}]}], ",", 
    RowBox[{"Chop", "[", 
     RowBox[{
      RowBox[{"hA", "*", "hB"}], "-", "hAB"}], "]"}], ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"hA", "+", "hB", "-", "hAB"}], "]"}]}], "}"}], "//", 
  "TraditionalForm"}], "\n", 
 RowBox[{"{", 
  RowBox[{"\"\<Change Target group to\>\"", ",", 
   RowBox[{"id", "[", "K", "]"}]}], "}"}], "\n", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"A", ",", 
    RowBox[{"hA", "=", 
     RowBox[{"tohyPolar", "[", 
      RowBox[{"A", ",", "\"\<K\>\""}], "]"}]}], ",", 
    RowBox[{"Chop", "[", 
     RowBox[{
      RowBox[{"tohyVector", "[", "hA", "]"}], "-", "A"}], "]"}], ",", "B", 
    ",", 
    RowBox[{"hB", "=", 
     RowBox[{"tohyPolar", "[", "B", "]"}]}], ",", 
    RowBox[{"AB", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"A", ",", "B"}], "]"}]}], ",", 
    RowBox[{"hAB", "=", 
     RowBox[{"tohyPolar", "[", "AB", "]"}]}], ",", 
    RowBox[{"Chop", "[", 
     RowBox[{
      RowBox[{"hA", "*", "hB"}], "-", "hAB"}], "]"}], ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"hA", "+", "hB", "-", "hAB"}], "]"}]}], "}"}], "//", 
  "TraditionalForm"}]}], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Target group is\"\>", ",", "\<\"C4\"\>", 
   ",", "\<\"with hypolar form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "d"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], "2"], "-", 
         RowBox[{"1.`", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "+", "d"}], ")"}], "2"]}]}], "\[Equal]", "0"}], ",", 
       "\[Infinity]", ",", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], "+", 
          RowBox[{"(", 
           RowBox[{"b", "+", "d"}], ")"}]}], 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "c"}], ")"}], "2"], "-", 
           RowBox[{"1.`", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "+", "d"}], ")"}], "2"]}]}]]], "]"}]}], "]"}], ",",
      
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "d"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "c"}], ",", 
       RowBox[{"b", "-", "d"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"Function", 
      RowBox[{"a", " ", "or", " ", 
       SuperscriptBox["u", "2"]}], 
      RowBox[{
       RowBox[{".", "b"}], " ", "or", " ", "hyperangle"}], 
      RowBox[{"c", " ", "or", " ", 
       SuperscriptBox["v", "2"]}], 
      RowBox[{
       RowBox[{".", "d"}], " ", "or", " ", "hyperangle"}]},
     {"vectorA", 
      RowBox[{"3", "\[InvisibleSpace]", "-", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], "5", 
      RowBox[{"-", "2"}], 
      RowBox[{"2.", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}]},
     {
      RowBox[{"hA", "=", 
       RowBox[{"hypolarC4", "[", "A", "]"}]}], 
      RowBox[{
       RowBox[{"-", "51"}], "-", 
       RowBox[{"18", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.0919", "\[InvisibleSpace]", "+", 
       RowBox[{"1.2768", "\[ImaginaryI]"}]}], 
      RowBox[{"29", "\[InvisibleSpace]", "-", 
       RowBox[{"26", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.5306", "\[InvisibleSpace]", "+", 
       RowBox[{"0.0257", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"A", "-", 
       RowBox[{"hyvectorC4", "[", "hA", "]"}]}], "0", "0", "0", "0"},
     {
      RowBox[{"vector", " ", "B"}], 
      RowBox[{"5", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}], 
      RowBox[{"3.", "-", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "2"}], "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "4."},
     {
      RowBox[{"hB", "=", 
       RowBox[{"hypolarC4", "[", "B", "]"}]}], 
      RowBox[{
       RowBox[{"-", "40"}], "+", 
       RowBox[{"16", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.4952", "\[InvisibleSpace]", "-", 
       RowBox[{"1.7610", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"30", "\[InvisibleSpace]", "+", 
       RowBox[{"60", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.2318"}], "-", 
       RowBox[{"0.1469", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"vector", " ", "AB"}], 
      RowBox[{"49", "\[InvisibleSpace]", "-", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"21", "\[InvisibleSpace]", ".", 
        RowBox[{"-", "15"}]}], " ", "\[ImaginaryI]"}], 
      RowBox[{"1", "\[InvisibleSpace]", "-", 
       RowBox[{"13", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"5.", "\[InvisibleSpace]", "-", 
       RowBox[{"12.", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"hypolarC4", "[", "AB", "]"}], 
      RowBox[{"2328", "\[InvisibleSpace]", "-", 
       RowBox[{"96", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.5872", "\[InvisibleSpace]", "-", 
       RowBox[{"0.4842", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"2430", "+", 
       RowBox[{"960", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.2988", "\[InvisibleSpace]", "-", 
       RowBox[{"0.1213", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"Both", " ", "sizes", " ", "multiply"}], "0", 
      RowBox[{"1.7068", "\[InvisibleSpace]", "+", 
       RowBox[{"0.9547", " ", "\[ImaginaryI]"}]}], "0", 
      RowBox[{
       RowBox[{"-", "0.4180"}], "+", 
       RowBox[{"0.0374", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"Both", " ", "angles", " ", "add"}], 
      RowBox[{
       RowBox[{"-", "2419"}], "+", 
       RowBox[{"94", " ", "\[ImaginaryI]"}]}], "0", 
      RowBox[{
       RowBox[{"-", "2371"}], "-", 
       RowBox[{"926", " ", "\[ImaginaryI]"}]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Input",\

 PageWidth->WindowWidth,
 Evaluatable->False,
 FontSize->9,
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Change Target group to\"\>", ",", "\<\"K\"\>"}], 
  "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"Function", 
      RowBox[{"a", " ", "or", " ", 
       SuperscriptBox["u", "2"]}], 
      RowBox[{
       RowBox[{".", "b"}], " ", "or", " ", "hyperangle"}], 
      RowBox[{"c", " ", "or", " ", 
       SuperscriptBox["v", "2"]}], 
      RowBox[{
       RowBox[{".", "d"}], " ", "or", " ", "hyperangle"}]},
     {"vectorA", 
      RowBox[{"3", "-", 
       RowBox[{"2", "\[ImaginaryI]"}]}], "5", 
      RowBox[{"-", "2"}], 
      RowBox[{"2.", "+", "\[ImaginaryI]"}]},
     {
      RowBox[{"hA", "=", 
       RowBox[{"hypolarC4", "[", "A", "]"}]}], 
      RowBox[{
       RowBox[{"-", "51"}], "-", 
       RowBox[{"18", "\[ImaginaryI]"}]}], 
      RowBox[{".09193", "+", 
       RowBox[{"1.2768", "\[ImaginaryI]"}]}], 
      RowBox[{"13", "-", 
       RowBox[{"14", "\[ImaginaryI]"}]}], 
      RowBox[{".67026", "+", 
       RowBox[{".0524", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"A", "-", 
       RowBox[{"hyvectorC4", "[", "hA", "]"}]}], "0", "0", "0", "0"},
     {
      RowBox[{"vector", " ", "B"}], 
      RowBox[{"5", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}], 
      RowBox[{"3.", "-", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "2"}], "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "4"},
     {
      RowBox[{"hB", "=", 
       RowBox[{"hypolarC4", "[", "B", "]"}]}], 
      RowBox[{
       RowBox[{"-", "40"}], "+", 
       RowBox[{"16", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.49525", "\[InvisibleSpace]", "-", 
       RowBox[{"1.7610", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"36", "+", 
       RowBox[{"52", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.22291"}], "-", 
       RowBox[{"0.1609", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"vector", " ", "AB"}], 
      RowBox[{"44", "\[InvisibleSpace]", "-", 
       RowBox[{"7", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"21.", "\[InvisibleSpace]", "-", 
       RowBox[{"15", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"6", "-", 
       RowBox[{"8", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"5.", "-", 
       RowBox[{"12", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"hypolarC4", "[", "AB", "]"}], 
      RowBox[{"2328", "-", 
       RowBox[{"96", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.58718", "\[InvisibleSpace]", "-", 
       RowBox[{"0.48425", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"1196", "+", 
       RowBox[{"172", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.4412", "-", 
       RowBox[{"0.1084", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"Both", " ", "sizes", " ", "multiply"}], "0", 
      RowBox[{"1.7069", "+", 
       RowBox[{".9547", " ", "\[ImaginaryI]"}]}], "0", 
      RowBox[{
       RowBox[{"-", ".5863"}], "+", 
       RowBox[{".0114", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"Both", " ", "angles", " ", "add"}], 
      RowBox[{
       RowBox[{"-", "2419"}], "+", 
       RowBox[{"94", " ", "\[ImaginaryI]"}]}], "0", 
      RowBox[{
       RowBox[{"-", "1147"}], "-", 
       RowBox[{"134", " ", "\[ImaginaryI]"}]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Input",\

 PageWidth->WindowWidth,
 Evaluatable->False,
 FontSize->9,
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2.3 Non-abelian Pseudo-powers and Roots induce rotations.", \
"Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tUntil November 2005, I had found no non-abelian polar forms. Non-abelian \
hoops conserve repeated quadratic factors that are sums of more than three \
squares; each duplicated quadratic releases three degrees of freedom and an \
angle can only take up one degree of freedom. I then realized that both the \
quadratic size and two r,\[Theta] components were needed. Applying this to \
D3, \[Eta]\[Eta]=",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "a"}], ")"}], "2"]}], ")"}], "/", "2"}], " ", 
   "and"}]],
  FontFamily->"Times New Roman"],
 "\n\[Kappa]\[Kappa]=",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"e", "-", "a"}], ")"}], "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "d"}], ")"}], "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"d", "-", "f"}], ")"}], "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"f", "-", "b"}], ")"}], "2"]}], ")"}], "/", "2"}]],
  FontFamily->"Times New Roman"],
 " are supplied by ",
 StyleBox["toPolar",
  FontSlant->"Italic"],
 ". The two radii are then calculated by ",
 StyleBox["toVector",
  FontSlant->"Italic"],
 " as ",
 Cell[BoxData[
  FormBox[
   SqrtBox["\[Kappa]\[Kappa]"], TraditionalForm]],
  FontFamily->"Times New Roman"],
 " and ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"\[Kappa]\[Kappa]", "-", "\[Eta]\[Eta]"}]], TraditionalForm]],
  FontFamily->"Times New Roman"],
 " i.e. ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "d"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "-", "f"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"f", "-", "b"}], ")"}], "2"]}], ")"}], "/", "2"}]], 
   TraditionalForm]]],
 ". The corresponding angles are multiplied by exponents in ",
 StyleBox["hoopP",
  FontSlant->"Italic"],
 "o",
 StyleBox["wer",
  FontSlant->"Italic"],
 ", and give results with correct sizes, so ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      SuperscriptBox["A", 
       RowBox[{"1", "/", "r"}]],
      TraditionalForm], ")"}], "r"], TraditionalForm]]],
 "=A, but the radii are not conserved. Consequently these \"powers\" differ \
from repeated products, though they have the same sizes. I call them \
\"pseudo-powers\". The following examples show this for ",
 Cell[BoxData[
  FormBox[
   RadicalBox["A", "3"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "2"], TraditionalForm]]],
 " in the D3 algebra. The same calculations in the C3C2 algebra show that \
abelian powers match repeated products - provided that angles do not exceed 2\
\[Pi]."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 29A. D3 pseudo-powers induce rotations.", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "\"\<D3\>\"", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{"\"\<A         \>\"", ",", 
    RowBox[{"A", "=", 
     RowBox[{"{", 
      RowBox[{"1.", ",", "3.", ",", "0.", ",", 
       RowBox[{"-", "1."}], ",", 
       RowBox[{"-", "2."}], ",", "1."}], "}"}]}], ",", 
    "\"\<\\nshape  A  =\>\"", ",", 
    RowBox[{"shape", "[", "A", "]"}], ",", 
    "\"\<\\nr3A=\!\(\*SuperscriptBox[\(A\), \(1/3\)]\)    \>\"", ",", 
    RowBox[{"r3A", "=", 
     RowBox[{"hoopPower", "[", 
      RowBox[{"A", ",", 
       RowBox[{"1", "/", "3"}]}], "]"}]}], ",", "\"\<\\nshape r3A =\>\"", ",",
     
    RowBox[{"shape", "[", "r3A", "]"}], ",", 
    "\"\<\\n\!\(\*SuperscriptBox[\(r3A\), \(3\)]\)=A     \>\"", ",", "\n", 
    RowBox[{"r3A3", "=", 
     RowBox[{"hoopPower", "[", 
      RowBox[{"r3A", ",", "3."}], "]"}]}], ",", 
    "\"\<\\nshape \!\(\*SuperscriptBox[\(r3A\), \(3\)]\)=\>\"", ",", 
    RowBox[{"shape", "[", "r3A3", "]"}], ",", "\"\<\\nr3A.r3A.r3A\>\"", ",", 
    RowBox[{"A3AA", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"r3A", ",", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"r3A", ",", "r3A"}], "]"}]}], "]"}]}], ",", 
    "\"\<\\nshape \!\(\*SuperscriptBox[\(r3A\), \(3\)]\)=\>\"", ",", 
    RowBox[{"shape", "[", "A3AA", "]"}], ",", 
    "\"\<\\n\!\(\*SuperscriptBox[\(A\), \(2\)]\)=        \>\"", ",", "\n", 
    RowBox[{"hoopPower", "[", 
     RowBox[{"A", ",", "2."}], "]"}], ",", "\"\<\\nAA =       \>\"", ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "A"}], "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A         \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "3.`", ",", "0.`", ",", 
     RowBox[{"-", "1.`"}], ",", 
     RowBox[{"-", "2.`"}], ",", "1.`"}], "}"}], ",", "\<\"\\nshape  A  =\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", 
     RowBox[{"-", "4.`"}], ",", 
     RowBox[{"-", "5.`"}]}], "}"}], 
   ",", "\<\"\\nr3A=\\!\\(\\*SuperscriptBox[\\(A\\), \\(1/3\\)]\\)    \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.8415068369191917`", ",", "1.724204854952156`", ",", 
     RowBox[{"-", "0.3144346503134702`"}], ",", 
     RowBox[{"-", "0.3410981904303987`"}], ",", 
     RowBox[{"-", "0.6908121876423841`"}], ",", "0.040554386409779375`"}], 
    "}"}], ",", "\<\"\\nshape r3A =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.2599210498948743`", ",", 
     RowBox[{"-", "1.5874010519681994`"}], ",", 
     RowBox[{"-", "1.709975946676696`"}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*SuperscriptBox[\\(r3A\\), \\(3\\)]\\)=A     \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "0.9999999999999998`", ",", "2.9999999999999987`", ",", "0", ",", 
     RowBox[{"-", "0.9999999999999966`"}], ",", 
     RowBox[{"-", "1.9999999999999967`"}], ",", "1.0000000000000013`"}], 
    "}"}], ",", "\<\"\\nshape \\!\\(\\*SuperscriptBox[\\(r3A\\), \\(3\\)]\\)=\
\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"2.000000000000006`", ",", 
     RowBox[{"-", "4.`"}], ",", 
     RowBox[{"-", "4.9999999999999885`"}]}], "}"}], 
   ",", "\<\"\\nr3A.r3A.r3A\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"10.739318173995784`", ",", "12.167783272907078`", ",", 
     RowBox[{"-", "4.187868655321187`"}], ",", 
     RowBox[{"-", "6.289252845067995`"}], ",", 
     RowBox[{"-", "7.551449518674594`"}], ",", 
     RowBox[{"-", "2.878530427839082`"}]}], "}"}], 
   ",", "\<\"\\nshape \\!\\(\\*SuperscriptBox[\\(r3A\\), \\(3\\)]\\)=\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"2.000000000000007`", ",", 
     RowBox[{"-", "3.9999999999999973`"}], ",", 
     RowBox[{"-", "5.000000000000028`"}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*SuperscriptBox[\\(A\\), \\(2\\)]\\)=        \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.333333333333333`"}], ",", "6.2007750890142095`", ",", 
     "1.6666666666666672`", ",", 
     RowBox[{"-", "2.4015501780284176`"}], ",", 
     RowBox[{"-", "6.333333333333333`"}], ",", "6.2007750890142095`"}], "}"}],
    ",", "\<\"\\nAA =       \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"12.`", ",", "6.`", ",", "3.`", ",", 
     RowBox[{"-", "10.`"}], ",", 
     RowBox[{"-", "5.`"}], ",", 
     RowBox[{"-", "2.`"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Example 29B. C3C2 powers are not rotated unless angles exceed 2\[Pi].\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "\"\<C3C2\>\"", "]"}], ";", 
  RowBox[{"Chop", "[", 
   RowBox[{"{", 
    RowBox[{"\"\<A         \>\"", ",", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{"1.", ",", "3.", ",", "0.", ",", 
        RowBox[{"-", "1."}], ",", 
        RowBox[{"-", "2."}], ",", "1."}], "}"}]}], ",", 
     "\"\<\\nshape  A  =\>\"", ",", 
     RowBox[{"shape", "[", "A", "]"}], ",", 
     "\"\<\\nr3A=\!\(\*SuperscriptBox[\(A\), \(1/3\)]\)    \>\"", ",", 
     RowBox[{"r3A", "=", 
      RowBox[{"hoopPower", "[", 
       RowBox[{"A", ",", 
        RowBox[{"1", "/", "3"}]}], "]"}]}], ",", "\"\<\\nshape r3A =\>\"", 
     ",", 
     RowBox[{"shape", "[", "r3A", "]"}], ",", 
     "\"\<\\n\!\(\*SuperscriptBox[\(r3A\), \(3\)]\)=A     \>\"", ",", "\n", 
     RowBox[{"r3A3", "=", 
      RowBox[{"hoopPower", "[", 
       RowBox[{"r3A", ",", "3."}], "]"}]}], ",", 
     "\"\<\\nshape \!\(\*SuperscriptBox[\(r3A\), \(3\)]\)=\>\"", ",", 
     RowBox[{"shape", "[", "r3A3", "]"}], ",", "\"\<\\nr3A.r3A.r3A\>\"", ",", 
     
     RowBox[{"A3AA", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"r3A", ",", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"r3A", ",", "r3A"}], "]"}]}], "]"}]}], ",", 
     "\"\<\\nshape \!\(\*SuperscriptBox[\(r3A\), \(3\)]\)=\>\"", ",", 
     RowBox[{"shape", "[", "A3AA", "]"}], ",", 
     "\"\<\\n\!\(\*SuperscriptBox[\(A\), \(2\)]\)=        \>\"", ",", "\n", 
     RowBox[{"hoopPower", "[", 
      RowBox[{"A", ",", "2."}], "]"}], ",", "\"\<\\nAA =       \>\"", ",", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"A", ",", "A"}], "]"}]}], "}"}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A         \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "3.`", ",", "0", ",", 
     RowBox[{"-", "1.`"}], ",", 
     RowBox[{"-", "2.`"}], ",", "1.`"}], "}"}], ",", "\<\"\\nshape  A  =\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", "6.`", ",", "1.`", ",", "27.`"}], "}"}], 
   ",", "\<\"\\nr3A=\\!\\(\\*SuperscriptBox[\\(A\\), \\(1/3\\)]\\)    \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "1.179506940454502`", ",", "0.17950694045450213`", ",", 
     "0.17950694045450222`", ",", 
     RowBox[{"-", "0.42619992382287764`"}], ",", 
     RowBox[{"-", "0.42619992382287775`"}], ",", "0.5738000761771221`"}], 
    "}"}], ",", "\<\"\\nshape r3A =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1.2599210498948732`", ",", "1.8171205928321397`", ",", "1.`", ",", 
     "2.999999999999999`"}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*SuperscriptBox[\\(r3A\\), \\(3\\)]\\)=A     \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "2.999999999999999`", ",", "0", ",", 
     RowBox[{"-", "1.`"}], ",", 
     RowBox[{"-", "1.9999999999999993`"}], ",", "0.9999999999999993`"}], 
    "}"}], ",", "\<\"\\nshape \\!\\(\\*SuperscriptBox[\\(r3A\\), \\(3\\)]\\)=\
\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1.9999999999999993`", ",", "5.999999999999999`", ",", 
     "0.9999999999999991`", ",", "26.99999999999998`"}], "}"}], 
   ",", "\<\"\\nr3A.r3A.r3A\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "0.9999999999999998`", ",", "2.9999999999999987`", ",", "0", ",", 
     RowBox[{"-", "0.9999999999999996`"}], ",", 
     RowBox[{"-", "1.999999999999999`"}], ",", "0.9999999999999987`"}], "}"}],
    ",", "\<\"\\nshape \\!\\(\\*SuperscriptBox[\\(r3A\\), \\(3\\)]\\)=\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "1.9999999999999996`", ",", "5.999999999999998`", ",", 
     "0.9999999999999989`", ",", "26.999999999999957`"}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*SuperscriptBox[\\(A\\), \\(2\\)]\\)=        \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.`"}], ",", "11.`", ",", "10.999999999999995`", ",", 
     "4.`", ",", 
     RowBox[{"-", "9.999999999999998`"}], ",", 
     RowBox[{"-", "9.999999999999993`"}]}], "}"}], 
   ",", "\<\"\\nAA =       \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.`"}], ",", "11.`", ",", "11.`", ",", "4.`", ",", 
     RowBox[{"-", "10.`"}], ",", 
     RowBox[{"-", "10.`"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "\tQuaternion pseudo-powers can be formulated in different ways; quaternions \
conserve the sum of four squares which can be paired off arbitrarily. The \
implementation uses ArcTan[a,b] and ArcTan[c,d]; ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      SuperscriptBox["Q", "r"],
      TraditionalForm], ")"}], 
    RowBox[{"1", "/", "r"}]], TraditionalForm]]],
 " reverts correctly (if no wrap-round occurs). The standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package <<Quaternion`  implements procedures for ",
 StyleBox["Quaternion[{a,b,c,d}] ",
  FontSlant->"Italic"],
 "objects, but rejects biquaternions (i.e.with complex coefficients). My ",
 StyleBox["QPower[{a,b,c,d},r]",
  FontSlant->"Italic"],
 " calculates powers and roots for both quaternions and biquaternions, \
matching ",
 StyleBox["Quaternion[{a,b,c,d}]^r ",
  FontSlant->"Italic"],
 "in the first case. "
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 29c. Quaternion powers and pseudo-powers.", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<A           =\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{".2", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{".5", "-", 
      RowBox[{".1", "\[ImaginaryI]"}]}], ",", ".3", ",", 
     RowBox[{"-", ".4"}]}], "}"}], ",", "\"\<\\nCube Root r3A=\>\"", ",", 
   RowBox[{"r3A", "=", 
    RowBox[{"QPower", "[", 
     RowBox[{
      RowBox[{"A", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "+", 
          RowBox[{".2", " ", "\[ImaginaryI]"}]}], ",", 
         RowBox[{".5", "-", 
          RowBox[{".1", "\[ImaginaryI]"}]}], ",", ".3", ",", 
         RowBox[{"-", ".4"}]}], "}"}]}], ",", 
      RowBox[{"1", "/", "3"}]}], "]"}]}], ",", "\"\<\\ncubes correctly\>\"", 
   ",", "\[IndentingNewLine]", 
   RowBox[{"r3A3", "=", 
    RowBox[{"Chop", "[", 
     RowBox[{"QPower", "[", 
      RowBox[{"r3A", ",", "3"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"id", "[", "\"\<Qr\>\"", "]"}], ";", 
    "\"\<\\nPseudo-Cube Root q3A=\>\""}], ",", 
   RowBox[{"g3A", "=", 
    RowBox[{"hoopPower", "[", 
     RowBox[{"A", ",", 
      RowBox[{"1", "/", "3"}]}], "]"}]}], ",", "\"\<\\ncubes correctly\>\"", 
   ",", "\[IndentingNewLine]", 
   RowBox[{"g3A3", "=", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopPower", "[", 
      RowBox[{"g3A", ",", "3"}], "]"}], "]"}]}], ",", 
   "\"\<\\nA^2           =\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"A2", "=", 
    RowBox[{"Chop", "[", 
     RowBox[{"QPower", "[", 
      RowBox[{"A", ",", "2"}], "]"}], "]"}]}], ",", 
   "\"\<\\nA A is the same\>\"", ",", "\n", 
   RowBox[{"AA", "=", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"A", ",", "A"}], "]"}], "]"}]}], ",", 
   "\"\<\\ncorrect QPower roots  \>\"", ",", "\n", 
   RowBox[{"rA2", "=", 
    RowBox[{"Chop", "[", 
     RowBox[{"QPower", "[", 
      RowBox[{"A2", ",", 
       RowBox[{"1", "/", "2"}]}], "]"}], "]"}]}], ",", 
   "\"\<\\nhoopPower A^2\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"gA2", "=", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopPower", "[", 
      RowBox[{"A", ",", "2"}], "]"}], "]"}]}], ",", 
   "\"\<\\ncorrect hoopPower roots\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"Chop", "[", 
    RowBox[{"hoopPower", "[", 
     RowBox[{"gA2", ",", 
      RowBox[{"1", "/", "2"}]}], "]"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A           =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{"0.2`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.5`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ",", "0.3`", ",", 
     RowBox[{"-", "0.4`"}]}], "}"}], ",", "\<\"\\nCube Root r3A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.0466264504350709`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.045570703801412205`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.15026919914397022`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.04502081217784149`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.09188847783434914`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.008634791739835045`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.12251797044579887`"}], "+", 
      RowBox[{"0.011513055653113393`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\ncubes correctly\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.0000000000000004`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.19999999999999982`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.5000000000000002`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.09999999999999988`", " ", "\[ImaginaryI]"}]}], ",", 
     "0.3000000000000002`", ",", 
     RowBox[{"-", "0.4000000000000003`"}]}], "}"}], 
   ",", "\<\"\\nPseudo-Cube Root q3A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.7069860045263642`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.05929016780217533`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.10836924093942352`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.029446089346106017`", " ", "\[ImaginaryI]"}]}], ",", 
     "0.7560856467169442`", ",", 
     RowBox[{"-", "0.24144361614268647`"}]}], "}"}], 
   ",", "\<\"\\ncubes correctly\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.0000000000000002`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.19999999999999965`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.49999999999999983`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.09999999999999924`", " ", "\[ImaginaryI]"}]}], ",", 
     "0.30000000000000016`", ",", 
     RowBox[{"-", "0.40000000000000013`"}]}], "}"}], 
   ",", "\<\"\\nA^2           =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.47000000000000014`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.5000000000000002`", " ", "\[ImaginaryI]"}]}], ",", "1.04`", 
     ",", 
     RowBox[{"0.6`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.12000000000000005`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.8`"}], "-", 
      RowBox[{"0.16000000000000006`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\nA A is the same\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.47`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.5`", " ", "\[ImaginaryI]"}]}], ",", "1.04`", ",", 
     RowBox[{"0.6000000000000001`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.12`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.8`"}], "-", 
      RowBox[{"0.16000000000000003`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\ncorrect QPower roots  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.20000000000000007`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.5`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.10000000000000007`", " ", "\[ImaginaryI]"}]}], ",", 
     "0.29999999999999993`", ",", 
     RowBox[{"-", "0.3999999999999999`"}]}], "}"}], 
   ",", "\<\"\\nhoopPower A^2\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.8708116248988153`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.5604192616283038`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.2278523695613623`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.043180767621174315`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"-", "0.07000000000000003`"}], ",", 
     RowBox[{"-", "0.24`"}]}], "}"}], 
   ",", "\<\"\\ncorrect hoopPower roots\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.2000000000000001`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.5000000000000001`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.10000000000000016`", " ", "\[ImaginaryI]"}]}], ",", "0.3`", 
     ",", 
     RowBox[{"-", "0.4`"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "Quaternion algebra is a Clifford algebra, and so rotations can employ \
\"rotors\" to pr- and post-multiply by a half angle. This will be implemented \
in ",
 StyleBox["CliffordG.m",
  FontSlant->"Italic"],
 ". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
6.2.4 Powers and Repeated Products may differ for Signed Sizes.\
\>", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tA distinction must be drawn between powers and repeated products wherever \
sizes are signed. Powers, and their shapes, are continuous functions of the \
exponents. Powers revert correctly unless angles exceed 2\[Pi]. Repeated \
products must have sizes that respect the signs of the original sizes. If A \
has a negative size, AAA and AAAAA will have the same sign negative, but AA \
and AAAA will have it positive. ",
 Cell[BoxData[
  FormBox[
   SqrtBox["AA"], TraditionalForm]]],
 " will not equal A. If A has a complex size, powers will only have the same \
sign when the exponent is divisible by 4, etc. The power ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "p"], TraditionalForm]]],
 " is a continuous function of ",
 StyleBox["p",
  FontSlant->"Italic"],
 ".\n\tThis is demonstrated in the next example, where a C4 vector is chosen \
to have the second size negative. A={3.,4.,2.,4.5}, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "2"], TraditionalForm]]],
 " differs from AA; but ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    SuperscriptBox["A", "2"]], TraditionalForm]]],
 " is A whilst ",
 Cell[BoxData[
  FormBox[
   SqrtBox["AA"], TraditionalForm]]],
 "={4.75,2.25,3.75,2.75}. The angle is small, so powers up the 6th reverts \
correctly; the 7th power gives a rotated 7th root (not shown)."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example 29a. C4 powers & multiplication with a negative size.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "\"\<C4\>\"", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{"\"\<If A = \>\"", ",", 
    RowBox[{"A", "=", 
     RowBox[{"{", 
      RowBox[{"3.", ",", "4.", ",", "2.", ",", "4.5"}], "}"}]}], ",", 
    "\"\<\\nShape[A] =   \>\"", ",", 
    RowBox[{"shape", "[", "A", "]"}], ",", "\"\<\\n& toPolar[A]=\>\"", ",", 
    RowBox[{"toPolar", "[", "A", "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"If A = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3.`", ",", "4.`", ",", "2.`", ",", "4.5`"}], "}"}], 
   ",", "\<\"\\nShape[A] =   \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"13.5`", ",", 
     RowBox[{"-", "3.5`"}], ",", "1.25`"}], "}"}], 
   ",", "\<\"\\n& toPolar[A]=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"13.5`", ",", 
     RowBox[{"-", "3.5`"}], ",", "1.25`", ",", 
     RowBox[{"-", "0.4636476090008061`"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A19", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*SuperscriptBox[\(A\), \(1.99\)]\)\>\"", ",", 
        RowBox[{"hoopPower", "[", 
         RowBox[{"A", ",", "1.99"}], "]"}]}], "}"}], "]"}]}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SuperscriptBox[\(A\), \(2\)]\)\>\"", ",", 
       RowBox[{"A20", "=", 
        RowBox[{"hoopPower", "[", 
         RowBox[{"A", ",", "2"}], "]"}]}]}], "}"}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SuperscriptBox[\(A\), \(2.01\)]\)\>\"", ",", 
       RowBox[{"A21", "=", 
        RowBox[{"hoopPower", "[", 
         RowBox[{"A", ",", "2.01"}], "]"}]}]}], "}"}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"rA20", "=", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*SqrtBox[SuperscriptBox[\(A\), \(2\)]]\)\>\"", ",", 
        RowBox[{"hoopPower", "[", "A20", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"A\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",
FontSlant->\"Italic\"]\)\>\"", ",", 
       RowBox[{"AA", "=", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", "A"}], "]"}]}]}], "}"}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SqrtBox[\(A . A\)]\)\>\"", ",", 
       RowBox[{"rAA", "=", 
        RowBox[{"hoopPower", "[", "AA", "]"}]}]}], "}"}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*RadicalBox[SuperscriptBox[\(A\), \(6\)], \(6\)]\)\>\"", ",", 
       
       RowBox[{"r6A6", "=", 
        RowBox[{"hoopPower", "[", 
         RowBox[{
          RowBox[{"hoopPower", "[", 
           RowBox[{"A", ",", "6"}], "]"}], ",", 
          RowBox[{"1", "/", "6"}]}], "]"}]}]}], "}"}], "]"}]}], "}"}], "//", 
  "tf"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"\\!\\(\\*SuperscriptBox[\\(A\\), \\(1.99\\)]\\)\"\>", 
      "41.74446850777318`", "46.91862160036751`", "40.99068159240931`", 
      "47.91402230130491`"},
     {"\<\"\\!\\(\\*SuperscriptBox[\\(A\\), \\(2\\)]\\)\"\>", "42.875`", 
      "48.125`", "42.125`", "49.125`"},
     {"\<\"\\!\\(\\*SuperscriptBox[\\(A\\), \\(2.01\\)]\\)\"\>", 
      "44.035903835721854`", "49.36273103621788`", "43.28971628609258`", 
      "50.36731784269318`"},
     {"\<\"\\!\\(\\*SqrtBox[SuperscriptBox[\\(A\\), \\(2\\)]]\\)\"\>", "3.`", 
      "4.`", "2.`", "4.5`"},
     {"\<\"\\!\\(\\*\\nStyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\
\\(\\*\\nStyleBox[\\\".\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "49.`", "42.`", 
      "48.25`", "43.`"},
     {"\<\"\\!\\(\\*SqrtBox[\\(A . A\\)]\\)\"\>", "4.75`", "2.25`", "3.75`", 
      "2.75`"},
     {"\<\"\\!\\(\\*RadicalBox[SuperscriptBox[\\(A\\), \\(6\\)], \
\\(6\\)]\\)\"\>", "2.9999999999999996`", "3.999999999999999`", 
      "1.9999999999999996`", "4.5`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3. Generalized Multiplicative Inverse, Division .", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tCramer's rule provides a generalized multiplicative inverse Ainv, such \
that Ainv\[CenterDot]A = {1,0,...} (the unit). Wherever the multiplication is \
conservative, Ainv\[CenterDot]AB = B, allowing division C/A = \
Ainv\[CenterDot]C. This is implemented as ",
 StyleBox["hoopInverse",
  FontSlant->"Italic"],
 ". Ainv is the left inverse in non-abelian hoops. For small algebras, Ainv \
can be found by solving the equations {p,q,r,..} \[Times] {a,b,c,..} == \
{1,0,0,..} for the elements of the inverse, {p,q,r,..}. This was demonstrated \
in Example 16. It is shown for several more algebras in Examples 30 - 32. \
Each element of the inverse is a fraction, with a divisor (denominator) that \
is related to the table determinant. The denominators factorise in many \
cases, permitting the inverse elements to be expressed as partial fractions. \
This provides ",
 "generalized",
 " \"partial-fraction division\", which is developed in Sections 6.4. & 6.5. \
The partial fraction numerators are derivations of the denominators, wrt. \
each variable. Division is closely related to differentiation and the orbits \
are solutions to the banded sets of differential equations described by the \
hoops.\n\tExample 30 gives the general \"Terplex\" or ",
 StyleBox["C3",
  FontSlant->"Italic"],
 " inverse of ",
 StyleBox["{a,b,c}",
  FontSlant->"Italic"],
 ", and then shows that ",
 StyleBox["Ainv",
  FontSlant->"Italic"],
 "*",
 StyleBox["AB=B",
  FontSlant->"Italic"],
 ". Terplex \"fits between\" Real and Complex algebra (which are folded from \
the ",
 StyleBox["C2",
  FontSlant->"Italic"],
 " and ",
 StyleBox["C4",
  FontSlant->"Italic"],
 " groups and are \"algebras without real divisors of zero\"). It differs \
from them in having partial-fraction divisors of zero."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example 30. \"Terplex\" vecs have a multiplicative inverse & Partial-fraction \
Division.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{id[C3];\"Terplex solution to {p,q,r}\[Times]{a,b,c}=={1,0,0} \
is\",Solve[hoopTimes[{p,q,r},{a,b,c},C3]=={1,0,0},{p,q,r}],
\"\\nThe denominator is the determinant. It factorises into\" \
,fa[C3],\"\\nallowing the elements to split into partial fractions so that \
the Terplex inverse of {a,b,c} =\",Apart[hoopInverse[{a,b,c}]],\"\\nNumeric \
Example:-\",{\"\\nA    =\",
A={1.,5,5},\"\\nB    =\",B={4.,3,1},\"\\nAB   =\",AB=hoopTimes[A,B],\"\\nAi = \
 \",Ainv=hoopInverse[A],
    \"\\nAi\[Times]AB \",hoopTimes[Ainv,AB]}//tf}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Terplex solution to {p,q,r}\[Times]{a,b,c}=={1,0,0} is\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"b", " ", "c"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
          SuperscriptBox["c", "3"]}]]}]}], ",", 
      RowBox[{"q", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"a", " ", "b"}], "-", 
          SuperscriptBox["c", "2"]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
          SuperscriptBox["c", "3"]}]]}]}], ",", 
      RowBox[{"r", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"a", " ", "c"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
          SuperscriptBox["c", "3"]}]]}]}]}], "}"}], "}"}], 
   ",", "\<\"\\nThe denominator is the determinant. It factorises into\"\>", 
   ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"a", " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"a", " ", "c"}], "-", 
      RowBox[{"b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}], 
   ",", "\<\"\\nallowing the elements to split into partial fractions so that \
the Terplex inverse of {a,b,c} =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"a", " ", "b"}], "+", 
          SuperscriptBox["b", "2"], "-", 
          RowBox[{"a", " ", "c"}], "-", 
          RowBox[{"b", " ", "c"}], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}]]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", 
        RowBox[{"2", " ", "c"}]}], 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"a", " ", "b"}], "+", 
          SuperscriptBox["b", "2"], "-", 
          RowBox[{"a", " ", "c"}], "-", 
          RowBox[{"b", " ", "c"}], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}]]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "-", "c"}], 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"a", " ", "b"}], "+", 
          SuperscriptBox["b", "2"], "-", 
          RowBox[{"a", " ", "c"}], "-", 
          RowBox[{"b", " ", "c"}], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}]]}]}], "}"}], 
   ",", "\<\"\\nNumeric Example:-\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"{", 
      RowBox[{"\<\"\\nA    =\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", "5", ",", "5"}], "}"}], ",", "\<\"\\nB    =\"\>", 
       ",", 
       RowBox[{"{", 
        RowBox[{"4.`", ",", "3", ",", "1"}], "}"}], ",", "\<\"\\nAB   =\"\>", 
       ",", 
       RowBox[{"{", 
        RowBox[{"24.`", ",", "28.`", ",", "36.`"}], "}"}], 
       ",", "\<\"\\nAi =  \"\>", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13636363636363635`"}], ",", "0.11363636363636365`", 
         ",", "0.11363636363636365`"}], "}"}], 
       ",", "\<\"\\nAi\[Times]AB \"\>", ",", 
       RowBox[{"{", 
        RowBox[{
        "4.000000000000002`", ",", "3.0000000000000013`", ",", 
         "1.0000000000000013`"}], "}"}]}], "}"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThe database contains nine 3\[Times]3 signed tables that define \
conservative division algebras. The multiplicative inverses for four of these \
are found in Example 31. The shapes are conjugates of the determinants; in \
the first example conjugation has no effect as everything is real.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["Example 31. Inverses for some other 3-element algebras.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{\"C3C2c =\",tst=cd[{3}];tst//tf,id[tst];\"C3C2c solution to \
{p,q,r}\[Times]{a,b,c}]=={1,0,0} \
is\",Solve[hoopTimes[{p,q,r},{a,b,c}]=={1,0,0},{p,q,r}],
\"\\nThe denominator is the determinant and factorises into\\n \
(a-b+c)*(((a+b)^2+(b+c)^2+(c-a)^2)/2)\",

\"\\n\\nC4C3c =\",tst=C4C3c;tst//tf,id[tst];
\"\\nC4C3c solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} is\",
Solve[hoopTimes[{p,q,r},{a,b,c}]=={1,0,0},{p,q,r}],
\"\\nThe denominator is NOT the determinant, which is\",
Expand[fa[tst]],\"the denominator factorises into ((a-\[ImaginaryI] b-\
\[ImaginaryI] c)((a + \[ImaginaryI] b)^2-(b-c)^2+(\[ImaginaryI] c+a)^2)/2\",

tst=C3i;id[tst];\"\\n\\nC3i =\",tst//tf,\"\\nC3i solution to \
{p,q,r}\[Times]{a,b,c}]=={1,0,0} 
is\",Solve[hoopTimes[{p,q,r},{a,b,c}]\[Equal]{1,0,0},{p,q,r}],    \"\\nThe \
denominator is NOT the determinant, which is\",
Expand[fa[tst]],\"the denominator factorises into (a-\[ImaginaryI] b-c)((a+\
\[ImaginaryI] b)^2+(\[ImaginaryI] b-c)^2+(c+a)^2)/2\",

tst=C9J;\"\\n\\nC9J =\",tst//tf,id[C9J];\"\\nC9J solution to \
{p,q,r}\[Times]{a,b,c}]=={1,0,0} is\",
Solve[hoopTimes[{p,q,r},{a,b,c}]=={1,0,0},{p,q,r}]/.\[DoubleStruckCapitalJ]^3 \
-> 1,
\"\\nThe denominator does not factorize. It is NOT the determinant, which \
is\" ,-fa[tst]/.\[DoubleStruckCapitalJ]^3 -> 1}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C3C2c =\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", "3", "1"},
        {"3", "1", "2"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"C3C2c solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} is\"\>", ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"b", " ", "c"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
          SuperscriptBox["c", "3"]}]]}]}], ",", 
      RowBox[{"q", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"a", " ", "b"}], "-", 
          SuperscriptBox["c", "2"]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
          SuperscriptBox["c", "3"]}]]}]}], ",", 
      RowBox[{"r", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"a", " ", "c"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
          SuperscriptBox["c", "3"]}]]}]}]}], "}"}], "}"}], 
   ",", "\<\"\\nThe denominator is the determinant and factorises into\\n \
(a-b+c)*(((a+b)^2+(b+c)^2+(c-a)^2)/2)\"\>", ",", "\<\"\\n\\nC4C3c =\"\>", ",",
    
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", 
         RowBox[{"3", " ", "\[ImaginaryI]"}], 
         RowBox[{"-", "1"}]},
        {"3", 
         RowBox[{"-", "1"}], 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\nC4C3c solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} is\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"b", " ", "c"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["b", "3"]}], "+", 
          RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["c", "3"]}]}]]}]}], ",", 
      RowBox[{"q", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "a", " ", "b"}], "+", 
          SuperscriptBox["c", "2"]}], 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["a", "3"]}], "+", 
          SuperscriptBox["b", "3"], "+", 
          RowBox[{"3", " ", "\[ImaginaryI]", " ", "a", " ", "b", " ", "c"}], 
          "+", 
          SuperscriptBox["c", "3"]}]]}]}], ",", 
      RowBox[{"r", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "a", " ", "c"}]}], 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["a", "3"]}], "+", 
          SuperscriptBox["b", "3"], "+", 
          RowBox[{"3", " ", "\[ImaginaryI]", " ", "a", " ", "b", " ", "c"}], 
          "+", 
          SuperscriptBox["c", "3"]}]]}]}]}], "}"}], "}"}], 
   ",", "\<\"\\nThe denominator is NOT the determinant, which is\"\>", ",", 
   RowBox[{
    SuperscriptBox["a", "3"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["b", "3"]}], "+", 
    RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["c", "3"]}]}], 
   ",", "\<\"the denominator factorises into ((a-\[ImaginaryI] \
b-\[ImaginaryI] c)((a + \[ImaginaryI] b)^2-(b-c)^2+(\[ImaginaryI] c+a)^2)/2\"\
\>", ",", "\<\"\\n\\nC3i =\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", "3", "\[ImaginaryI]"},
        {"3", "\[ImaginaryI]", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\nC3i solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} \\nis\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "b", " ", "c"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["b", "3"]}], "-", 
          RowBox[{"3", " ", "\[ImaginaryI]", " ", "a", " ", "b", " ", "c"}], 
          "-", 
          SuperscriptBox["c", "3"]}]]}]}], ",", 
      RowBox[{"q", "\[Rule]", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", "b"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["c", "2"]}]}], ")"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SuperscriptBox["a", "3"]}], "+", 
         SuperscriptBox["b", "3"], "-", 
         RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["c", "3"]}]}]]}], ",", 
      RowBox[{"r", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}]}], ")"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SuperscriptBox["a", "3"]}], "+", 
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["c", "3"]}]}]]}]}]}], "}"}], "}"}], 
   ",", "\<\"\\nThe denominator is NOT the determinant, which is\"\>", ",", 
   RowBox[{
    SuperscriptBox["a", "3"], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["b", "3"]}], "+", 
    RowBox[{"3", " ", "\[ImaginaryI]", " ", "a", " ", "b", " ", "c"}], "-", 
    SuperscriptBox["c", "3"]}], 
   ",", "\<\"the denominator factorises into (a-\[ImaginaryI] b-c)((a+\
\[ImaginaryI] b)^2+(\[ImaginaryI] b-c)^2+(c+a)^2)/2\"\>", 
   ",", "\<\"\\n\\nC9J =\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", "3", "\[DoubleStruckCapitalJ]"},
        {"3", "\[DoubleStruckCapitalJ]", 
         RowBox[{"2", " ", "\[DoubleStruckCapitalJ]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\nC9J solution to {p,q,r}\[Times]{a,b,c}]=={1,0,0} is\"\>", ",",
    
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
          RowBox[{
          "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}],
           "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", 
           SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}], ",", 
      RowBox[{"q", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"a", " ", "b"}], "-", 
          RowBox[{
           SuperscriptBox["c", "2"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
          RowBox[{
          "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}],
           "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", 
           SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}], ",", 
      RowBox[{"r", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"a", " ", "c"}]}], 
         RowBox[{
          SuperscriptBox["a", "3"], "+", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
          RowBox[{
          "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}],
           "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", 
           SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}]}], "}"}], 
    "}"}], ",", "\<\"\\nThe denominator does not factorize. It is NOT the \
determinant, which is\"\>", ",", 
   RowBox[{
    SuperscriptBox["c", "3"], "+", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
    RowBox[{
    "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], "+", 
    
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The database also contains eleven 4\[Times]4 signed tables. Example 32 \
calculates the inverses for four of them:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell["Example 32. Some 4-element algebra inverses.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{\"Qr =\",tst=cd[{-1,-1}];tst//tf,id[tst];\"Qr solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\",Solve[hoopTimes[{p,q,r,s},{a,b,c,d}]=={1,0,0,0},{p,q,r,s}],\"\\nThe \
determinant is the denominator squared 
(a^2+b^2+c^2+d^2)^2\",

\"\\n\\nDav=\",tst=cd[{-1,-1.}];tst//tf,id[tst];\"\\nDavenport Algebra \
solution to {p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\",ss=Solve[hoopTimes[{p,q,r,s},{a,b,c,d}]=={1,0,0,0},{p,q,r,s}];d0=Factor[\
ss[[1,1,2,3,1]]][[1]];d1=frag[d0];e0=  \
Factor[ss[[1,1,2,3,1]]][[2]];e1=frag[e0];{p->Apart[ss[[1,1,2]]],\"\\n\",q->\
Apart[ss[[1,2,2]]],\"\\n\",r->Apart[ss[[1,3,2]]],\"\\n\",s->Apart[ss[[1,4,2]]]\
}/.{d0\[Rule]d1,e0\[Rule]e1},\"\\nThe denominator is the determinant, with \
factors\", {d1,e1},

\"\\n\\nP4 =\",tst=P4;tst//tf,id[tst];\"\\nP4 solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\",Solve[hoopTimes[{p,q,r,s},{a,b,c,d}]=={1,0,0,0},{p,q,r,s}],
\"\\nThe determinant is the denominator squared \
\",Factor[Det[gmap[tst,alph]]],

\"\\n\\nCL2 =\",
tst=cd[{1,-1}];tst//tf,id[tst];\"\\nClifford(2) solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} \
is\",Solve[hoopTimes[{p,q,r,s},{a,b,c,d}]=={1,0,0,0},{p,q,r,s}],
\"\\nThe negated determinant is the denominator squared \
\",-Factor[Det[gmap[tst,alph]]]}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Qr =\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", 
         RowBox[{"-", "1"}], "4", 
         RowBox[{"-", "3"}]},
        {"3", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "1"}], "2"},
        {"4", "3", 
         RowBox[{"-", "2"}], 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"Qr solution to {p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} is\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", 
       FractionBox["a", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"]}]]}], ",", 
      RowBox[{"q", "\[Rule]", 
       RowBox[{"-", 
        FractionBox["b", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["d", "2"]}]]}]}], ",", 
      RowBox[{"r", "\[Rule]", 
       RowBox[{"-", 
        FractionBox["c", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["d", "2"]}]]}]}], ",", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", 
        FractionBox["d", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["d", "2"]}]]}]}]}], "}"}], "}"}], 
   ",", "\<\"\\nThe determinant is the denominator squared \
\\n(a^2+b^2+c^2+d^2)^2\"\>", ",", "\<\"\\n\\nDav=\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", 
         RowBox[{"-", "1"}], "4", 
         RowBox[{"-", "3"}]},
        {"3", "4", 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "2"}]},
        {"4", 
         RowBox[{"-", "3"}], 
         RowBox[{"-", "2"}], "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\nDavenport Algebra solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{"a", "-", "d"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "+", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "d"}], ")"}], "2"]}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{"a", "+", "d"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", "d"}], ")"}], "2"]}], ")"}]}]]}], "}"}]}], 
     ",", "\<\"\\n\"\>", ",", 
     RowBox[{"q", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "b"}], "-", "c"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "+", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "d"}], ")"}], "2"]}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "b"}], "+", "c"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", "d"}], ")"}], "2"]}], ")"}]}]]}], "}"}]}], 
     ",", "\<\"\\n\"\>", ",", 
     RowBox[{"r", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "b"}], "-", "c"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "+", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "d"}], ")"}], "2"]}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{"b", "-", "c"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", "d"}], ")"}], "2"]}], ")"}]}]]}], "}"}]}], 
     ",", "\<\"\\n\"\>", ",", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "a"}], "+", "d"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "+", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "d"}], ")"}], "2"]}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{"a", "+", "d"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", "d"}], ")"}], "2"]}], ")"}]}]]}], "}"}]}]}], 
    "}"}], ",", "\<\"\\nThe denominator is the determinant, with factors\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "d"}], ")"}], "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "d"}], ")"}], "2"]}], "}"}]}], "}"}], 
   ",", "\<\"\\n\\nP4 =\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", "1", 
         RowBox[{
          RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}], 
         RowBox[{"3", " ", "\[ImaginaryI]"}]},
        {"3", 
         RowBox[{"4", " ", "\[ImaginaryI]"}], "1", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}]},
        {"4", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], 
         RowBox[{"2", " ", "\[ImaginaryI]"}], "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\nP4 solution to {p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} is\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", 
       FractionBox["a", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"], "-", 
         SuperscriptBox["d", "2"]}]]}], ",", 
      RowBox[{"q", "\[Rule]", 
       FractionBox["b", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"]}]]}], ",", 
      RowBox[{"r", "\[Rule]", 
       FractionBox["c", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"]}]]}], ",", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", 
        FractionBox["d", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"], "-", 
          SuperscriptBox["d", "2"]}]]}]}]}], "}"}], "}"}], 
   ",", "\<\"\\nThe determinant is the denominator squared \"\>", ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["d", "2"]}], ")"}], "2"], ",", "\<\"\\n\\nCL2 =\"\>", 
   ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", "1", "4", "3"},
        {"3", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "1"}], "2"},
        {"4", 
         RowBox[{"-", "3"}], 
         RowBox[{"-", "2"}], "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], 
   ",", "\<\"\\nClifford(2) solution to \
{p,q,r,s}\[Times]{a,b,c,d}]=={1,0,0,0} is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", 
       FractionBox["a", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "-", 
         SuperscriptBox["d", "2"]}]]}], ",", 
      RowBox[{"q", "\[Rule]", 
       FractionBox["b", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"]}]]}], ",", 
      RowBox[{"r", "\[Rule]", 
       FractionBox["c", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["d", "2"]}]]}], ",", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", 
        FractionBox["d", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"], "-", 
          SuperscriptBox["d", "2"]}]]}]}]}], "}"}], "}"}], 
   ",", "\<\"\\nThe negated determinant is the denominator squared \"\>", ",",
    
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["d", "2"]}], ")"}], "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe denominators are the \"plex-conjugates\" (Section 7) of the \
determinants; in many cases the only signs in an expression are \"+\" and \"-\
\" and the conjugate is identical to the determinant. Many inverses were \
found empirically. They led me to believe (until September 2003) that the \
determinant (or its repeated factor) was the denominator. The more general \
conjugate relationship was discovered after finding the inverses for ",
 StyleBox["C9J & C3C3J",
  FontSlant->"Italic"],
 " by the above technique."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe ",
 StyleBox["hoopInverse",
  FontSlant->"Italic"],
 " procedure calculates the inverse for vecs in any conservatve algebra, \
provided that the sizes are known or can be calculated. The individual \
partial-fractions are \"derivates\" (polynomials identical to the derivative \
but defined without recourse to infinitesimals) of the denominators, derived \
with respect to the variables taken in an order corresponding to the position \
of the (possibly signed) unit in the multiplication table. This is a \
consequence of Cramer's method. As another consequence, repeated factors \
appear as multiples of the single-factor term, rather than in the general \
partial-fraction with several terms appearing with different powers in the \
denominators. The database contains the ",
 StyleBox["shape",
  FontSlant->"Italic"],
 " of many protoloop tables, as symbolic denominators or their factors; the \
lists ",
 StyleBox["gi & gp",
  FontSlant->"Italic"],
 " are also included. ",
 StyleBox["gp",
  FontSlant->"Italic"],
 " is related to polar duals and is described in Section 9.1; ",
 StyleBox["gi",
  FontSlant->"Italic"],
 " is the above-mentioned location of the variables, multiplied by any sign \
needed by the corresponding partial fraction; ",
 StyleBox["gi",
  FontSlant->"Italic"],
 " also includes the multiplicity of each size, needed by ",
 StyleBox["hoopInverse",
  FontSlant->"Italic"],
 ". Where known, ",
 StyleBox["plex",
  FontSlant->"Italic"],
 " is also set by ",
 StyleBox["sh",
  FontSlant->"Italic"],
 ". Multiplying a vector by its plex gives a quadratic size; each plex is an \
involution.",
 StyleBox["\n\thoopInverse",
  FontSlant->"Italic"],
 " builds up the inverse for the symbolic protoloop (i.e. with elements \
{a,b,..}), and finally replaces the standard symbols by the coefficients of \
the argument. (The next section discusses the inverse when a size becomes \
zero.) Example 33 uses ",
 StyleBox["hoopInverse",
  FontSlant->"Italic"],
 " to calculate symbolic inverses for several tables, and confirms their \
correctness by showing that Ai\[CenterDot]A={1,0...}. (This has already been \
checked in Test 8 , Section 1.4. of ",
 StyleBox["GroupLoopTest.nb",
  FontSlant->"Italic"],
 ")"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 33. ",
 StyleBox["hoopIn",
  FontSlant->"Italic"],
 StyleBox["verse",
  FontSlant->"Italic"],
 " for some small hoops. "
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"glo", "=", "C3"}], ";", 
     RowBox[{"id", "[", "glo", "]"}]}], ",", "\"\< Inverse =\>\"", ",", 
    RowBox[{"tst", "=", 
     RowBox[{"hoopInverse", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]}], ",", 
    "\"\<\\nconfirmation\>\"", ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"tst", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\"\<\\n\\n\>\"", ",", 
    RowBox[{
     RowBox[{"glo", "=", 
      RowBox[{"cd", "[", 
       RowBox[{"{", "3", "}"}], "]"}]}], ";", 
     RowBox[{"id", "[", "glo", "]"}]}], ",", "\"\< Inverse =\>\"", ",", 
    RowBox[{"tst", "=", 
     RowBox[{"hoopInverse", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]}], ",", 
    "\"\<\\nconfirmation Ainv.A =\>\"", ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"tst", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\"\<\\n\\n\>\"", ",", 
    RowBox[{
     RowBox[{"glo", "=", "C4C3c"}], ";", 
     RowBox[{"id", "[", "glo", "]"}]}], ",", "\"\< Inverse =\>\"", ",", 
    RowBox[{"tst", "=", 
     RowBox[{"hoopInverse", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]}], ",", 
    "\"\<\\nconfirmation Ainv.A =\>\"", ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"tst", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\"\<\\n\\n\>\"", ",", 
    RowBox[{
     RowBox[{"glo", "=", "C9J"}], ";", 
     RowBox[{"id", "[", "glo", "]"}]}], ",", "\"\< Inverse =\>\"", ",", 
    RowBox[{"tst", "=", 
     RowBox[{"hoopInverse", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]}], ",", 
    "\"\<\\nconfirmation Ainv.A =\>\"", ",", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"tst", ",", 
        RowBox[{"{", 
         RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], "\[Rule]", "1"}]}], ",",
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\"\<\\n\\n\>\"", ",", 
    RowBox[{
     RowBox[{"glo", "=", "C4"}], ";", 
     RowBox[{"id", "[", "glo", "]"}]}], ",", "\"\< Inverse =\>\"", ",", 
    RowBox[{"tst", "=", 
     RowBox[{"hoopInverse", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], "]"}]}], ",", 
    "\"\<\\nconfirmation Ainv.A =\>\"", ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"tst", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}]}], "]"}], "]"}], 
    ",", "\[IndentingNewLine]", "\[IndentingNewLine]", "\"\<\\n\\n\>\"", ",", 
    
    RowBox[{
     RowBox[{"glo", "=", 
      RowBox[{"cd", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "}"}], "]"}]}], ";", 
     RowBox[{"id", "[", "glo", "]"}]}], ",", "\"\< Inverse =\>\"", ",", 
    RowBox[{"tst", "=", 
     RowBox[{"hoopInverse", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], "]"}]}], ",", 
    "\"\<\\nconfirmation Ainv.A =\>\"", ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"tst", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}]}], "]"}], "]"}]}], 
   "}"}], "\[IndentingNewLine]"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C3\"\>", ",", "\<\" Inverse =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"b", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       SuperscriptBox["c", "3"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "b"}], "+", 
       SuperscriptBox["c", "2"]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       SuperscriptBox["c", "3"]}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"a", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       SuperscriptBox["c", "3"]}]]}], "}"}], ",", "\<\"\\nconfirmation\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "\<\"\\n\\n\"\>", 
   ",", "\<\"C3\"\>", ",", "\<\" Inverse =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"b", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       SuperscriptBox["c", "3"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "b"}], "+", 
       SuperscriptBox["c", "2"]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       SuperscriptBox["c", "3"]}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"a", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       SuperscriptBox["c", "3"]}]]}], "}"}], 
   ",", "\<\"\\nconfirmation Ainv.A =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "\<\"\\n\\n\"\>", 
   ",", "\<\"C4C3c\"\>", ",", "\<\" Inverse =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       RowBox[{"b", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          SuperscriptBox["c", "3"]}], ")"}]}]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "b"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["c", "2"]}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          SuperscriptBox["c", "3"]}], ")"}]}]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "a", " ", "c"}]}], 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", "\[ImaginaryI]", " ", "a", " ", "b", " ", "c"}], 
        "+", 
        SuperscriptBox["c", "3"]}]]}]}], "}"}], 
   ",", "\<\"\\nconfirmation Ainv.A =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "\<\"\\n\\n\"\>", 
   ",", "\<\"C9J\"\>", ",", "\<\" Inverse =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
       "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", "\[DoubleStruckCapitalJ]"}]}], 
        ")"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
       "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"a", " ", "c"}]}], ")"}], " ", 
       SuperscriptBox["\[DoubleStruckCapitalJ]", "3"]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
       "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]]}], "}"}], ",", "\<\"\\nconfirmation Ainv.A =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
       "+", 
       RowBox[{
        SuperscriptBox["\[DoubleStruckCapitalJ]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
       "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]], ",", "0", ",", "0"}], "}"}], ",", "\<\"\\n\\n\"\>", 
   ",", "\<\"C4\"\>", ",", "\<\" Inverse =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "c"}], ")"}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "d"}], ")"}], "2"]}]], "+", 
        FractionBox["1", 
         RowBox[{"a", "-", "b", "+", "c", "-", "d"}]], "+", 
        FractionBox["1", 
         RowBox[{"a", "+", "b", "+", "c", "+", "d"}]]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"b", "-", "d"}], ")"}]}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "d"}], ")"}], "2"]}]]}], "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "-", "c", "+", "d"}]], "+", 
        FractionBox["1", 
         RowBox[{"a", "+", "b", "+", "c", "+", "d"}]]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "c"}], ")"}]}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "d"}], ")"}], "2"]}]]}], "+", 
        FractionBox["1", 
         RowBox[{"a", "-", "b", "+", "c", "-", "d"}]], "+", 
        FractionBox["1", 
         RowBox[{"a", "+", "b", "+", "c", "+", "d"}]]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "d"}], ")"}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "d"}], ")"}], "2"]}]], "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "-", "c", "+", "d"}]], "+", 
        FractionBox["1", 
         RowBox[{"a", "+", "b", "+", "c", "+", "d"}]]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nconfirmation Ainv.A =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "\<\"\\n\\n\"\>",
    ",", "\<\"CL2\"\>", ",", "\<\" Inverse =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["a", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "-", 
       SuperscriptBox["d", "2"]}]], ",", 
     FractionBox["b", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}]], ",", 
     RowBox[{"-", 
      FractionBox["c", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "-", 
        SuperscriptBox["d", "2"]}]]}], ",", 
     FractionBox["d", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["d", "2"]}]]}], "}"}], 
   ",", "\<\"\\nconfirmation Ainv.A =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "6.4. Zero sizes, \"",
 StyleBox["Renormalizing",
  FontSlant->"Italic"],
 "\" Partial-Fraction Division, \"",
 StyleBox["remainders\"",
  FontSlant->"Italic"],
 " ."
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tIf a vec has one or more size that is zero, size conservation means that \
the same size(s) of any product will also be zero. The result is \
\"projected\" onto a sub-algebra in which this size is constrained to be \
zero. This can create \"annihilators\" (vecs with all shapes zero). Example \
34 sets up three vecs, each having one of the D3 sizes equal to zero. Their \
product is an annihilator - a vector with all sizes zero - in the D3 algebra.\
\
\>", "Text",
 PageWidth->WindowWidth],

Cell["Example 34. D3 vecs with Zero Sizes, Annihilators.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "D3", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{"\"\<z0      =\>\"", ",", 
    RowBox[{"z0", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "1"}], "}"}]}], ",", "\"\<\\n z1      =\>\"", 
    ",", 
    RowBox[{"z1", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "2", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}]}], ",", "\"\<\\n z2      =\>\"", 
    ",", 
    RowBox[{"z2", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "6"}]}], "}"}]}], ",", "\"\<\\nz0 z1    =\>\"", ",", 
    RowBox[{"z01", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"z0", ",", "z1"}], "]"}]}], ",", "\"\<\\nz0 z1 z2 =\>\"", ",", 
    RowBox[{"zz", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"z2", ",", "z01"}], "]"}]}], ",", "\"\<\\nz0 shape      =\>\"", 
    ",", 
    RowBox[{"shape", "[", "z0", "]"}], ",", "\"\<\\nz1 shape      =\>\"", ",",
     
    RowBox[{"shape", "[", "z1", "]"}], ",", "\"\<\\nz0z1 shape    =\>\"", ",",
     
    RowBox[{"shape", "[", "z01", "]"}], ",", "\"\<\\nz2 shape      =\>\"", 
    ",", 
    RowBox[{"shape", "[", "z2", "]"}], ",", "\"\<\\nz0 z1 z2 shape=\>\"", ",",
     
    RowBox[{"shape", "[", "zz", "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"z0      =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", "\<\"\\n z1      =\"\>", ",",
    
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "2", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", "\<\"\\n z2      =\"\>", ",",
    
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", "\<\"\\nz0 z1    =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"17", ",", "1", ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "5"}], ",", "11"}], "}"}], ",", "\<\"\\nz0 z1 z2 =\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "6", ",", "6", ",", "6", ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", "\<\"\\nz0 shape      =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", "\<\"\\nz1 shape      =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2", ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", "\<\"\\nz0z1 shape    =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "288"}], "}"}], 
   ",", "\<\"\\nz2 shape      =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18"}], ",", "12", ",", "0"}], "}"}], 
   ",", "\<\"\\nz0 z1 z2 shape=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tAny vec ",
 StyleBox["A0",
  FontSlant->"Italic"],
 " with one or more zero size is a member of a constrained sub-algebra (of \
reduced symmetry) in which these sizes are constrained to be zero.  The \
result of multiplying a general vec by such a vec must be in this \
sub-algebra, for the zero sizes are conserved. Multiplication \"projects\" \
vecs into the sub-algebra. To make the algebra conservative, the sizes that \
would be lost are \"ejected\" into \"remainders\". This is analogous to \
integer division of I by J, where I/J gives a quotient Q and a remainder \
(smaller than J) of R, so that I = Q*J + R. By analogy, hoop division A/B \
gives a quotient Q and (if necessary) two remainders Rl & Rr (whose sizes are \
the zeroes of the left and right arguments respectively), with A=Q*B+Rl, \
B=Q*A+Rr. As division is multiplication by an inverse (e.g. B=1/C), \
multiplication gives a product P but also generates left & right remainders; \
A*B = P+Rl+Rr, with P/A+Rl = B, P/B+Rr = A. This is implemented in ",
 StyleBox["hoopT",
  FontSlant->"Italic"],
 "i",
 StyleBox["mes",
  FontSlant->"Italic"],
 " wherever the multiplicands have different sizes that are zero to within an \
arbitrarily small number ",
 StyleBox["hmin",
  FontSlant->"Italic"],
 ". This requires that the inverse calculated by ",
 StyleBox["hoopInverse[B]",
  FontSlant->"Italic"],
 " is given a zero size wherever B has near-zero size. Note the analogy with \
\"q-deformed\" algebras.",
 StyleBox[" ",
  FontSlant->"Italic"],
 "In effect, the multiplicands are reduced to vecs with compatible sizes \
before multiplication, by ejecting the remainders. Of course, in many cases \
the shapes are compatible and both the remainders are zero vectors. \n\t\
Example 35 sets up two vecs that have different zero-sizes in the C4 algebra, \
multiplies them, shows that the remainders have the correct sizes, and shows \
that dividing AB by B0 does not give A until the remainder has been added."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "C4", "]"}], ";", 
  RowBox[{"Chop", "[", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Example 35. C4 multiplication with remainders\>\"", ",", 
     "\"\<\\n         A0 = \>\"", ",", 
     RowBox[{"A0", "=", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "}"}]}], ",", 
     "\"\<\\n\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)A0 = \>\"", ",", 
     RowBox[{"sA0", "=", 
      RowBox[{"shape", "[", 
       RowBox[{"A0", ",", "\"\<C4\>\""}], "]"}]}], ",", 
     "\[IndentingNewLine]", "\"\<\\n         B0 = \>\"", ",", 
     RowBox[{"B0", "=", 
      RowBox[{"{", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}], ",", "2", ",", 
        RowBox[{"-", "4"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     "\"\<\\n\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) B0 = \>\"", ",", 
     RowBox[{"shape", "[", "B0", "]"}], ",", "\[IndentingNewLine]", 
     "\"\<\\n         AB = \>\"", ",", 
     RowBox[{"AB", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A0", ",", "B0"}], "]"}]}], ",", "\[IndentingNewLine]", 
     "\"\<\\n\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) AB = \>\"", ",", 
     RowBox[{"shape", "[", "AB", "]"}], ",", "\[IndentingNewLine]", 
     "\"\<\\n\!\(\*
StyleBox[\"Note\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"that\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"two\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"sizes\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"have\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"become\",
FontSlant->\"Italic\"]\) 0\>\"", ",", "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Remainder\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Rl\",
FontSlant->\"Italic\"]\)\>\"", ",", 
     RowBox[{"RA", "=", "Rl"}], ",", "\"\<\\n\!\(\*
StyleBox[\"has\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\) \>\"", ",", 
     RowBox[{"shape", "[", "Rl", "]"}], ",", "\"\<\\n\!\(\*
StyleBox[\"remainder\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Rr\",
FontSlant->\"Italic\"]\)\>\"", ",", "Rr", ",", "\"\<\\n\!\(\*
StyleBox[\"has\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\>\"", ",", 
     RowBox[{"shape", "[", "Rr", "]"}], ",", "\"\<\\nAB/B0      =\>\"", ",", 
     RowBox[{"AoB", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"AB", ",", 
        RowBox[{"hoopInverse", "[", "B0", "]"}]}], "]"}]}], ",", 
     "\"\<\\nAdding Rl gives A0\>\"", ",", 
     RowBox[{"AoB", "+", "RA"}]}], 
    StyleBox["}",
     FontSlant->"Italic"]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 FontFamily->"Courier New",
 FontSize->10],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Example 35. C4 multiplication with remainders\"\>", 
   ",", "\<\"\\n         A0 = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)A0 = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "2", ",", "0"}], "}"}], 
   ",", "\<\"\\n         B0 = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}], ",", "2", ",", 
     RowBox[{"-", "4"}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) B0 = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "10", ",", "10"}], "}"}], 
   ",", "\<\"\\n         AB = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     RowBox[{"-", "5"}], ",", "5", ",", 
     RowBox[{"-", "5"}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) AB = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "20", ",", "0"}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Note\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"that\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"two\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"sizes\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"have\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"become\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) 0\"\>", 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Remainder\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"Rl\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "2"], ",", 
     FractionBox["3", "2"], ",", 
     FractionBox["3", "2"], ",", 
     FractionBox["3", "2"]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"a\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\) \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "0", ",", "0"}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"remainder\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"Rr\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     FractionBox["3", "2"], ",", 
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"-", 
      FractionBox["3", "2"]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"a\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "10"}], "}"}], ",", "\<\"\\nAB/B0      =\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["1", "2"], ",", 
     RowBox[{"-", 
      FractionBox["1", "2"]}]}], "}"}], ",", "\<\"\\nAdding Rl gives A0\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tDivision is multiplication by the multiplicative inverse, found by ",
 StyleBox["hoopInverse",
  FontSlant->"Italic"],
 ". This is therefore formulated so that the inverse ",
 StyleBox["A0inv",
  FontSlant->"Italic"],
 " has the same zeroes as ",
 StyleBox["A0",
  FontSlant->"Italic"],
 ", rather than these sizes being infinite. If any of the numerator sizes \
approach zero (to within an arbitrary ",
 StyleBox["hmin",
  FontSlant->"Italic"],
 "), the calculation proceeds in the sub-algebra in which these factors are \
constrained to be zero. The result is projected",
 StyleBox[" ",
  FontSlant->"Italic"],
 "into the sub-algebra, and the infinite terms have been \"factored out\" or \
\"renormalized\". Conic sections provide an analogy - constraining a distance \
from some plane reduces the 3D symmetry of the bicone to one of several 2d \
symmetries. ",
 StyleBox["hoopInverse",
  FontSlant->"Italic"],
 " is a unary operation and the remainders do not exist until division \
(multiplication by the inverse) occurs. Thus remainders are the result of the \
binary operation of hoop multiplication. (Discovered 19th Dec. 2004.)"
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tPutting hmin = 1-q relates projection to \"q-analogues\", which are \
functions involving 1-q that change form when q becomes 1, i.e. when hmin\
\[RightArrow]0.  \
\>", "Text"],

Cell[TextData[{
 "\tVecs can be projected onto a sub-space by pre-multiplying by a vec such \
as ",
 StyleBox["A0",
  FontSlant->"Italic"],
 " and then post-multiplying by its inverse. This is demonstrated in Example \
36, using the C4 algebra (complex coefficients are used to show that the \
algebra is effective over the complex field); ",
 StyleBox["A0",
  FontSlant->"Italic"],
 " is chosen to have the second size zero. The size of the remainder is the \
second size of the original vec:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 36. ",
 StyleBox["C4 Division with Zero Sizes; Projection, Remainders.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "C4", "]"}], ";", 
  RowBox[{"Chop", "[", 
   RowBox[{"{", 
    RowBox[{"\"\<        A0=  \>\"", ",", 
     RowBox[{"A0", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "4", ",", 
        RowBox[{"5.", "+", "\[ImaginaryI]"}], ",", 
        RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], ",", "\"\<\\n\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)A0 = \>\"", ",", 
     RowBox[{"sA0", "=", 
      RowBox[{"shape", "[", 
       RowBox[{"A0", ",", "\"\<C4\>\""}], "]"}]}], ",", "\"\<\\nA0i\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Inverse\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) A0, =\>\"", ",", 
     RowBox[{"A0i", "=", 
      RowBox[{"hoopInverse", "[", "A0", "]"}]}], ",", "\[IndentingNewLine]", 
     "\"\<\\n\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) A0i =\>\"", ",", 
     RowBox[{"shape", "[", "A0i", "]"}], ",", "\[IndentingNewLine]", 
     "\"\<\\n         B=   \>\"", ",", 
     RowBox[{"B", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1.", "+", 
         RowBox[{"4", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{
         RowBox[{"-", "4"}], "-", 
         RowBox[{"3", "\[ImaginaryI]"}]}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) B   =\>\"", ",", 
     RowBox[{"shape", "[", "B", "]"}], ",", "\[IndentingNewLine]", 
     "\"\<\\n      BA0i=   \>\"", ",", 
     RowBox[{"BA0i", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A0i", ",", "B", ",", "\"\<C4\>\""}], "]"}]}], ",", 
     "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) BA0i \>\"", ",", 
     RowBox[{"shape", "[", "BA0i", "]"}], ",", "\[IndentingNewLine]", 
     "\"\<\\n\!\(\*
StyleBox[\"Note\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"that\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"nd\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"size\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"has\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"become\",
FontSlant->\"Italic\"]\) 0   \[UpArrow]\>\"", ",", "\[IndentingNewLine]", 
     "\"\<\\n\!\(\*
StyleBox[\"Multiplying\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"by\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A0\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gives\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"projection\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)B\>\"", ",", 
     RowBox[{"A0BA0i", "=", 
      RowBox[{"hoopTimes", " ", "[", 
       RowBox[{"A0", ",", "BA0i", ",", "\"\<C4\>\""}], "]"}]}], ",", 
     "\"\<\\n\!\(\*
StyleBox[\"with\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\) \>\"", ",", 
     RowBox[{"shape", "[", "A0BA0i", "]"}], ",", "\[IndentingNewLine]", 
     "\"\<\\n\!\(\*
StyleBox[\"with\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"1\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"st\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"&\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"rd\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"sizes\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"matching\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)B,\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"&\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"nd\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"size\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"zero\",
FontSlant->\"Italic\"]\).\>\"", ",", "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Premultiplying\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)B \!\(\*
StyleBox[\"by\",
FontSlant->\"Italic\"]\) A0\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gives\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)A0B\>\"", ",", 
     RowBox[{"A0B", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A0", ",", "B", ",", "\"\<C4\>\""}], "]"}]}], ",", 
     "\"\<\\n\!\(\*
StyleBox[\"shape\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) A0B =\>\"", ",", 
     RowBox[{"shape", "[", 
      RowBox[{"A0B", "=", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"A0", ",", "B", ",", "\"\<C4\>\""}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Multiply\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"by\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A0i\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"gives\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"same\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"projection\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\) B\>\"", ",", 
     RowBox[{"B0", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A0i", ",", "A0B", ",", "\"\<C4\>\""}], "]"}]}], ",", 
     "\"\<\\n\!\(\*
StyleBox[\"The\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"difference\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"between\",
FontSlant->\"Italic\"]\) B & A0BA0i \!\(\*
StyleBox[\"is\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"remainder\",
FontSlant->\"Italic\"]\) Rr\>\"", ",", 
     RowBox[{"Rr", "=", 
      RowBox[{"B", "-", "A0BA0i"}]}], ",", "\"\<\\n\!\(\*
StyleBox[\"with\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"sizes\",
FontSlant->\"Italic\"]\)\>\"", ",", 
     RowBox[{"shape", "[", "Rr", "]"}], ",", "\"\< \!\(\*
StyleBox[\"i\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"e\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",
FontSlant->\"Italic\"]\) \!\(\*
StyleBox[\"the\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"second\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"size\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",
FontSlant->\"Italic\"]\)  B.\>\""}], 
    StyleBox["}",
     FontSlant->"Italic"]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 FontFamily->"Courier New",
 FontSize->10],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"        A0=  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", 
     RowBox[{"5.`", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}], ",", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)A0 = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12.`", "\[InvisibleSpace]", "+", 
      RowBox[{"2", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
     RowBox[{"18.`", "\[InvisibleSpace]", "+", 
      RowBox[{"4.`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\nA0i\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"Inverse\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\
\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) A0, =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.09149443561208266`"}], "-", 
      RowBox[{"0.006319554848966614`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.026788553259141493`"}], "+", 
      RowBox[{"0.03485691573926868`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.13203497615262322`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.0004372019077901433`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.06732909379968204`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.04161367249602544`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) A0i =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.08108108108108111`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.01351351351351351`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
      
     RowBox[{"0.05294117647058823`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.011764705882352941`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n         B=   \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.`", "\[InvisibleSpace]", "+", 
      RowBox[{"4", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) B   =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "9.`"}], "+", "\[ImaginaryI]"}], ",", 
     RowBox[{"3.`", "\[InvisibleSpace]", "+", 
      RowBox[{"7", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"4.`", "\[InvisibleSpace]", "+", 
      RowBox[{"52.`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n      BA0i=   \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.5172893481717011`"}], "-", 
      RowBox[{"0.3463831478537361`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.7819952305246423`"}], "-", 
      RowBox[{"0.2875596184419713`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.15918124006359308`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.44773449920508746`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.42388712241653415`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.38891096979332274`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) BA0i \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.7162162162162162`"}], "+", 
      RowBox[{"0.20270270270270285`", " ", "\[ImaginaryI]"}]}], ",", "0", ",",
      
     RowBox[{"0.8235294117647058`", "\[InvisibleSpace]", "+", 
      RowBox[{"2.7058823529411766`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Note\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"that\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"nd\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"size\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"become\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) 0   \[UpArrow]\"\>", 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Multiplying\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"by\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"A0\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"a\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"projection\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.2500000000000002`", "\[InvisibleSpace]", "+", 
      RowBox[{"2.25`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.2500000000000002`"}], "+", 
      RowBox[{"1.7500000000000002`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4.749999999999999`"}], "-", 
      RowBox[{"1.7499999999999996`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "3.25`"}], "-", 
      RowBox[{"1.2499999999999996`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"a\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "9.`"}], "+", 
      RowBox[{"1.0000000000000009`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
     
     RowBox[{"3.999999999999994`", "\[InvisibleSpace]", "+", 
      RowBox[{"51.999999999999986`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"1\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"st\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"&\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"3\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\"rd\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"sizes\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"matching\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)B,\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"&\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\"nd\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"size\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"zero\\\",\\nFontSlant->\\\"Italic\\\"\
]\\).\"\>", 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Premultiplying\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)B \
\\!\\(\\*\\nStyleBox[\\\"by\\\",\\nFontSlant->\\\"Italic\\\"]\\) \
A0\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"gives\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)A0B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "39.`"}], "-", 
      RowBox[{"14", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "23.`"}], "-", 
      RowBox[{"7.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "16.`"}], "+", 
      RowBox[{"11.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "32.`"}], "+", 
      RowBox[{"4.`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\) A0B =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "110.`"}], "-", 
      RowBox[{"6.`", " ", "\[ImaginaryI]"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "136.`"}], "+", 
      RowBox[{"952.`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Multiply\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"by\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"A0i\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"gives\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"same\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"projection\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"\
]\\) B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.2499999999999991`", "\[InvisibleSpace]", "+", 
      RowBox[{"2.25`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.2500000000000009`"}], "+", 
      RowBox[{"1.75`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4.750000000000001`"}], "-", 
      RowBox[{"1.7499999999999996`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "3.2500000000000004`"}], "-", 
      RowBox[{"1.25`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"The\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"difference\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"between\\\",\\nFontSlant->\\\"\
Italic\\\"]\\) B & A0BA0i \
\\!\\(\\*\\nStyleBox[\\\"is\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"the\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"remainder\\\",\\nFontSlant->\\\"\
Italic\\\"]\\) Rr\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.7499999999999998`", "\[InvisibleSpace]", "+", 
      RowBox[{"1.75`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.7499999999999998`"}], "-", 
      RowBox[{"1.7500000000000002`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.7499999999999991`", "\[InvisibleSpace]", "+", 
      RowBox[{"1.7499999999999996`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.75`"}], "-", 
      RowBox[{"1.7500000000000004`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"with\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"sizes\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"2.9999999999999987`", "\[InvisibleSpace]", "+", 
      RowBox[{"7.`", " ", "\[ImaginaryI]"}]}], ",", "0"}], "}"}], 
   ",", "\<\" \\!\\(\\*\\nStyleBox[\\\"i\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"e\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\".\
\\\",\\nFontSlant->\\\"Italic\\\"]\\) \
\\!\\(\\*\\nStyleBox[\\\"the\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"second\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"size\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"of\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)  B.\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThus renormalizing multiplication/division is conservative if it is \
interpreted as projecting the result into the constrained sub-algebra whilst \
splitting off (ejecting) remainders that contains the lost sizes. Conjecture \
- this may be related to fundamental particle interactions and decay, where \
particles with different symmetries occur, but the symmetries may be \
conserved by the creation of more than one particle.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.5. Degenerate monosized algebras.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tFolding loops to hoops makes many sizes zero; some signed table hoops \
have only one (often repeated) size and so cannot exhibit renormalisation. In \
this respect, they are degenerate hoops. Those in the database are shown in \
Example 37. They include C4c=\[DoubleStruckCapitalC]; Qr=quaternion algebra, \
\[DoubleStruckCapitalH]; the octonion algebra Octi, Octc=Octonions \
\[DoubleStruckCapitalO]; Octi=split-Octonions, P4=Pauli-\[Sigma]; \
Cliffords(2), (3), (0,4), (1,3), (2,2), (3,1), (4) (but not C8r, \
Clifford(2,1), Clifford(0,3), shown in Example 37a). In the example, some \
factors are found by ",
 StyleBox["fa[mp[mnemonic]]",
  FontSlant->"Italic"],
 ", which factorizes the determinant after mapping members of the alphabet \
onto the index table. Others are given by the same mapping onto the known \
shape, whilst the 16-membered Cliffords are mapped with {a,3,7,1,2,.. ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "n"], TraditionalForm]]],
 "...",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "12"], TraditionalForm]]],
 "} (truncated as appropriate) to provide compact output. Three other hoops, \
with two distinct factors, are shown in Example 37a."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 37. ",
 StyleBox["Some degenerate hoops. ",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"Ex", ".", " ", "37"}], " ", "Single"}], "-", 
     RowBox[{"Factor", " ", "Hoops"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a8", "=", 
     RowBox[{"Take", "[", 
      RowBox[{"alpha", ",", "8"}], "]"}]}], ";", 
    RowBox[{"{", 
     RowBox[{"\"\<\[DoubleStruckCapitalC]   \!\(\*
StyleBox[\"Factor\",
FontSlant->\"Italic\"]\) \>\"", ",", 
      RowBox[{"-", 
       RowBox[{"fa", "[", 
        RowBox[{"mp", "[", "\"\<C4c\>\"", "]"}], "]"}]}], ",", 
      "\"\<\\nC9J  \!\(\*
StyleBox[\"Factor\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{
       RowBox[{"sh", "[", "\"\<C9J\>\"", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<\\nQr   \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fa", "[", 
       RowBox[{"mp", "[", "\"\<Qr\>\"", "]"}], "]"}], ",", 
      "\"\<\\nOctr \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fa", "[", 
       RowBox[{"mp", "[", "\"\<Octr\>\"", "]"}], "]"}], ",", 
      "\"\<\\nOcti \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fa", "[", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], "]"}], "]"}], ",", "\"\<\\nP4   \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fa", "[", 
       RowBox[{"mp", "[", "\"\<P4\>\"", "]"}], "]"}], ",", 
      "\"\<\\nCL2  \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fa", "[", 
       RowBox[{"clf", "[", "2", "]"}], "]"}], ",", "\"\<\\nCL04 \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fp", "[", 
       RowBox[{"clf", "[", 
        RowBox[{"0", ",", "4"}], "]"}], "]"}], ",", "\"\<\\nCL13 \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fp", "[", 
       RowBox[{"clf", "[", 
        RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", "\"\<\\nCL22 \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fp", "[", 
       RowBox[{"clf", "[", 
        RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", "\"\<\\nCL31 \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fp", "[", 
       RowBox[{"clf", "[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", "\"\<\\nCL4  \!\(\*
StyleBox[\"Factors\",
FontSlant->\"Italic\"]\)\>\"", ",", 
      RowBox[{"fp", "[", 
       RowBox[{"clf", "[", "4", "]"}], "]"}]}], "}"}]}]}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 FontFamily->"Courier New"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\[DoubleStruckCapitalC]   \\!\\(\\*\\nStyleBox[\\\"Factor\\\",\
\\nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"]}], 
   ",", "\<\"\\nC9J  \
\\!\\(\\*\\nStyleBox[\\\"Factor\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{
    SuperscriptBox["a", "3"], "+", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
    RowBox[{
    "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], "+", 
    
    RowBox[{
     SuperscriptBox["c", "3"], " ", 
     SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], 
   ",", "\<\"\\nQr   \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"]}], ")"}], "2"], 
   ",", "\<\"\\nOctr \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ")"}], "4"], 
   ",", "\<\"\\nOcti \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "-", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "-", 
      SuperscriptBox["h", "2"]}], ")"}], "4"], 
   ",", "\<\"\\nP4   \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["d", "2"]}], ")"}], "2"], 
   ",", "\<\"\\nCL2  \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"]}], ")"}], "2"], 
   ",", "\<\"\\nCL04 \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"128102388808777273", "+", 
      RowBox[{"1413496832", " ", "a"}], "-", 
      RowBox[{"697668950", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "4"], 
   ",", "\<\"\\nCL13 \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"46116860489329705", "-", 
      RowBox[{"876625920", " ", "a"}], "+", 
      RowBox[{"447129190", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "4"], 
   ",", "\<\"\\nCL22 \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"35904129604188153", "+", 
      RowBox[{"742408192", " ", "a"}], "-", 
      RowBox[{"363440490", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "4"], 
   ",", "\<\"\\nCL31 \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"35347485413419257", "-", 
      RowBox[{"734019584", " ", "a"}], "+", 
      RowBox[{"358001046", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "4"], 
   ",", "\<\"\\nCL4  \
\\!\\(\\*\\nStyleBox[\\\"Factors\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"35345327484971257", "+", 
      RowBox[{"733986816", " ", "a"}], "-", 
      RowBox[{"357979754", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "4"]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Example 37a.",
  FontWeight->"Bold"],
 " Related Hoops with two factors."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\"\<C8r \!\(\*
StyleBox[\"splits\",
FontSlant->\"Italic\"]\)\>\"", ",", 
    RowBox[{"shape", "[", 
     RowBox[{"a8", ",", "\"\<C8r\>\""}], "]"}], ",", "\"\<\\nCL21 \!\(\*
StyleBox[\"splits\",
FontSlant->\"Italic\"]\) \>\"", ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"shape", "[", 
       RowBox[{"a8", ",", "\"\<CL21\>\""}], "]"}], ")"}], "^", "2"}], ",", 
    "\"\<\\nCL03 \!\(\*
StyleBox[\"splits\",
FontSlant->\"Italic\"]\) \>\"", ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"shape", "[", 
       RowBox[{"a8", ",", "\"\<CL03\>\""}], "]"}], ")"}], "^", "2"}]}], "}"}],
   TraditionalForm]], "Input",
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C8r \
\\!\\(\\*\\nStyleBox[\\\"splits\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\<\"a\"\>", "2"], "+", 
      SuperscriptBox["\<\"b\"\>", "2"], "+", 
      SuperscriptBox["\<\"c\"\>", "2"], "+", 
      SuperscriptBox["\<\"d\"\>", "2"], "+", 
      RowBox[{
       SqrtBox["2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\<\"a\"\>", " ", "\<\"b\"\>"}], "-", 
         RowBox[{"\<\"b\"\>", " ", "\<\"c\"\>"}], "+", 
         RowBox[{"\<\"a\"\>", " ", "\<\"d\"\>"}], "+", 
         RowBox[{"\<\"c\"\>", " ", "\<\"d\"\>"}]}], ")"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["\<\"a\"\>", "2"], "+", 
      SuperscriptBox["\<\"b\"\>", "2"], "+", 
      SuperscriptBox["\<\"c\"\>", "2"], "+", 
      SuperscriptBox["\<\"d\"\>", "2"], "-", 
      RowBox[{
       SqrtBox["2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\<\"a\"\>", " ", "\<\"b\"\>"}], "-", 
         RowBox[{"\<\"b\"\>", " ", "\<\"c\"\>"}], "+", 
         RowBox[{"\<\"a\"\>", " ", "\<\"d\"\>"}], "+", 
         RowBox[{"\<\"c\"\>", " ", "\<\"d\"\>"}]}], ")"}]}]}]}], "}"}], 
   ",", "\<\"\\nCL21 \
\\!\\(\\*\\nStyleBox[\\\"splits\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"d\"\>", "+", "\<\"e\"\>"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"c\"\>", "+", "\<\"f\"\>"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"b\"\>", "-", "\<\"g\"\>"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"a\"\>", "-", "\<\"h\"\>"}], ")"}], "2"]}], ")"}], "2"],
      ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"d\"\>", "-", "\<\"e\"\>"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"c\"\>", "-", "\<\"f\"\>"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"b\"\>", "+", "\<\"g\"\>"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"a\"\>", "+", "\<\"h\"\>"}], ")"}], "2"]}], ")"}], 
      "2"]}], "}"}], 
   ",", "\<\"\\nCL03 \
\\!\\(\\*\\nStyleBox[\\\"splits\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"d\"\>", "+", "\<\"e\"\>"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"c\"\>", "-", "\<\"f\"\>"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"b\"\>", "+", "\<\"g\"\>"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"a\"\>", "-", "\<\"h\"\>"}], ")"}], "2"]}], ")"}], "2"],
      ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"d\"\>", "-", "\<\"e\"\>"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"c\"\>", "+", "\<\"f\"\>"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"b\"\>", "-", "\<\"g\"\>"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\<\"a\"\>", "+", "\<\"h\"\>"}], ")"}], "2"]}], ")"}], 
      "2"]}], "}"}]}], "}"}]], "Output",
 FontSize->9]
}, Open  ]],

Cell["\<\
Since writing the above, I have found that some Clifford algebras conserve \
complex factors, found by, e.g. Factor[sh[\"CL3\"], GaussianIntegers \[Rule] \
True]\
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 37b.",
  FontWeight->"Bold"],
 " Related Hoops with conserved complex factors."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<CL12 conserves the complex factors\>\"", ",", 
   RowBox[{"sh", "[", "\"\<CL12\>\"", "]"}], ",", 
   "\"\<CL3 conserves the complex factors\>\"", ",", 
   RowBox[{"sh", "[", "\"\<CL3\>\"", "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL12 conserves the complex factors\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", 
         RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", 
         RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", 
         RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "+", 
          RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", 
         RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", 
         RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"CL3 conserves the complex factors\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", 
         RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", 
         RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", 
         RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "+", 
         RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", 
         RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", 
         RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", 
         RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe sizes of \[DoubleStruckCapitalC], \[DoubleStruckCapitalH], and \
\[DoubleStruckCapitalO] are sums of squared coefficients, and so can only be \
zero (for real coefficients) in the trivial case where all the coefficients \
are zero. This makes them (together with \[DoubleStruckCapitalR]) the only \
\"division algebras without real divisors of zero\". All other hoops have \
real divisors of zero; all hoops (including \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], and \
\[DoubleStruckCapitalO]) have divisors of zero in the complex field. (The \
sizes of ",
 StyleBox["Sed",
  FontSlant->"Italic"],
 " and higher Cayley-Dickson algebras are also sums of squares, but they are \
not conserved.) \n\tDivision of a vector A by an annihilitor (i.e. a vector \
whose sizes are all zero) is interpreted as giving a result {0,0...} and a \
remainder that is all of A."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. Many algebras are Hoops.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". Most of the algebras of Mathematical Physics are Hoop algebras or \
constrained Hoop algebras."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["7.1. Real, Complex, Quaternion, Octonion Algebras.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tThe importance of hoops is that most \"physical\" algebras are hoops or \
restrictions on hoops, and so have conserved properties. C2 is the \
multiplication table for real numbers, expressed as {+,-}, with +*+ and -*- \
both giving +. C4c (folded from C4) is Complex, {r,i}, with i*i = - r \
(Example 27). Non-abelian Quaternions, non-associative Octonions, \
non-alternative & non-conservative (but power-associative) sedenions are all \
Cayley-Dickson algebras:- Qr, Octc, Sed. Qr, Oct & Octi compose with C2 to \
form (associative) Q8 & (alternative) Oct and M(16,2) Moufang loops; they \
describe rotations in 3 & 7 dimensions (Section 6.6) and also multiply \
univectors to give scalar products and cross products. Composing Sed and \
higher Cayley-Dickson algebras does not give Moufang loops; they are not \
conservative division algebras.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
\t(Technical note. It is well-known that the 16 vectors {\[PlusMinus]1/2,\
\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/2} are \"rational units\" for \
Quaternions; it may be a new observation that there are many others. \
Permutations of {\[PlusMinus]2/3,\[PlusMinus]2/3,\[PlusMinus]1/3,0}, {\
\[PlusMinus]4/5,\[PlusMinus]2/5,\[PlusMinus]2/5,\[PlusMinus]1/5}, {\
\[PlusMinus]5/6,\[PlusMinus]3/6,\[PlusMinus]1/6,\[PlusMinus]1/6}, {\
\[PlusMinus]4/6,\[PlusMinus]4/6,\[PlusMinus]1/6,\[PlusMinus]1/6}, {\
\[PlusMinus]5/7,\[PlusMinus]4/7,\[PlusMinus]2/7,\[PlusMinus]2/7}, and {\
\[PlusMinus]6/7,\[PlusMinus]3/7,\[PlusMinus]2/7,0} are examples - in each \
case the sum of the squared elements (the size) is 1. Similarly, permutations \
of {\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/2,0,0,0,0}, \
{\[PlusMinus]2/3,\[PlusMinus]1/3,\[PlusMinus]1/3,\[PlusMinus]1/3,\[PlusMinus]\
1/3,\[PlusMinus]1/3,0,0}, {\[PlusMinus]3/4,\[PlusMinus]1/4,\[PlusMinus]1/4,\
\[PlusMinus]1/4,\[PlusMinus]1/4,\[PlusMinus]1/4,\[PlusMinus]1/4,\[PlusMinus]1/\
4},  {\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/2,\[PlusMinus]1/4,\
\[PlusMinus]1/4,\[PlusMinus]1/4,\[PlusMinus]1/4,0} are all octonion rational \
units.)\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2. Vector Dot & Cross products.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
This needs revising, as Clifford algebras (which include quaternions) \
generalise dot and cross products 29/07/08)\
\>", "Text",
 FontColor->RGBColor[1, 0, 0]],

Cell["\<\
\tExample 38 shows that dot & cross products are hoop multiplications where \
only the univectors are multiplied (i.e. the scalar and multivector elements \
of the multiplicands are kept at zero). The symbols are chosen to match those \
in [3, p11] for quaternions and CL2, and to match [3, p37] for octonions and \
CL3.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 38. ",
 StyleBox["Dot & Cross products with Qr & Octr.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["e", "1"], ",", 
      SubscriptBox["e", "2"], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["u", "1"], ",", 
      SubscriptBox["u", "2"], ",", "0"}], "}"}], ",", "\"\<Qr\>\""}], "]"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "1"]}], " ", 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "2"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "2"]}], " ", 
     SubscriptBox["u", "1"]}], "+", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "2"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["a", "1"], ",", 
      SubscriptBox["a", "2"], ",", "0", ",", 
      SubscriptBox["a", "3"], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["b", "1"], ",", 
      SubscriptBox["b", "2"], ",", "0", ",", 
      SubscriptBox["b", "3"], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    "\"\<Octr\>\""}], "]"}], TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["a", "1"]}], " ", 
     SubscriptBox["b", "1"]}], "-", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SubscriptBox["b", "2"]}], "-", 
    RowBox[{
     SubscriptBox["a", "3"], " ", 
     SubscriptBox["b", "3"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["a", "2"]}], " ", 
     SubscriptBox["b", "1"]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     SubscriptBox["b", "2"]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["a", "3"]}], " ", 
     SubscriptBox["b", "1"]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     SubscriptBox["b", "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["a", "3"]}], " ", 
     SubscriptBox["b", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SubscriptBox["b", "3"]}]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tIn both cases the first term is the scalar product (up to a sign), whilst \
the univectors (and octonion trivector) in the product are zero. The Qr \
trivector result ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["e", "2"], 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "1"], 
     SubscriptBox["u", "2"]}]}], TraditionalForm]]],
 " is the 2D cross product, and Octc gives the (negated) 3D scalar product ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     SubscriptBox["b", "1"]}], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SubscriptBox["b", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "3"], " ", 
     SubscriptBox["b", "3"]}]}],
   FontSlant->"Italic"]]],
 " together with the vector cross product  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "2"]}], " ", 
      SubscriptBox["b", "1"]}], "+", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      SubscriptBox["b", "2"]}]}], ")"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["e", "1"], 
    SubscriptBox["e", "2"]}], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "3"]}], " ", 
       SubscriptBox["b", "1"]}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       SubscriptBox["b", "3"]}]}], ")"}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["e", "1"], 
    SubscriptBox["e", "3"]}], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "3"]}], " ", 
      SubscriptBox["b", "2"]}], "+", 
     RowBox[{
      SubscriptBox["a", "2"], " ", 
      SubscriptBox["b", "3"]}]}], ")"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["e", "2"], 
    SubscriptBox["e", "3"]}], TraditionalForm]]],
 ". (Remember that the bivector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["e", "1"], 
    SubscriptBox["e", "2"]}], TraditionalForm]]],
 " is the 4th element basis direction, etc., with coefficient 0 in the \
multiplicands). "
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
7.3. Cayley-Dickson, Clifford, Exterior, Wedge & Lie Algebras.\
\>", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tSection 3.2.7 demonstrated some generalisations of the Cayley-Dickson \
process, creating many hoops.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["This needs revising. 29/07/08)", "Text",
 FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
 "\tClifford algebras are hoops, created by ",
 StyleBox["cl",
  FontSlant->"Italic"],
 " or by folding a specific group isomorph. Wedge (exterior) algebras are the \
bivector part of the Clifford product ([3] p.10). They multiply univectors \
using Clifford algebra rules; the scalars and multivectors are kept at zero \
in the multiplicands so various products are zero (i.e. these are Grassmann \
algebras). Multiplying univectors ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["u", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["u", "2"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "2"], TraditionalForm]]],
 " in CL2 gives a scalar ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["e", "1"], 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "2"], 
     SubscriptBox["u", "2"]}]}], TraditionalForm]]],
 " and a bivector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["e", "1"], 
     SubscriptBox["u", "2"]}], "-", 
    RowBox[{
     SubscriptBox["e", "2"], 
     SubscriptBox["u", "1"]}]}], TraditionalForm]]],
 "; the univectors in the product are zero. CL3 gives the wedge product of \
three univectors when the scalar and multivector terms are zero in the \
multiplicands:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 39a. ",
 StyleBox["Wedge Products, Exterior Algebras. Qr, Octr.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["u", "1"], ",", 
      SubscriptBox["u", "2"], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["v", "1"], ",", 
      SubscriptBox["v", "2"], ",", "0"}], "}"}], ",", "\"\<Qr\>\""}], "]"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["u", "1"], ",", 
      SubscriptBox["u", "2"], ",", "0", ",", 
      SubscriptBox["u", "3"], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["v", "1"], ",", 
      SubscriptBox["v", "2"], ",", "0", ",", 
      SubscriptBox["v", "3"], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    "\"\<Octr\>\""}], "]"}], TraditionalForm]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "1"]}], " ", 
     SubscriptBox["v", "1"]}], "-", 
    RowBox[{
     SubscriptBox["u", "2"], " ", 
     SubscriptBox["v", "2"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "2"]}], " ", 
     SubscriptBox["v", "1"]}], "+", 
    RowBox[{
     SubscriptBox["u", "1"], " ", 
     SubscriptBox["v", "2"]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "1"]}], " ", 
     SubscriptBox["v", "1"]}], "-", 
    RowBox[{
     SubscriptBox["u", "2"], " ", 
     SubscriptBox["v", "2"]}], "-", 
    RowBox[{
     SubscriptBox["u", "3"], " ", 
     SubscriptBox["v", "3"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "2"]}], " ", 
     SubscriptBox["v", "1"]}], "+", 
    RowBox[{
     SubscriptBox["u", "1"], " ", 
     SubscriptBox["v", "2"]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "3"]}], " ", 
     SubscriptBox["v", "1"]}], "+", 
    RowBox[{
     SubscriptBox["u", "1"], " ", 
     SubscriptBox["v", "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "3"]}], " ", 
     SubscriptBox["v", "2"]}], "+", 
    RowBox[{
     SubscriptBox["u", "2"], " ", 
     SubscriptBox["v", "3"]}]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Example 39b. ",
 StyleBox["Wedge Products, Exterior Algebras. CL2, CL3",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["u", "1"], ",", 
      SubscriptBox["u", "2"], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["v", "1"], ",", 
      SubscriptBox["v", "2"], ",", "0"}], "}"}], ",", "\"\<CL2\>\""}], "]"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["u", "1"], ",", 
      SubscriptBox["u", "2"], ",", "0", ",", 
      SubscriptBox["u", "3"], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      SubscriptBox["v", "1"], ",", 
      SubscriptBox["v", "2"], ",", "0", ",", 
      SubscriptBox["v", "3"], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    "\"\<CL3\>\""}], "]"}], TraditionalForm]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "1"], " ", 
     SubscriptBox["v", "1"]}], "-", 
    RowBox[{
     SubscriptBox["u", "2"], " ", 
     SubscriptBox["v", "2"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "2"]}], " ", 
     SubscriptBox["v", "1"]}], "+", 
    RowBox[{
     SubscriptBox["u", "1"], " ", 
     SubscriptBox["v", "2"]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "1"], " ", 
     SubscriptBox["v", "1"]}], "+", 
    RowBox[{
     SubscriptBox["u", "2"], " ", 
     SubscriptBox["v", "2"]}], "+", 
    RowBox[{
     SubscriptBox["u", "3"], " ", 
     SubscriptBox["v", "3"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "2"]}], " ", 
     SubscriptBox["v", "1"]}], "+", 
    RowBox[{
     SubscriptBox["u", "1"], " ", 
     SubscriptBox["v", "2"]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "3"]}], " ", 
     SubscriptBox["v", "1"]}], "+", 
    RowBox[{
     SubscriptBox["u", "1"], " ", 
     SubscriptBox["v", "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "3"]}], " ", 
     SubscriptBox["v", "2"]}], "+", 
    RowBox[{
     SubscriptBox["u", "2"], " ", 
     SubscriptBox["v", "3"]}]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThese only differ from the quaternion and octonion univector products in \
the sign of the first term.\n\tLounesto [3, footnote 11, p11; p38] points out \
the distinction between the oriented plane-area bivector wedge product and \
the vector-valued cross product. The cross products involve a metric; wedge \
products do not.\n\tDifferent 16-element Clifford algebras multiply 4 \
univectors to give scalars and three bivectors with assorted signs. (Trailing \
zeroes are omitted in the input; ",
 StyleBox["hoopTi",
  FontSlant->"Italic"],
 StyleBox["mes",
  FontSlant->"Italic"],
 " pads out short vecs with zeroes.):- "
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 40. ",
 StyleBox["Wedge Products, Exterior Algebras. CL4 etc",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  FormBox[
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       SubscriptBox["e", "1"], ",", 
       SubscriptBox["e", "2"], ",", "0", ",", 
       SubscriptBox["e", "3"], ",", "0", ",", "0", ",", 
       SubscriptBox["e", "4"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       SubscriptBox["u", "1"], ",", 
       SubscriptBox["u", "2"], ",", "0", ",", 
       SubscriptBox["u", "3"], ",", "0", ",", "0", ",", 
       SubscriptBox["u", "4"]}], "}"}], ",", "\"\<CL4\>\""}], "]"}],
   TraditionalForm], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       SubscriptBox["e", "1"], ",", 
       SubscriptBox["e", "2"], ",", "0", ",", 
       SubscriptBox["e", "3"], ",", "0", ",", "0", ",", 
       SubscriptBox["e", "4"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       SubscriptBox["u", "1"], ",", 
       SubscriptBox["u", "2"], ",", "0", ",", 
       SubscriptBox["u", "3"], ",", "0", ",", "0", ",", 
       SubscriptBox["u", "4"]}], "}"}], ",", "\"\<CL04\>\""}], "]"}],
   TraditionalForm], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  FormBox[
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       SubscriptBox["e", "1"], ",", 
       SubscriptBox["e", "2"], ",", "0", ",", 
       SubscriptBox["e", "3"], ",", "0", ",", "0", ",", 
       SubscriptBox["e", "4"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       SubscriptBox["u", "1"], ",", 
       SubscriptBox["u", "2"], ",", "0", ",", 
       SubscriptBox["u", "3"], ",", "0", ",", "0", ",", 
       SubscriptBox["u", "4"]}], "}"}], ",", "\"\<CL31\>\""}], "]"}],
   TraditionalForm], TraditionalForm]}], "Input",
 PageWidth->WindowWidth,
 FontFamily->"Courier New"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "1"]}], "+", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "3"]}], "-", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "2"]}], " ", 
     SubscriptBox["u", "1"]}], "+", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "3"]}], "+", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "3"]}], " ", 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "3"]}], "-", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "4"]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "3"]}], "+", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "1"]}], " ", 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "2"]}], "-", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "3"]}], "+", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "2"]}], " ", 
     SubscriptBox["u", "1"]}], "+", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "2"]}], "-", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "3"]}], "-", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "3"]}], " ", 
     SubscriptBox["u", "1"]}], "+", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "3"]}], "+", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "4"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "4"]}], " ", 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "3"]}], "-", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "1"]}], " ", 
     SubscriptBox["u", "1"]}], "+", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "3"]}], "+", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "2"]}], " ", 
     SubscriptBox["u", "1"]}], "+", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "3"]}], "+", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "3"]}], " ", 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "4"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "3"]}], "-", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "4"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["e", "4"]}], " ", 
     SubscriptBox["u", "1"]}], "-", 
    RowBox[{
     SubscriptBox["e", "3"], " ", 
     SubscriptBox["u", "2"]}], "+", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["u", "3"]}], "-", 
    RowBox[{
     SubscriptBox["e", "1"], " ", 
     SubscriptBox["u", "4"]}]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tFinite Lie algebras appear to be Clifford hoops for which the real (scalar) \
elements have been zeroed. This has yet to be explored. Clifford(5) has the \
same number of distinct off-diagonal elements as the string theory group with \
496 (=32/31/2) elements, suggesting that these elements are related to \
multivectors.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.4. Penrose Twistors.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
[Wikipedia,Twistor theory] \"Twistors map the geometric objects of the four \
dimensional (Minkowski) space-time .. into the geometric objects in the \
4-dimensional complex space with the metric signature (2,2).\" \
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\t CL2 conserves ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox["d", "2"]}], TraditionalForm]]],
 ". C2D4r & CL21 conserve two (repeated) functions, both composed of four \
squares, with two negated. Thus they have sub-algebras with the signature \
(2,2). D4, KiC4c & KiC4r have (2,2) repeated sizes, but also have other \
sizes. I have not explored the relationships with twistors."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<Shape C2D4r =\>\"", ",", 
   RowBox[{
    RowBox[{"id", "[", 
     RowBox[{"mp", "[", "\"\<C2D4r\>\"", "]"}], "]"}], ";", 
    RowBox[{"shape", "[", 
     RowBox[{"a8", "=", 
      RowBox[{"Take", "[", 
       RowBox[{"alph", ",", "8"}], "]"}]}], "]"}]}], ",", 
   "\"\<\\nShape  CL21 =\>\"", ",", 
   RowBox[{
    RowBox[{"id", "[", 
     RowBox[{"mp", "[", "\"\<CL21\>\"", "]"}], "]"}], ";", 
    RowBox[{"shape", "[", "a8", "]"}]}], ",", "\"\<\\nShape    D4 =\>\"", ",",
    
   RowBox[{
    RowBox[{"id", "[", 
     RowBox[{"mp", "[", "\"\<D4\>\"", "]"}], "]"}], ";", 
    RowBox[{"shape", "[", "a8", "]"}]}], ",", "\"\<\\nShape KiC4c =\>\"", ",",
    
   RowBox[{
    RowBox[{"id", "[", 
     RowBox[{"mp", "[", "\"\<KiC4c\>\"", "]"}], "]"}], ";", 
    RowBox[{"shape", "[", "a8", "]"}]}], ",", "\"\<\\nShape KiC4r =\>\"", ",",
    
   RowBox[{
    RowBox[{"id", "[", 
     RowBox[{"mp", "[", "\"\<KiC4r\>\"", "]"}], "]"}], ";", 
    RowBox[{"shape", "[", "a8", "]"}]}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Shape C2D4r =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "+", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"g", "+", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"g", "-", "h"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nShape  CL21 =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "+", "e"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "e"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "h"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nShape    D4 =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "g"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nShape KiC4c =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "g"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"f", "-", "h"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nShape KiC4r =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "g"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "e", "+", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "d", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "e", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "d", "+", "g", "+", "h"}], ")"}], "2"]}]}], "}"}]}],
   "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["8. (Visualization Deleted).", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["9. Orbits.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". Polar duals become continuous \"Orbits\" when the non-zero offsets and \
squared radii (or their product) are constrained to be one, defining \"unital\
\" sub-algebras. Many orbits appear to be unstable and have zero size. The \
implications of the few cases with finite sizes are discussed Section 10."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["9.1. C3, K & C4 Orbits have fixed amplitudes.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tFinite groups have finite \"orbits\", sets of points. These become \
continuous orbits (continuous multi-phase sinusoids) in algebras with polar \
duals - the duals form an equivalence class if offsets and squared radii (or \
ulnae) are constrained to values of 0 or 1 whilst angles are allowed to vary. \
They constitute continuous closed unitary sub-algebras; hoop multiplication \
of two orbits gives another orbit.\n\tOrbit vector values are given by ",
 StyleBox["toVector",
  FontSlant->"Italic"],
 " using arbitrary angles, all other parameters being 0 or 1. (",
 StyleBox["toVector",
  FontSlant->"Italic"],
 " uses the table ",
 StyleBox["gp",
  FontSlant->"Italic"],
 " which is set up by ",
 StyleBox["sh[\"mnemonic\"] ",
  FontSlant->"Italic"],
 "to distinguish between sizes and angles.) The three C3 and four C4 orbits \
are set up in Example 41; the names correspond to the sizes. Note that ",
 StyleBox["shape[\"C3\"]",
  FontSlant->"Italic"],
 " has one L1(linear) and one L2 (quadratic) size whilst a C3 vector has 3 \
degrees of freedom. Similarly, ",
 StyleBox["shape[\"C4\"]",
  FontSlant->"Italic"],
 " has three size parameters to describe a 4-element vector. Each squared \
radius provides a degree of freedom that is utilized by the angle parameter, \
which is a \"hidden variable\" for the cartesian form. Each polar form is the \
shape together with an angle for each quadratic size. Example 41 also sets up \
and multiplies the C3 orbits, showing the product to be an orbit with the \
angles added. Then four C4 orbit pairs are set up and multiplied; the \
products are orbits with the correct sizes:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 41. ",
 StyleBox["C3 & C4 Orbit Multiplication.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 FormBox["a", TraditionalForm]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\"\<C3 Orbits\>\"", ",", 
   "\"\<\\nOC301 is {0,1,\[Sigma]} with vector form\>\"", ",", 
   RowBox[{
    RowBox[{"gmn", "=", "\"\<C3\>\""}], ";", 
    RowBox[{"mm", "=", "3"}], ";", 
    RowBox[{"OC301", "=", 
     RowBox[{"toVector", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "\[Sigma]"}], "}"}], "]"}]}]}], ",", 
   "\"\<\\nOC311 is {1,1,\[Sigma]} with vector form\>\"", ",", 
   RowBox[{"OC311", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "\[Sigma]"}], "}"}], "]"}]}], ",", 
   "\"\<\\nProducts are orbits with added angles; the polar form of the \
product is\>\"", ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{"toPolar", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"OC301", ",", "OC311", ",", "C3"}], "]"}], "]"}], "]"}], ",", 
   "\"\<\\n\\nC4 Orbits\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gmn", "=", "\"\<C4\>\""}], ";", 
    RowBox[{"mm", "=", "4"}], ";", 
    "\"\<\\nOC4001 is {0,0,1,a} with vector form\>\""}], ",", 
   RowBox[{"OC4001", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "a"}], "}"}], "]"}]}], ",", 
   "\"\<\\nOC4011 is {0,1,1,b} with vector form\>\"", ",", 
   RowBox[{"OC4011", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1", ",", "b"}], "}"}], "]"}]}], ",", 
   "\"\<\\nOC4101 = {1,0,1,c} with vector form\>\"", ",", 
   RowBox[{"OC4101", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1", ",", "c"}], "}"}], "]"}]}], ",", 
   "\"\<\\nOC4111 is {1,1,1,d} with vector form\>\"", ",", 
   RowBox[{"OC4111", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1", ",", "d"}], "}"}], "]"}]}], ",", 
   "\"\<\\n\\n\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<OC4001\[Times]OC4001 has the 001 shape\>\"", ",", 
      RowBox[{"shape", "[", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"OC4001", ",", "OC4001", ",", "C4"}], "]"}], "]"}], ",", 
      "\"\<\\nOC4101\[Times]OC4011 also has the 001 shape\\nas the two \
offsets disappear   \>\"", ",", 
      RowBox[{"shape", "[", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"OC4101", ",", "OC4011"}], "]"}], "]"}], ",", 
      "\"\<\\nOC4101\[Times]OC4111 has the 101 shape\>\"", ",", 
      RowBox[{"shape", "[", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"OC4101", ",", "OC4111"}], "]"}], "]"}], ",", 
      "\"\<\\nOC4111\[Times]OC4111 has the 111 shape\>\"", ",", 
      RowBox[{"shape", "[", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"OC4111", ",", "OC4111"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  "}"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->10],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C3 Orbits\"\>", 
   ",", "\<\"\\nOC301 is {0,1,a} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "a", "]"}]}], "3"], ",", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"a", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}], ",", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"a", "-", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}]}], "}"}], 
   ",", "\<\"\\nOC311 is {1,1,b} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "b", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"b", "+", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"b", "-", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nProducts are orbits with added angles; the polar form of the \
product is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"a", "+", "b"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"a", "+", "b"}], "]"}]}], "]"}]}], "}"}], 
   ",", "\<\"\\n\\nC4 Orbits\"\>", 
   ",", "\<\"\\nOC4001 is {0,0,1,a} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Cos", "[", "a", "]"}], "2"], ",", 
     FractionBox[
      RowBox[{"Sin", "[", "a", "]"}], "2"], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Cos", "[", "a", "]"}], "2"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Sin", "[", "a", "]"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nOC4011 is {0,1,1,b} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "b", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "b", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "b", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "b", "]"}]}]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nOC4101 = {1,0,1,c} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "c", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "c", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "c", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "c", "]"}]}]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nOC4111 is {1,1,1,d} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "d", "]"}]}]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"Sin", "[", "d", "]"}], "2"], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "d", "]"}]}]}], ")"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Sin", "[", "d", "]"}], "2"]}]}], "}"}], ",", "\<\"\\n\\n\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OC4001\[Times]OC4001 has the 001 shape\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], 
     ",", "\<\"\\nOC4101\[Times]OC4011 also has the 001 shape\\nas the two \
offsets disappear   \"\>", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], 
     ",", "\<\"\\nOC4101\[Times]OC4111 has the 101 shape\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1"}], "}"}], 
     ",", "\<\"\\nOC4111\[Times]OC4111 has the 111 shape\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "Example 42. ",
 StyleBox["C3 & C4 Chiral Orbits.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[TextData[{
 "These orbits possess chirality, as the order of the orbit components is \
reversed if the angle is negated. I appending a ",
 StyleBox["c",
  FontSlant->"Italic"],
 " to the orbit name to indicate negation of the angle"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<OC301c is {0,1,-a} with vector form\>\"", ",", 
   RowBox[{
    RowBox[{"gmn", "=", "\"\<C3\>\""}], ";", 
    RowBox[{"mm", "=", "3"}], ";", 
    RowBox[{"OC301", "=", 
     RowBox[{"toVector", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", 
        RowBox[{"-", "a"}]}], "}"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"gmn", "=", "\"\<C4\>\""}], ";", 
    RowBox[{"mm", "=", "4"}], ";", 
    "\"\<\\nOC4001c is {0,0,1,-a} with vector form\>\""}], ",", 
   RowBox[{"OC4001", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", 
       RowBox[{"-", "a"}]}], "}"}], "]"}]}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"OC301c is {0,1,-a} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "a", "]"}]}], "3"], ",", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"a", "-", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}], ",", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"a", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}]}], "}"}], 
   ",", "\<\"\\nOC4001c is {0,0,1,-a} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Cos", "[", "a", "]"}], "2"], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Sin", "[", "a", "]"}], "2"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Cos", "[", "a", "]"}], "2"]}], ",", 
     FractionBox[
      RowBox[{"Sin", "[", "a", "]"}], "2"]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "\tThe group K (C2C2) cannot have a polar orbit as it has no L2 size, but \
the four L1 sizes can be combined to give six paired difference-of-squares \
formulations. Hyperbolic orbits can be defined using any of these as \
adjacent",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 ", opposite",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 " pairs. Two orbits are set up in Example 43 and multiplied. The product is \
shown to be an orbit with unit sizes; its \"angles\" appear in complex form \
but numeric substitutions show that they are the sums of those in the \
multiplicands."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 43. Klein Group Hyperbolic Orbit Multiplication.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"gmn", "=", "\"\<K\>\""}], ";", 
    "\"\<OKh11a is {1,\[Alpha],1,a} with vector form\\n\>\""}], ",", 
   RowBox[{"OKh11a", "=", 
    RowBox[{"tohyVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Alpha]", ",", "1", ",", "a"}], "}"}], "]"}]}], 
   ",", "\"\<\\nOKh11b is {1,\[Beta],1,b} with vector form\>\"", ",", 
   RowBox[{"OKh11b", "=", 
    RowBox[{"tohyVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Beta]", ",", "1", ",", "b"}], "}"}], "]"}]}], ",", 
   "\"\<\\nTheir product Polar form is\\n\>\"", ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{"tohyPolar", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"OKh11a", ",", "OKh11b", ",", "K"}], "]"}], "]"}], "]"}], ",", 
   "\"\<\\nSubstituting \[Alpha]\[Rule].1, \[Beta]\[Rule].3, a\[Rule].22, b\
\[Rule].28 shows that the angles have added to give \>\"", ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cosh", "[", 
          RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}], "+", 
         RowBox[{"Sinh", "[", 
          RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}], ")"}], "]"}], ",", 
      RowBox[{"Log", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cosh", "[", 
          RowBox[{"a", "+", "b"}], "]"}], "+", 
         RowBox[{"Sinh", "[", 
          RowBox[{"a", "+", "b"}], "]"}]}], ")"}], "]"}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "\[Rule]", ".1"}], ",", 
      RowBox[{"a", "\[Rule]", ".22"}], ",", 
      RowBox[{"\[Beta]", "\[Rule]", ".3"}], ",", 
      RowBox[{"b", "\[Rule]", ".28"}]}], "}"}]}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 FontSize->10],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"OKh11a is {1,\[Alpha],1,a} with vector form\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Cosh", "[", "a", "]"}], "2"], "+", 
      FractionBox[
       RowBox[{"Cosh", "[", "\[Alpha]", "]"}], "2"]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"Sinh", "[", "a", "]"}], "2"], "+", 
      FractionBox[
       RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Cosh", "[", "a", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"Cosh", "[", "\[Alpha]", "]"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sinh", "[", "a", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nOKh11b is {1,\[Beta],1,b} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Cosh", "[", "b", "]"}], "2"], "+", 
      FractionBox[
       RowBox[{"Cosh", "[", "\[Beta]", "]"}], "2"]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"Sinh", "[", "b", "]"}], "2"], "+", 
      FractionBox[
       RowBox[{"Sinh", "[", "\[Beta]", "]"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Cosh", "[", "b", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"Cosh", "[", "\[Beta]", "]"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sinh", "[", "b", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"Sinh", "[", "\[Beta]", "]"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nTheir product Polar form is\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Cosh", "[", 
          RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}], "==", 
         RowBox[{"Sinh", "[", 
          RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}], "||", 
        RowBox[{
         RowBox[{
          RowBox[{"Cosh", "[", 
           RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}], "+", 
          RowBox[{"Sinh", "[", 
           RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}], "==", "0"}]}], ",", 
       
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x$1117", "\[NotEqual]", "0"}], ",", 
         FractionBox[
          RowBox[{"\[Infinity]", " ", 
           RowBox[{"Sign", "[", "y$1117", "]"}]}], 
          RowBox[{"Sign", "[", "x$1117", "]"}]], ",", "0", ",", "0"}], "]"}], 
       ",", 
       RowBox[{
        RowBox[{"b$1117", "=", 
         RowBox[{"Log", "[", 
          RowBox[{"N", "[", 
           FractionBox[
            RowBox[{"x$1117", "+", "y$1117"}], 
            SqrtBox[
             RowBox[{
              SuperscriptBox["x$1117", "2"], "-", 
              SuperscriptBox["y$1117", "2"]}]]], "]"}], "]"}]}], ";", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"Re", "[", "b$1117", "]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Chop", "[", 
            RowBox[{"Im", "[", "b$1117", "]"}], "]"}]}]}], "]"}]}]}], "]"}], 
     ",", "1", ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Cosh", "[", 
          RowBox[{"a", "+", "b"}], "]"}], "==", 
         RowBox[{"Sinh", "[", 
          RowBox[{"a", "+", "b"}], "]"}]}], "||", 
        RowBox[{
         RowBox[{
          RowBox[{"Cosh", "[", 
           RowBox[{"a", "+", "b"}], "]"}], "+", 
          RowBox[{"Sinh", "[", 
           RowBox[{"a", "+", "b"}], "]"}]}], "==", "0"}]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x$1118", "\[NotEqual]", "0"}], ",", 
         FractionBox[
          RowBox[{"\[Infinity]", " ", 
           RowBox[{"Sign", "[", "y$1118", "]"}]}], 
          RowBox[{"Sign", "[", "x$1118", "]"}]], ",", "0", ",", "0"}], "]"}], 
       ",", 
       RowBox[{
        RowBox[{"b$1118", "=", 
         RowBox[{"Log", "[", 
          RowBox[{"N", "[", 
           FractionBox[
            RowBox[{"x$1118", "+", "y$1118"}], 
            SqrtBox[
             RowBox[{
              SuperscriptBox["x$1118", "2"], "-", 
              SuperscriptBox["y$1118", "2"]}]]], "]"}], "]"}]}], ";", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"Re", "[", "b$1118", "]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Chop", "[", 
            RowBox[{"Im", "[", "b$1118", "]"}], "]"}]}]}], "]"}]}]}], "]"}]}],
     "}"}], ",", "\<\"\\nSubstituting \[Alpha]\[Rule].1, \[Beta]\[Rule].3, a\
\[Rule].22, b\[Rule].28 shows that the angles have added to give \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0.4`", ",", "0.5`"}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["9.2. C5, C7 & C8 Orbits have unstable amplitudes.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThe orbits of C3 are of fixed squared radius 2/3 and offsets 0 or 1/3.  \
Those of C4 are of fixed squared radii or ulnae of magnitude 1/2, and offsets \
0 or \[PlusMinus]1/4. For C2 there is only one, hyperbolic, orbit with a unit \
ulna. Orbits of Cp (p prime>3) can be developed, with p sinusoidal phases, \
but their radii are unconstrained, though their offsets are 0 or 1/p. Example \
44 shows that OC51r, a five-phase orbit with radius ",
 StyleBox["r",
  FontSlant->"Italic"],
 ", has an L4 size of zero and so is unconstrained. The angle and L1 and L4 \
parameters only use 3 of the 5 degrees of freedom. Example 45 shows that a \
seven-phase orbit with radius ",
 StyleBox["r",
  FontSlant->"Italic"],
 " has a zero size in C7 (I have not found a polar expression for this \
group). These orbits also appear to be unstable - numerical integration of \
the relevant differential-equation sets is unstable. Example 46 shows that an \
eight-phase orbit with radius ",
 StyleBox["r",
  FontSlant->"Italic"],
 " has a zero size in C8. "
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 44.  ",
 StyleBox["Zero-sized C5 orbit.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{gmn = \"C5\";\"OC51r is\",OC51r = 
    toVector[{d, r, \[Sigma]}], 
  \"\\nThe radius disappears from the shape\", 
  Simplify[shape[OC51r]]}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 FontFamily->"Courier",
 FontSize->10],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"OC51r is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "5"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], "5"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"6", " ", "\[Pi]"}], "5"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"8", " ", "\[Pi]"}], "5"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}]}], "}"}], 
   ",", "\<\"\\nThe radius disappears from the shape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Example 45. ",
 StyleBox[" Zero-sized C7 orbit.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{tst = {d + r*Sin[\[Sigma]], 
     d + r*Sin[(2*Pi)/7 + \[Sigma]], 
     d + r*Sin[(4*Pi)/7 + \[Sigma]], 
     d + r*Sin[(6*Pi)/7 + \[Sigma]], 
     d + r*Sin[(8*Pi)/7 + \[Sigma]], 
     d + r*Sin[(10*Pi)/7 + 
         \[Sigma]], d + 
      r*Sin[(12*Pi)/7 + \[Sigma]]}/
    7;\"OC7dr is\",tst,\"The determinant simplifies (slowly!) to\", Simplify[
    fp[ca[7], tst]]}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"OC7dr is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "7"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "7"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "7"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "7"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], "7"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "7"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"6", " ", "\[Pi]"}], "7"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "7"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"8", " ", "\[Pi]"}], "7"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "7"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"10", " ", "\[Pi]"}], "7"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "7"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"12", " ", "\[Pi]"}], "7"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}]}], "}"}], 
   ",", "\<\"The determinant simplifies (slowly!) to\"\>", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Example 46. ",
 StyleBox[" Zero-sized C8 orbit.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{tst = {d + r*Sin[\[Sigma]], 
     d + r*Sin[(2*Pi)/8 + \[Sigma]], 
     d + r*Sin[(4*Pi)/8 + \[Sigma]], 
     d + r*Sin[(6*Pi)/8 + \[Sigma]], 
     d + r*Sin[(8*Pi)/8 + \[Sigma]], 
     d + r*Sin[(10*Pi)/8 + 
         \[Sigma]], d + 
      r*Sin[(12*Pi)/8 + \[Sigma]], d + 
      r*Sin[(14*Pi)/8 + \[Sigma]]}/
    8;\"OC8dr is\",tst,\"The determinant simplifies to\", Simplify[
    fp[ca[8], tst]]}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"OC8dr is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "4"], "+", "\[Sigma]"}], "]"}]}]}], ")"}]}], 
     ",", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"3", " ", "\[Pi]"}], "4"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"5", " ", "\[Pi]"}], "4"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"7", " ", "\[Pi]"}], "4"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}]}], "}"}], ",", "\<\"The determinant simplifies to\"\>", ",", 
   "0"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\t Stable, finite amplitude, orbits with 3, 4, 6, 9, and 12 phases have been \
found, some of which have polarization and chirality. They may be related to \
deBroglie waves. This leads to the surmise that quarks are wave packets with \
ternary symmetry, and leptons are wave packets with 4-fold symmetry. Some of \
the elements of hoops act as half-spin and unit-spin quantum operators (see \
Section 10). The orbit magnitudes may be related to the Planck size of \
\"extended\" particles; the number of types of particles may be related to \
the number of stable orbits. This is discussed in Section 10.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["9.3. Non-Abelian Orbits. (Under development.)", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tNon-Abelian groups have repeated factors that release extra degrees of \
freedom that cannot be taken up by the (radius,angle} formulation. On \
25/11/05 I discovered a polar form for repeated (i.e. non-abelian) quadratic \
shapes such as D3 and Qr, breaking the quadratic into two parts that are not \
conserved separately. These give \"pseudo-powers\" that revert to a vector of \
the correct size, even though the angles do not add.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 47.  ",
 StyleBox["D3 orbit.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toPol", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
   ",", "\"\<D3\>\""}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "e"}], ")"}], "2"]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "d"}], ")"}], "2"]}], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "-", "f"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "b"}], "+", "f"}], ")"}], "2"]}], ")"}]}]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "c", "-", "e"}], ",", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "c"}], "+", "e"}], ")"}]}]}], "]"}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "e"}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "b"}], "-", "d", "-", "f"}], ",", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "d"}], "+", "f"}], ")"}]}]}], "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Gamma]", ",", "\[Delta]", ",", "\[Eta]\[Eta]", ",", "\[Chi]", ",", 
      "\[Kappa]\[Kappa]", ",", "\[Psi]"}], "}"}], ",", "\"\<D3\>\""}], "]"}], 
  "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"4", 
      SqrtBox["\[Eta]\[Eta]"]}], "\[Rule]", "\[Eta]"}], ",", 
    RowBox[{
     RowBox[{"4", 
      SqrtBox["\[Kappa]\[Kappa]"]}], "\[Rule]", "\[Kappa]"}], ",", 
    RowBox[{
     RowBox[{"4", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"-", "\[Eta]\[Eta]"}], "+", "\[Kappa]\[Kappa]"}]]}], 
     "\[Rule]", "\[Nu]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"\[Kappa]", " ", 
       RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"\[Nu]", " ", 
       RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"\[Kappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "\[Chi]"}], "]"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"\[Nu]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "\[Psi]"}], "]"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"\[Kappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"], "-", "\[Chi]"}], "]"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"\[Nu]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"], "-", "\[Psi]"}], "]"}]}]}], 
     ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"id", "[", "D3", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{
   "\"\<If A=\>\"", ",", "A", ",", 
    "\"\<\\n\!\(\*SqrtBox[\(\(A\)\(\\\ \)\)]\)=\>\"", ",", 
    RowBox[{"rA", "=", 
     RowBox[{"hoopPower", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
    "\"\<\\n with Polar form\>\"", ",", 
    RowBox[{"toPolar", "[", "A", "]"}], ",", "\[IndentingNewLine]", 
    "\"\<\\n(\!\(\*SqrtBox[\(A\)]\)\!\(\*SuperscriptBox[\()\), \(2\)]\) is \
correct\>\"", ",", 
    RowBox[{"rA2", "=", 
     RowBox[{"hoopPower", "[", 
      RowBox[{"rA", ",", "2"}], "]"}]}], ",", "\[IndentingNewLine]", 
    "\"\<\\nbut \!\(\*SqrtBox[\(A\)]\).\!\(\*SqrtBox[\(\(A\)\(\\\ \
\)\)]\)=\>\"", ",", 
    RowBox[{"rArA", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"rA", ",", "rA"}], "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"shape", "[", "A", "]"}], ",", "\"\<Shape[\!\(\*
StyleBox[\"A\",
FontSlant->\"Italic\"]\)]\>\""}], "]"}], ",", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"shape", "[", "rA", "]"}], ",", 
      "\"\<Shape[\!\(\*SqrtBox[\(A\)]\)]\>\""}], "]"}], ",", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"shape", "[", "rA2", "]"}], ",", 
      "\"\<Shape[\!\(\*SuperscriptBox[\((\*SqrtBox[\(A\)])\), \
\(2\)]\)]\>\""}], "]"}], ",", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"shape", "[", "rArA", "]"}], ",", 
      "\"\<Shape[\!\(\*SqrtBox[\(A\)]\).\!\(\*SqrtBox[\(A\)]\)]\>\""}], 
     "]"}]}], "}"}], "//", "tf"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"If A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", 
     RowBox[{"-", "1.`"}], ",", "4.`", ",", "1.`", ",", "3.`", ",", "5.`"}], 
    "}"}], ",", "\<\"\\n\\!\\(\\@\\(\\(A\\)\\(\\\\ \\)\\)\\)=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1.184026244006728`", ",", "0.8945386347732366`", ",", 
     "1.5773461371970567`", ",", 
     RowBox[{"-", "1.4154813976717826`"}], ",", "0.1094563121831859`", ",", 
     "1.391771456285517`"}], "}"}], ",", "\<\"\\n with Polar form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"14.`", ",", "4.`", ",", 
     RowBox[{"-", "25.`"}], ",", 
     RowBox[{"-", "2.6179938779914944`"}], ",", "3.`", ",", 
     "2.4278682746450277`"}], "}"}], 
   ",", "\<\"\\n(\\!\\(\\@A\\)\\!\\(\\()\\^2\\)\\) is correct\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.9999999999999998`", ",", 
     RowBox[{"-", "1.0000000000000007`"}], ",", "4.`", ",", 
     "1.0000000000000024`", ",", "3.`", ",", "5.000000000000001`"}], "}"}], 
   ",", "\<\"\\nbut \\!\\(\\@A\\).\\!\\(\\@\\(\\(A\\)\\(\\\\ \\)\\)\\)=\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "6.4880338717125845`", ",", "2.078320452493908`", ",", 
     "1.7559830641437073`", ",", "0.5046192161472423`", ",", 
     "0.7559830641437076`", ",", "2.417060331358851`"}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"Shape[\\!\\(\\* \
StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)]\"\>", "14.`", "4.`", 
      RowBox[{"-", "25.`"}]},
     {"\<\"Shape[\\!\\(\\@A\\)]\"\>", "3.7416573867739418`", 
      "1.9999999999999993`", 
      RowBox[{"-", "5.`"}]},
     {"\<\"Shape[\\!\\(\\((\\@A)\\)\\^2\\)]\"\>", "14.000000000000004`", 
      "3.9999999999999956`", 
      RowBox[{"-", "25.00000000000001`"}]},
     {"\<\"Shape[\\!\\(\\@A\\).\\!\\(\\@A\\)]\"\>", "14.000000000000002`", 
      "3.9999999999999982`", "24.999999999999993`"}
    }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "D3", "]"}], ";", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<If B=\>\"", ",", 
        RowBox[{"B", "=", 
         RowBox[{"{", 
          RowBox[{"3.", ",", 
           RowBox[{"-", "1."}], ",", "2.", ",", "2.", ",", "5.", ",", "3."}], 
          "}"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<AB = \>\"", ",", 
        RowBox[{"AB", "=", 
         RowBox[{"hoopTimes", "[", 
          RowBox[{"A", ",", "B"}], "]"}]}]}], "}"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<Polar A= \>\"", ",", 
        RowBox[{"sa", "=", 
         RowBox[{"toPolar", "[", "A", "]"}]}]}], "}"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<Polar B= \>\"", ",", 
        RowBox[{"sb", "=", 
         RowBox[{"toPolar", "[", "B", "]"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<Polar AB=\>\"", ",", 
        RowBox[{"sab", "=", 
         RowBox[{"toPolar", "[", "AB", "]"}]}]}], "}"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<Only 3 sizes multiply\>\"", ",", 
        RowBox[{
         RowBox[{"sa", " ", "sb"}], "-", "sab"}]}], "}"}], "]"}]}], "}"}], "//",
    "tf"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"If B=\"\>", "3.`", 
      RowBox[{"-", "1.`"}], "2.`", "2.`", "5.`", "3.`"},
     {"\<\"AB = \"\>", "50.`", "40.`", "37.`", "17.`", "23.`", "29.`"},
     {"\<\"Polar A= \"\>", "14.`", "4.`", 
      RowBox[{"-", "25.`"}], 
      RowBox[{"-", "2.6179938779914944`"}], "3.`", "2.4278682746450277`"},
     {"\<\"Polar B= \"\>", "14.`", "6.`", 
      RowBox[{"-", "6.`"}], "1.7609219301413634`", "7.`", 
      "2.899028779494308`"},
     {"\<\"Polar AB=\"\>", "196.`", "24.`", "150.`", 
      RowBox[{"-", "0.5449788606363033`"}], "547.`", "0.5486956907469642`"},
     {"\<\"Only 3 sizes multiply\"\>", "0.`", "0.`", "0.`", 
      RowBox[{"-", "4.065103972094753`"}], 
      RowBox[{"-", "526.`"}], "6.4897643102701625`"}
    }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
\tAs with high-angle abelian multiplication, non-abelian powers rotate \
vectors.

Clifford algebras should clarify this section!\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["9.4. Harmonics. (Under development.)", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tThis study started with the observation that banded sets of differential \
equations had multi-phase sinusoidal solutions, and was followed by the study \
of groups. Multi-phase sinusoidal orbits imply a relationship - the groups \
are acting like the differential equations, with each group element rate of \
change being the difference between two other elements. Orbits may be first \
harmonics corresponding to stable particles, and higher harmonics should be \
resonances corresponding to unstable particles. \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["10. \"ROGER\" Algebras, Quantum Operators, Subsymmetry.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Summary. ",
 StyleBox["A few hoop algebras have stable orbits that define a fundamental \
area, and provide operators with half-integral or integral spin. It is \
surmized that these Renormalizing Orbit-Generating Equivalence-Relation \
(ROGER) algebras may provide an explanation of  fundamental particle \
stability. Their use as Quantum Operators is discussed. C3K provides \
half-spin operators; folding it to C3C2 gives integer-spin sub-symmetrical \
operators. \"Dozal\" (the unitary algebra of 12-element directors) conserves \
many functions that may be related to particle properties.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["10.1. Quantum operators.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tOrbits have only been found for a few hoops in the database, but some hoops \
have stable orbits with 3, 4, 6, 12 & 16 phases that may define a fundamental \
size. Some other hoops have unstable orbits that do not define a fundamental \
size (Section 9.2). It is conjectured that stable orbit sizes are related to \
the Planck area, and that their orbits are related to deBroglie waves. These \
Renormalizing Orbit-Generating Equivalence-Relation \"ROGER\" algebras may \
provide quantum operators for fundamental particles. In particular, elements \
of the C3K (g1205) algebra appear to be half-spin operators.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tJ.J.Hamilton published [9] a \"hypercomplex arithmetic\" with half-spin \
hypercomplex quantum operators as well as integer-spin quantum operators. He \
",
 "generalized",
 " complex conjugation (in which the conjugate of a conjugate is the \
original, ",
 StyleBox["i:(i*)*=+i",
  FontSlant->"Italic"],
 ") to include elements ",
 StyleBox["{a,b,a*,b*}",
  FontSlant->"Italic"],
 " demonstrating \"biconjugation\" (my term) in which the conjugate of a \
conjugate is the negated original, ",
 StyleBox["a:a** =-a, (a*)** =-a*,  b:b** =-b, (b*)** =-b*.",
  FontSlant->"Italic"],
 "  He demonstrated that ",
 StyleBox["{a,b,a*,b*}",
  FontSlant->"Italic"],
 "  act like fundamental half-integral spin quantum operators with properties \
that cannot be expressed as complex numbers. (This is because they exist in \
the hyperbolic plane of Example 41 rather than the complex plane. They are \
different square roots of unity whilst his full-spin operators ",
 StyleBox["i ",
  FontSlant->"Italic"],
 "& ",
 StyleBox["k ",
  FontSlant->"Italic"],
 "are different fourth roots.) Matrix representations (which are are not \
fundamental) can be obtained for them. He stated that ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "r"], TraditionalForm]]],
 " elements are required, thereby unnecessarily restricting himself to \
hypercomplex, rather than general, number systems. His multiplication table \
(Table II, reproduced below) uses the eight elements ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["E", 
     RowBox[{"n", " "}]], "="}], TraditionalForm]]],
 " {",
 StyleBox["1, i, h, k, a, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b", "*"], TraditionalForm]]],
 StyleBox[", ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "*"], TraditionalForm]]],
 StyleBox[", b",
  FontSlant->"Italic"],
 "}. However, he has several distinct \"-1\" elements (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["h", "2"], ",", " ", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "and", " ", 
     SuperscriptBox["a", 
      RowBox[{"*", "2"}]]}]}], TraditionalForm]]],
 " are all +1); he also introduces several other elements and many aliases. \
Example 48 converts his Table II to an index table and identifies it as an O4 \
isomorph. O4 is obtained on folding C4K, C3KC2, & C8K."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 48. ",
 StyleBox["J.J.Hamiltons's Hypercomplex Multiplication Table.  (His Table \
II.)",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{"     ", 
  FormBox[GridBox[{
     {" ", 
      SubscriptBox["E", "0"], 
      SubscriptBox["E", "1"], 
      SubscriptBox["E", "2"], 
      SubscriptBox["E", "3"], 
      SubscriptBox["E", "4"], 
      SubscriptBox["E", "5"], 
      SubscriptBox["E", "6"], 
      SubscriptBox["E", "7"]},
     {
      SubscriptBox["E", "0"], "1", "i", "h", "k", "a", 
      SuperscriptBox["b", "*"], 
      SuperscriptBox["a", "*"], "b"},
     {
      SubscriptBox["E", "1"], "i", 
      RowBox[{"-", "1"}], "k", 
      RowBox[{"-", "h"}], 
      SuperscriptBox["b", "*"], 
      RowBox[{"-", "a"}], "b", 
      RowBox[{"-", 
       SuperscriptBox["a", "*"]}]},
     {
      SubscriptBox["E", "2"], "h", "k", "1", "i", 
      SuperscriptBox["a", "*"], "b", "a", 
      SuperscriptBox["b", "*"]},
     {
      SubscriptBox["E", "3"], "k", 
      RowBox[{"-", "h"}], "i", 
      RowBox[{"-", "1"}], "b", 
      RowBox[{"-", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["b", "*"], 
      RowBox[{"-", "a"}]},
     {
      SubscriptBox["E", "4"], "a", 
      SuperscriptBox["b", "*"], 
      SuperscriptBox["a", "*"], "b", "1", "i", "h", "k"},
     {
      SubscriptBox["E", "5"], 
      SuperscriptBox["b", "*"], 
      RowBox[{"-", "a"}], "b", 
      RowBox[{"-", 
       SuperscriptBox["a", "*"]}], "i", 
      RowBox[{"-", "1"}], "k", 
      RowBox[{"-", "h"}]},
     {
      SubscriptBox["E", "6"], 
      SuperscriptBox["a", "*"], "b", "a", 
      SuperscriptBox["b", "*"], "h", "k", "1", "i"},
     {
      SubscriptBox["E", "7"], "b", 
      RowBox[{"-", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["b", "*"], 
      RowBox[{"-", "a"}], "k", 
      RowBox[{"-", "h"}], "i", 
      RowBox[{"-", "1"}]}
    }],
   TraditionalForm]}]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<This is \>\"", ",", 
   RowBox[{"id", "[", 
    RowBox[{"tst", "=", 
     RowBox[{"caylindex", "[", "   ", 
      FormBox[GridBox[{
         {"1", "i", "h", "k", "a", 
          SuperscriptBox["b", "*"], 
          SuperscriptBox["a", "*"], "b"},
         {"i", 
          RowBox[{"-", "1"}], "k", 
          RowBox[{"-", "h"}], 
          SuperscriptBox["b", "*"], 
          RowBox[{"-", "a"}], "b", 
          RowBox[{"-", 
           SuperscriptBox["a", "*"]}]},
         {"h", "k", "1", "i", 
          SuperscriptBox["a", "*"], "b", "a", 
          SuperscriptBox["b", "*"]},
         {"k", 
          RowBox[{"-", "h"}], "i", 
          RowBox[{"-", "1"}], "b", 
          RowBox[{"-", 
           SuperscriptBox["a", "*"]}], 
          SuperscriptBox["b", "*"], 
          RowBox[{"-", "a"}]},
         {"a", 
          SuperscriptBox["b", "*"], 
          SuperscriptBox["a", "*"], "b", "1", "i", "h", "k"},
         {
          SuperscriptBox["b", "*"], 
          RowBox[{"-", "a"}], "b", 
          RowBox[{"-", 
           SuperscriptBox["a", "*"]}], "i", 
          RowBox[{"-", "1"}], "k", 
          RowBox[{"-", "h"}]},
         {
          SuperscriptBox["a", "*"], "b", "a", 
          SuperscriptBox["b", "*"], "h", "k", "1", "i"},
         {"b", 
          RowBox[{"-", 
           SuperscriptBox["a", "*"]}], 
          SuperscriptBox["b", "*"], 
          RowBox[{"-", "a"}], "k", 
          RowBox[{"-", "h"}], "i", 
          RowBox[{"-", "1"}]}
        }],
       TraditionalForm], "]"}]}], "]"}], ",", 
   RowBox[{"tst", "//", "tf"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"This is \"\>", ",", "\<\"O4\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8"},
        {"2", 
         RowBox[{"-", "1"}], "4", 
         RowBox[{"-", "3"}], "6", 
         RowBox[{"-", "5"}], "8", 
         RowBox[{"-", "7"}]},
        {"3", "4", "1", "2", "7", "8", "5", "6"},
        {"4", 
         RowBox[{"-", "3"}], "2", 
         RowBox[{"-", "1"}], "8", 
         RowBox[{"-", "7"}], "6", 
         RowBox[{"-", "5"}]},
        {"5", "6", "7", "8", "1", "2", "3", "4"},
        {"6", 
         RowBox[{"-", "5"}], "8", 
         RowBox[{"-", "7"}], "2", 
         RowBox[{"-", "1"}], "4", 
         RowBox[{"-", "3"}]},
        {"7", "8", "5", "6", "3", "4", "1", "2"},
        {"8", 
         RowBox[{"-", "7"}], "6", 
         RowBox[{"-", "5"}], "4", 
         RowBox[{"-", "3"}], "2", 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tBecause O4 (g0813) is an equivalence relation on C3KC2 (g2415), Table II \
is embedded in C3KC2, and also in C3K, which is folded from C3KC2. Completing \
an \"extended table\" using Hamilton's definitions for -",
 StyleBox["1,-h,-a",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["-a*",
  FontSlant->"Italic"],
 ", and for their products, gives a 12\[Times]12 C3K isomorph. Choosing \
generators  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["i", "3"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", "2"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 "=1 (to match Hamilton's nomenclature) gives the elements that are shown \
above the table in Example 48. If the supplementary and ill-defined \"-1\" \
term is converted to an arbitrary variable ",
 StyleBox["ii",
  FontSlant->"Italic"],
 " (it is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["i", "2"], TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["E", "1", "2"], TraditionalForm]]],
 " in Table II), the table becomes C3K. Deleting the rows and columns \
starting with negated elements (and shown in plain face) reduces this table \
to his Table II, which is therefore embedded in C3K:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 49. ",
 StyleBox["J.J.Hamiltons's Table II is embedded in C3K.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{"(*", "    ", 
  RowBox[{"1", "  ", "i", "   ", 
   SuperscriptBox["i", "2"], "  ", "h", "  ", "hi", " ", 
   SuperscriptBox["hi", "2"], " ", "a", "  ", "ai", "  ", 
   SuperscriptBox["ai", "2"], "ah", " ", "ahi", " ", 
   SuperscriptBox["ahi", "2"]}], " ", "*)"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"jjh3", "=", 
   RowBox[{GridBox[{
      {"1", "i", 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], "h", "k", 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], "a", 
       SuperscriptBox["b", "*"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       SuperscriptBox["a", "*"], "b", 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"]},
      {"i", 
       RowBox[{"-", "1"}], 
       StyleBox["1",
        FontWeight->"Plain"], "k", 
       RowBox[{"-", "h"}], 
       StyleBox["h",
        FontWeight->"Plain"], 
       SuperscriptBox["b", "*"], 
       RowBox[{"-", "a"}], 
       StyleBox["a",
        FontWeight->"Plain"], "b", 
       RowBox[{"-", 
        SuperscriptBox["a", "*"]}], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"]},
      {
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"], 
       StyleBox["i",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], 
       StyleBox["h",
        FontWeight->"Plain"], 
       StyleBox["k",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       StyleBox["a",
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["b", "*"],
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       StyleBox["b",
        FontWeight->"Plain"]},
      {"h", "k", 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], "1", "i", 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       SuperscriptBox["a", "*"], "b", 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], "a", 
       SuperscriptBox["b", "*"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"]},
      {"k", 
       RowBox[{"-", "h"}], 
       StyleBox["h",
        FontWeight->"Plain"], "i", 
       RowBox[{"-", "1"}], 
       StyleBox["1",
        FontWeight->"Plain"], "b", 
       RowBox[{"-", 
        SuperscriptBox["a", "*"]}], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       SuperscriptBox["b", "*"], 
       RowBox[{"-", "a"}], 
       StyleBox["a",
        FontWeight->"Plain"]},
      {
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], 
       StyleBox["h",
        FontWeight->"Plain"], 
       StyleBox["k",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"], 
       StyleBox["i",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       StyleBox["b",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       StyleBox["a",
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["b", "*"],
        FontWeight->"Plain"]},
      {"a", 
       SuperscriptBox["b", "*"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       SuperscriptBox["a", "*"], "b", 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], "1", "i", 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], "h", "k", 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"]},
      {
       SuperscriptBox["b", "*"], 
       RowBox[{"-", "a"}], 
       StyleBox["a",
        FontWeight->"Plain"], "b", 
       RowBox[{"-", 
        SuperscriptBox["a", "*"]}], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], "i", 
       RowBox[{"-", "1"}], 
       StyleBox["1",
        FontWeight->"Plain"], "k", 
       RowBox[{"-", "h"}], 
       StyleBox["h",
        FontWeight->"Plain"]},
      {
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       StyleBox["a",
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["b", "*"],
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       StyleBox["b",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"], 
       StyleBox["i",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], 
       StyleBox["h",
        FontWeight->"Plain"], 
       StyleBox["k",
        FontWeight->"Plain"]},
      {
       SuperscriptBox["a", "*"], "b", 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], "a", 
       SuperscriptBox["b", "*"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], "h", "k", 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], "1", "i", 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"]},
      {"b", 
       RowBox[{"-", 
        SuperscriptBox["a", "*"]}], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       SuperscriptBox["b", "*"], 
       RowBox[{"-", "a"}], 
       StyleBox["a",
        FontWeight->"Plain"], "k", 
       RowBox[{"-", "h"}], 
       StyleBox["h",
        FontWeight->"Plain"], "i", 
       RowBox[{"-", "1"}], 
       StyleBox["1",
        FontWeight->"Plain"]},
      {
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       StyleBox["b",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       StyleBox["a",
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["b", "*"],
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], 
       StyleBox["h",
        FontWeight->"Plain"], 
       StyleBox["k",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"], 
       StyleBox["i",
        FontWeight->"Plain"]}
     }], "/.", 
    RowBox[{
     RowBox[{"-", "1"}], "\[Rule]", "ii"}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{"\"\<This is \>\"", ",", 
    RowBox[{"id", "[", 
     RowBox[{"caylindex", "[", "jjh3", "]"}], "]"}]}], "}"}]}]], "Input",
 Editable->False,
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"This is \"\>", ",", "\<\"C3K\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tHence Hamilton's hypercomplex algebra can be interpreted as the C3K \
algebra if his ",
 StyleBox["i",
  FontSlant->"Italic"],
 " is a cube root of 1, with ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["h",
  FontSlant->"Italic"],
 " being different square roots of 1. His half-spin operators {",
 StyleBox["a, a*, -a\[Congruent]a**,b, b*, -b\[Congruent]b**\[Congruent]-a*",
  FontSlant->"Italic"],
 "} are then {",
 StyleBox["a, a h, a i i, a h i, a i , a h i i",
  FontSlant->"Italic"],
 "}; conjugation is multiplication by ",
 StyleBox["h",
  FontSlant->"Italic"],
 " (with ",
 StyleBox["h h",
  FontSlant->"Italic"],
 " =1), but biconjugation becomes multiplication by ",
 StyleBox["i",
  FontSlant->"Italic"],
 " or ",
 StyleBox["i i",
  FontSlant->"Italic"],
 ". This introduces ternary symmetry, and defies the prejudice that there \
must be ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "n"], TraditionalForm]]],
 " elements in an algebra - which is only true for real algebras without \
divisors of zero."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tC3K has a polar-vector duality, interconverting the vector form {e,i,ii, \
h,hi,hii, a,ai,aii, ah,ahi,ahii} (where e is the neutral element or 1) and \
the polar form with four scalar offsets {\[Alpha], \[Beta], \[Gamma], \
\[Delta]}, and four {squared radius, angle} pairs {\[Zeta]\[Zeta], \[Tau], \
\[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \[Chi], ",
 StyleBox["\[CurlyKappa]\[CurlyKappa]",
  FontWeight->"Bold"],
 ", \[Psi]} in a three-phase system. The squared radii are sums of squares, \
and so are positive for real vec coefficients. (The interconversions are \
still valid for complex coefficients, but these can give complex and negative \
radii.) \nThe following expressions are edited to emphasise the \
inter-relationships between the vector and polar forms. In particular, \
quadratic polar elements such as \[Zeta]\[Zeta] become radii such as \[Zeta], \
and 2\[Pi]/3 is written as \[Omega]:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 50. ",
 StyleBox["C3K Polar Dual.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{"toPolar", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h",
      ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}], ",", "\"\<C3K\>\""}], 
  "]"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"(*", "\[Alpha]", "*)"}], 
  RowBox[{
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h", 
    "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
   RowBox[{"\[Beta]", "=", 
    RowBox[{
    "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", "h",
      "+", "i", "-", "j", "-", "k", "-", "l"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"(*", "\[Gamma]", "*)"}], 
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-", "h", 
    "-", "i", "-", "j", "-", "k", "-", "l"}], ",", 
   RowBox[{"\[Delta]", "=", 
    RowBox[{
    "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "-", "h",
      "-", "i", "+", "j", "+", "k", "+", "l"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"(*", "\[Zeta]\[Zeta]", "*)"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-", 
         "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-", 
         "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "+", "i",
          "-", "j", "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "\[Tau]", "*)"}], 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
      RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "+", 
      RowBox[{"2", " ", "g"}], "-", "h", "-", "i", "+", 
      RowBox[{"2", " ", "j"}], "-", "k", "-", "l"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
       "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-", 
        "l"}], ")"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", "\[Lambda]\[Lambda]", "*)"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", "+", 
         "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "-", "g", "+", "i",
          "+", "j", "-", "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", "+", 
         "l"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"(*", "\[Phi]", "*)"}], 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
      RowBox[{"2", " ", "d"}], "+", "e", "+", "f", "+", 
      RowBox[{"2", " ", "g"}], "-", "h", "-", "i", "-", 
      RowBox[{"2", " ", "j"}], "+", "k", "+", "l"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
       "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", "+", 
        "l"}], ")"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", "\[Eta]\[Eta]", "*)"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "-", "g", "+", "h", "-", "j", "+", 
         "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "+", "g", "-", "i",
          "+", "j", "-", "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "+", "e", "-", "f", "-", "h", "+", "i", "-", "k", "+", 
         "l"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"(*", "\[Chi]", "*)"}], 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
      RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "-", 
      RowBox[{"2", " ", "g"}], "+", "h", "+", "i", "-", 
      RowBox[{"2", " ", "j"}], "+", "k", "+", "l"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
       "b", "-", "c", "+", "e", "-", "f", "-", "h", "+", "i", "-", "k", "+", 
        "l"}], ")"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", "\[CurlyKappa]\[CurlyKappa]", "*)"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "-", "d", "+", "e", "-", "g", "+", "h", "+", "j", "-", 
         "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "-", "e", "+", "f", "-", "h", "+", "i", "+", "k", "-", 
         "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "+", "g", "-", "i",
          "-", "j", "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "\[Psi]", "*)"}], 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
      RowBox[{"2", " ", "d"}], "+", "e", "+", "f", "-", 
      RowBox[{"2", " ", "g"}], "+", "h", "+", "i", "+", 
      RowBox[{"2", " ", "j"}], "-", "k", "-", "l"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
       "b", "-", "c", "-", "e", "+", "f", "-", "h", "+", "i", "+", "k", "-", 
        "l"}], ")"}]}]}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[TextData[{
 "Example 51. ",
 StyleBox["C3K Polar-Dual reversion to Cartesian form.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{"C3Kv", "=", 
  RowBox[{
   RowBox[{"toVector", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]", ",", 
       "\[Zeta]\[Zeta]", ",", "\[Tau]", ",", "\[Lambda]\[Lambda]", ",", 
       "\[Phi]", ",", "\[Eta]\[Eta]", ",", "\[Chi]", ",", 
       "\[CurlyKappa]\[CurlyKappa]", ",", "\[Psi]"}], "}"}], ",", 
     "\"\<C3K\>\""}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", 
       RowBox[{"\[Pi]", "/", "3"}]}], "\[Rule]", "\[Omega]"}], ",", " ", 
     RowBox[{
      RowBox[{"4", 
       RowBox[{"\[Pi]", "/", "3"}]}], "\[Rule]", 
      RowBox[{"2", "\[Omega]"}]}], ",", 
     RowBox[{
      SqrtBox["\[Zeta]\[Zeta]"], "\[Rule]", "\[Zeta]"}], ",", 
     RowBox[{
      SqrtBox["\[Lambda]\[Lambda]"], "\[Rule]", "\[Lambda]"}], ",", 
     RowBox[{
      SqrtBox["\[Eta]\[Eta]"], "\[Rule]", "\[Eta]"}], ",", 
     RowBox[{
      SqrtBox["\[CurlyKappa]\[CurlyKappa]"], "\[Rule]", "\[CurlyKappa]"}]}], 
    "}"}]}]}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "  ", 
   RowBox[{"(*", "a", "*)"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "       ", "+", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "+", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "b", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "c", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "d", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "-", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "e", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "f", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "g", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "-", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "h", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "i", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "j", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "+", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "k", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(*", "l", "*)"}], 
    RowBox[{"(", 
     RowBox[{
     "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
      RowBox[{"2", " ", "\[Zeta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Lambda]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Eta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[CurlyKappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}]}], "}"}], "/", 
  "12"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[TextData[{
 "\tThese polar-duals define orbits in the unital cases (i.e. when the \
product of non-zero sizes is constrained to be 1). ",
 StyleBox["Giving angles such as ",
  FontWeight->"Plain"],
 "\[Tau]",
 StyleBox[" ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["the form -(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["E", "p"], " ", "t"}], "-"}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["P.x)/\[HBar]  gives the orbit the properties of a multi-phase \
deBroglie wave.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "10.2. ",
 StyleBox["Dozal", "Text"],
 ". (under development.)"
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\t\"Dozal\" is my name for the algebra of 12 real elements. There are five \
12-element groups, with mnemonics ",
 StyleBox["C3C4, Q12, C3K, D3C2 & A4",
  FontSlant->"Italic"],
 ". I have not found a polar form for ",
 StyleBox["A4",
  FontSlant->"Italic"],
 ", but the others have closely related polar forms with intrinsic \
Planck-area-like finite amplitudes. The cubic A4 size ",
 StyleBox["l3",
  FontSlant->"Italic"],
 " discriminates between different types of orbit - a topic still to be \
investigated. The interconversions are shown in the same format as that used \
in Examples 50 & 51. \nIn Sci.Math, Jan 2006. Robert Israel provided a lemma \
to split a quartic C3C4 factor \"L4\" into two sums of squares, giving the \
l22a & l22b sizes. Prior to that, my version of the C3C4 shape did not \
conserve angles and so did not calculate powers correctly. The conversion of \
the vector form to the polar form is only expressed compactly if local \
variables {e1,e2, etc, with \[Psi]6=\[Psi]+\[Pi]/6}are used:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Example", " ", "52.", " ", 
  StyleBox["General",
   FontWeight->"Plain"], 
  StyleBox[" ",
   FontWeight->"Plain"], 
  StyleBox["C3C4",
   FontWeight->"Plain"], 
  StyleBox[" ",
   FontWeight->"Plain"], 
  StyleBox[
   RowBox[{"orbit", "."}],
   FontWeight->"Plain"]}]], "Input",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"C3C4abcdefghijkl", ".", "\[IndentingNewLine]", "Local"}], " ", 
  "symbols", " ", 
  RowBox[{"{", 
   RowBox[{"\[Epsilon]", ",", 
    RowBox[{"r", "=", 
     RowBox[{"-", 
      RowBox[{"Sqrt", "[", "3", "]"}]}]}], ",", 
    RowBox[{"e1", "=", 
     RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}]}], ",", 
    RowBox[{"e2", "=", 
     RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"a1", "=", 
     RowBox[{
     "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-", 
      "k"}]}], ",", 
    RowBox[{"a2", "=", 
     RowBox[{
     "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", "+", 
      "k"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"b1", "=", 
     RowBox[{
     "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-", 
      "l"}]}], ",", 
    RowBox[{"b2", "=", 
     RowBox[{
     "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", "+", 
      "l"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"c1", "=", 
     RowBox[{
     "c", "-", "a", "+", "f", "-", "d", "+", "i", "-", "g", "+", "l", "-", 
      "j"}]}], ",", 
    RowBox[{"c2", "=", 
     RowBox[{
     "c", "-", "a", "-", "f", "+", "d", "+", "i", "-", "g", "-", "l", "+", 
      "j"}]}], ",", 
    RowBox[{"f1", "=", 
     RowBox[{"a", "-", "b", "-", "g", "+", "h", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "+", "e", "-", 
         RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
         RowBox[{"2", "l"}]}], ")"}], "r3"}]}]}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"f2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", 
         RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
         RowBox[{"2", "i"}]}], ")"}], "r3"}], "-", "d", "+", "e", "+", "j", 
      "-", "k"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"f3", "=", 
     RowBox[{"a", "-", "b", "-", "g", "+", "h", "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "+", "e", "-", 
         RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
         RowBox[{"2", "l"}]}], ")"}], "r3"}]}]}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"f4", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", 
         RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
         RowBox[{"2", "i"}]}], ")"}], "r3"}], "+", "d", "-", "e", "-", "j", 
      "+", "k"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
    "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h",
      "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
    RowBox[{
    "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", "h",
      "+", "i", "-", "j", "-", "k", "-", "l"}], ",", "\[IndentingNewLine]", 
    RowBox[{"\[Epsilon]", "=", 
     RowBox[{
      SuperscriptBox["e1", "2"], "+", 
      SuperscriptBox["e2", "2"]}]}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Epsilon]", "==", "0"}], "&&", 
       RowBox[{"e2", "\[Equal]", "0"}]}], ",", "0", ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"e1", ",", "e2"}], "]"}], ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"e1", ",", "e2"}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a1", "2"], "+", 
       SuperscriptBox["b1", "2"], "+", 
       SuperscriptBox["c1", "2"]}], ")"}], "/", "2"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"b1", "\[Equal]", "0"}], ",", "0", ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"a1", "-", "c1"}], ",", 
        RowBox[{"r", " ", "b1"}]}], "]"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a2", "2"], "+", 
       SuperscriptBox["b2", "2"], "+", 
       SuperscriptBox["c2", "2"]}], ")"}], "/", "2"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"b2", "\[Equal]", "0"}], ",", "0", ",", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"a2", "-", "c2"}], ",", 
        RowBox[{"r", " ", "b2"}]}], "]"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["f1", "2"], "+", 
       SuperscriptBox["f2", "2"]}], ")"}], 
     RowBox[{"3", "/", "4"}]}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"f2", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], "/", "6"}], ",", 
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{"f1", ",", "f2"}], "]"}], "-", 
       RowBox[{"\[Pi]", "/", "6"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["f3", "2"], "+", 
       SuperscriptBox["f4", "2"]}], ")"}], 
     RowBox[{"3", "/", "4"}]}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"f4", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], "/", "6"}], ",", 
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{"f3", ",", "f4"}], "]"}], "-", 
       RowBox[{"\[Pi]", "/", "6"}]}]}], "]"}]}], "}"}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 Evaluatable->False,
 FontSize->9],

Cell[BoxData[
 RowBox[{"           ", 
  RowBox[{
   RowBox[{
   "C3C4\[Alpha]\[Beta]\[Epsilon]\[Sigma]\[Zeta]\[Tau]\[Lambda]\[Phi]\[Eta]\
\[Chi]\[Kappa]\[Psi]", " ", ".", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
       RowBox[{
        SqrtBox["3"], " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", "\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{
        SqrtBox["3"], " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "-", 
       RowBox[{
        SqrtBox["3"], " ", "\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], 
       "                          ", "-", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "                         ", 
       "-", 
       RowBox[{"2", " ", "\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
       RowBox[{
        SqrtBox["3"], " ", "\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", "\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", "\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}], "-", 
       RowBox[{
        SqrtBox["3"], " ", "\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], 
       "                         ", "-", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{"2", " ", "\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
       RowBox[{
        SqrtBox["3"], " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "-", 
       RowBox[{
        SqrtBox["3"], " ", "\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", "\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], 
       "                         ", "+", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "                          ", 
       "+", 
       RowBox[{"2", " ", "\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
       RowBox[{
        SqrtBox["3"], " ", "\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}], "-", 
       RowBox[{
        SqrtBox["3"], " ", "\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{
        SqrtBox["3"], " ", "\[Eta]", " ", 
        RowBox[{"Sin", "[", "\[Chi]6", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", "\[Kappa]", " ", 
        RowBox[{"Sin", "[", "\[Psi]6", "]"}]}]}], ",", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}], "                             ",
         "2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]6", "]"}]}], "                     ", "-", 
       
       RowBox[{"2", " ", "\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]6", "]"}]}]}]}], "}"}]}], "/", 
   "12"}]}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell["\<\
\tAs Q12 and D3C2 are noncommutative, the dual forms do not create angles \
that add on multiplication and cannot create true powers or roots.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 53. ",
 StyleBox["Q12 Cartesian & Polar-Dual interconversions.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["id",
    FontColor->GrayLevel[0]], "[", "Q12", "]"}], ";", 
  RowBox[{"Q12p", "=", 
   RowBox[{"toPolar", "[", 
    RowBox[{"{", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}], 
    "]"}]}]}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h", 
    "+", "i", "+", "j", "+", "k", "+", "l"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", "h", 
    "+", "i", "-", "j", "-", "k", "-", "l"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], ")"}], 
     "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}], ")"}], 
     "2"]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], ",", 
     RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}]}], "]"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "g", "-", "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", "h", "-", "i"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "g", "+", "i"}], ")"}], "2"]}], 
     ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
      RowBox[{"2", " ", "g"}], "-", "h", "-", "i"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "-", "c", "+", "h", "-", "i"}], ")"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "e", "+", "j", "-", "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "f", "+", "k", "-", "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "f", "-", "j", "+", "l"}], ")"}], "2"]}], 
     ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "+", 
      RowBox[{"2", " ", "j"}], "-", "k", "-", "l"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"e", "-", "f", "+", "k", "-", "l"}], ")"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "g", "-", "i"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "-", "h", "+", "i"}], ")"}], "2"]}], ")"}], 
    "/", "2"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
      RowBox[{"2", " ", "g"}], "+", "h", "+", "i"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "-", "c", "-", "h", "+", "i"}], ")"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "e", "-", "j", "+", "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "f", "+", "j", "-", "l"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "f", "-", "k", "+", "l"}], ")"}], "2"]}], ")"}], 
    "/", "2"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "-", 
      RowBox[{"2", " ", "j"}], "+", "k", "+", "l"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"e", "-", "f", "-", "k", "+", "l"}], ")"}]}]}], "]"}]}], 
  "}"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{"     ", 
  RowBox[{
  "Q12\[Alpha]\[Beta]\[Epsilon]\[Sigma]\[Zeta]\[Tau]\[Lambda]\[Phi]\[Eta]\
\[Chi]\[CurlyKappa]\[Psi]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "+", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "+", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "         ", "-", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "      ", "+", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "-", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "      ", "+", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
        RowBox[{"2", " ", "\[Epsilon]", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "      ", "+", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}]}], "}"}], "/",
     "12"}]}]}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[TextData[{
 "Example 54. ",
 StyleBox["General D3C2 orbit.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "D3C2", "]"}], ";", " ", 
  RowBox[{"D3C2p", "=", 
   RowBox[{"toPolar", "[", 
    RowBox[{"{", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}], 
    "]"}]}]}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h", 
    "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
   RowBox[{
   "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", "h", 
    "+", "i", "-", "j", "-", "k", "-", "l"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-", "h", 
    "-", "i", "-", "j", "-", "k", "-", "l"}], ",", 
   RowBox[{
   "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "-", "h", 
    "-", "i", "+", "j", "+", "k", "+", "l"}], ",", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "g", "-", "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", "h", "-", "i"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "g", "+", "i"}], ")"}], "2"]}], 
     ")"}], "/", "2"}], ",", "  ", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
      RowBox[{"2", " ", "g"}], "-", "h", "-", "i"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "-", "c", "+", "h", "-", "i"}], ")"}]}]}], "]"}], ",", 
   " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "e", "-", "j", "+", "k"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "f", "+", "j", "-", "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "e"}], "+", "f", "-", "k", "+", "l"}], ")"}], "2"]}], 
     ")"}], "/", "2"}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "d"}], "+", "e", "+", "f", "-", 
      RowBox[{"2", " ", "j"}], "+", "k", "+", "l"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "e"}], "+", "f", "-", "k", "+", "l"}], ")"}]}]}], "]"}], 
   ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "g", "-", "i"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "-", "h", "+", "i"}], ")"}], "2"]}], ")"}], 
    "/", "2"}], ",", "  ", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
      RowBox[{"2", " ", "g"}], "+", "h", "+", "i"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "-", "c", "-", "h", "+", "i"}], ")"}]}]}], "]"}], ",", 
   " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "e", "+", "j", "-", "k"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "e"}], "+", "f", "+", "k", "-", "l"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "f", "-", "j", "+", "l"}], ")"}], "2"]}], ")"}], 
    "/", "2"}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "d"}], "+", "e", "+", "f", "+", 
      RowBox[{"2", " ", "j"}], "-", "k", "-", "l"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "e"}], "+", "f", "+", "k", "-", "l"}], ")"}]}]}], 
    "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{"     ", 
  RowBox[{
  "D3C2\[Alpha]\[Beta]\[Gamma]\[Delta]\[Zeta]\[Tau]\[Lambda]\[Phi]\[Eta]\[Chi]\
\[CurlyKappa]\[Psi]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "+", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "      ",
         "-", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "      ",
         "-", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "      ",
         "-", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"4", " ", "\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"4", " ", "\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "      ",
         "-", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "      ",
         "-", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "      ",
         "-", 
        RowBox[{"4", " ", "\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"4", " ", "\[CurlyKappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}]}], "}"}], "/",
     "12"}]}]}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[TextData[{
 "\tDozal algebra has been investigated because of its potential as a \
particle paradigm, having just enough variety to describe fundamental \
particles. 39 functions have been found to be conserved by one or more of the \
five Dozal group multiplications. The following table shows (for the first \
23) those functions that are sizes (irreducible determinant factors) as \
\"i\",  conserved combinations of sizes by \"c\", those that are conserved on \
orbit multiplication by \"o\", and those that are only conserved when some \
\"radii\" are zero or negative by \"n\". (Negative radii can occur in ",
 StyleBox["Q12 & D3C2",
  FontSlant->"Italic"],
 " because they have sizes with 3 positive and 3 negative squared terms.) \
Preliminary speculations about the relation between functions and particle \
properties are also included. The names indicate the type of function:- o",
 StyleBox["n",
  FontSlant->"Italic"],
 " are linear functions, offsets in orbits. p",
 StyleBox["ab",
  FontSlant->"Italic"],
 "-s",
 StyleBox["ab",
  FontSlant->"Italic"],
 " have b terms each of order a. l3 is the cubic A4 size. l4",
 StyleBox["p",
  FontSlant->"Italic"],
 "-l4",
 StyleBox["s",
  FontSlant->"Italic"],
 " are quartic sizes."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
No. Name C3C4 Q12 C3K D3C2 A4 Property?
1   o1   i    i   i   i    i   
2   o2   i    i   i   i       Charge
3   o3            i   i       Hypercharge
4   o4            i   i       
5  l22a  i
6  l22b  i
7   p22  o    o   o   o       
8   q22  i    i   o   o       Leptons
9   r22  c    c   c   c       
10  s22           c   c    i   
11  p23  i    n   i   n       u Quarks
12  q23  i    n   i   n       d Quarks    
13  r23  o    n   i   n       
14  s23  o    n   i   n       
15  q24  o    o   o   o       metric(0,4)
16  p24           o   o       Minkowski(1,3)
17  p26       i       i       
18  q26  o    o   n   i       s Quarks
19  r26  o    n   o   o       c Quarks
20  s26  o    i   o   o
21  l3                     i  Discriminant
22  l4
23  l4p  c    n   c   n
24  l4q  o    n   c   n
25  l4r       n       n
26  l4s  c    n   o   n       Gravity??\
\>", "Text",
 PageWidth->WindowWidth,
 FontFamily->"Courier New"],

Cell[TextData[{
 "This topic needs to be explored in more detail. The implications of \
remainders being split-off have yet to be explored. ",
 StyleBox["GroupLoopTest.nb",
  FontSlant->"Italic"],
 " includes extensive tabulations of functions that are conserved in various \
Dozal operations; I hope to correlate them with particle properties"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["Conservation, general vector.", "Subsubsection",
 PageWidth->WindowWidth],

Cell["\<\
Arbitrary vectors (with no sizes zero) are multiplied using the Dozal hoops, \
and conservation is recorded.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{
    ".2", ",", "1.", ",", "1.3", ",", ".7", ",", ".4", ",", ".6", ",", ".5", 
     ",", ".9", ",", ".8", ",", "0", ",", ".1", ",", ".2"}], "}"}]}], ";", 
  RowBox[{"B", "=", 
   RowBox[{"{", 
    RowBox[{
    ".3", ",", "2.", ",", "1.", ",", "0.", ",", "4", ",", ".66", ",", ".55", 
     ",", ".7", ",", ".8", ",", ".9", ",", "1.1", ",", "1.2"}], "}"}]}], ";", 
  
  RowBox[{"AB", "=", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"A", ",", "B", ",", "\"\<C3C4\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Transpose", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sa", "=", 
       RowBox[{"sh12", "[", "A", "]"}]}], ",", 
      RowBox[{"sb", "=", 
       RowBox[{"sh12", "[", "B", "]"}]}], ",", 
      RowBox[{"sab", "=", 
       RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
      RowBox[{"sasb", "=", 
       RowBox[{"sa", " ", "sb"}]}], ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{"sab", "-", "sasb"}], ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "8"}]}]}], "]"}], ",", 
      RowBox[{"Range", "[", "26", "]"}]}], "}"}]}]}], ";", 
  RowBox[{"cs", "=", 
   RowBox[{"{", "\"\<C3C4\>\"", "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", "i"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sa", "=", 
       RowBox[{"sh12", "[", "A", "]"}]}], ",", 
      RowBox[{"sb", "=", 
       RowBox[{"sh12", "[", "B", "]"}]}], ",", 
      RowBox[{"sab", "=", 
       RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
      RowBox[{"sasb", "=", 
       RowBox[{"sa", " ", "sb"}]}], ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{"sab", "-", "sasb"}], ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "8"}]}]}], "]"}]}], "}"}], "]"}]}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cs", ",", "\"\<\\nNames\>\""}], "]"}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", 
        RowBox[{"ds", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";", "cs"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C3C4\"\>", ",", "1", ",", "2", ",", "5", ",", "6", ",", "8", 
   ",", "9", ",", "11", ",", "12", ",", "22", ",", "25", ",", "32", 
   ",", "\<\"\\nNames\"\>", ",", "\<\"o1\"\>", ",", "\<\"o2\"\>", 
   ",", "\<\"l22a\"\>", ",", "\<\"l22b\"\>", ",", "\<\"q22\"\>", 
   ",", "\<\"r22\"\>", ",", "\<\"p23\"\>", ",", "\<\"q23\"\>", 
   ",", "\<\"l4p\"\>", ",", "\<\"l4s\"\>", ",", "\<\"L4a6\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AB", "=", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"A", ",", "B", ",", "\"\<Q12\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sa", "=", 
      RowBox[{"sh12", "[", "A", "]"}]}], ",", 
     RowBox[{"sb", "=", 
      RowBox[{"sh12", "[", "B", "]"}]}], ",", 
     RowBox[{"sab", "=", 
      RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
     RowBox[{"sasb", "=", 
      RowBox[{"sa", " ", "sb"}]}], ",", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"sab", "-", "sasb"}], ",", 
       RowBox[{"10", "^", 
        RowBox[{"-", "8"}]}]}], "]"}], ",", 
     RowBox[{"Range", "[", "26", "]"}]}], "}"}]}], ";", 
  RowBox[{"cs", "=", 
   RowBox[{"{", "\"\<Q12\>\"", "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", "i"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sa", "=", 
       RowBox[{"sh12", "[", "A", "]"}]}], ",", 
      RowBox[{"sb", "=", 
       RowBox[{"sh12", "[", "B", "]"}]}], ",", 
      RowBox[{"sab", "=", 
       RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
      RowBox[{"sasb", "=", 
       RowBox[{"sa", " ", "sb"}]}], ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{"sab", "-", "sasb"}], ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "8"}]}]}], "]"}]}], "}"}], "]"}]}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cs", ",", "\"\<\\nNames\>\""}], "]"}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", 
        RowBox[{"ds", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";", "cs"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Q12\"\>", ",", "1", ",", "2", ",", "8", ",", "9", ",", "17", 
   ",", "20", ",", "\<\"\\nNames\"\>", ",", "\<\"o1\"\>", ",", "\<\"o2\"\>", 
   ",", "\<\"q22\"\>", ",", "\<\"r22\"\>", ",", "\<\"p26\"\>", 
   ",", "\<\"s26\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"id", "[", "C3K", "]"}], ";", 
  RowBox[{"AB", "=", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"A", ",", "B"}], "]"}]}], ";", 
  RowBox[{"res", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sa", "=", 
      RowBox[{"sh12", "[", "A", "]"}]}], ",", 
     RowBox[{"sb", "=", 
      RowBox[{"sh12", "[", "B", "]"}]}], ",", 
     RowBox[{"sab", "=", 
      RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
     RowBox[{"sasb", "=", 
      RowBox[{"sa", " ", "sb"}]}], ",", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"sab", "-", "sasb"}], ",", 
       RowBox[{"10", "^", 
        RowBox[{"-", "8"}]}]}], "]"}], ",", 
     RowBox[{"Range", "[", "26", "]"}]}], "}"}]}], ";", 
  RowBox[{"cs", "=", 
   RowBox[{"{", "\"\<C3K\>\"", "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", "i"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sa", "=", 
       RowBox[{"sh12", "[", "A", "]"}]}], ",", 
      RowBox[{"sb", "=", 
       RowBox[{"sh12", "[", "B", "]"}]}], ",", 
      RowBox[{"sab", "=", 
       RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
      RowBox[{"sasb", "=", 
       RowBox[{"sa", " ", "sb"}]}], ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{"sab", "-", "sasb"}], ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "8"}]}]}], "]"}]}], "}"}], "]"}]}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cs", ",", "\"\<\\nNames\>\""}], "]"}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", 
        RowBox[{"ds", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";", "cs"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C3K\"\>", ",", "1", ",", "2", ",", "3", ",", "4", ",", "9", 
   ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "22", ",", 
   "23", ",", "32", ",", "33", ",", "\<\"\\nNames\"\>", ",", "\<\"o1\"\>", 
   ",", "\<\"o2\"\>", ",", "\<\"o3\"\>", ",", "\<\"o4\"\>", 
   ",", "\<\"r22\"\>", ",", "\<\"s22\"\>", ",", "\<\"p23\"\>", 
   ",", "\<\"q23\"\>", ",", "\<\"r23\"\>", ",", "\<\"s23\"\>", 
   ",", "\<\"l4p\"\>", ",", "\<\"l4q\"\>", ",", "\<\"L4a6\"\>", 
   ",", "\<\"L4b6\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AB", "=", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"A", ",", "B", ",", "\"\<D3C2\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sa", "=", 
      RowBox[{"sh12", "[", "A", "]"}]}], ",", 
     RowBox[{"sb", "=", 
      RowBox[{"sh12", "[", "B", "]"}]}], ",", 
     RowBox[{"sab", "=", 
      RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
     RowBox[{"sasb", "=", 
      RowBox[{"sa", " ", "sb"}]}], ",", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"sab", "-", "sasb"}], ",", 
       RowBox[{"10", "^", 
        RowBox[{"-", "8"}]}]}], "]"}], ",", 
     RowBox[{"Range", "[", "26", "]"}]}], "}"}]}], ";", 
  RowBox[{"cs", "=", 
   RowBox[{"{", "\"\<D3C2\>\"", "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", "i"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sa", "=", 
       RowBox[{"sh12", "[", "A", "]"}]}], ",", 
      RowBox[{"sb", "=", 
       RowBox[{"sh12", "[", "B", "]"}]}], ",", 
      RowBox[{"sab", "=", 
       RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
      RowBox[{"sasb", "=", 
       RowBox[{"sa", " ", "sb"}]}], ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{"sab", "-", "sasb"}], ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "8"}]}]}], "]"}]}], "}"}], "]"}]}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cs", ",", "\"\<\\nNames\>\""}], "]"}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", 
        RowBox[{"ds", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";", "cs"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"D3C2\"\>", ",", "1", ",", "2", ",", "3", ",", "4", ",", "9", 
   ",", "10", ",", "17", ",", "18", ",", "\<\"\\nNames\"\>", 
   ",", "\<\"o1\"\>", ",", "\<\"o2\"\>", ",", "\<\"o3\"\>", ",", "\<\"o4\"\>",
    ",", "\<\"r22\"\>", ",", "\<\"s22\"\>", ",", "\<\"p26\"\>", 
   ",", "\<\"q26\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AB", "=", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"A", ",", "B", ",", "\"\<A4\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sa", "=", 
      RowBox[{"sh12", "[", "A", "]"}]}], ",", 
     RowBox[{"sb", "=", 
      RowBox[{"sh12", "[", "B", "]"}]}], ",", 
     RowBox[{"sab", "=", 
      RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
     RowBox[{"sasb", "=", 
      RowBox[{"sa", " ", "sb"}]}], ",", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"sab", "-", "sasb"}], ",", 
       RowBox[{"10", "^", 
        RowBox[{"-", "8"}]}]}], "]"}], ",", 
     RowBox[{"Range", "[", "26", "]"}]}], "}"}]}], ";", 
  RowBox[{"cs", "=", 
   RowBox[{"{", "\"\<A4\>\"", "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", "i"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sa", "=", 
       RowBox[{"sh12", "[", "A", "]"}]}], ",", 
      RowBox[{"sb", "=", 
       RowBox[{"sh12", "[", "B", "]"}]}], ",", 
      RowBox[{"sab", "=", 
       RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
      RowBox[{"sasb", "=", 
       RowBox[{"sa", " ", "sb"}]}], ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{"sab", "-", "sasb"}], ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "8"}]}]}], "]"}]}], "}"}], "]"}]}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cs", ",", "\"\<\\nNames\>\""}], "]"}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "[", 
        RowBox[{"[", 
         RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"cs", ",", 
        RowBox[{"ds", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";", "cs"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A4\"\>", ",", "1", ",", "11", ",", "21", 
   ",", "\<\"\\nNames\"\>", ",", "\<\"o1\"\>", ",", "\<\"p23\"\>", 
   ",", "\<\"l3\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell["Summary.", "Text",
 PageWidth->WindowWidth],

Cell["\<\
C3C4 conserves o1, o2, l22a, l22b, q22, r23,       p23, q23,        l4p, l4s, \
L4a6
Q12 conserves   o1, o2,                 q22, r22,            p26,s26
C3K conserves  o1, o2, o3, o4,              r22, s22, p23, q23,  r23, s23, \
l4p, l4q, L4a6,L4b6
D3C2 conserves o1, o2, o3, o4,             r22, s22,     p26,   q26, 
A4 conserves     o1,                                               p23,       \
     l3.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conservation, unitary vector, equal angles.", "Subsubsection",
 PageWidth->WindowWidth],

Cell["\<\
Now look at unitary vectors (so A4 must be omitted) and sh12 by inserting the \
names in the hidden cell:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cs", "=", 
   RowBox[{"{", 
    RowBox[{"id", "[", "\"\<C3C4\>\"", "]"}], "}"}]}], ";", 
  RowBox[{"A", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"3.", ",", 
       RowBox[{
        RowBox[{"-", "1."}], "/", "3"}], ",", "4.", ",", "0.1", ",", 
       RowBox[{"1.", "/", "4"}], ",", "0.1", ",", 
       RowBox[{"8.", "/", "3"}], ",", "0.1", ",", 
       RowBox[{"3.", "/", "5."}], ",", "0.1", ",", 
       RowBox[{"5.", "/", "8"}], ",", "0.1"}], "}"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"2.", ",", ".5", ",", 
       RowBox[{"3.", "/", "5"}], ",", "0.2", ",", 
       RowBox[{"5", "/", "3."}], ",", "0.2", ",", 
       RowBox[{"4", "/", "7"}], ",", "0.2", ",", 
       RowBox[{"7", "/", "5."}], ",", "0.2", ",", 
       RowBox[{"4", "/", "5"}], ",", "0.2"}], "}"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AB", "=", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"A", ",", "B"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"res", "=", 
    RowBox[{"Chop", "[", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sa", "=", 
         RowBox[{"sh12", "[", "A", "]"}]}], ",", 
        RowBox[{"sb", "=", 
         RowBox[{"sh12", "[", "B", "]"}]}], ",", 
        RowBox[{"sab", "=", 
         RowBox[{"sh12", "[", "AB", "]"}]}], ",", 
        RowBox[{"sasb", "=", 
         RowBox[{"sa", " ", "sb"}]}], ",", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"sab", "-", "sasb"}], ",", 
          RowBox[{"10", "^", 
           RowBox[{"-", "8"}]}]}], "]"}], ",", 
        RowBox[{"Range", "[", "39", "]"}]}], "}"}], "]"}], "]"}]}], ";", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"res", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "5"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"cs", ",", 
         RowBox[{"ds", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "39"}], "}"}]}], "]"}], ";", "cs"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Take", "[", 
         RowBox[{"res", ",", "13"}], "]"}], "]"}], "//", "tf"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Take", "[", 
        RowBox[{"res", ",", 
         RowBox[{"{", 
          RowBox[{"14", ",", "26"}], "}"}]}], "]"}], "]"}]}], "//", 
     RowBox[{"tf", "\[IndentingNewLine]", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Drop", "[", 
        RowBox[{"res", ",", "26"}], "]"}], "]"}]}]}], "//", "tf"}], 
   "*)"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell["Summary", "Text"],

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{"\<\"C3C4\"\>", ",", "\<\"o1\"\>", ",", "\<\"o2\"\>", 
   ",", "\<\"l22a\"\>", ",", "\<\"l22b\"\>", ",", "\<\"q22\"\>", 
   ",", "\<\"r22\"\>", ",", "\<\"p23\"\>", ",", "\<\"q23\"\>", 
   ",", "\<\"p26\"\>", ",", "\<\"q26\"\>", ",", "\<\"l4p\"\>", 
   ",", "\<\"l4s\"\>", ",", "\<\"L4a3\"\>", ",", "\<\"L4b3\"\>", 
   ",", "\<\"L4c3\"\>", ",", "\<\"L4d3\"\>", ",", "\<\"L4a6\"\>"}], 
  "}"}], "\n", 
 RowBox[{"{", 
  RowBox[{"\<\"Q12\"\>", ",", "\<\"o1\"\>", ",", "\<\"o2\"\>", 
   ",", "\<\"q22\"\>", ",", "\<\"r22\"\>", ",", "\<\"p26\"\>", 
   ",", "\<\"s26\"\>"}], "}"}], "\n", 
 RowBox[{"{", 
  RowBox[{"\<\"C3K\"\>", ",", "\<\"o1\"\>", ",", "\<\"o2\"\>", 
   ",", "\<\"o3\"\>", ",", "\<\"o4\"\>", ",", "\<\"r22\"\>", 
   ",", "\<\"s22\"\>", ",", "\<\"p23\"\>", ",", "\<\"q23\"\>", 
   ",", "\<\"r23\"\>", ",", "\<\"s23\"\>", ",", "\<\"p26\"\>", 
   ",", "\<\"q26\"\>", ",", "\<\"l4p\"\>", ",", "\<\"l4q\"\>", 
   ",", "\<\"L4a3\"\>", ",", "\<\"L4b3\"\>", ",", "\<\"L4c3\"\>", 
   ",", "\<\"L4d3\"\>", ",", "\<\"L4a6\"\>", ",", "\<\"L4b6\"\>", 
   ",", "\<\"L4c6\"\>"}], "}"}], "\n", 
 RowBox[{"{", 
  RowBox[{"\<\"D3C2\"\>", ",", "\<\"o1\"\>", ",", "\<\"o2\"\>", 
   ",", "\<\"o3\"\>", ",", "\<\"o4\"\>", ",", "\<\"r22\"\>", 
   ",", "\<\"s22\"\>", ",", "\<\"p26\"\>", ",", "\<\"q26\"\>"}], 
  "}"}]}], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.3. Unital Subalgebras, Chirality, Polarization,", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tConstraining any set of sizes to multiply to 1 (ignoring zero sizes) gives \
a constrained sub-algebra. Signed-tables are sub-algebras of loops, for the \
introduction of negation (via equivalence relations) constrains one or more \
of the loop sizes to be zero. The offsets and squared radii of polar algebras \
are sizes in the algebra. Setting some offsets and squared radii to 0 gives \
subalgebras that are even more constrained, being restricted to a subspace of \
the full algebra (which is already a subspace of the parent loop). Setting \
the product of the remaining sizes to 1 gives \"unital\" subalgebras, in \
which the determinant is 1 (after factoring-out the irrelevant zeroes). \
Products in these algebras remain within the constraints. The expressions \
C3Kv & C3Kp for vector-polar interconversions in the C3K hoop were set up in \
section 10.1. They simplify to unital algebras when the offsets and radii are \
constrained to be 1:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 52. ",
 StyleBox["C3K Orbits are Chiral.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 FormBox[
  RowBox[{"C3KOrbit", " ", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"C3Kv", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"o1", "\[Rule]", "1"}], ",", 
       RowBox[{"o2", "\[Rule]", "1"}], ",", 
       RowBox[{"o3", "\[Rule]", "1"}], ",", 
       RowBox[{"o4", "\[Rule]", "1"}], ",", 
       RowBox[{"p", "\[Rule]", "1"}], ",", 
       RowBox[{"q", "\[Rule]", "1"}], ",", 
       RowBox[{"r", "\[Rule]", "1"}], ",", 
       RowBox[{"s", "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}], "\[Rule]", "\[Omega]"}], ",", 
       RowBox[{
        RowBox[{"4", 
         RowBox[{"\[Pi]", "/", "3"}]}], "\[Rule]", 
        RowBox[{"2", "\[Omega]"}]}]}], "}"}]}], "]"}]}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"(", "         ", 
     RowBox[{
      RowBox[{"Cos", "[", "pa", "]"}], "+", "         ", 
      RowBox[{"Cos", "[", "qa", "]"}], "+", "         ", 
      RowBox[{"Cos", "[", "ra", "]"}], "+", "         ", 
      RowBox[{"Cos", "[", "sa", "]"}], "+", "2"}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "pa"}], "]"}], "+", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "qa"}], "]"}], "+", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "ra"}], "]"}], "+", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "sa"}], "]"}], "+", "2"}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "pa"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "qa"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "ra"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "sa"}], "]"}], "+", "2"}], ")"}], ",",
     " ", 
    RowBox[{"(", "        ", 
     RowBox[{
      RowBox[{"Cos", "[", "pa", "]"}], "-", "         ", 
      RowBox[{"Cos", "[", "qa", "]"}], "+", "         ", 
      RowBox[{"Cos", "[", "ra", "]"}], "-", "    ", 
      RowBox[{"Cos", "[", "sa", "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "pa"}], "]"}], "-", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "qa"}], "]"}], "+", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "ra"}], "]"}], "-", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "sa"}], "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "pa"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "qa"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "ra"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "sa"}], "]"}]}], ")"}], ",", 
    RowBox[{"(", "        ", 
     RowBox[{
      RowBox[{"Cos", "[", "pa", "]"}], "+", "         ", 
      RowBox[{"Cos", "[", "qa", "]"}], "-", "        ", 
      RowBox[{"Cos", "[", "ra", "]"}], "-", "         ", 
      RowBox[{"Cos", "[", "sa", "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "pa"}], "]"}], "+", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "qa"}], "]"}], "-", 
      RowBox[{"Cos", "[", "  ", 
       RowBox[{"\[Omega]", "+", "ra"}], "]"}], "-", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "sa"}], "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "pa"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "qa"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "ra"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "sa"}], "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", "        ", 
     RowBox[{
      RowBox[{"Cos", "[", "pa", "]"}], "-", "         ", 
      RowBox[{"Cos", "[", "qa", "]"}], "-", "         ", 
      RowBox[{"Cos", "[", "ra", "]"}], "+", "         ", 
      RowBox[{"Cos", "[", "sa", "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "pa"}], "]"}], "-", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "qa"}], "]"}], "-", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "ra"}], "]"}], "+", 
      RowBox[{"Cos", "[", "   ", 
       RowBox[{"\[Omega]", "+", "sa"}], "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "pa"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "qa"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "ra"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", "\[Omega]"}], "+", "sa"}], "]"}]}], ")"}]}], "}"}], "/", 
  "6"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9,
 FontWeight->"Plain"],

Cell[TextData[{
 "\tAngle ",
 StyleBox["pa",
  FontSlant->"Italic"],
 " contributes four sets of three-phase sinusoids in a clockwise arrangement, \
Cos[pa], Cos[2 \[Pi]/3+pa], Cos[4 \[Pi]/3+pa]. Angle ",
 StyleBox["qa",
  FontSlant->"Italic"],
 " gives two sets of six-phase sinusoids, Cos[qa], Cos[2 \[Pi]/3+qa], Cos[4 \
\[Pi]/3+qa], -Cos[qa], -Cos[2 \[Pi]/3+qa], -Cos[4 \[Pi]/3+qa]. Angles ",
 StyleBox["ra, sa",
  FontSlant->"Italic"],
 " also give two sets of six-phase sinusoids, but with different sequences. \
These are all chiral; negating the angles reverses the chirality.\n\tIf any \
two angles are linked, e.g. by putting ",
 StyleBox["qa=pa+\[Phi]",
  FontSlant->"Italic"],
 ", they form polarized phases:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 53. ",
 StyleBox["C3K Orbits can exhibit Polarizations.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"C3KOrbit", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qa", "->", "pa"}], ",", 
     RowBox[{"sa", "->", "ra"}]}], "}"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Cos", "[", "pa", "]"}], "+", 
      RowBox[{"Cos", "[", "ra", "]"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"pa", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"pa", "+", 
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"]}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}]}], ")"}]}], 
   ",", "0", ",", "0", ",", "0", ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "pa", "]"}], "-", 
      RowBox[{"Cos", "[", "ra", "]"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"pa", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"pa", "+", 
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"]}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}]}], ")"}]}], 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Cos", "[", "pa", "]"}], "+", 
      RowBox[{"Cos", "[", "ra", "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"pa", "+", 
        RowBox[{"2", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], ")"}], ",", " ",
     
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"pa", "+", 
        RowBox[{"4", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"4", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], ")"}], ",", "0",
     ",", "0", ",", "0", ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "pa", "]"}], "-", 
      RowBox[{"Cos", "[", "ra", "]"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"pa", "+", 
        RowBox[{"2", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], ")"}], ",", " ",
     
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"pa", "+", 
        RowBox[{"4", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"4", " ", 
         RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], ")"}], ",", "0",
     ",", "0", ",", "0"}], "}"}], "/", "3"}]], "Input",
 PageWidth->WindowWidth,
 FontWeight->"Plain"],

Cell[TextData[{
 "\tAnother unital possibility is that two or more sizes are in a reciprocal \
relationship, with their product constrained to be 1. If two squared radii \
are reciprocal (one very small, the other very large), the result could be \
the so-called \"law of large numbers\", the observation that some large and \
small characteristics of the universe have magnitudes that are \
(approximately) powers of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "40"], TraditionalForm]]],
 ". This is illustrated in Example 54, by making ",
 StyleBox["rr.ss",
  FontSlant->"Italic"],
 "=1, and writing them as r & R. All the offsets have been set to 1 and ",
 StyleBox["qa=pa",
  FontSlant->"Italic"],
 " for simplicity. The C3K orbits have phases with amplitudes \
(p\[PlusMinus]q)/6, R/6, and r/6. If r is very small & R is very large, the \
other terms resemble \"curled-up\" Kaluza-Klein terms and the R terms \
resemble a space curvature, whilst r is curled much more tightly than the \
Kaluza-Klein terms. Also the amplitudes p+q and p-q can give six phases with \
very small amplitudes if p-q is small. I speculate that this relates to \
point-like particles. "
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 54. ",
 StyleBox["C3K Orbits with reciprocal Radii. \"Law of Large Numbers\"?",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"C3KR", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"C3KOrbit", "\[IndentingNewLine]", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"qa", "->", "pa"}], ",", 
       RowBox[{"o1", "\[Rule]", "1"}], ",", 
       RowBox[{"o2", "\[Rule]", "1"}], ",", 
       RowBox[{"o3", "\[Rule]", "1"}], ",", 
       RowBox[{"o4", "\[Rule]", "1"}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox["pp"], "\[Rule]", "p"}], ",", 
     RowBox[{
      SqrtBox["qq"], "\[Rule]", "q"}], ",", 
     RowBox[{
      SqrtBox["rr"], "\[Rule]", "R"}], ",", 
     RowBox[{
      SqrtBox["ss"], "\[Rule]", "r"}]}], "}"}]}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "pa", "]"}]}], "+", 
      RowBox[{"Cos", "[", "ra", "]"}], "+", 
      RowBox[{"Cos", "[", "sa", "]"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "sa"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         FractionBox[
          RowBox[{"4", " ", "\[Pi]"}], "3"]}], "]"}]}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "sa"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "ra", "]"}], "-", 
      RowBox[{"Cos", "[", "sa", "]"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "sa"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "sa"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "pa", "]"}]}], "-", 
      RowBox[{"Cos", "[", "ra", "]"}], "-", 
      RowBox[{"Cos", "[", "sa", "]"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "sa"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         FractionBox[
          RowBox[{"4", " ", "\[Pi]"}], "3"]}], "]"}]}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "sa"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cos", "[", "ra", "]"}]}], "+", 
      RowBox[{"Cos", "[", "sa", "]"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}]}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "sa"}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "ra"}], "]"}]}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "sa"}], "]"}]}], ")"}]}]}], 
  "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "+", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", "pa", "]"}]}], "               ", "+", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", "ra", "]"}]}], "               ", "+", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "sa", "]"}]}], "               ", "+", "2"}], 
     ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "+", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "sa"}], "]"}]}], "+", "2"}], 
     ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "+", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "sa"}], "]"}]}], "+", "2"}], 
     ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", "pa", "]"}]}], "               ", "+", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", "ra", "]"}]}], "              ", "-", " ", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "sa", "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], "-", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "sa"}], "]"}]}]}], ")"}], ",", 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "+", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], "-", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "sa"}], "]"}]}]}], ")"}], ",", 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "+", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", "pa", "]"}]}], "               ", "-", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", "ra", "]"}]}], "              ", "-", " ", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "sa", "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "+", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "-", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], "-", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "sa"}], "]"}]}]}], ")"}], ",", 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "+", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "-", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], "-", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "sa"}], "]"}]}]}], ")"}], ",", 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", "pa", "]"}]}], "               ", "-", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", "ra", "]"}]}], "              ", "+", " ", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "sa", "]"}]}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "-", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "sa"}], "]"}]}]}], ")"}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "q"}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"pa", "+", 
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}], "-", 
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "ra"}], "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"\[Pi]", "/", "3"}]}], "+", "sa"}], "]"}]}]}], ")"}]}], 
   "}"}], "/", "6"}]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False,
 FontSize->9,
 FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.4. Hoops & Anti-Hermitian Matrix Multiplication.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tHoops multiplication is not matrix multiplication, but hoop products can \
be obtained by matrix multiplication of the matrices ",
 StyleBox["lmatrix & rmatrix",
  FontSlant->"Italic"],
 ", which are created by reordering columns or rows of the hoop table to put \
1's on the diagonal",
 StyleBox[". ",
  FontSlant->"Italic"],
 "These are the matrix equivalents of the corresponding hoop; the \
multiplication of two vectors can be effected by mapping one vector onto ",
 StyleBox["lmatrix ",
  FontSlant->"Italic"],
 "or",
 StyleBox[" rmatrix",
  FontSlant->"Italic"],
 " and then dot multiplying the result by the second vector. (Hoop \
multiplication is conceptually simpler!) This is demonstrated with the signed \
table C8r :-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Example 55. ",
 StyleBox["Hoop multiplication by mapping vecs onto ",
  FontWeight->"Plain"],
 StyleBox["lmatrix",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" or ",
  FontWeight->"Plain"],
 StyleBox["rmatrix",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[".",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"C8r", "=", 
     RowBox[{"ts", "[", 
      RowBox[{"ca", "[", 
       RowBox[{"8", ",", "5"}], "]"}], "]"}]}], ";", "\"\<C8r =   \>\""}], 
   ",", 
   RowBox[{"C8r", "//", "tf"}], ",", "\"\<\\nlmatrix =\>\"", ",", 
   RowBox[{"l4", "=", 
    RowBox[{
     RowBox[{"lmatrix", "[", "C8r", "]"}], "//", "tf"}]}], ",", 
   "\"\<\\nrmatrix =\>\"", ",", 
   RowBox[{"r4", "=", 
    RowBox[{
     RowBox[{"rmatrix", "[", "C8r", "]"}], "//", "tf"}]}], ",", 
   "\"\<\\nC8r product of A\>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{"6.", ",", "1", ",", "2", ",", "0"}], "}"}]}], ",", 
   "\"\< and B\>\"", ",", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{"5.", ",", "0.", ",", "3", ",", "7"}], "}"}]}], ",", 
   "\"\<\\ngives\>\"", ",", 
   RowBox[{"AB", " ", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B", ",", "\"\<C8r\>\""}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   "\"\<\\nUsing the lmatrix dot product gives the same \\nA=\>\"", ",", 
   RowBox[{
    RowBox[{"la4", "=", 
     RowBox[{"gmap", "[", 
      RowBox[{"l4", ",", "B"}], "]"}]}], ";", 
    RowBox[{"la4", "//", "tf"}]}], ",", 
   RowBox[{"la4", ".", "A"}], ",", "\[IndentingNewLine]", 
   "\"\<\\nSo does the rmatrix dot product\>\"", ",", 
   RowBox[{
    RowBox[{"ra4", "=", 
     RowBox[{"gmap", "[", 
      RowBox[{"r4", ",", "A"}], "]"}]}], ";", "\"\<\\nB.\>\""}], ",", 
   RowBox[{"ra4", "//", "tf"}], ",", "\"\<=\>\"", ",", 
   RowBox[{"B", ".", "ra4"}], ",", 
   "\"\<\\nPlease ignore the extraneous commas!\>\""}], "}"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C8r =   \"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"2", 
         RowBox[{"-", "3"}], "4", "1"},
        {"3", "4", 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "2"}]},
        {"4", "1", 
         RowBox[{"-", "2"}], "3"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nlmatrix =\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "4", 
         RowBox[{"-", "3"}], "2"},
        {"2", "1", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "3"}]},
        {"3", 
         RowBox[{"-", "2"}], "1", "4"},
        {"4", "3", "2", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nrmatrix =\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4"},
        {"4", "1", 
         RowBox[{"-", "2"}], "3"},
        {
         RowBox[{"-", "3"}], 
         RowBox[{"-", "4"}], "1", "2"},
        {"2", 
         RowBox[{"-", "3"}], "4", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nC8r product of A\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"6.`", ",", "1", ",", "2", ",", "0"}], "}"}], 
   ",", "\<\" and B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"5.`", ",", "0.`", ",", "3", ",", "7"}], "}"}], 
   ",", "\<\"\\ngives\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"31.`", ",", 
     RowBox[{"-", "9.`"}], ",", "28.`", ",", "45.`"}], "}"}], 
   ",", "\<\"\\nUsing the lmatrix dot product gives the same \\nA=\"\>", ",", 
   
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"5.`", "7", 
         RowBox[{"-", "3"}], "0.`"},
        {"0.`", "5.`", 
         RowBox[{"-", "7"}], 
         RowBox[{"-", "3"}]},
        {"3", "0.`", "5.`", "7"},
        {"7", "3", "0.`", "5.`"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   RowBox[{"{", 
    RowBox[{"31.`", ",", 
     RowBox[{"-", "9.`"}], ",", "28.`", ",", "45.`"}], "}"}], 
   ",", "\<\"\\nSo does the rmatrix dot product\"\>", ",", "\<\"\\nB.\"\>", 
   ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"6.`", "1", "2", "0"},
        {"0", "6.`", 
         RowBox[{"-", "1"}], "2"},
        {
         RowBox[{"-", "2"}], "0", "6.`", "1"},
        {"1", 
         RowBox[{"-", "2"}], "0", "6.`"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"31.`", ",", 
     RowBox[{"-", "9.`"}], ",", "28.`", ",", "45.`"}], "}"}], 
   ",", "\<\"\\nPlease ignore the extraneous commas!\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This is true for all hoops, by the definition of ",
 StyleBox["rmatrix & lmatrix",
  FontSlant->"Italic"],
 ".  The matrices are anti-hermitian, insofar as their off-diagonal \
transposed elements are mutual inverses in the hoop table. Consequently, Hoop \
multiplication is always anti-hermitian. "
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.5. Projection & ejection of wavicles.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "If Dozal emulates physics, the stable particles (neutrinos, electron, \
positron, proton, antiproton) must be minimal orbits - they cannot eject \
something to give a simpler system. Electrons and protons have mass & charge, \
but are produced by decay of neutral more-massive particles and from \
uncharged massless photon pairs. This constrains the search space in the \
Dozal conserved functions. The factorization of L4 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["x",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 "-3",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["y",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 " = (x+",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "y)(x-",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "y)  could be relevant, with (x-",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "y)\[ShortRightArrow]\[HBar]?\nMore work (and inspiration?) needed."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox["Factor",
    FontSlant->"Plain"], 
   StyleBox["[",
    FontSlant->"Plain"], 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      StyleBox["x",
       FontSlant->"Plain"], "2"], "-", 
     RowBox[{"3", 
      SuperscriptBox[
       StyleBox["y",
        FontSlant->"Plain"], "2"]}]}], " ", ",", 
    RowBox[{"Extension", "\[Rule]", 
     SqrtBox["3"]}]}], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "x"}], "+", 
     RowBox[{
      SqrtBox["3"], " ", "y"}]}], ")"}]}], " ", 
  RowBox[{"(", 
   RowBox[{"x", "+", 
    RowBox[{
     SqrtBox["3"], " ", "y"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell["\<\
\tI conjecture that Quarks are different phases of a multiphase system with \
12-fold (Dozal) symmetry. Three, six, and 12-phase wave systems occur in the \
C3C4 and C3K polar duals. \
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["11. Speculations about Mass & Gravity.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "   Hoop algebras give tantalizing suggestions about the re-interpretation \
of mathematical physics, which (at 79) I cannot expect to explore:-\n  a). \
Hoop multiplication with remainders has analogies with particle interactions, \
and addition/subtraction (which conserves linear sizes) with particle \
combination and decay. \n  b.) Time enters orbits as a separate \"direction\" \
parameter that cannot fold to a dimension. It may enter a \"mixed metric\" \
via a \"city-blocks\" contribution, whilst spatial dimensions remain \
pythagorean; ",
 StyleBox["interval",
  FontSlant->"Italic"],
 " = ",
 StyleBox["(t-",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[") - Sqrt[",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"x", "-", 
      FormBox[
       SubscriptBox["x", "0"],
       TraditionalForm]}], ")"}], "2"], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" + ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"y", "-", 
      FormBox[
       SubscriptBox["y", "0"],
       TraditionalForm]}], ")"}], "2"], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox["+ ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"z", "-", 
      FormBox[
       SubscriptBox["z", "0"],
       TraditionalForm]}], ")"}], "2"], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox["]",
  FontSlant->"Italic"],
 ". The L4 metric (Section 10.6) (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          StyleBox["a",
           FontSlant->"Plain"], "-", 
          StyleBox["b",
           FontSlant->"Plain"]}], ")"}], "2"],
       TraditionalForm], "+", 
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          StyleBox["b",
           FontSlant->"Plain"], "-", 
          StyleBox["c",
           FontSlant->"Plain"]}], ")"}], "2"],
       TraditionalForm], "+", 
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          StyleBox["c",
           FontSlant->"Plain"], "-", 
          StyleBox["a",
           FontSlant->"Plain"]}], ")"}], "2"],
       TraditionalForm], "+", 
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          StyleBox["d",
           FontSlant->"Plain"], "-", 
          StyleBox["e",
           FontSlant->"Plain"]}], ")"}], "2"],
       TraditionalForm], "+", 
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          StyleBox["e",
           FontSlant->"Plain"], "-", 
          StyleBox["f",
           FontSlant->"Plain"]}], ")"}], "2"],
       TraditionalForm], "+", 
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          StyleBox["f",
           FontSlant->"Plain"], "-", 
          StyleBox["d",
           FontSlant->"Plain"]}], ")"}], "2"],
       TraditionalForm]}], ")"}], "2"], TraditionalForm]]],
 "-\n3",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       StyleBox["a",
        FontSlant->"Plain"], 
       StyleBox["(",
        FontSlant->"Italic"], 
       RowBox[{
        StyleBox["e",
         FontSlant->"Plain"], 
        StyleBox["-",
         FontSlant->"Italic"], 
        StyleBox["f",
         FontSlant->"Plain"]}], 
       StyleBox[")",
        FontSlant->"Italic"]}], "+", 
      RowBox[{
       StyleBox["b",
        FontSlant->"Plain"], 
       StyleBox["(",
        FontSlant->"Italic"], 
       RowBox[{
        StyleBox["f",
         FontSlant->"Plain"], 
        StyleBox["-",
         FontSlant->"Italic"], 
        StyleBox["d",
         FontSlant->"Plain"]}], 
       StyleBox[")",
        FontSlant->"Italic"]}], "+", 
      RowBox[{
       StyleBox["c",
        FontSlant->"Plain"], "(", 
       RowBox[{
        StyleBox["d",
         FontSlant->"Plain"], 
        StyleBox["-",
         FontSlant->"Italic"], 
        StyleBox["e",
         FontSlant->"Plain"]}], 
       StyleBox[")",
        FontSlant->"Italic"]}]}], ")"}], "2"], TraditionalForm]]],
 "is non-negative. It simplifies (with a-b\[RightArrow]w, b-c\[RightArrow]x, \
d-e\[RightArrow]y, e-f\[RightArrow]z)  to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox[
       SuperscriptBox[
        StyleBox["w",
         FontSlant->"Plain"], "2"],
       TraditionalForm], "+", 
      RowBox[{
       StyleBox["w",
        FontSlant->"Plain"], " ", 
       StyleBox["x",
        FontSlant->"Plain"]}], "+", 
      FormBox[
       SuperscriptBox[
        StyleBox["x",
         FontSlant->"Plain"], "2"],
       TraditionalForm], "+", 
      FormBox[
       SuperscriptBox["y", "2"],
       TraditionalForm], "+", 
      RowBox[{
       StyleBox["y",
        FontSlant->"Plain"], " ", 
       StyleBox["z",
        FontSlant->"Plain"]}], "+", 
      FormBox[
       SuperscriptBox[
        StyleBox["z",
         FontSlant->"Plain"], "2"],
       TraditionalForm]}], ")"}], "2"], TraditionalForm]]],
 " -3",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       StyleBox["x",
        FontSlant->"Plain"], " ", 
       StyleBox["y",
        FontSlant->"Plain"]}], "-", 
      RowBox[{
       StyleBox["w",
        FontSlant->"Plain"], " ", 
       StyleBox["z",
        FontSlant->"Plain"]}]}], ")"}], "2"], TraditionalForm]]],
 " and this factorises into  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SuperscriptBox[
      StyleBox["w",
       FontSlant->"Plain"], "2"],
     TraditionalForm], "+", 
    RowBox[{
     StyleBox["w",
      FontSlant->"Plain"], " ", 
     StyleBox["x",
      FontSlant->"Plain"]}], "+", 
    FormBox[
     SuperscriptBox[
      StyleBox["x",
       FontSlant->"Plain"], "2"],
     TraditionalForm], "+", 
    FormBox[
     SuperscriptBox[
      StyleBox["y",
       FontSlant->"Plain"], "2"],
     TraditionalForm], "+", 
    RowBox[{
     StyleBox["y",
      FontSlant->"Plain"], " ", 
     StyleBox["z",
      FontSlant->"Plain"]}], "+", 
    FormBox[
     SuperscriptBox[
      StyleBox["z",
       FontSlant->"Plain"], "2"],
     TraditionalForm]}], TraditionalForm]]],
 " \[PlusMinus]",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      StyleBox["x",
       FontSlant->"Plain"], " ", 
      StyleBox["y",
       FontSlant->"Plain"]}], "-", 
     RowBox[{
      StyleBox["w",
       FontSlant->"Plain"], " ", 
      StyleBox["z",
       FontSlant->"Plain"]}]}], ")"}], TraditionalForm]]],
 "; this may provide a \"6-vector\" metric in which (x y-w z) is related to \
time, which is then a dependent variable. \n  c.) A \"Fixed Velocity PDE\" \
describes (see Glossary) non-dispersive disturbances travelling in any number \
of directions at a fixed (light?) speed. If this applies to particles as \
wave-packets, Kaluza-Klein orbital velocities would provide mass by reducing \
spatial velocities below the speed of light; massless packets, with no KK \
velocity, would travel at light speed. Remember that wave-packets decay \
because of \"dispersion\", the variation of wave velocity with period, so \
fixed velocity packets do not decay..\n  d.)  Orbits must be \"unital\", the \
product of the non-zero sizes is 1. Some dimensions could be in a reciprocal \
relation, with large (curvature of space, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "40"], TraditionalForm]]],
 "?) and small (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "40"}]], TraditionalForm]]],
 "?) values, leaving some \"force\" (KK Planck-scale) fields. This could \
explain the \"law of large numbers\" conjecture - that several properties of \
the universe scale to powers of approximately ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "40"], TraditionalForm]]],
 ".  Phases in the intermediate dimensions would describe non-point-like \
particles with an intrinsic Planck scale. Does orbit maths underly (and \
simplify) string maths?\n  e.) The 4-element Pauli-sigma hoop conserves the \
Minkowski metric ",
 StyleBox["t^2 - x^2 - y^2 - z^2",
  FontSlant->"Italic"],
 ", and is related to a group (describing ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalR]", 
    RowBox[{"3", ",", "1"}]], TraditionalForm]]],
 ") obtained by dot multiplication of the Dirac 4x4 gamma matrices. This \
group conserves a square of the Minkowski metric added to another squared \
term; it needs investigating in connection with gravity.\n  f.) Ternary \
symmetries occur without invoking octonion triality."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["12. Conclusion.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\tPrimal (unsigned continuous) numbers provide a more fundamental basis for \
mathematics than real or complex numbers. Loop multiplications of directors \
(indexed sets of primal coefficients) become algebras when a negation \
operation is supplied. Conservative \"Hoop\" algebras have the Frobenius \
determinant-conservation property, and provide a generalisation that includes \
many standard algebras used in particle physics. Noether's laws relate their \
conserved symmetries to particles and forces\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe ",
 "generalized",
 " function ",
 StyleBox["hoopT",
  FontSlant->"Italic"],
 "i",
 StyleBox["mes ",
  FontSlant->"Italic"],
 "defines multiplication with any multiplication table or \"loop\". For \
conservative Moufang loops, if the shape function has been found for the \
table (or the table is smaller than 12\[Times]12 so the shape can be \
calculated in a reasonable time), ",
 StyleBox[" hoopShape & hoopInverse",
  FontSlant->"Italic"],
 " define division. This will be renormalisable (projecting onto a sub-space \
of reduced symmetry, ejection of remainders to maintain conservation) if \
there are at least two determinant factors - hence all group algebras have \
renormalising division because the sum of the elements always provides a \
first factor. For some tables,",
 StyleBox[" hoopPower, toPolar & toVector",
  FontSlant->"Italic"],
 " give consistent powers and roots via a polar or a hyperbolic \
transformation. hoopTest determines which algebraic properties are valid for \
any table. Algebras without renormalization are degenerate equivalence \
relations, with only one conserved factor, on more general algebras."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tMany algebras have \"signed tables\" as multiplication rules. The signs \
+, - =",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"+", "1"}]], TraditionalForm]]],
 ", \[ImaginaryI]=",
 Cell[BoxData[
  FormBox[
   RadicalBox[
    RowBox[{"+", "1"}], "4"], TraditionalForm]]],
 ", and -\[ImaginaryI]=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      RadicalBox[
       RowBox[{"+", "1"}], "4"],
      TraditionalForm], ")"}], "3"], TraditionalForm]]],
 " must be extended to the \"generalized signs\" that are needed in \
mathematical physics; in particular \[DoubleStruckK]=",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"+", "1"}]], TraditionalForm]]],
 ", \[DoubleStruckCapitalJ]=",
 Cell[BoxData[
  FormBox[
   RadicalBox[
    RowBox[{"+", "1"}], "3"], TraditionalForm]]],
 " and \[DoubleStruckH]=",
 Cell[BoxData[
  FormBox[
   RadicalBox[
    RowBox[{"+", "1"}], "6"], TraditionalForm]]],
 ", which are needed to describe quark symmetries. Complex mathematics is a \
special case of mathematics involving generalized signs, such as multi-phase \
sinusoids.\n\n\tRenormalizing Orbit-Generating Equivalence Relation \"ROGER\" \
algebras may provide an explanation of fundamental particle properties. They \
have integer-spin and half-integer-spin quantum operators with multi-phase \
(polar or chiral) deBroglie-wave-like orbits and a stable finite \
Planck-area-like amplitude."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tRenormalization corresponds to symmetry breaking by ejecting remainders and \
projecting the result into a constrained sub-algebra, which may relate to \
different full algebras (e.g. O4 is a sub-algebra of both C3K and C4K). \
Bosonic integer spin algebras (e.g. C3C2) are supersymmetries of fermionic \
half-integer spin algebras (e.g. C3K again) that describe quantum phenomena. \
In this interpretation, there are fewer supersymmetric particles than their \
(subsymmetric) partner particles! Pauli and Dirac matrix sub-algebras \
conserve the Minkowski metric; their full algebras conserve a quartic \
function that may relate to general relativity. The algebras that combine \
these particle and relativistic properties are too large for the author to \
investigate properly (even if he had the ability), but the properties of the \
universe may be emergent properties of conservative Moufang loop algebras.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tI have made many discoveries that appear to be new, and I claim to have \
opened up a new area of mathematics and mathematical physics.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["13. Appendix A. Algebraic Loop operations.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". Some operations that are relevant to groups and loops rather than hoops \
are collected here. Tests for group properties and the development of ge \
rules are included."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["13.1 Algebraic Loop Properties.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tExample A1 demonstrates various property tests on Q12 and on the \
16-element octonion groupoid \"Oct\", which is shown to be alternative & \
conservative. ",
 StyleBox["conservativeQ",
  FontSlant->"Italic"],
 " substitutes small random numbers into A & B and tests whether the product \
determinant equals the product of the multiplicand determinants. The groupoid \
\"Alt12n\" is then shown to be alternative but not conservative - \
alternativity does not imply conservativity. Functions for Q12 and some \
subgroups of Q12 are then evaluated."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"glo", "=", "Q12"}], ";", 
  RowBox[{"abelianQ", "[", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"abelianQ", "[", "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Example", " ", 
      RowBox[{"A1", ".", " ", "Properties"}]}], " ", "&"}], " ", 
    "Functions"}], " ", "*)"}], " ", 
  RowBox[{"{", 
   RowBox[{"\"\<Q12 properties \>\"", ",", 
    RowBox[{
     RowBox[{"glo", "=", "Q12"}], ";", "\"\<\\nabelian     \>\""}], ",", 
    RowBox[{"abelianQ", "[", "]"}], ",", "\"\<\\nassociative \>\"", ",", 
    RowBox[{"associativeQ", "[", "]"}], ",", "\"\<\\nalternative \>\"", ",", 
    RowBox[{"alternativeQ", "[", "]"}], ",", "\"\<\\nconservative\>\"", ",", 
    RowBox[{"conservativeQ", "[", "]"}], ",", "\"\<\\nmoufang     \>\"", ",", 
    
    RowBox[{"moufangQ", "[", "]"}], ",", "\"\<\\nflexible    \>\"", ",", 
    RowBox[{"flexibleQ", "[", "]"}], ",", "\"\<\\nflex        \>\"", ",", 
    RowBox[{"flexQ", "[", "]"}], ",", "\"\<\\nentropic    \>\"", ",", 
    RowBox[{"entropicQ", "[", "]"}], ",", "\"\<\\nfenyves     \>\"", ",", 
    RowBox[{"fenyvesQ", "[", "]"}], ",", "\"\<\\nnegatable   \>\"", ",", 
    RowBox[{"negatableQ", "[", "]"}], ",", "\"\<\\nhamiltonian \>\"", ",", 
    RowBox[{"hamiltonianQ", "[", "]"}], ",", "\"\<\\njacobi      \>\"", ",", 
    RowBox[{"jacobiQ", "[", "]"}], ",", "\"\<\\njordan      \>\"", ",", 
    RowBox[{"jordanQ", "[", "]"}], ",", "\"\<\\n\\nOct properties \>\"", ",", 
    
    RowBox[{
     RowBox[{"glo", "=", 
      RowBox[{"cd", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], "]"}]}], ";", 
     "\"\<\\nabelian     \>\""}], ",", 
    RowBox[{"abelianQ", "[", "]"}], ",", "\"\<\\nassociative \>\"", ",", 
    RowBox[{"associativeQ", "[", "]"}], ",", "\"\<\\nalternative \>\"", ",", 
    RowBox[{"alternativeQ", "[", "]"}], ",", "\"\<\\nconservative\>\"", ",", 
    RowBox[{"conservativeQ", "[", "]"}], ",", "\"\<\\nmoufang     \>\"", ",", 
    
    RowBox[{"moufangQ", "[", "]"}], ",", "\"\<\\nflexible    \>\"", ",", 
    RowBox[{"flexibleQ", "[", "]"}], ",", "\"\<\\nflex        \>\"", ",", 
    RowBox[{"flexQ", "[", "]"}], ",", "\"\<\\nentropic    \>\"", ",", 
    RowBox[{"entropicQ", "[", "]"}], ",", "\"\<\\nfenyves     \>\"", ",", 
    RowBox[{"fenyvesQ", "[", "]"}], ",", "\"\<\\nnegatable   \>\"", ",", 
    RowBox[{"negatableQ", "[", "]"}], ",", "\"\<\\nhamiltonian \>\"", ",", 
    RowBox[{"hamiltonianQ", "[", "]"}], ",", "\"\<\\njacobi      \>\"", ",", 
    RowBox[{"jacobiQ", "[", "]"}], ",", "\"\<\\njordan      \>\"", ",", 
    RowBox[{"jordanQ", "[", "]"}], ",", "\"\<\\n\\nAlt12n properties \>\"", 
    ",", 
    RowBox[{
     RowBox[{"glo", "=", "Alt12n"}], ";", "\"\<\\nalternative \>\""}], ",", 
    RowBox[{"alternativeQ", "[", "]"}], ",", "\"\<\\nconservative\>\"", ",", 
    RowBox[{"conservativeQ", "[", "]"}], ",", "\n", 
    "\"\<\\n\\nQ12 centralizer \>\"", ",", 
    RowBox[{"centralizer", "[", 
     RowBox[{"3", ",", "Q12"}], "]"}], ",", "\"\<\\nQ12 period\>\"", ",", 
    RowBox[{"period", "[", "Q12", "]"}], ",", "\"\<\\nQ12 orderCount\>\"", 
    ",", 
    RowBox[{"orderCount", "[", "Q12", "]"}], ",", "\"\<\\nQ12 centre\>\"", 
    ",", 
    RowBox[{"centre", "[", "Q12", "]"}], ",", "\"\<\\nQ12 inverses \>\"", ",",
     
    RowBox[{"gInverse", "[", "Q12", "]"}], ",", "\"\<\\nQ12 subgroups=\>\"", 
    ",", 
    RowBox[{"subgroups", "[", "Q12", "]"}], ",", 
    "\"\<\\nQ12 subgroups are identified as \>\"", ",", 
    RowBox[{"collect", "[", 
     RowBox[{"subgroupTypes", "[", "sg", "]"}], "]"}], ",", 
    "\"\<\\nNormal {1,4,7,10} in Q12?\>\"", ",", 
    RowBox[{"normalSubgroup", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "4", ",", "7", ",", "10"}], "}"}], ",", "Q12"}], 
     "]"}], ",", "\"\<\\nfactorGroup of {1,2,3} in Q12 =\>\"", ",", 
    RowBox[{"factorGroup", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", "Q12"}], "]"}], ",", 
    "\"\<\\nallFactorGroups in Q12 =\>\"", ",", 
    RowBox[{"allFactorGroups", "[", "Q12", "]"}], ",", 
    "\"\<\\nlcoset {1,2,3} in Q12 =\>\"", ",", 
    RowBox[{"lcoset", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", "Q12"}], "]"}], ",", 
    "\"\<\\nC3C4 (q1202) is a 12-element subgroup of Q24 (shown by returning \
'2')\>\"", ",", 
    RowBox[{"subgroups", "[", 
     RowBox[{
      RowBox[{"ca", "[", 
       RowBox[{"24", ",", "11"}], "]"}], ",", "0", ",", "12", ",", "12", ",", 
      
      RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Q12 properties \"\>", ",", "\<\"\\nabelian     \"\>", ",", 
   RowBox[{"abelianQ", "[", "]"}], ",", "\<\"\\nassociative \"\>", ",", 
   RowBox[{"associativeQ", "[", "]"}], ",", "\<\"\\nalternative \"\>", ",", 
   RowBox[{"alternativeQ", "[", "]"}], ",", "\<\"\\nconservative\"\>", ",", 
   RowBox[{"conservativeQ", "[", "]"}], ",", "\<\"\\nmoufang     \"\>", ",", 
   RowBox[{"moufangQ", "[", "]"}], ",", "\<\"\\nflexible    \"\>", ",", 
   RowBox[{"flexibleQ", "[", "]"}], ",", "\<\"\\nflex        \"\>", ",", 
   RowBox[{"flexQ", "[", "]"}], ",", "\<\"\\nentropic    \"\>", ",", 
   RowBox[{"entropicQ", "[", "]"}], ",", "\<\"\\nfenyves     \"\>", ",", 
   RowBox[{"fenyvesQ", "[", "]"}], ",", "\<\"\\nnegatable   \"\>", ",", 
   RowBox[{"negatableQ", "[", "]"}], ",", "\<\"\\nhamiltonian \"\>", ",", 
   RowBox[{"hamiltonianQ", "[", "]"}], ",", "\<\"\\njacobi      \"\>", ",", 
   RowBox[{"jacobiQ", "[", "]"}], ",", "\<\"\\njordan      \"\>", ",", 
   RowBox[{"jordanQ", "[", "]"}], ",", "\<\"\\n\\nOct properties \"\>", 
   ",", "\<\"\\nabelian     \"\>", ",", 
   RowBox[{"abelianQ", "[", "]"}], ",", "\<\"\\nassociative \"\>", ",", 
   RowBox[{"associativeQ", "[", "]"}], ",", "\<\"\\nalternative \"\>", ",", 
   RowBox[{"alternativeQ", "[", "]"}], ",", "\<\"\\nconservative\"\>", ",", 
   RowBox[{"conservativeQ", "[", "]"}], ",", "\<\"\\nmoufang     \"\>", ",", 
   RowBox[{"moufangQ", "[", "]"}], ",", "\<\"\\nflexible    \"\>", ",", 
   RowBox[{"flexibleQ", "[", "]"}], ",", "\<\"\\nflex        \"\>", ",", 
   RowBox[{"flexQ", "[", "]"}], ",", "\<\"\\nentropic    \"\>", ",", 
   RowBox[{"entropicQ", "[", "]"}], ",", "\<\"\\nfenyves     \"\>", ",", 
   RowBox[{"fenyvesQ", "[", "]"}], ",", "\<\"\\nnegatable   \"\>", ",", 
   RowBox[{"negatableQ", "[", "]"}], ",", "\<\"\\nhamiltonian \"\>", ",", 
   RowBox[{"hamiltonianQ", "[", "]"}], ",", "\<\"\\njacobi      \"\>", ",", 
   RowBox[{"jacobiQ", "[", "]"}], ",", "\<\"\\njordan      \"\>", ",", 
   RowBox[{"jordanQ", "[", "]"}], ",", "\<\"\\n\\nAlt12n properties \"\>", 
   ",", "\<\"\\nalternative \"\>", ",", 
   RowBox[{"alternativeQ", "[", "]"}], ",", "\<\"\\nconservative\"\>", ",", 
   RowBox[{"conservativeQ", "[", "]"}], ",", "\<\"\\n\\nQ12 centralizer \"\>",
    ",", 
   RowBox[{"centralizer", "[", 
    RowBox[{"3", ",", "Q12"}], "]"}], ",", "\<\"\\nQ12 period\"\>", ",", 
   RowBox[{"period", "[", "Q12", "]"}], ",", "\<\"\\nQ12 orderCount\"\>", ",",
    
   RowBox[{"orderCount", "[", "Q12", "]"}], ",", "\<\"\\nQ12 centre\"\>", ",",
    
   RowBox[{"centre", "[", "Q12", "]"}], ",", "\<\"\\nQ12 inverses \"\>", ",", 
   
   RowBox[{"gInverse", "[", "Q12", "]"}], ",", "\<\"\\nQ12 subgroups=\"\>", 
   ",", 
   RowBox[{"subgroups", "[", "Q12", "]"}], 
   ",", "\<\"\\nQ12 subgroups are identified as \"\>", ",", 
   RowBox[{"collect", "[", 
    RowBox[{"subgroupTypes", "[", "sg", "]"}], "]"}], 
   ",", "\<\"\\nNormal {1,4,7,10} in Q12?\"\>", ",", 
   RowBox[{"normalSubgroup", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "7", ",", "10"}], "}"}], ",", "Q12"}], 
    "]"}], ",", "\<\"\\nfactorGroup of {1,2,3} in Q12 =\"\>", ",", 
   RowBox[{"factorGroup", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", "Q12"}], "]"}], 
   ",", "\<\"\\nallFactorGroups in Q12 =\"\>", ",", 
   RowBox[{"allFactorGroups", "[", "Q12", "]"}], 
   ",", "\<\"\\nlcoset {1,2,3} in Q12 =\"\>", ",", 
   RowBox[{"lcoset", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", "Q12"}], "]"}], 
   ",", "\<\"\\nC3C4 (q1202) is a 12-element subgroup of Q24 (shown by \
returning '2')\"\>", ",", 
   RowBox[{"subgroups", "[", 
    RowBox[{
     RowBox[{"ca", "[", 
      RowBox[{"24", ",", "11"}], "]"}], ",", "0", ",", "12", ",", "12", ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "Example A2 demonstrates loops that have different combinations of \
properties. \"type\" is taken from ",
 StyleBox["dico",
  FontSlant->"Italic"],
 ", so that Abelian tables give real numbers, non-abelian tables give \
integers, signed tables give negated numbers, and unrecognised tables give \
zero. The tables with names \"?\" are not groups (but are shown to have \
normal subgroups by the ",
 StyleBox["hamiltonianQ",
  FontSlant->"Italic"],
 " test in Ex A3). The second row named ? is a non-conservative quasigroup \
created by ",
 StyleBox["cd[{-1,-1,1,{2}}]",
  FontSlant->"Italic"],
 " that is not in the database but has the same ",
 StyleBox["dico",
  FontSlant->"Italic"],
 " as Q8C2. "
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Example", " ", 
    RowBox[{"A2", ".", " ", "Properties"}], " ", "of", " ", "different", " ", 
    "tables"}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"res", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<loop\>\"", ",", "\"\<len\>\"", ",", "\"\<type\>\"", ",", 
         "\"\<Abl'n\>\"", ",", "\"\<AbelGr\>\"", ",", "\"\<Alt\>\"", ",", 
         "\"\<Cons.\>\"", ",", "\"\<Entr.\>\"", ",", "\"\<Flex\>\"", ",", 
         "\"\<mouf\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<test\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<xy=\>\"", 
         ",", "\"\<xy.z=\>\"", ",", "\"\<xx.y=\>\"", ",", "\"\<DetADetB=\>\"",
          ",", "\"\<wx.yz=\>\"", ",", "\"\<xy.z\>\"", ",", 
         "\"\<|zx.yx|=\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<yx\>\"", ",", 
         "\"\<x.yz\>\"", ",", "\"\<x.xy\>\"", ",", "\"\<DetAB\>\"", ",", 
         "\"\<wz.yx\>\"", ",", "\"\<x.yz\>\"", ",", "\"\<|z.xy.z|\>\""}], 
        "}"}]}], "}"}]}], ";", 
    RowBox[{"inc", "=", 
     RowBox[{"{", 
      RowBox[{"C3", ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], "]"}], ",", "P4", ",", 
       RowBox[{"ts", "[", 
        RowBox[{"ca", "[", 
         RowBox[{"8", ",", "5"}], "]"}], "]"}], ",", "C5n", ",", "D3", ",", 
       "C6n", ",", 
       RowBox[{"ca", "[", 
        RowBox[{"8", ",", "3"}], "]"}], ",", 
       RowBox[{"ca", "[", 
        RowBox[{"10", ",", "3"}], "]"}], ",", 
       RowBox[{"co", "[", 
        RowBox[{"C3", ",", "C4", ",", "2"}], "]"}], ",", "Alt12n", ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", "1", ",", 
          RowBox[{"{", "2", "}"}]}], "}"}], "]"}], ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{"4.", ",", "1", ",", "1"}], "}"}], "]"}], ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"{", "2", "}"}]}], "}"}], "]"}], ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"AppendTo", "[", 
       RowBox[{"res", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"i", "=", 
            RowBox[{"id", "[", 
             RowBox[{"tst", "=", 
              RowBox[{"inc", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
           RowBox[{"If", "[", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"i", "==", "\"\<Q8C2\>\""}], "||", 
              RowBox[{"i", "===", "\"\<Unrecognised\>\""}]}], ",", 
             "\"\<?\>\"", ",", "i"}], "]"}]}], ",", 
          RowBox[{"Length", "[", "tst", "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "===", "\"\<Unrecognised\>\""}], ",", "0", ",", 
            RowBox[{"Sign", "[", 
             RowBox[{
              RowBox[{"gd", "[", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"3", ",", "2", ",", "1"}], "]"}], "]"}], "]"}]}], 
           "]"}], ",", 
          RowBox[{"abelianQ", "[", "tst", "]"}], ",", 
          RowBox[{"abelGrassmanQ", "[", "tst", "]"}], ",", 
          RowBox[{"alternativeQ", "[", "tst", "]"}], ",", 
          RowBox[{"conservativeQ", "[", "tst", "]"}], ",", 
          RowBox[{"entropicQ", "[", "tst", "]"}], ",", 
          RowBox[{"flexQ", "[", "tst", "]"}], ",", 
          RowBox[{"moufangQ", "[", "tst", "]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "inc", "]"}]}], "}"}]}], "]"}], ";", 
    RowBox[{"res", "//", "tf"}]}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"loop\"\>", "\<\"len\"\>", "\<\"type\"\>", "\<\"Abl'n\"\>", \
"\<\"AbelGr\"\>", "\<\"Alt\"\>", "\<\"Cons.\"\>", "\<\"Entr.\"\>", \
"\<\"Flex\"\>", "\<\"mouf\"\>"},
     {"\<\"test\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"xy=\"\>", "\<\"xy.z=\"\>", \
"\<\"xx.y=\"\>", "\<\"DetADetB=\"\>", "\<\"wx.yz=\"\>", "\<\"xy.z\"\>", \
"\<\"|zx.yx|=\"\>"},
     {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"yx\"\>", "\<\"x.yz\"\>", \
"\<\"x.xy\"\>", "\<\"DetAB\"\>", "\<\"wz.yx\"\>", "\<\"x.yz\"\>", \
"\<\"|z.xy.z|\"\>"},
     {"\<\"C3\"\>", "3", "1", "True", "True", "True", "True", "True", "True", 
      "True"},
     {"\<\"Qr\"\>", "4", 
      RowBox[{"-", "1"}], "False", "True", "True", "True", "True", "True", 
      "True"},
     {"\<\"P4\"\>", "4", 
      RowBox[{"-", "\[ImaginaryI]"}], "False", "True", "True", "True", "True",
       "True", "True"},
     {"\<\"C8r\"\>", "4", 
      RowBox[{"-", "1"}], "True", "True", "True", "True", "True", "True", 
      "True"},
     {"\<\"C5n\"\>", "5", "1", "False", "False", "False", "False", "False", 
      "True", "False"},
     {"\<\"D3\"\>", "6", "1", "False", "False", "True", "True", "True", 
      "True", "True"},
     {"\<\"C6n\"\>", "6", "1", "False", "False", "False", "False", "False", 
      "False", "False"},
     {"\<\"Q8\"\>", "8", "1", "False", "False", "True", "True", "True", 
      "True", "True"},
     {"\<\"?\"\>", "10", "0", "False", "False", "False", "False", "False", 
      "False", "False"},
     {"\<\"Q12\"\>", "12", "1", "False", "False", "True", "True", "True", 
      "True", "True"},
     {"\<\"Alt12n\"\>", "12", "1", "False", "False", "True", "False", "False",
       "False", "False"},
     {"\<\"?\"\>", "16", "1", "False", "False", "False", "False", "False", 
      "False", "False"},
     {"\<\"\\!\\(C2\\^5\\)r\"\>", "16", 
      RowBox[{"-", "1"}], "True", "True", "True", "True", "True", "True", 
      "True"},
     {"\<\"Oct\"\>", "16", "1", "False", "False", "True", "True", "False", 
      "True", "True"},
     {"\<\"Sed\"\>", "16", 
      RowBox[{"-", "1"}], "False", "True", "True", "False", "True", "True", 
      "True"}
    }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 PageWidth->WindowWidth,
 FontSize->9]
}, Open  ]],

Cell["\<\
Example A3 demonstrates further properties with the same set of loops.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Example", " ", 
    RowBox[{"A3", ".", " ", "Further"}], " ", 
    RowBox[{"properties", "."}]}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"res", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<loop\>\"", ",", "\"\<len\>\"", ",", "\"\<type\>\"", ",", 
         "\"\<A_m\>\"", ",", "\"\<bol\>\"", ",", "\"\<C\>\"", ",", 
         "\"\<Hamilton\>\"", ",", "\"\<Mouf\>\"", ",", "\"\<moufL\>\"", ",", 
         "\"\<RIFF\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<test\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
         "\"\<x(yx.zx)=\>\"", ",", "\"\<(z.yz)x=\>\"", ",", 
         "\"\<(xy.y)z=\>\"", ",", "\"\<Normal\>\"", ",", "\"\<zx.yx=\>\"", 
         ",", "\"\<|(zy.z)x|=\>\"", ",", "\"\<xy(z.xy)=\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<(xy.xz)x\>\"",
          ",", "\"\<z(y.zx)\>\"", ",", "\"\<x(yy.z)\>\"", ",", 
         "\"\<subgrps\>\"", ",", "\"\<z.xy.z\>\"", ",", "\"\<|z(y.zx)|\>\"", 
         ",", "\"\<((x.yz))x)y\>\""}], "}"}]}], "}"}]}], ";", 
    RowBox[{"inc", "=", 
     RowBox[{"{", 
      RowBox[{"C3", ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], "]"}], ",", "P4", ",", 
       RowBox[{"ts", "[", 
        RowBox[{"ca", "[", 
         RowBox[{"8", ",", "5"}], "]"}], "]"}], ",", "C5n", ",", "D3", ",", 
       "C6n", ",", 
       RowBox[{"ca", "[", 
        RowBox[{"8", ",", "3"}], "]"}], ",", 
       RowBox[{"ca", "[", 
        RowBox[{"10", ",", "3"}], "]"}], ",", 
       RowBox[{"co", "[", 
        RowBox[{"C3", ",", "C4", ",", "2"}], "]"}], ",", "Alt12n", ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", "1", ",", 
          RowBox[{"{", "2", "}"}]}], "}"}], "]"}], ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{"4.", ",", "1", ",", "1"}], "}"}], "]"}], ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"{", "2", "}"}]}], "}"}], "]"}], ",", 
       RowBox[{"cd", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"AppendTo", "[", 
       RowBox[{"res", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"i", "=", 
            RowBox[{"id", "[", 
             RowBox[{"tst", "=", 
              RowBox[{"inc", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
           RowBox[{"If", "[", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"i", "==", "\"\<Q8C2\>\""}], "||", 
              RowBox[{"i", "===", "\"\<Unrecognised\>\""}]}], ",", 
             "\"\<?\>\"", ",", "i"}], "]"}]}], ",", 
          RowBox[{"Length", "[", "tst", "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "===", "\"\<Unrecognised\>\""}], ",", "0", ",", 
            RowBox[{"Sign", "[", 
             RowBox[{
              RowBox[{"gd", "[", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"3", ",", "2", ",", "1"}], "]"}], "]"}], "]"}]}], 
           "]"}], ",", 
          RowBox[{"amQ", "[", "tst", "]"}], ",", 
          RowBox[{"bolQ", "[", "tst", "]"}], ",", 
          RowBox[{"cQ", "[", "tst", "]"}], ",", 
          RowBox[{"hamiltonianQ", "[", "tst", "]"}], ",", 
          RowBox[{"MoufangQ", "[", "tst", "]"}], ",", 
          RowBox[{"moufangLQ", "[", "tst", "]"}], ",", 
          RowBox[{"riffQ", "[", "tst", "]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "inc", "]"}]}], "}"}]}], "]"}], ";", 
    RowBox[{"res", "//", "tf"}]}], "\[IndentingNewLine]", 
   RowBox[{"inc", "=."}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"loop\"\>", "\<\"len\"\>", "\<\"type\"\>", "\<\"A_m\"\>", \
"\<\"bol\"\>", "\<\"C\"\>", "\<\"Hamilton\"\>", "\<\"Mouf\"\>", \
"\<\"moufL\"\>", "\<\"RIFF\"\>"},
     {"\<\"test\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"x(yx.zx)=\"\>", \
"\<\"(z.yz)x=\"\>", "\<\"(xy.y)z=\"\>", "\<\"Normal\"\>", "\<\"zx.yx=\"\>", "\
\<\"|(zy.z)x|=\"\>", "\<\"xy(z.xy)=\"\>"},
     {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"(xy.xz)x\"\>", \
"\<\"z(y.zx)\"\>", "\<\"x(yy.z)\"\>", "\<\"subgrps\"\>", "\<\"z.xy.z\"\>", \
"\<\"|z(y.zx)|\"\>", "\<\"((x.yz))x)y\"\>"},
     {"\<\"C3\"\>", "3", "1", "True", "True", "True", "False", "True", "True",
       "True"},
     {"\<\"Qr\"\>", "4", 
      RowBox[{"-", "1"}], "False", "False", "True", "True", "False", "True", 
      "True"},
     {"\<\"P4\"\>", "4", 
      RowBox[{"-", "\[ImaginaryI]"}], "False", "\<\"Complex\"\>", "True", 
      "True", "False", "True", "True"},
     {"\<\"C8r\"\>", "4", 
      RowBox[{"-", "1"}], "True", "False", "False", "False", "False", "True", 
      "True"},
     {"\<\"C5n\"\>", "5", "1", "True", "False", "False", "True", "False", 
      "False", "True"},
     {"\<\"D3\"\>", "6", "1", "True", "True", "True", "True", "True", "True", 
      "True"},
     {"\<\"C6n\"\>", "6", "1", "False", "False", "False", "True", "False", 
      "False", "False"},
     {"\<\"Q8\"\>", "8", "1", "True", "True", "True", "True", "True", "True", 
      "True"},
     {"\<\"?\"\>", "10", "0", "False", "False", "False", "True", "False", 
      "False", "False"},
     {"\<\"Q12\"\>", "12", "1", "True", "True", "True", "True", "True", 
      "True", "True"},
     {"\<\"Alt12n\"\>", "12", "1", "False", "False", "True", "True", "False", 
      "False", "False"},
     {"\<\"?\"\>", "16", "1", "False", "False", "False", "True", "False", 
      "False", "False"},
     {"\<\"\\!\\(C2\\^5\\)r\"\>", "16", 
      RowBox[{"-", "1"}], "True", "False", "True", "False", "False", "True", 
      "True"},
     {"\<\"Oct\"\>", "16", "1", "False", "True", "True", "True", "True", 
      "True", "True"},
     {"\<\"Sed\"\>", "16", 
      RowBox[{"-", "1"}], "False", "False", "True", "True", "False", "True", 
      "True"}
    }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 PageWidth->WindowWidth,
 FontSize->9]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["conservativeQ",
  FontSlant->"Italic"],
 " test does not match any of the other tests exactly.  ",
 StyleBox["moufangQ",
  FontSlant->"Italic"],
 "  is the nearest, but passes ",
 StyleBox["Sed",
  FontSlant->"Italic"],
 "; ",
 StyleBox["AbelGrassmann ",
  FontSlant->"Italic"],
 "is split by C8r / D3; ",
 StyleBox["alternativeQ",
  FontSlant->"Italic"],
 " is split by Octi / Alt12n; ",
 StyleBox["entropicQ",
  FontSlant->"Italic"],
 " fails for Oct; ",
 StyleBox["A_m",
  FontSlant->"Italic"],
 " fails for Qr; ",
 StyleBox["bolQ, CQ &HamiltonQ",
  FontSlant->"Italic"],
 " fail for C8r.\n\tExample A4 is a test-bed for newly discovered tables. It \
tests the signed table ",
 StyleBox["tst10 ",
  FontSlant->"Italic"],
 " (from Example 10) for most of the programmed properties:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Example", " ", 
    RowBox[{"A4", ".", " ", "Property"}], " ", "List"}], " ", "*)"}], 
  " "}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"tst", "=", 
    RowBox[{"mp", "[", "\"\<Octr\>\"", "]"}]}], ";", 
   RowBox[{"{", 
    RowBox[{"\"\<abelian    \>\"", ",", 
     RowBox[{"abelianQ", "(", "tst", ")"}], ",", "\"\<\\nassociative \>\"", 
     ",", 
     RowBox[{"associativeQ", "(", "tst", ")"}], ",", 
     "\"\<\\nabelGrassman\>\"", ",", 
     RowBox[{"abelGrassmanQ", "(", "tst", ")"}], ",", 
     "\"\<\\nalternative \>\"", ",", 
     RowBox[{"alternativeQ", "(", "tst", ")"}], ",", 
     "\"\<\\nam          \>\"", ",", 
     RowBox[{"amQ", "(", "tst", ")"}], ",", "\"\<\\nbol         \>\"", ",", 
     RowBox[{"bolQ", "(", "tst", ")"}], ",", "\"\<\\nc           \>\"", ",", 
     RowBox[{"cQ", "(", "tst", ")"}], ",", "\"\<\\nentropic    \>\"", ",", 
     RowBox[{"entropicQ", "(", "tst", ")"}], ",", "\"\<\\nflexible    \>\"", 
     ",", 
     RowBox[{"flexibleQ", "(", "tst", ")"}], ",", "\"\<\\nfenyves     \>\"", 
     ",", 
     RowBox[{"fenyvesQ", "(", "tst", ")"}], ",", "\"\<\\nflex        \>\"", 
     ",", 
     RowBox[{"flexQ", "(", "tst", ")"}], ",", "\"\<\\nhamiltonian \>\"", ",", 
     
     RowBox[{"hamiltonianQ", "(", "tst", ")"}], ",", 
     "\"\<\\njacobi      \>\"", ",", 
     RowBox[{"jacobiQ", "(", "tst", ")"}], ",", "\"\<\\njordan      \>\"", 
     ",", 
     RowBox[{"jordanQ", "(", "tst", ")"}], ",", "\"\<\\nmoufang     \>\"", 
     ",", 
     RowBox[{"moufangQ", "(", "tst", ")"}], ",", "\"\<\\nnegatable   \>\"", 
     ",", 
     RowBox[{"negatableQ", "(", "tst", ")"}], ",", "\"\<\\nriff        \>\"", 
     ",", 
     RowBox[{"riffQ", "(", "tst", ")"}]}], "}"}]}], TraditionalForm]], "Input",\

 PageWidth->WindowWidth,
 FontFamily->"Courier New"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"abelian    \"\>", ",", "False", ",", "\<\"\\nassociative \"\>",
    ",", "True", ",", "\<\"\\nabelGrassman\"\>", ",", "True", 
   ",", "\<\"\\nalternative \"\>", ",", "True", 
   ",", "\<\"\\nam          \"\>", ",", "False", 
   ",", "\<\"\\nbol         \"\>", ",", "False", 
   ",", "\<\"\\nc           \"\>", ",", "True", 
   ",", "\<\"\\nentropic    \"\>", ",", "True", 
   ",", "\<\"\\nflexible    \"\>", ",", "False", 
   ",", "\<\"\\nfenyves     \"\>", ",", "True", 
   ",", "\<\"\\nflex        \"\>", ",", "True", 
   ",", "\<\"\\nhamiltonian \"\>", ",", "True", 
   ",", "\<\"\\njacobi      \"\>", ",", 
   RowBox[{"jacobiQ", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
        "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}], ",", "4", ",", 
        RowBox[{"-", "3"}], ",", "6", ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "8"}], ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "1"}], ",", "2", ",", "7", ",", "8", ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "6"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3", ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "1"}], ",", "8", ",", 
        RowBox[{"-", "7"}], ",", "6", ",", 
        RowBox[{"-", "5"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "7"}], ",", 
        RowBox[{"-", "8"}], ",", 
        RowBox[{"-", "1"}], ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5", ",", 
        RowBox[{"-", "8"}], ",", "7", ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "4"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "8", ",", "5", ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "3"}], ",", "4", ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", 
        RowBox[{"-", "7"}], ",", "6", ",", "5", ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "3"}], ",", "2", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}], 
   ",", "\<\"\\njordan      \"\>", ",", 
   RowBox[{"jordanQ", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
        "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}], ",", "4", ",", 
        RowBox[{"-", "3"}], ",", "6", ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "8"}], ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "1"}], ",", "2", ",", "7", ",", "8", ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "6"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3", ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "1"}], ",", "8", ",", 
        RowBox[{"-", "7"}], ",", "6", ",", 
        RowBox[{"-", "5"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "7"}], ",", 
        RowBox[{"-", "8"}], ",", 
        RowBox[{"-", "1"}], ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5", ",", 
        RowBox[{"-", "8"}], ",", "7", ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "4"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "8", ",", "5", ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "3"}], ",", "4", ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", 
        RowBox[{"-", "7"}], ",", "6", ",", "5", ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "3"}], ",", "2", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}], 
   ",", "\<\"\\nmoufang     \"\>", ",", "True", 
   ",", "\<\"\\nnegatable   \"\>", ",", "False", 
   ",", "\<\"\\nriff        \"\>", ",", "True"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\thoopTimes[A,B,tst,1] uses a minimal multiplication routine, developed to \
test conservation of large tables that need not be in the databank. It has \
been used to establish which compositions of Oct are conservative. (Only \
compositions with Abelian groups.) \
\>", "Text",
 PageWidth->WindowWidth],

Cell["Revised 24/2/2007", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"co", "[", 
    RowBox[{"Oct", ",", 
     RowBox[{"tst1", "=", 
      RowBox[{"mp", "[", 
       RowBox[{"16", ",", "1"}], "]"}]}]}], "]"}]}], ";", 
  RowBox[{"id", "[", "tst1", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"While", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Random", "[", 
         RowBox[{"Integer", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "tst", "]"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"sA", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Det", "[", 
        RowBox[{"gmap", "[", 
         RowBox[{"tst", ",", "A"}], "]"}], "]"}], "]"}]}], ";", 
     RowBox[{"sA", "==", "0"}]}], ","}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"While", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Random", "[", 
         RowBox[{"Integer", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "tst", "]"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"sB", "=", 
      RowBox[{"Det", "[", 
       RowBox[{"gmap", "[", 
        RowBox[{"tst", ",", "B"}], "]"}], "]"}]}], ";", 
     RowBox[{"sB", "==", "0"}]}], ","}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AB", "=", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"A", ",", "B", ",", "tst", ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sAB", "=", 
   RowBox[{"Det", "[", 
    RowBox[{"gmap", "[", 
     RowBox[{"tst", ",", "AB"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Chop", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"sA", " ", "sB"}], "-", "sAB"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"sA", "+", "sB"}], ")"}]}], "]"}], "\[Equal]", "0"}], ",", 
   "True", ",", 
   RowBox[{
    RowBox[{"Chop", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"sA", " ", "sB"}], "+", "sAB"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"sA", "+", "sB"}], ")"}]}], "]"}], "\[Equal]", "0"}]}], 
  "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"C16\"\>"], "Output"],

Cell[BoxData["True"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.2. ",
 StyleBox["Groups from Relators", "Text"],
 "."
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tMost of the ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " rules were discovered empirically, retaining the shortest wherever more \
than one gave a particular group. I later learned that they could be found by \
the GAP instruction:- ",
 StyleBox["gap>RelatorsOfFpGroup(Image(IsomorphismFpGroup(SmallGroup(mm,nn))))\
",
  FontSlant->"Italic"],
 ";\nthis gives the result in terms of F1, F2, etc. The result can be copied \
(e.g. from a Wordpad document) and processed as in Example A6. The GAP \
formulation {2,2,3},{aa\[Rule]b,ca\[Rule]acc} is not the most compact form; \
the database rule for Q12 is {3,4},{\"ba\"\[Rule]\"a2b\"}:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example A5. Gap relators & generators for SmallGroup(12,1)", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\"\<The GAP Relators for SmallGroup{12,1) are F1^2*F2^-1, \
F2^-1*F1^-1*F2*F1, F3^-1*F1^-1*F3*F1*F3^-1, F2^2, \n  F3^-1*F2^-1*F3*F2, F3^3\
\\nThey convert to\>\"", ",", 
   StyleBox[
    RowBox[{
     RowBox[{"Hold", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"F1", "^", "2"}], "*", 
        RowBox[{"F2", "^", 
         RowBox[{"-", "1"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"F2", "^", 
         RowBox[{"-", "1"}]}], "*", 
        RowBox[{"F1", "^", 
         RowBox[{"-", "1"}]}], "*", "F2", "*", "F1"}], ",", " ", 
       RowBox[{
        RowBox[{"F3", "^", 
         RowBox[{"-", "1"}]}], "*", 
        RowBox[{"F1", "^", 
         RowBox[{"-", "1"}]}], "*", "F3", "*", "F1", "*", 
        RowBox[{"F3", "^", 
         RowBox[{"-", "1"}]}]}], ",", " ", 
       RowBox[{"F2", "^", "2"}], ",", " ", "\n", "  ", 
       RowBox[{
        RowBox[{"F3", "^", 
         RowBox[{"-", "1"}]}], "*", 
        RowBox[{"F2", "^", 
         RowBox[{"-", "1"}]}], "*", "F3", "*", "F2"}], ",", " ", 
       RowBox[{"F3", "^", "3"}]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"F1", "->", "a"}], ",", 
       RowBox[{"F2", "->", "b"}], ",", 
       RowBox[{"F3", "->", "c"}]}], "}"}]}],
    FormatType->StandardForm], 
   StyleBox[",",
    FormatType->StandardForm], 
   StyleBox[
    "\"\<\\nwhich translates to {2,2,3},{aa\[Rule]b,ca\[Rule]acc}.\\nThis \
generates\>\"",
    FormatType->StandardForm], 
   StyleBox[",",
    FormatType->StandardForm], 
   RowBox[{"id", "[", 
    RowBox[{"ge", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"aa", "\[Rule]", "b"}], ",", 
        RowBox[{"ca", "\[Rule]", "acc"}]}], "}"}]}], "]"}], "]"}], ",", 
   "\"\<\\nData\>\"", ",", 
   RowBox[{"gd", "[", "]"}]}], 
  StyleBox["}",
   FormatType->StandardForm]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"The GAP Relators for SmallGroup{12,1) are F1^2*F2^-1, \
F2^-1*F1^-1*F2*F1, F3^-1*F1^-1*F3*F1*F3^-1, F2^2,    F3^-1*F2^-1*F3*F2, \
F3^3\\nThey convert to\"\>", ",", 
   RowBox[{"Hold", "[", 
    RowBox[{
     FractionBox[
      SuperscriptBox["a", "2"], "b"], ",", 
     FractionBox[
      RowBox[{"b", " ", "a"}], 
      RowBox[{"b", " ", "a"}]], ",", 
     FractionBox[
      RowBox[{"c", " ", "a"}], 
      RowBox[{"c", " ", "a", " ", "c"}]], ",", 
     SuperscriptBox["b", "2"], ",", 
     FractionBox[
      RowBox[{"c", " ", "b"}], 
      RowBox[{"c", " ", "b"}]], ",", 
     SuperscriptBox["c", "3"]}], "]"}], 
   ",", "\<\"\\nwhich translates to {2,2,3},{aa\[Rule]b,ca\[Rule]acc}.\\nThis \
generates\"\>", ",", "\<\"Q12\"\>", ",", "\<\"\\nData\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "1", ",", 
     RowBox[{"{", 
      RowBox[{"\<\"Q12\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         SubscriptBox["2", "2"], ",", "6"}], "}"}], ",", "0", 
       ",", "\<\"co[C3,C4,2]\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\<\"ba\"\>", "\[Rule]", "\<\"a2b\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "13"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "36"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", ",", "16"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",\

 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["ba/ba",
  FontSlant->"Italic"],
 " etc cases are handled automatically by ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " and are ignored. \nThe ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "n"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["a", "n"], 
    StyleBox["/",
     FontSlant->"Italic"], 
    StyleBox["b",
     FontSlant->"Italic"]}], TraditionalForm]]],
 " & ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["a", "n"], 
    StyleBox["/",
     FontSlant->"Italic"], 
    StyleBox[
     SuperscriptBox["b", "m"],
     FontSlant->"Italic"]}], TraditionalForm]]],
 " etc. cases define ",
 StyleBox["n",
  FontSlant->"Italic"],
 " for the members of the generator power list. \n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["a", "n"], 
    StyleBox["/",
     FontSlant->"Italic"], 
    StyleBox["b",
     FontSlant->"Italic"]}], TraditionalForm]]],
 " & ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["a", "n"], 
    StyleBox["/",
     FontSlant->"Italic"], 
    StyleBox[
     SuperscriptBox["b", "m"],
     FontSlant->"Italic"]}], TraditionalForm]]],
 " imply non-abelian rules \"an\"->\"b\" & \"an\"->\"bm\". \n",
 StyleBox["ba/(ba,c)",
  FontSlant->"Italic"],
 "  becomes \"ba\"->\"abc\". (KnC4)\n",
 StyleBox["ba/(ba,cb) ",
  FontSlant->"Italic"],
 "becomes \"ba\"->\"abc\".",
 StyleBox["  \nca/(ca,c)",
  FontSlant->"Italic"],
 " becomes \"ca\"->\"acc\". (Q12)\n",
 StyleBox["ba/(ba,",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]]],
 ") becomes \"ba\"->\"anb\" (g2003)\n",
 StyleBox["cb/(cb,",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]]],
 ") becomes \"cb\"->\"bcn\"\n",
 StyleBox["ba/(ba,yxc)",
  FontSlant->"Italic"],
 "  becomes \"ba\"->\"abcxy\"\n",
 StyleBox["ba/(ba,yxb)",
  FontSlant->"Italic"],
 "  becomes \"ba\"->\"abxy\" (SL23).  \ng4828, g4829 and g6005 (\"A5\") have \
terms that have not been resolved. E.g. A5 gives a5/b5, a5/baba, 1/aa bb/aa \
bb."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "14. Appendix B. ",
 StyleBox["Signed Table Search.", "Text"]
}], "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThis appendix demonstrates the search for a reordering that allows a \
table to be folded. ",
 StyleBox["dico",
  FontSlant->"Italic"],
 " is first inspected. The counts must be divisible by ",
 StyleBox["r",
  FontSlant->"Italic"],
 " to allow ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold folding. In the example they are ",
 Cell[BoxData[
  RowBox[{"12", ",", "4", ",", 
   SubscriptBox["8", "2"]}]]],
 " (the 23 is a diagnostic, not a count) and so ",
 StyleBox["r",
  FontSlant->"Italic"],
 " may be 2 or 4."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst2", "=", 
   RowBox[{"mp", "[", "\"\<KiC4M\>\"", "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"id", "[", "tst2", "]"}], "\[IndentingNewLine]", 
 RowBox[{"gd", "[", "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"KiC4M\"\>"], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"32", ",", "59", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"KiC4M\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "4", ",", 
       SubscriptBox["8", "2"], ",", "23"}], "}"}], ",", "0", 
     ",", "\<\"md[co[K,C4,2],{1,4,3,2,7,8,5,6,9,12,11,10,15,16,13,14}]\"\>", 
     ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "\tA partial reordering is compared with the required form for the (",
 StyleBox["m",
  FontSlant->"Italic"],
 "/2+1)th row, and modified in an obvious way to correct the errors. In this \
case, the 17'th column is not correct, and the table does not 2-fold."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ord", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Position", "[", 
      RowBox[{
       RowBox[{"tst2", "[", 
        RowBox[{"[", "17", "]"}], "]"}], ",", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{"i", "+", "16"}], ",", "32", ",", "1"}], "]"}]}], "]"}], ",",
      
     RowBox[{"{", 
      RowBox[{"i", ",", "32"}], "}"}]}], "]"}], "]"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "4", ",", "3", ",", "2", ",", "7", ",", "8", ",", "5", ",", "6", 
   ",", "9", ",", "12", ",", "11", ",", "10", ",", "15", ",", "16", ",", "13",
    ",", "14", ",", "17", ",", "20", ",", "19", ",", "18", ",", "23", ",", 
   "24", ",", "21", ",", "22", ",", "25", ",", "28", ",", "27", ",", "26", 
   ",", "31", ",", "32", ",", "29", ",", "30"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"reorder", "[", 
    RowBox[{"tst2", ",", "ord"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Range", "[", 
     RowBox[{"17", ",", "32"}], "]"}], ",", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", "16"}], "]"}], ",", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", 
      RowBox[{"-", "16"}]}], "]"}], ",", 
    RowBox[{"Range", "[", "16", "]"}]}], "}"}], "//", "tf"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", 
      "29", "30", "31", "32"},
     {"17", "20", "19", "18", "23", "24", "21", "22", "25", "28", "27", "26", 
      "31", "32", "29", "30"},
     {"1", "4", "3", "2", "7", "8", "5", "6", "9", "12", "11", "10", "15", 
      "16", "13", "14"},
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

 PageWidth->WindowWidth,
 GeneratedCell->False,
 CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"reorder", "[", 
    RowBox[{"tst2", ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
       ",", "15", ",", "16", ",", "17", ",", "20", ",", "19", ",", "18", ",", 
       "23", ",", "24", ",", "21", ",", "22", ",", "25", ",", "28", ",", "27",
        ",", "26", ",", "31", ",", "32", ",", "29", ",", "30"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", "16"}], "]"}], ",", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", 
      RowBox[{"-", "16"}]}], "]"}]}], "}"}], "//", 
  "tf"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Transpose", "[", "tst", "]"}], "[", 
  RowBox[{"[", "17", "]"}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", 
      "29", "30", "31", "32"},
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "20", ",", "19", ",", "18", ",", "23", ",", "24", ",", "21", ",",
    "22", ",", "25", ",", "28", ",", "27", ",", "26", ",", "31", ",", "32", 
   ",", "29", ",", "30", ",", "1", ",", "4", ",", "3", ",", "2", ",", "7", 
   ",", "8", ",", "5", ",", "6", ",", "9", ",", "12", ",", "11", ",", "10", 
   ",", "15", ",", "16", ",", "13", ",", "14"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["The other 32-element Moufang Loops also fail:-", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tstp", "=", 
   RowBox[{"mp", "[", "\"\<P16M\>\"", "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"name", "=", 
  RowBox[{"id", "[", "tstp", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"gd", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ord", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Range", "[", "16", "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"tstp", "[", 
          RowBox[{"[", "17", "]"}], "]"}], ",", 
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"i", "+", "16"}], ",", "32", ",", "1"}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "17", ",", "32"}], "}"}]}], "]"}]}], "}"}], 
   "]"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"P16M\"\>"], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"32", ",", "57", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"P16M\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "16", ",", "15"}], "}"}], ",", "0", 
     ",", "\<\"md[co[P4,C4],{1,10,11,12,5,14,15,16,9,2,3,4,13,6,7,8}]\"\>", 
     ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "15",
    ",", "16", ",", "17", ",", "26", ",", "27", ",", "28", ",", "21", ",", 
   "30", ",", "31", ",", "32", ",", "25", ",", "18", ",", "19", ",", "20", 
   ",", "29", ",", "22", ",", "23", ",", "24"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"reorder", "[", 
    RowBox[{"tstp", ",", "ord"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", "16"}], "]"}], ",", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", 
      RowBox[{"-", "16"}]}], "]"}]}], "}"}], "//", 
  "tf"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Transpose", "[", "tst", "]"}], "[", 
  RowBox[{"[", "17", "]"}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", 
      "29", "30", "31", "32"},
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "26", ",", "27", ",", "28", ",", "21", ",", "30", ",", "31", ",",
    "32", ",", "25", ",", "18", ",", "19", ",", "20", ",", "29", ",", "22", 
   ",", "23", ",", "24", ",", "1", ",", "10", ",", "11", ",", "12", ",", "5", 
   ",", "14", ",", "15", ",", "16", ",", "9", ",", "2", ",", "3", ",", "4", 
   ",", "13", ",", "6", ",", "7", ",", "8"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tstc", "=", 
   RowBox[{"mp", "[", "\"\<C8pC2M\>\"", "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"name", "=", 
  RowBox[{"id", "[", "tstc", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"gd", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ord", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Range", "[", "16", "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"tstc", "[", 
          RowBox[{"[", "17", "]"}], "]"}], ",", 
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"i", "+", "16"}], ",", "32", ",", "1"}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "17", ",", "32"}], "}"}]}], "]"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"reorder", "[", 
    RowBox[{"tstc", ",", "ord"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", "16"}], "]"}], ",", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", 
      RowBox[{"-", "16"}]}], "]"}]}], "}"}], "//", 
  "tf"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Transpose", "[", "tst", "]"}], "[", 
  RowBox[{"[", "17", "]"}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"C8pC2M\"\>"], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"32", ",", "58", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C8pC2M\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", 
       SubscriptBox["8", "3"], ",", "7"}], "}"}], ",", "99", 
     ",", "\<\"md[co[ca[8],C2,4],{1,6,3,8,5,2,7,4,13,14,15,16,9,10,11,12}]\"\>\
", ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "15",
    ",", "16", ",", "17", ",", "22", ",", "19", ",", "24", ",", "21", ",", 
   "18", ",", "23", ",", "20", ",", "29", ",", "30", ",", "31", ",", "32", 
   ",", "25", ",", "26", ",", "27", ",", "28"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", 
      "29", "30", "31", "32"},
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "22", ",", "19", ",", "24", ",", "21", ",", "18", ",", "23", ",",
    "20", ",", "29", ",", "30", ",", "31", ",", "32", ",", "25", ",", "26", 
   ",", "27", ",", "28", ",", "1", ",", "6", ",", "3", ",", "8", ",", "5", 
   ",", "2", ",", "7", ",", "4", ",", "13", ",", "14", ",", "15", ",", "16", 
   ",", "9", ",", "10", ",", "11", ",", "12"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tstq", "=", 
   RowBox[{"mp", "[", "\"\<Q8C2M\>\"", "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"name", "=", 
  RowBox[{"id", "[", "tstq", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"gd", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ord", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Range", "[", "16", "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"tstq", "[", 
          RowBox[{"[", "17", "]"}], "]"}], ",", 
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"i", "+", "16"}], ",", "32", ",", "1"}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "17", ",", "32"}], "}"}]}], "]"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"reorder", "[", 
    RowBox[{"tstq", ",", "ord"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", "16"}], "]"}], ",", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", 
      RowBox[{"-", "16"}]}], "]"}]}], "}"}], "//", 
  "tf"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Transpose", "[", "tst", "]"}], "[", 
  RowBox[{"[", "17", "]"}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"Q8C2M\"\>"], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"32", ",", "60", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Q8C2M\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", "12", ",", "31"}], "}"}], ",", "0", 
     ",", "\<\"md[co[Q8,C2]]\"\>", ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "15",
    ",", "16", ",", "17", ",", "22", ",", "23", ",", "24", ",", "21", ",", 
   "18", ",", "19", ",", "20", ",", "25", ",", "30", ",", "31", ",", "32", 
   ",", "29", ",", "26", ",", "27", ",", "28"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", 
      "29", "30", "31", "32"},
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "22", ",", "23", ",", "24", ",", "21", ",", "18", ",", "19", ",",
    "20", ",", "25", ",", "30", ",", "31", ",", "32", ",", "29", ",", "26", 
   ",", "27", ",", "28", ",", "1", ",", "6", ",", "7", ",", "8", ",", "5", 
   ",", "2", ",", "3", ",", "4", ",", "9", ",", "14", ",", "15", ",", "16", 
   ",", "13", ",", "10", ",", "11", ",", "12"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tsto", "=", 
   RowBox[{"mp", "[", "\"\<O16\>\"", "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"name", "=", 
  RowBox[{"id", "[", "tsto", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"gd", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ord", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Range", "[", "16", "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"tsto", "[", 
          RowBox[{"[", "17", "]"}], "]"}], ",", 
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"i", "+", "16"}], ",", "32", ",", "1"}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "17", ",", "32"}], "}"}]}], "]"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"reorder", "[", 
    RowBox[{"tsto", ",", "ord"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", "16"}], "]"}], ",", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "17", "]"}], "]"}], ",", 
      RowBox[{"-", "16"}]}], "]"}]}], "}"}], "//", 
  "tf"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Transpose", "[", "tst", "]"}], "[", 
  RowBox[{"[", "17", "]"}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"O16\"\>"], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"32", ",", "62", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"O16\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "16.`"}], ",", "16", ",", "35"}], "}"}], ",", "0", 
     ",", "\<\"cd[{-1,1,1,1,1}]\"\>", ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "15",
    ",", "16", ",", "17", ",", "18", ",", "19", ",", "20", ",", "21", ",", 
   "22", ",", "23", ",", "24", ",", "25", ",", "26", ",", "27", ",", "28", 
   ",", "29", ",", "30", ",", "31", ",", "32"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", 
      "29", "30", "31", "32"},
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "18", ",", "19", ",", "20", ",", "21", ",", "22", ",", "23", ",",
    "24", ",", "25", ",", "26", ",", "27", ",", "28", ",", "29", ",", "30", 
   ",", "31", ",", "32", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", 
   ",", "6", ",", "7", ",", "8", ",", "9", ",", "10", ",", "11", ",", "12", 
   ",", "13", ",", "14", ",", "15", ",", "16"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["Problem with ts??", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"id", "[", 
  RowBox[{"tst", "=", 
   RowBox[{"ts", "[", 
    RowBox[{"cd", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], "]"}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"tst", "//", "tf"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"Fail, not an indexTable.\"\>"], "Print"],

Cell[BoxData["\<\"C3C4j\"\>"], "Output"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], "1", "2"},
     {
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], "2", "1"},
     {"1", "2", "3", "4"},
     {"2", "1", "4", "3"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "15. Appendix C. ",
 StyleBox["T", "Text"],
 "he Hypercomplex Plane, ",
 StyleBox["arcTanh", "Text"],
 "."
}], "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\t",
 StyleBox["toHypolar & toHyvector ",
  FontSlant->"Italic"],
 "provide coordinates in the hypercomplex plane. (I have not explored the \
relationship between this and the \"Projected Hyperbolic Plane\" discussed in \
Penrose 2004.) An extended definition of ArcTanh (as arcTanh[adj,opp]) \
accounts for the octant of the arguments (this makes the resulting angle \
complex in 6 octants). ",
 StyleBox["Cosh",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Sinh",
  FontSlant->"Italic"],
 " are used in definitions of ",
 StyleBox["tohyVec",
  FontSlant->"Italic"],
 " such as:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tohyPol", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ":=", 
  RowBox[{"Chop", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ",", 
     RowBox[{"arcTanh", "[", 
      RowBox[{"a", ",", "b"}], "]"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tohyVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"uu_", ",", "\[Phi]_"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ":=",
   
  RowBox[{"Chop", "[", 
   RowBox[{
    SqrtBox["uu"], " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cosh", "[", "\[Phi]", "]"}], ",", 
      RowBox[{"Sinh", "[", "\[Phi]", "]"}]}], "}"}]}], "]"}]}]}], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[BoxData[
 FormBox[
  RowBox[{"??", "arcTanh"}], TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThis definition was brought to my attention by \"Klueless\", \
sci.math.symbolic, May 2001, and implemented by me in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " for ",
 StyleBox["tohyPol ",
  FontSlant->"Italic"],
 "&",
 StyleBox[" tohyVec",
  FontSlant->"Italic"],
 ". Example 35 (Section 6.2) showed that complex values are handled \
successfully. The different combinations of real coordinates and complex \
angles are illustrated below. "
}], "Text",
 PageWidth->WindowWidth],

Cell["Example C1. arcTanh.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\"\<arcTanh[2, 1]  is  \>\"", ",", 
    RowBox[{"arcTanh", "[", 
     RowBox[{"2", ",", "1"}], "]"}], ",", "\"\<\\narcTanh[-2, 1]  is \>\"", 
    ",", 
    RowBox[{"arcTanh", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", "1"}], "]"}], ",", 
    "\"\<\\narcTanh[-2,-1]  is  \>\"", ",", 
    RowBox[{"arcTanh", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "1"}]}], "]"}], ",", "\"\<\\narcTanh[ 2,-1]  is \>\"", ",",
     
    RowBox[{"arcTanh", "[", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}], "]"}], ",", "\"\<\\narcTanh[ 1, 2]  is  \>\"", 
    ",", 
    RowBox[{"arcTanh", "[", 
     RowBox[{"1", ",", "2"}], "]"}], ",", "\"\<\\narcTanh[-1, 2]  is \>\"", 
    ",", 
    RowBox[{"arcTanh", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "2"}], "]"}], ",", 
    "\"\<\\narcTanh[-1,-2]  is  \>\"", ",", 
    RowBox[{"arcTanh", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "2"}]}], "]"}], ",", "\"\<\\narcTanh[ 1,-2]  is \>\"", ",",
     
    RowBox[{"arcTanh", "[", 
     RowBox[{"1", ",", 
      RowBox[{"-", "2"}]}], "]"}], ",", 
    "\"\<\\narcTanh[1,2+\[ImaginaryI]]  is  \>\"", ",", 
    RowBox[{"arcTanh", "[", 
     RowBox[{"1", ",", 
      RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}]}], "}"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"arcTanh[2, 1]  is  \"\>", ",", "0.5493061443340548`", 
   ",", "\<\"\\narcTanh[-2, 1]  is \"\>", ",", 
   RowBox[{
    RowBox[{"-", "0.5493061443340549`"}], "+", 
    RowBox[{"3.141592653589793`", " ", "\[ImaginaryI]"}]}], 
   ",", "\<\"\\narcTanh[-2,-1]  is  \"\>", ",", 
   RowBox[{"0.5493061443340548`", "\[InvisibleSpace]", "+", 
    RowBox[{"3.141592653589793`", " ", "\[ImaginaryI]"}]}], 
   ",", "\<\"\\narcTanh[ 2,-1]  is \"\>", ",", 
   RowBox[{"-", "0.5493061443340549`"}], 
   ",", "\<\"\\narcTanh[ 1, 2]  is  \"\>", ",", 
   RowBox[{"0.5493061443340548`", "\[InvisibleSpace]", "-", 
    RowBox[{"1.5707963267948966`", " ", "\[ImaginaryI]"}]}], 
   ",", "\<\"\\narcTanh[-1, 2]  is \"\>", ",", 
   RowBox[{
    RowBox[{"-", "0.5493061443340549`"}], "-", 
    RowBox[{"1.5707963267948966`", " ", "\[ImaginaryI]"}]}], 
   ",", "\<\"\\narcTanh[-1,-2]  is  \"\>", ",", 
   RowBox[{"0.5493061443340548`", "\[InvisibleSpace]", "+", 
    RowBox[{"1.5707963267948966`", " ", "\[ImaginaryI]"}]}], 
   ",", "\<\"\\narcTanh[ 1,-2]  is \"\>", ",", 
   RowBox[{
    RowBox[{"-", "0.5493061443340549`"}], "+", 
    RowBox[{"1.5707963267948966`", " ", "\[ImaginaryI]"}]}], 
   ",", "\<\"\\narcTanh[1,2+\[ImaginaryI]]  is  \"\>", ",", 
   RowBox[{"0.40235947810852524`", "\[InvisibleSpace]", "+", 
    RowBox[{"1.3389725222944935`", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["Example C2. Hyperbolic Plane. ", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"xy", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"tohyVec", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "th"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"th", ",", 
        RowBox[{"-", "1.6"}], ",", "1.6", ",", ".1"}], "}"}]}], "]"}]}], 
   ";"}], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{
    RowBox[{"xy1", "=", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"tohyVec", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "th"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"th", ",", 
          RowBox[{"1.6", "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
          RowBox[{
           RowBox[{"-", "1.6"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
          RowBox[{"-", ".1"}]}], "}"}]}], "]"}]}]}], ";"}],
   TraditionalForm], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{
    RowBox[{"xy2", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"tohyVec", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "th"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"th", ",", 
         RowBox[{
          RowBox[{"-", "1.6"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], ",", 
         RowBox[{"1.6", "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], ",", ".1"}], "}"}]}], 
      "]"}]}], ";"}],
   TraditionalForm], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{
    RowBox[{"xy3", "=", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"tohyVec", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "th"}], "}"}], ",", "\"\<C2\>\""}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"th", ",", 
          RowBox[{"1.6", "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
          RowBox[{
           RowBox[{"-", "1.6"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
          RowBox[{"-", ".1"}]}], "}"}]}], "]"}]}]}], ";"}],
   TraditionalForm], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"xy7", "=", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"tohyVec", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.5"}], ",", "th"}], "}"}], ",", "\"\<C2\>\""}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"th", ",", 
         RowBox[{"-", "1.4"}], ",", "1.4", ",", ".1"}], "}"}]}], "]"}]}]}], 
   ";"}], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{
    RowBox[{"xy6", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"tohyVec", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.5"}], ",", "th"}], "}"}], ",", "\"\<C2\>\""}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"th", ",", 
         RowBox[{"1.4", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "1.4"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
         RowBox[{"-", ".1"}]}], "}"}]}], "]"}]}], ";"}],
   TraditionalForm], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{
    RowBox[{"xy5", "=", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"tohyVec", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.5"}], ",", "th"}], "}"}], ",", "\"\<C2\>\""}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"th", ",", 
          RowBox[{
           RowBox[{"-", "1.4"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], ",", 
          RowBox[{"1.4", "+", 
           RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], ",", ".1"}], "}"}]}], 
       "]"}]}]}], ";"}],
   TraditionalForm], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"xy8", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"tohyVec", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "th"}], "}"}], ",", "\"\<C2\>\""}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"th", ",", 
        RowBox[{"1.4", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
        RowBox[{
         RowBox[{"-", "1.4"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
        RowBox[{"-", ".1"}]}], "}"}]}], "]"}]}], ";"}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"xy9", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"tohyVec", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{".8", "\[ImaginaryI]"}], ",", "th"}], "}"}], ",", 
         "\"\<C2\>\""}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"th", ",", 
        RowBox[{"-", "2.05"}], ",", "2.05", ",", ".1"}], "}"}]}], "]"}]}], 
   ";", 
   FormBox[
    RowBox[{
     RowBox[{"xy10", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"tohyVec", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{".8", "\[ImaginaryI]"}], ",", "th"}], "}"}], ",", 
           "\"\<C2\>\""}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"th", ",", 
          RowBox[{"2.05", "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
          RowBox[{
           RowBox[{"-", "2.05"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
          RowBox[{"-", ".1"}]}], "}"}]}], "]"}]}], ";"}],
    TraditionalForm]}], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{
    RowBox[{"xy11", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"tohyVec", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{".8", "\[ImaginaryI]"}], ",", "th"}], "}"}], ",", 
          "\"\<C2\>\""}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"th", ",", 
         RowBox[{
          RowBox[{"-", "2.05"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], ",", 
         RowBox[{"2.05", "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], ",", ".1"}], "}"}]}], 
      "]"}]}], ";"}],
   TraditionalForm], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{
    RowBox[{"xy12", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"tohyVec", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{".8", "\[ImaginaryI]"}], ",", "th"}], "}"}], ",", 
          "\"\<C2\>\""}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"th", ",", 
         RowBox[{"2.05", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
         RowBox[{
          RowBox[{"-", "2.05"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
         RowBox[{"-", ".1"}]}], "}"}]}], "]"}]}], ";"}],
   TraditionalForm], TraditionalForm], "\n", 
 FormBox[
  FormBox[
   RowBox[{
    RowBox[{"xyp", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "xy9", ",", "xy10", ",", "xy11", ",", "xy12", ",", "xy", ",", "xy1", 
         ",", "xy2", ",", "xy3", ",", "xy5", ",", "xy6", ",", "xy7", ",", 
         "xy8"}], "}"}], ",", "1"}], "]"}]}], ";"}],
   TraditionalForm], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"ListPlot", "[", 
   RowBox[{"xyp", ",", 
    RowBox[{"PlotJoined", "->", "True"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}]}], " ", "]"}], 
  TraditionalForm]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], 
    LineBox[{{2.097757540261134, -2.}, {
     2.060874277740826, -1.9614287620644733`}, {
     1.8747172944770798`, -1.7648130026185387`}, {
     1.7073231120107033`, -1.5858600848769453`}, {
     1.5570163931004446`, -1.4227789878907822`}, {
     1.4222928175836178`, -1.273937541227962}, {
     1.3018040266342925`, -1.1378460896629465`}, {
     1.194344127934967, -1.0131425842065551`}, {
     1.098837626700939, -0.8985789502618854}, {
     1.0143286617670149`, -0.7930085964742519}, {
     0.9399714390076914, -0.6953749392595265}, {
     0.8750217663452683, -0.6047008281604989}, {
     0.8188296056254007, -0.5200787661966688}, {
     0.7708325668167669, -0.44066182732944487`}, {
     0.7305502794226084, -0.36565518014168913`}, {
     0.6975795847713397, -0.29430813289774166`}, {
     0.6715905010690582, -0.2259066203682144}, {
     0.6523229208308383, -0.1597660572251694}, {
     0.6395840076375988, -0.0952244864820602}, {
     0.6332462661644053, -0.03163595440571863}, {0.6332462661644053, 
     0.031635954405719}, {0.6395840076375988, 0.09522448648206056}, {
     0.6523229208308383, 0.1597660572251698}, {0.6715905010690583, 
     0.22590662036821474`}, {0.69757958477134, 0.29430813289774205`}, {
     0.7305502794226085, 0.3656551801416895}, {0.7708325668167673, 
     0.44066182732944537`}, {0.8188296056254011, 0.5200787661966693}, {
     0.8750217663452685, 0.6047008281604993}, {0.9399714390076919, 
     0.6953749392595271}, {1.014328661767015, 0.7930085964742524}, {
     1.0988376267009394`, 0.8985789502618862}, {1.1943441279349676`, 
     1.013142584206556}, {1.3018040266342932`, 1.137846089662947}, {
     1.4222928175836187`, 1.273937541227963}, {1.5570163931004453`, 
     1.4227789878907828`}, {1.707323112010704, 1.5858600848769462`}, {
     1.874717294477081, 1.7648130026185398`}, {2.060874277740827, 
     1.9614287620644744`}, {2.097757540261134, 2.}}], 
    LineBox[{{1.8971344114637336`, 2.}, {1.764813002618539, 
     1.87471729447708}, {1.5858600848769455`, 1.7073231120107033`}, {
     1.4227789878907824`, 1.5570163931004448`}, {1.2739375412279623`, 
     1.4222928175836178`}, {1.1378460896629463`, 1.3018040266342923`}, {
     1.0131425842065551`, 1.194344127934967}, {0.8985789502618856, 
     1.098837626700939}, {0.793008596474252, 1.0143286617670149`}, {
     0.6953749392595265, 0.9399714390076914}, {0.6047008281604989, 
     0.8750217663452683}, {0.5200787661966688, 0.8188296056254009}, {
     0.4406618273294449, 0.7708325668167669}, {0.36565518014168924`, 
     0.7305502794226084}, {0.2943081328977417, 0.6975795847713397}, {
     0.22590662036821432`, 0.6715905010690582}, {0.15976605722516948`, 
     0.6523229208308383}, {0.09522448648206021, 0.6395840076375988}, {
     0.031635954405718744`, 0.6332462661644053}, {-0.031635954405718945`, 
     0.6332462661644053}, {-0.09522448648206056, 
     0.6395840076375988}, {-0.15976605722516982`, 
     0.6523229208308383}, {-0.22590662036821485`, 
     0.6715905010690583}, {-0.29430813289774194`, 
     0.6975795847713399}, {-0.36565518014168946`, 
     0.7305502794226085}, {-0.4406618273294453, 
     0.7708325668167672}, {-0.5200787661966693, 
     0.8188296056254011}, {-0.6047008281604995, 
     0.8750217663452686}, {-0.6953749392595269, 
     0.9399714390076916}, {-0.7930085964742523, 
     1.014328661767015}, {-0.8985789502618861, 
     1.0988376267009394`}, {-1.013142584206556, 
     1.1943441279349676`}, {-1.1378460896629472`, 
     1.3018040266342934`}, {-1.2739375412279628`, 
     1.4222928175836183`}, {-1.4227789878907826`, 
     1.557016393100445}, {-1.5858600848769462`, 
     1.707323112010704}, {-1.7648130026185398`, 
     1.874717294477081}, {-1.8971344114637338`, 2.}}], 
    LineBox[{{-2.0977575402611346`, 2.}, {-2.060874277740826, 
     1.961428762064473}, {-1.8747172944770796`, 
     1.7648130026185385`}, {-1.707323112010703, 
     1.585860084876945}, {-1.5570163931004444`, 
     1.4227789878907822`}, {-1.4222928175836176`, 
     1.273937541227962}, {-1.301804026634292, 
     1.137846089662946}, {-1.194344127934967, 
     1.0131425842065551`}, {-1.098837626700939, 
     0.8985789502618854}, {-1.0143286617670146`, 
     0.7930085964742518}, {-0.9399714390076913, 
     0.6953749392595264}, {-0.8750217663452682, 
     0.6047008281604986}, {-0.8188296056254007, 
     0.5200787661966687}, {-0.7708325668167669, 
     0.44066182732944476`}, {-0.7305502794226083, 
     0.36565518014168913`}, {-0.6975795847713397, 
     0.2943081328977416}, {-0.671590501069058, 
     0.2259066203682142}, {-0.6523229208308383, 
     0.15976605722516934`}, {-0.6395840076375988, 
     0.0952244864820601}, {-0.6332462661644053, 
     0.031635954405718626`}, {-0.6332462661644053, -0.03163595440571906}, \
{-0.6395840076375988, -0.09522448648206067}, {-0.6523229208308383, \
-0.15976605722516993`}, {-0.6715905010690583, -0.22590662036821496`}, \
{-0.69757958477134, -0.29430813289774205`}, {-0.7305502794226085, \
-0.3656551801416896}, {-0.7708325668167673, -0.4406618273294455}, \
{-0.8188296056254011, -0.5200787661966695}, {-0.8750217663452687, \
-0.6047008281604996}, {-0.9399714390076918, -0.695374939259527}, \
{-1.014328661767015, -0.7930085964742525}, {-1.0988376267009397`, \
-0.8985789502618863}, {-1.1943441279349678`, -1.0131425842065562`}, \
{-1.3018040266342936`, -1.1378460896629474`}, {-1.4222928175836185`, \
-1.273937541227963}, {-1.5570163931004453`, -1.422778987890783}, \
{-1.7073231120107042`, -1.5858600848769464`}, {-1.8747172944770811`, \
-1.76481300261854}, {-2.0608742777408278`, -1.9614287620644748`}, \
{-2.0977575402611346`, -2.}}], 
    LineBox[{{-1.8971344114637338`, -2.}, {-1.7648130026185387`, \
-1.8747172944770798`}, {-1.5858600848769453`, -1.707323112010703}, \
{-1.4227789878907822`, -1.5570163931004446`}, {-1.273937541227962, \
-1.4222928175836176`}, {-1.137846089662946, -1.3018040266342923`}, \
{-1.0131425842065551`, -1.194344127934967}, {-0.8985789502618855, \
-1.098837626700939}, {-0.7930085964742519, -1.0143286617670146`}, \
{-0.6953749392595264, -0.9399714390076913}, {-0.6047008281604987, \
-0.8750217663452682}, {-0.5200787661966687, -0.8188296056254007}, \
{-0.4406618273294448, -0.7708325668167669}, {-0.3656551801416892, \
-0.7305502794226083}, {-0.2943081328977416, -0.6975795847713397}, \
{-0.22590662036821424`, -0.671590501069058}, {-0.1597660572251694, \
-0.6523229208308383}, {-0.09522448648206014, -0.6395840076375988}, \
{-0.03163595440571867, -0.6332462661644053}, {
     0.03163595440571902, -0.6332462661644053}, {
     0.09522448648206064, -0.6395840076375988}, {
     0.1597660572251699, -0.6523229208308383}, {
     0.22590662036821493`, -0.6715905010690583}, {
     0.29430813289774205`, -0.69757958477134}, {
     0.3656551801416895, -0.7305502794226085}, {
     0.4406618273294454, -0.7708325668167673}, {
     0.5200787661966694, -0.8188296056254011}, {
     0.6047008281604996, -0.8750217663452687}, {
     0.695374939259527, -0.9399714390076918}, {
     0.7930085964742525, -1.014328661767015}, {
     0.8985789502618862, -1.0988376267009394`}, {
     1.013142584206556, -1.1943441279349678`}, {
     1.1378460896629474`, -1.3018040266342934`}, {
     1.2739375412279628`, -1.4222928175836185`}, {
     1.4227789878907828`, -1.5570163931004453`}, {
     1.5858600848769464`, -1.7073231120107042`}, {
     1.76481300261854, -1.8747172944770811`}, {1.8971344114637336`, -2.}}], 
    LineBox[{{2.236614928580492, -2.}, {
     2.1508984653931407`, -1.9043015014515343`}, {
     1.9709142303266285`, -1.698382437292616}, {
     1.8106555673243752`, -1.509461355412173}, {
     1.6685185538222564`, -1.335647470124177}, {
     1.5430806348152437`, -1.1752011936438014`}, {
     1.4330863854487743`, -1.0265167257081753`}, {
     1.3374349463048447`, -0.888105982187623}, {
     1.255169005630943, -0.7585837018395336}, {
     1.1854652182422678`, -0.6366535821482414}, {
     1.1276259652063807`, -0.5210953054937474}, {
     1.0810723718384547`, -0.4107523258028155}, {
     1.0453385141288605`, -0.30452029344714265`}, {
     1.020066755619076, -0.201336002541094}, {
     1.0050041680558035`, -0.10016675001984403`}, {1., 0.}, {
     1.0050041680558035`, 0.10016675001984403`}, {1.020066755619076, 
     0.201336002541094}, {1.0453385141288605`, 0.30452029344714265`}, {
     1.0810723718384547`, 0.4107523258028155}, {1.1276259652063807`, 
     0.5210953054937474}, {1.1854652182422678`, 0.6366535821482414}, {
     1.255169005630943, 0.7585837018395336}, {1.3374349463048447`, 
     0.888105982187623}, {1.4330863854487743`, 1.0265167257081753`}, {
     1.5430806348152437`, 1.1752011936438014`}, {1.6685185538222564`, 
     1.335647470124177}, {1.8106555673243752`, 1.509461355412173}, {
     1.9709142303266285`, 1.698382437292616}, {2.1508984653931407`, 
     1.9043015014515343`}, {2.236614928580492, 2.}}], 
    LineBox[{{1.7316593210667375`, 2.}, {1.698382437292616, 
     1.9709142303266285`}, {1.509461355412173, 1.8106555673243752`}, {
     1.335647470124177, 1.6685185538222564`}, {1.1752011936438014`, 
     1.5430806348152437`}, {1.0265167257081753`, 1.4330863854487743`}, {
     0.888105982187623, 1.3374349463048447`}, {0.7585837018395336, 
     1.255169005630943}, {0.6366535821482414, 1.1854652182422678`}, {
     0.5210953054937474, 1.1276259652063807`}, {0.4107523258028154, 
     1.0810723718384547`}, {0.30452029344714265`, 1.0453385141288605`}, {
     0.20133600254109393`, 1.020066755619076}, {0.10016675001984411`, 
     1.0050041680558035`}, {0., 1.}, {-0.10016675001984411`, 
     1.0050041680558035`}, {-0.20133600254109393`, 
     1.020066755619076}, {-0.30452029344714265`, 
     1.0453385141288605`}, {-0.4107523258028154, 
     1.0810723718384547`}, {-0.5210953054937474, 
     1.1276259652063807`}, {-0.6366535821482414, 
     1.1854652182422678`}, {-0.7585837018395337, 
     1.2551690056309432`}, {-0.8881059821876234, 
     1.337434946304845}, {-1.026516725708175, 
     1.4330863854487743`}, {-1.1752011936438014`, 
     1.5430806348152437`}, {-1.335647470124177, 
     1.6685185538222564`}, {-1.509461355412173, 
     1.8106555673243752`}, {-1.6983824372926164`, 
     1.970914230326629}, {-1.7316593210667375`, 2.}}], 
    LineBox[{{-2.236614928580492, 2.}, {-2.1508984653931407`, 
     1.9043015014515343`}, {-1.9709142303266285`, 
     1.698382437292616}, {-1.8106555673243752`, 
     1.509461355412173}, {-1.6685185538222564`, 
     1.335647470124177}, {-1.5430806348152437`, 
     1.1752011936438014`}, {-1.4330863854487743`, 
     1.0265167257081753`}, {-1.3374349463048447`, 
     0.888105982187623}, {-1.255169005630943, 
     0.7585837018395336}, {-1.1854652182422678`, 
     0.6366535821482414}, {-1.1276259652063807`, 
     0.5210953054937474}, {-1.0810723718384547`, 
     0.4107523258028154}, {-1.0453385141288605`, 
     0.30452029344714265`}, {-1.020066755619076, 
     0.20133600254109393`}, {-1.0050041680558035`, 
     0.10016675001984411`}, {-1., 
     0.}, {-1.0050041680558035`, -0.10016675001984411`}, {-1.020066755619076, \
-0.20133600254109393`}, {-1.0453385141288605`, -0.30452029344714265`}, \
{-1.0810723718384547`, -0.4107523258028154}, {-1.1276259652063807`, \
-0.5210953054937474}, {-1.1854652182422678`, -0.6366535821482414}, \
{-1.2551690056309432`, -0.7585837018395337}, {-1.337434946304845, \
-0.8881059821876234}, {-1.4330863854487743`, -1.026516725708175}, \
{-1.5430806348152437`, -1.1752011936438014`}, {-1.6685185538222564`, \
-1.335647470124177}, {-1.8106555673243752`, -1.509461355412173}, \
{-1.970914230326629, -1.6983824372926164`}, {-2.1508984653931402`, \
-1.9043015014515339`}, {-2.236614928580492, -2.}}], 
    LineBox[{{-1.7316593210667375`, -2.}, {-1.698382437292616, \
-1.9709142303266285`}, {-1.509461355412173, -1.8106555673243752`}, \
{-1.335647470124177, -1.6685185538222564`}, {-1.1752011936438014`, \
-1.5430806348152437`}, {-1.0265167257081753`, -1.4330863854487743`}, \
{-0.888105982187623, -1.3374349463048447`}, {-0.7585837018395336, \
-1.255169005630943}, {-0.6366535821482414, -1.1854652182422678`}, \
{-0.5210953054937474, -1.1276259652063807`}, {-0.4107523258028154, \
-1.0810723718384547`}, {-0.30452029344714265`, -1.0453385141288605`}, \
{-0.20133600254109393`, -1.020066755619076}, {-0.10016675001984411`, \
-1.0050041680558035`}, {0., -1.}, {
     0.10016675001984411`, -1.0050041680558035`}, {
     0.20133600254109393`, -1.020066755619076}, {
     0.30452029344714265`, -1.0453385141288605`}, {
     0.4107523258028154, -1.0810723718384547`}, {
     0.5210953054937474, -1.1276259652063807`}, {
     0.6366535821482414, -1.1854652182422678`}, {
     0.7585837018395337, -1.2551690056309432`}, {
     0.8881059821876234, -1.337434946304845}, {
     1.026516725708175, -1.4330863854487743`}, {
     1.1752011936438014`, -1.5430806348152437`}, {
     1.335647470124177, -1.6685185538222564`}, {
     1.509461355412173, -1.8106555673243752`}, {
     1.6983824372926164`, -1.970914230326629}, {1.7316593210667375`, -2.}}], 
    LineBox[{{2.345932147772406, -2.}, {
     2.217591119937156, -1.8487050536048548`}, {
     2.0435095416155193`, -1.6358273890217356`}, {
     1.889880093633647, -1.4393216347685194`}, {
     1.7551652008394962`, -1.257221095208774}, {
     1.6380165913067435`, -1.087703246936481}, {
     1.5372618023761777`, -0.9290714983492147}, {
     1.451892446255328, -0.779738209589142}, {
     1.381054117734505, -0.6382088029097003}, {
     1.3240378430122883`, -0.5030668044391652}, {
     1.2802729840474258`, -0.37295966763404936`}, {
     1.2493215274215206`, -0.24658523653868844`}, {
     1.230873700553516, -0.12267871337076715`}, {1.224744871391589, 0.}, {
     1.230873700553516, 0.12267871337076741`}, {1.2493215274215206`, 
     0.246585236538689}, {1.2802729840474258`, 0.3729596676340499}, {
     1.3240378430122886`, 0.5030668044391655}, {1.3810541177345053`, 
     0.6382088029097006}, {1.4518924462553282`, 0.7797382095891423}, {
     1.5372618023761782`, 0.9290714983492152}, {1.638016591306744, 
     1.0877032469364816`}, {1.7551652008394967`, 1.2572210952087748`}, {
     1.889880093633648, 1.43932163476852}, {2.0435095416155193`, 
     1.6358273890217363`}, {2.2175911199371563`, 1.8487050536048553`}, {
     2.345932147772406, 2.}}], 
    LineBox[{{1.5801748080570617`, 2.}, {1.4393216347685194`, 
     1.889880093633647}, {1.257221095208774, 1.7551652008394962`}, {
     1.087703246936481, 1.6380165913067435`}, {0.9290714983492147, 
     1.5372618023761777`}, {0.779738209589142, 1.451892446255328}, {
     0.6382088029097003, 1.381054117734505}, {0.5030668044391652, 
     1.3240378430122883`}, {0.37295966763404936`, 1.2802729840474258`}, {
     0.24658523653868844`, 1.2493215274215206`}, {0.12267871337076715`, 
     1.230873700553516}, {0., 1.224744871391589}, {-0.12267871337076741`, 
     1.230873700553516}, {-0.246585236538689, 
     1.2493215274215206`}, {-0.3729596676340499, 
     1.2802729840474258`}, {-0.5030668044391655, 
     1.3240378430122886`}, {-0.6382088029097006, 
     1.3810541177345053`}, {-0.7797382095891423, 
     1.4518924462553282`}, {-0.9290714983492152, 
     1.5372618023761782`}, {-1.0877032469364816`, 
     1.638016591306744}, {-1.2572210952087748`, 
     1.7551652008394967`}, {-1.43932163476852, 
     1.889880093633648}, {-1.580174808057062, 2.}}], 
    LineBox[{{-2.345932147772406, 2.}, {-2.217591119937156, 
     1.8487050536048548`}, {-2.0435095416155193`, 
     1.6358273890217356`}, {-1.889880093633647, 
     1.4393216347685194`}, {-1.7551652008394962`, 
     1.257221095208774}, {-1.6380165913067435`, 
     1.087703246936481}, {-1.5372618023761777`, 
     0.9290714983492147}, {-1.451892446255328, 
     0.779738209589142}, {-1.381054117734505, 
     0.6382088029097003}, {-1.3240378430122883`, 
     0.5030668044391651}, {-1.2802729840474258`, 
     0.37295966763404936`}, {-1.2493215274215206`, 
     0.24658523653868858`}, {-1.230873700553516, 
     0.1226787133707671}, {-1.224744871391589, 
     0.}, {-1.2308737005535162`, -0.12267871337076752`}, \
{-1.2493215274215206`, -0.246585236538689}, {-1.2802729840474258`, \
-0.3729596676340498}, {-1.3240378430122886`, -0.5030668044391656}, \
{-1.3810541177345053`, -0.6382088029097006}, {-1.4518924462553282`, \
-0.7797382095891424}, {-1.5372618023761782`, -0.9290714983492152}, \
{-1.638016591306744, -1.0877032469364816`}, {-1.7551652008394965`, \
-1.2572210952087743`}, {-1.8898800936336473`, -1.4393216347685198`}, \
{-2.04350954161552, -1.6358273890217367`}, {-2.2175911199371563`, \
-1.8487050536048553`}, {-2.345932147772406, -2.}}], 
    LineBox[{{-1.5801748080570617`, -2.}, {-1.4393216347685194`, \
-1.889880093633647}, {-1.257221095208774, -1.7551652008394962`}, \
{-1.087703246936481, -1.6380165913067435`}, {-0.9290714983492147, \
-1.5372618023761777`}, {-0.779738209589142, -1.451892446255328}, \
{-0.6382088029097003, -1.381054117734505}, {-0.5030668044391652, \
-1.3240378430122883`}, {-0.37295966763404936`, -1.2802729840474258`}, \
{-0.24658523653868844`, -1.2493215274215206`}, {-0.12267871337076715`, \
-1.230873700553516}, {0., -1.224744871391589}, {
     0.12267871337076741`, -1.230873700553516}, {
     0.246585236538689, -1.2493215274215206`}, {
     0.3729596676340499, -1.2802729840474258`}, {
     0.5030668044391655, -1.3240378430122886`}, {
     0.6382088029097006, -1.3810541177345053`}, {
     0.7797382095891423, -1.4518924462553282`}, {
     0.9290714983492152, -1.5372618023761782`}, {
     1.0877032469364816`, -1.638016591306744}, {
     1.2572210952087748`, -1.7551652008394967`}, {
     1.43932163476852, -1.889880093633648}, {1.580174808057062, -2.}}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-2, 2}, {-2, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["16. Appendix D. Loop Factors, Shapes, Duals.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". Shapes are the factors of protoloops. Many loop factors are tabulated. \
Techniques to find factors are discussed. "
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[TextData[{
 "D.1 Significance of & Tables for ",
 StyleBox["Loop Determinant Factors", "Text"],
 "."
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tEvery group, and many hoops, have more than one determinant factor. \
Non-abelian hoops have repeated factors [11], though they correspond to \
eigenvectors with different signs. The structure of the factors provides a \
significant indicator of loop inter-relationships (some factors are common to \
several hoops of the same length), as well as indicating whether polar duals \
can be defined. In many cases the structure can be found by ",
 StyleBox["fp",
  FontSlant->"Italic"],
 " and expressed compactly by ",
 StyleBox["abbrFactors",
  FontSlant->"Italic"],
 ". The following tables give these compact expressions for hoops of various \
sizes. Monosized hoops are omitted. The output lists linear, quadratic, cubic \
and quartic factors in order, with superscripts to show repeated factors, \
subscripts to show the number of instances. E.g. S4 has the determinant \
structure ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\<\"1\"\>", "2"], ",", 
     SuperscriptBox["\<\"2\"\>", "\<\"2\"\>"], ",", 
     SubsuperscriptBox["\<\"3\"\>", "2", "\<\"3\"\>"]}], "}"}], 
   TraditionalForm]],
  PageWidth->PaperWidth,
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontSize->9],
 ", indicating two different linear factors, one quadratic factor that is \
repeated, and two cubic factors, each repeated three times. Cubic factors are \
very rare for loops; only occuring in A4, S4, g3603 and their relatives."
}], "Text",
 PageWidth->WindowWidth],

Cell["Ex. D1. Loop factor structure.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "j", "]"}], ";", 
  RowBox[{"tst", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"ll", "=", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "6", ",", "8", ",", "12", ",", "16"}], 
    "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"j", "=", 
      RowBox[{"ll", "[", 
       RowBox[{"[", "n", "]"}], "]"}]}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"len", "=", 
         RowBox[{"abbrFactors", "[", 
          RowBox[{"test", "=", 
           RowBox[{"mp", "[", 
            RowBox[{"j", ",", "i"}], "]"}]}], "]"}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"len", "\[NotEqual]", 
           RowBox[{"{", "\"\<0\>\"", "}"}]}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"tst", ",", 
            RowBox[{"{", 
             RowBox[{"len", ",", 
              RowBox[{"id", "[", "test", "]"}]}], "}"}]}], "]"}]}], "]"}]}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"loop", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{"Length", "[", "ll", "]"}]}], "}"}]}], "]"}], ";", 
  RowBox[{"len", "=", 
   RowBox[{"Floor", "[", 
    RowBox[{
     RowBox[{"Length", "[", "tst", "]"}], "/", "5"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tst", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"tst", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", "len"}], "]"}], "]"}], ",", 
      RowBox[{"tst", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", 
         RowBox[{"2", "len"}]}], "]"}], "]"}], ",", 
      RowBox[{"tst", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", 
         RowBox[{"3", "len"}]}], "]"}], "]"}], ",", 
      RowBox[{"tst", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", 
         RowBox[{"4", "len"}]}], "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "len"}], "}"}]}], "]"}], "//", "tf"}]}], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell["The following cases needed tables from other files:-", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "2"], ",", "\<\"16\"\>", 
           ",", "\<\"2\"\>", ",", "\<\"4\"\>", ",", "\<\"8\"\>"}], "}"}], 
         ",", "\<\"C32\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"C8nC4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "6", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"P32\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"8\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"g3242\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "6"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "4", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"g3202\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"8\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"g3215\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "4", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"KnD4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"4\"\>"]}], "}"}], 
         ",", "\<\"g3243\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "6"], ",", 
           SubscriptBox["\<\"4\"\>", "4"]}], "}"}], ",", "\<\"C8C4\"\>"}], 
        "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubscriptBox["\<\"4\"\>", "2"], ",", 
           SubscriptBox["\<\"8\"\>", "2"]}], "}"}], ",", "\<\"C16C2\"\>"}], 
        "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "4", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"KnQ8\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"4\"\>"]}], "}"}], 
         ",", "\<\"g3244\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "6"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"C8pC4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubscriptBox["\<\"4\"\>", "2"], ",", 
           SuperscriptBox["\<\"8\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"g3217\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"g3230\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "16"], ",", 
           SubscriptBox["\<\"2\"\>", "8"]}], "}"}], ",", "\<\"C4KC2\"\>"}], 
        "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubscriptBox["\<\"4\"\>", "2"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"KnC8\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SuperscriptBox["\<\"2\"\>", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"8\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"D16\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"g3231\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "16"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "4", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"D4K\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"4\"\>"]}], "}"}], 
         ",", "\<\"g3206\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SuperscriptBox["\<\"2\"\>", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"8\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q16nC2\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q8C4a\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "16"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "4", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q8K\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"4\"\>"]}], "}"}], 
         ",", "\<\"g3207\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SuperscriptBox["\<\"2\"\>", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"8\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q32\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "3", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"g3233\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "16"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"PC2\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"4\"\>"]}], "}"}], 
         ",", "\<\"g3208\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubscriptBox["\<\"2\"\>", "12"]}], "}"}], ",", "\<\"C4C4C2\"\>"}], 
        "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "6", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"C4nD4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "16"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"4\"\>"]}], "}"}], 
         ",", "\<\"CL31C2\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"D4nC4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubscriptBox["\<\"2\"\>", "4"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "4", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"KnC4C2\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "6", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"C4nQ8\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "16"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"4\"\>"]}], "}"}], 
         ",", "\<\"CL4C2\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q8nC4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubscriptBox["\<\"2\"\>", "4"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "4", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"C4nC4C2\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubscriptBox["\<\"2\"\>", "4"], ",", 
           SubscriptBox["\<\"4\"\>", "4"]}], "}"}], ",", "\<\"C8K\"\>"}], 
        "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          SubscriptBox["\<\"1\"\>", "32"], "}"}], ",", "\<\"KKC2\"\>"}], 
        "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubscriptBox["\<\"4\"\>", "4"]}], "}"}], ",", "\<\"g3211\"\>"}], 
        "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubscriptBox["\<\"2\"\>", "4"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"C2C4pC4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubscriptBox["\<\"2\"\>", "4"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"C2C8pC2\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          SubsuperscriptBox["\<\"4\"\>", "2", "\<\"4\"\>"], "}"}], 
         ",", "\<\"CL5?\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubscriptBox["\<\"4\"\>", "2"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"C4nC8\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubscriptBox["\<\"2\"\>", "4"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"D4C4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q8nK\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          SuperscriptBox["\<\"8\"\>", "\<\"4\"\>"], "}"}], 
         ",", "\<\"CL41?\"\>"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "4"], ",", 
           SubscriptBox["\<\"2\"\>", "2"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q8pC4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubscriptBox["\<\"2\"\>", "4"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SuperscriptBox["\<\"4\"\>", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q8C4\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["\<\"1\"\>", "8"], ",", 
           SubsuperscriptBox["\<\"2\"\>", "2", "\<\"2\"\>"], ",", 
           SubsuperscriptBox["\<\"4\"\>", "2", "\<\"2\"\>"]}], "}"}], 
         ",", "\<\"Q16C2\"\>"}], "}"}], 
       RowBox[{"{", 
        RowBox[{"Null", ",", "Null"}], "}"}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[{{{{
        Subscript["1", 2], "16", "2", "4", "8"}, "C32"}, {{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "C8nC4"}, {{
        Subscript["1", 8], Subscript["2", 6]^"2"}, "P32"}, {{
        Subscript["1", 8], Subscript["2", 2]^"2", "8"^"2"}, "g3242"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 6], Subscript["2", 4]^"2"}, "g3202"}, {{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", "8"^"2"}, "g3215"}, {{
        Subscript["1", 8], Subscript["2", 4]^"2", "4"^"2"}, "KnD4"}, {{
        Subscript["1", 8], Subscript["2", 2]^"2", "4"^"4"}, "g3243"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 6], 
        Subscript["4", 4]}, "C8C4"}, {{
        Subscript["1", 4], 
        Subscript["2", 2], 
        Subscript["4", 2], 
        Subscript["8", 2]}, "C16C2"}, {{
        Subscript["1", 8], Subscript["2", 4]^"2", "4"^"2"}, "KnQ8"}, {{
        Subscript["1", 8], Subscript["2", 2]^"2", "4"^"4"}, "g3244"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 6], Subscript["4", 2]^"2"}, "C8pC4"}, {{
        Subscript["1", 4], 
        Subscript["2", 2], 
        Subscript["4", 2], "8"^"2"}, "g3217"}, {{
        Subscript["1", 8], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "g3230"}, {{
        Subscript["1", 16], 
        Subscript["2", 8]}, "C4KC2"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", 
        Subscript["4", 2], "4"^"2"}, "KnC8"}, {{
        Subscript["1", 4], "2"^"2", "4"^"2", "8"^"2"}, "D16"}, {{
        Subscript["1", 8], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "g3231"}, {{
        Subscript["1", 16], Subscript["2", 4]^"2"}, "D4K"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", "4"^"4"}, "g3206"}, {{
        Subscript["1", 4], "2"^"2", "4"^"2", "8"^"2"}, "Q16nC2"}, {{
        Subscript["1", 8], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "Q8C4a"}, {{
        Subscript["1", 16], Subscript["2", 4]^"2"}, "Q8K"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", "4"^"4"}, "g3207"}, {{
        Subscript["1", 4], "2"^"2", "4"^"2", "8"^"2"}, "Q32"}, {{
        Subscript["1", 8], Subscript["4", 3]^"2"}, "g3233"}, {{
        Subscript["1", 16], Subscript["4", 2]^"2"}, "PC2"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", "4"^"4"}, "g3208"}, {{
        Subscript["1", 8], 
        Subscript["2", 12]}, "C4C4C2"}, {{
        Subscript["1", 8], Subscript["2", 6]^"2"}, "C4nD4"}, {{
        Subscript["1", 16], "4"^"4"}, "CL31C2"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "D4nC4"}, {{
        Subscript["1", 8], 
        Subscript["2", 4], Subscript["2", 4]^"2"}, "KnC4C2"}, {{
        Subscript["1", 8], Subscript["2", 6]^"2"}, "C4nQ8"}, {{
        Subscript["1", 16], "4"^"4"}, "CL4C2"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "Q8nC4"}, {{
        Subscript["1", 8], 
        Subscript["2", 4], Subscript["2", 4]^"2"}, "C4nC4C2"}, {{
        Subscript["1", 8], 
        Subscript["2", 4], 
        Subscript["4", 4]}, "C8K"}, {{
        Subscript["1", 32]}, "KKC2"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", 
        Subscript["4", 4]}, "g3211"}, {{
        Subscript["1", 8], 
        Subscript["2", 4], Subscript["4", 2]^"2"}, "C2C4pC4"}, {{
        Subscript["1", 8], 
        Subscript["2", 4], Subscript["4", 2]^"2"}, "C2C8pC2"}, {{
       Subscript["4", 2]^"4"}, "CL5?"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", 
        Subscript["4", 2], "4"^"2"}, "C4nC8"}, {{
        Subscript["1", 8], 
        Subscript["2", 4], Subscript["2", 2]^"2", "4"^"2"}, "D4C4"}, {{
        Subscript["1", 8], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "Q8nK"}, {{"8"^"4"}, "CL41?"}}, {{{
        Subscript["1", 4], 
        Subscript["2", 2], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "Q8pC4"}, {{
        Subscript["1", 8], 
        Subscript["2", 4], Subscript["2", 2]^"2", "4"^"2"}, "Q8C4"}, {{
        Subscript["1", 8], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "Q16C2"}, {Null, Null}}}, TableDepth -> 2]], 
  TraditionalForm]], "Output",
 PageWidth->WindowWidth,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 FontSize->9],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "2"], ",", "2", ",", 
           SubsuperscriptBox["2", "2", "2"], ",", 
           SubsuperscriptBox["6", "2", "2"]}], "}"}], ",", "Q36"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "4"], ",", 
           SubsuperscriptBox["2", "2", "2"], ",", 
           SubsuperscriptBox["6", "2", "2"]}], "}"}], ",", "D18"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "2"], ",", "2", ",", 
           SubsuperscriptBox["2", "8", "2"]}], "}"}], ",", "C3nQ12"}], "}"}], 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "4"], ",", 
           SubsuperscriptBox["2", "4", "2"], ",", 
           SuperscriptBox["4", "4"]}], "}"}], ",", "D3D3"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "4"], ",", 
           SubsuperscriptBox["2", "8", "2"]}], "}"}], ",", "E18C2"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "2"], ",", "12", ",", 
           SubscriptBox["2", "3"], ",", "4", ",", 
           SubscriptBox["6", "2"]}], "}"}], ",", "C36"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "4"], ",", 
           SubscriptBox["2", "4"], ",", 
           SubscriptBox["6", "4"]}], "}"}], ",", "C18C2"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "2"], ",", 
           SubscriptBox["2", "9"], ",", 
           SubscriptBox["4", "4"]}], "}"}], ",", "C12C3"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", 
           SubscriptBox["2", "4"], ",", 
           SuperscriptBox["3", "3"], ",", 
           SuperscriptBox["6", "3"]}], "}"}], ",", "A4C3"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "4"], ",", 
           SubscriptBox["2", "16"]}], "}"}], ",", "C6C6"}], "}"}]},
      {
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", 
           SuperscriptBox["3", "3"], ",", "6", ",", 
           SuperscriptBox["6", "3"]}], "}"}], ",", "g3603"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "2"], ",", 
           SubscriptBox["2", "3"], ",", 
           SubsuperscriptBox["2", "2", "2"], ",", "4", ",", 
           SubsuperscriptBox["4", "2", "2"]}], "}"}], ",", "Q12C3"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "2"], ",", "2", ",", 
           SubsuperscriptBox["4", "2", "4"]}], "}"}], ",", "g3609"}], "}"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["1", "4"], ",", 
           SubscriptBox["2", "4"], ",", 
           SubsuperscriptBox["2", "2", "2"], ",", 
           SubsuperscriptBox["4", "2", "2"]}], "}"}], ",", "D6C3"}], "}"}], 
       RowBox[{"{", "}"}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[{{{{
        Subscript["1", 2], "2", Subscript["2", 2]^"2", Subscript["6", 2]^"2"},
        "Q36"}, {{
        Subscript["1", 4], Subscript["2", 2]^"2", Subscript["6", 2]^"2"}, 
       "D18"}, {{
        Subscript["1", 2], "2", Subscript["2", 8]^"2"}, "C3nQ12"}, {{
        Subscript["1", 4], Subscript["2", 4]^"2", "4"^"4"}, "D3D3"}, {{
        Subscript["1", 4], Subscript["2", 4]^"2", "4"^"4"}, "D3D3"}}, {{{
        Subscript["1", 2], "12", 
        Subscript["2", 3], "4", 
        Subscript["6", 2]}, "C36"}, {{
        Subscript["1", 4], 
        Subscript["2", 4], 
        Subscript["6", 4]}, "C18C2"}, {{
        Subscript["1", 2], 
        Subscript["2", 9], 
        Subscript["4", 4]}, "C12C3"}, {{"1", 
        Subscript["2", 4], "3"^"3", "6"^"3"}, "A4C3"}, {{"1", 
        Subscript["2", 4], "3"^"3", "6"^"3"}, "A4C3"}}, {{{
       "1", "2", "3"^"3", "6", "6"^"3"}, "g3603"}, {{
        Subscript["1", 2], 
        Subscript["2", 3], Subscript["2", 2]^"2", "4", Subscript["4", 2]^"2"},
        "Q12C3"}, {{
        Subscript["1", 2], "2", Subscript["4", 2]^"4"}, "g3609"}, {{
        Subscript["1", 4], 
        Subscript["2", 4], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "D6C3"}, {{
        Subscript["1", 4], 
        Subscript["2", 4], Subscript["2", 2]^"2", Subscript["4", 2]^"2"}, 
       "D6C3"}}}, TableDepth -> 2]], TraditionalForm]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False,
 FontSize->10,
 FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["D.2 Creating Shapes and Duals.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[BoxData[
 FormBox[
  RowBox[{"?", "hoopShape"}], TraditionalForm]], "Input"],

Cell[TextData[{
 "\tKnown shapes are stored as ",
 StyleBox["sh[\"mnemonic\"]",
  FontSlant->"Italic"],
 ", which also defines the lists ",
 StyleBox["gi",
  FontSlant->"Italic"],
 ", together with (where polar duals occur) ",
 StyleBox["gp",
  FontSlant->"Italic"],
 ", and (where known) ",
 StyleBox["plex",
  FontSlant->"Italic"],
 ". ",
 StyleBox["hoopShape",
  FontSlant->"Italic"],
 " will attempt to create a shape if it is not in the database. ",
 StyleBox["gi",
  FontSlant->"Italic"],
 " contains the location of the 1's in the protoloop, with signs attached \
(see below about \[ImaginaryI] & \[DoubleStruckCapitalJ] signed tables), \
followed by the multiplicity ",
 StyleBox["m",
  FontSlant->"Italic"],
 " of the sizes in the determinant. ",
 StyleBox["hoopIn",
  FontSlant->"Italic"],
 StyleBox["verse",
  FontSlant->"Italic"],
 " needs the location and the sign of the 1's to define the Cramer's method \
",
 Cell[BoxData[
  SubscriptBox["\[PartialD]", "variable"]],
  FontSlant->"Italic"],
 StyleBox["[",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["size", "m"],
    FontSlant->"Italic"], TraditionalForm]]],
 StyleBox["]/",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["size", "m"],
    FontSlant->"Italic"], TraditionalForm]]],
 " terms. The exponent becomes a multiplier for the size. Powers do not \
result in the usual sets of partial fractions for repeated factors, because \
of the form of the derivation expression; a single partial fraction is \
created, weighted by the multiplicity. ",
 StyleBox["gp",
  FontSlant->"Italic"],
 " is a list used by ",
 StyleBox["hoopPo",
  FontSlant->"Italic"],
 StyleBox["wer",
  FontSlant->"Italic"],
 " to distinguish between sizes (1) and angles (0.) in polar forms. Finally, \
the sizes (stripped of multiplicities) are provided. Example D.2 demonstrated \
the process for the ",
 StyleBox["Q12r",
  FontSlant->"Italic"],
 " loop, which is a signed table obtained from ",
 StyleBox["Q12, ca[12,5]",
  FontSlant->"Italic"],
 ".",
 StyleBox[" ",
  FontSlant->"Italic"],
 "In this case,",
 StyleBox[" frag",
  FontSlant->"Italic"],
 " fails with the second size, but the correct fragmentation was deduced by \
inspection of the diagnostic output given by frag[ff[[2]],1]."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["Example D.2 Shape Creation for Q12r", "Subsubsection",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"ts", "[", 
    RowBox[{"ca", "[", 
     RowBox[{"12", ",", "5"}], "]"}], "]"}]}], ";", 
  RowBox[{"{", 
   RowBox[{"\"\<Q12r Table\>\"", ",", 
    RowBox[{"tst", "//", "tf"}], ",", "\"\<\\nFactors\>\"", ",", 
    RowBox[{"ff", "=", 
     RowBox[{"fa", "[", "tst", "]"}]}], ",", 
    "\"\<\\nFragmented first size\>\"", ",", 
    RowBox[{"frag", "[", 
     RowBox[{"ff", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Q12r Table\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6"},
        {"2", 
         RowBox[{"-", "1"}], "4", 
         RowBox[{"-", "3"}], "6", 
         RowBox[{"-", "5"}]},
        {"3", 
         RowBox[{"-", "6"}], "5", "2", 
         RowBox[{"-", "1"}], "4"},
        {"4", "5", "6", 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "2"}], 
         RowBox[{"-", "3"}]},
        {"5", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "6"}], 
         RowBox[{"-", "3"}], "2"},
        {"6", "3", 
         RowBox[{"-", "2"}], "5", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nFactors\"\>", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"2", " ", "b", " ", "d"}], "+", 
      SuperscriptBox["d", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "e"}], "-", 
      RowBox[{"2", " ", "c", " ", "e"}], "+", 
      SuperscriptBox["e", "2"], "+", 
      RowBox[{"2", " ", "b", " ", "f"}], "-", 
      RowBox[{"2", " ", "d", " ", "f"}], "+", 
      SuperscriptBox["f", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"], "+", 
       RowBox[{"a", " ", "c"}], "+", 
       SuperscriptBox["c", "2"], "+", 
       RowBox[{"b", " ", "d"}], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"a", " ", "e"}], "+", 
       RowBox[{"c", " ", "e"}], "+", 
       SuperscriptBox["e", "2"], "-", 
       RowBox[{"b", " ", "f"}], "+", 
       RowBox[{"d", " ", "f"}], "+", 
       SuperscriptBox["f", "2"]}], ")"}], "2"]}], 
   ",", "\<\"\\nFragmented first size\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "c", "+", "e"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "d", "+", "f"}], ")"}], "2"]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"frag", "[", 
  RowBox[{
   RowBox[{"ff", "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"i,p1,res\"\>", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "c", ",", "e"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "c"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"c", "-", "e"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "e"}], ")"}], "2"]}], "}"}]}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"i,p1,res\"\>", ",", "2", ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "d", ",", "f"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "c"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"c", "-", "e"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "e"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "d"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"d", "-", "f"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "f"}], ")"}], "2"]}], "}"}]}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"i,p1,res\"\>", ",", "3", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "c"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"c", "-", "e"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "e"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "d"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"d", "-", "f"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "f"}], ")"}], "2"]}], "}"}]}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"i,p1,res\"\>", ",", "4", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "c"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"c", "-", "e"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "e"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "d"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"d", "-", "f"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "f"}], ")"}], "2"]}], "}"}]}], "}"}]], "Print"],

Cell[BoxData["\<\"Frag2 failed to correct an error\"\>"], "Print"]
}, Open  ]],

Cell[BoxData["$Aborted"], "Output"]
}, Open  ]],

Cell["\<\
The signs in the proposed fragments can be corrected by inspection:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"a", " ", "c"}], "+", 
      SuperscriptBox["c", "2"], "+", 
      RowBox[{"b", " ", "d"}], "+", 
      SuperscriptBox["d", "2"], "-", 
      RowBox[{"a", " ", "e"}], "+", 
      RowBox[{"c", " ", "e"}], "+", 
      SuperscriptBox["e", "2"], "-", 
      RowBox[{"b", " ", "f"}], "+", 
      RowBox[{"d", " ", "f"}], "+", 
      SuperscriptBox["f", "2"]}], ")"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"c", "+", "e"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "+", "d"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "+", "f"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "f"}], ")"}], "2"]}], ")"}], "/", "2"}]}], "]"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe 1's are in columns 1, 2, 5, 4, 3, & 6, and all but the first are \
negated; the size multiplicities are 1 & 2; this fixes ",
 StyleBox["gi",
  FontSlant->"Italic"],
 ".\n As there are no shapes larger than quadratics, a polar form exists. It \
is created below, and has alternating sizes and angles, so ",
 StyleBox["gp",
  FontSlant->"Italic"],
 " can be specified. (The following cells are copied from the database, and \
are made non-evaluatable here.)"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", "\"\<Q12r\>\"", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"gi", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "5"}], ",", 
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "6"}], ",", "1", ",", "2"}], "}"}]}], ";", 
      RowBox[{"gp", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.", ",", "1", ",", "0.", ",", "1", ",", "0."}], 
        "}"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c", "+", "e"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "d", "+", "f"}], ")"}], "2"]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"c", "+", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "+", "d"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", "+", "f"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "f"}], ")"}], "2"]}], ")"}], "/", "2"}]}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[TextData[{
 "\tThe first size gives a four-phase contribution to the polar form ",
 StyleBox["toPol",
  FontSlant->"Italic"],
 ", whilst the repeated second size has to be split into two three-phase \
contributions. The ",
 StyleBox["toVec",
  FontSlant->"Italic"],
 " elements relate directly to the (signed) elements in the ArcTan \
expressions",
 ":-"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[{
 RowBox[{
  RowBox[{"toPol", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}], 
     "}"}], ",", "\"\<Q12r\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "c", "+", "e"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "d", "+", "f"}], ")"}], "2"]}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"b", "+", "f"}], "\[Equal]", "d"}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"a", "-", "c", "+", "e"}], ",", 
          RowBox[{"b", "-", "d", "+", "f"}]}], "]"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "+", "e"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "e"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"-", "e"}]}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "c", "-", "e"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{"c", "+", "e"}], ")"}]}]}], "]"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "d"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "+", "f"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "f"}], ")"}], "2"]}], ")"}], "/", "2"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"d", "\[Equal]", 
         RowBox[{"-", "f"}]}], ",", "0", ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", "b"}], "+", "d", "-", "f"}], ",", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], 
           RowBox[{"(", 
            RowBox[{"d", "+", "f"}], ")"}]}]}], "]"}]}], "]"}]}], "}"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Epsilon]\[Epsilon]_", ",", "\[Sigma]_", ",", "\[Eta]\[Eta]_", ",", 
      "\[Chi]_", ",", "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", 
    "\"\<Q12r\>\""}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Epsilon]", "=", 
       RowBox[{
        SqrtBox["\[Epsilon]\[Epsilon]"], "/", "3"}]}], ",", 
      RowBox[{"\[Eta]", "=", 
       RowBox[{"2", 
        RowBox[{
         SqrtBox["\[Eta]\[Eta]"], "/", "3"}]}]}], ",", 
      RowBox[{"\[Kappa]", "=", 
       RowBox[{"2", 
        RowBox[{
         SqrtBox["\[Kappa]\[Kappa]"], "/", "3"}]}]}]}], "}"}], ",", 
    RowBox[{"{", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], " ", ",", 
      "\[IndentingNewLine]", "  ", 
      RowBox[{
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Epsilon]"}], " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Epsilon]"}], " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "-", 
       RowBox[{"\[Kappa]", "  ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", "  ", 
      RowBox[{
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", 
          RowBox[{"4", " ", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", "  ", 
      RowBox[{
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Kappa]", "  ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", 
          RowBox[{"4", " ", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}]}]}]}], "}"}]}], 
   "]"}]}]}], "Input",
 Editable->False,
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell["\<\
Finally, the hoopTest procedure confirms that the sizes are conserved on \
multiplication, that the inverse provides division, that the polar-vector \
interconversions are correct, and that powers and roots are correct.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTest", "[", "\"\<Q12r\>\"", "]"}], TraditionalForm]], "Input",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
D.3 Shapes for \[ImaginaryI], \[DoubleStruckCapitalJ]-signed Conservative \
Division Algebra.\
\>", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["\tP4",
  FontSlant->"Italic"],
 " has \[ImaginaryI] & -\[ImaginaryI] as signs in the multiplication table, \
and the correct shape was obtained by the standard procedure. On 20/9/03 I \
found two more \[ImaginaryI]-signed tables with Det conservation & division, \
C12c & g2401c. Their shapes did not match the form for \[PlusMinus]signed \
tables, but were found by experiment."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example D.3 C12c", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["{tf[C12c], id[co[C12c, C4]], fa[C12c]}", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", "3", 
         RowBox[{"-", "\[ImaginaryI]"}]},
        {"3", 
         RowBox[{"-", "\[ImaginaryI]"}], 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"C3C4\"\>", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", 
      RowBox[{"\[ImaginaryI]", " ", "b"}], "-", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      RowBox[{"\[ImaginaryI]", " ", "a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"a", " ", "c"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "I found that the \[ImaginaryI] & -\[ImaginaryI] terms have to be exchanged \
in ",
 StyleBox["gi ",
  FontSlant->"Italic"],
 "& ",
 StyleBox["a-\[ImaginaryI] b-c",
  FontSlant->"Italic"],
 " to give the correct shape:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
sh[\"C12c\"]:=Module[{},gi={1,3*I,2*I,1,1};gp=.;{a+I*b-c,((a-I*b)^2+(a+c)^2+(\
c+I*b)^2)/2}]; \
\>", "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell["I then investigated g2401c:- ", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
{tst = ts[mp[{24, 1}], -4];id[tst],tst//tf,
  \"\\nfa=\", fa[tst]}\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"g2401c\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6"},
        {"2", "3", "1", "6", "4", "5"},
        {"3", "1", "2", "5", "6", "4"},
        {"4", "5", "6", "\[ImaginaryI]", 
         RowBox[{"2", " ", "\[ImaginaryI]"}], 
         RowBox[{"3", " ", "\[ImaginaryI]"}]},
        {"5", "6", "4", 
         RowBox[{"3", " ", "\[ImaginaryI]"}], "\[ImaginaryI]", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]},
        {"6", "4", "5", 
         RowBox[{"2", " ", "\[ImaginaryI]"}], 
         RowBox[{"3", " ", "\[ImaginaryI]"}], "\[ImaginaryI]"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nfa=\"\>", ",", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"a", " ", "b"}], "+", 
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"a", " ", "c"}], "-", 
       RowBox[{"b", " ", "c"}], "+", 
       SuperscriptBox["c", "2"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["d", "2"]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "d", " ", "e"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["e", "2"]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "d", " ", "f"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "e", " ", "f"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["f", "2"]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["d", "2"]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "d", " ", "e"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["e", "2"]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "d", " ", "f"}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "e", " ", "f"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["f", "2"]}]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Here, the \[ImaginaryI] & -\[ImaginaryI] terms are exchanged in ",
 StyleBox["gi ",
  FontSlant->"Italic"],
 "& both sizes to give the correct shape. The plex relates directly to the \
sizes as the difference of the first two and as sum of all three elements:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
sh[\"g2401c\"]:=Module[{},gi={1,3,2,-4*I,-5*I,-6*I,2,1};gp=.;{plex={a,c,b,-d,-\
e,-f};((a-b)^2+(a-c)^2+(b-c)^2-I*((d-e)^2+(d-f)^2+(e-f)^2))/2, \
(a+b+c)^2-I*(d+e+f)^2}]\
\>", "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[TextData[{
 " On 21/9/03 I found inverses of C3C3J & C9J by Solve, and constructed \
suitable shapes. The ",
 StyleBox["gi",
  FontSlant->"Italic"],
 " elements \[DoubleStruckCapitalJ]\[LeftRightArrow]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], TraditionalForm]]],
 ", \[ImaginaryI]\[LeftRightArrow]-\[ImaginaryI], so they are divisors rather \
than multipliers. This is equivalent to using the conjugate."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
id[C3C3j];mi=minsign[C3C3j];
Simplify[Solve[Chop[hoopTimes[{p,q,r},{a,b,c}]/.mi]=={1,0,0},{p,q,r}]]/.mi\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "+", 
       SuperscriptBox["c", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", 
        "\[DoubleStruckCapitalJ]"}]}]]}], ",", 
    RowBox[{"q", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "b"}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "+", 
       SuperscriptBox["c", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", 
        "\[DoubleStruckCapitalJ]"}]}]]}], ",", 
    RowBox[{"r", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "c"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       SuperscriptBox["b", "3"], "+", 
       SuperscriptBox["c", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", 
        "\[DoubleStruckCapitalJ]"}]}]]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
id[C9J];mi=minsign[C9J];Simplify[Solve[Chop[hoopTimes[{p,q,r},{a,b,c}]/.mi]=={\
1,0,0},{p,q,r}]]/.mi\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"b", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c", "3"], "+", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]]}], ",", 
    RowBox[{"q", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "b"}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", "\[DoubleStruckCapitalJ]"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c", "3"], "+", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]]}], ",", 
    RowBox[{"r", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "c"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c", "3"], "+", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]]}]}], "}"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
id[C9J];mi=minsign[C9J];Simplify[Solve[Chop[hoopTimes[{p,q,r},{a,b,c}]/.mi]=={\
1,0,0},{p,q,r}]]/.mi\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
       "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]]}], ",", 
    RowBox[{"q", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "b"}], "+", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", "\[DoubleStruckCapitalJ]"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
       "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]]}], ",", 
    RowBox[{"r", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"a", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "-", 
       RowBox[{
       "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], 
       "+", 
       RowBox[{"\[DoubleStruckCapitalJ]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          RowBox[{
           SuperscriptBox["c", "3"], " ", "\[DoubleStruckCapitalJ]"}]}], 
         ")"}]}]}]]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["The C4C3c shape was found in the same way:-", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
id[C4C3c];mi=minsign[C4C3c];Simplify[Solve[Chop[hoopTimes[{p,q,r},{a,b,c}]/.\
mi]=={1,0,0},{p,q,r}]]/.mi\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       RowBox[{"b", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          SuperscriptBox["c", "3"]}], ")"}]}]}]]}], ",", 
    RowBox[{"q", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", "\[ImaginaryI]", " ", "a", " ", "b", " ", "c"}], 
        "+", 
        SuperscriptBox["c", "3"]}]]}]}], ",", 
    RowBox[{"r", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["b", "2"]}], "-", 
       RowBox[{"a", " ", "c"}]}], 
      RowBox[{
       SuperscriptBox["a", "3"], "+", 
       RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "+", 
          SuperscriptBox["c", "3"]}], ")"}]}]}]]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
sh[\"C4C3c\"]:=Module[{},gi={1,-3,-2,1,1};{a+\[ImaginaryI] b+\[ImaginaryI] \
c,((a-\[ImaginaryI] b)^2+(a-\[ImaginaryI] c)^2-(b-c)^2)/2}];\
\>", "Input",
 PageWidth->WindowWidth],

Cell["\<\
\t The conserved properties are conjugate to the determinant factor. This \
corresponds to Frobenius's use of the inverse group table in his development \
of group characters.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "D.4 Finding ",
 StyleBox["Loop Determinant Factors", "Text"],
 "."
}], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tFor loops with fewer than 11 elements, the symbolic determinant can be \
calculated and factorised by ",
 StyleBox["fa[G]",
  FontSlant->"Italic"],
 ", which is an abbreviation for ",
 StyleBox["Factor[ Det[ gmap[ G,alph]]]",
  FontSlant->"Italic"],
 ". The time taken increases roughly as ",
 StyleBox["m",
  FontSlant->"Italic"],
 "!; it is greatly reduced if integers replace most of the symbols, and \
becomes feasible (but much less informative) for groups with up to at least \
72 elements if all but one of the elements are integers."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\t",
 StyleBox["fa",
  FontSlant->"Italic"],
 " gives the result as symmetric polynomials, which can be voluminous. \
\"Fragmentation\" is a generalization of factorization; it attempts to \
express symmetric polynomials as signed sums of powers of smaller \
\"fragment\" polynomials. A number of these were found by trial and error, \
including the cubic and quartic factors of A4 and C3C4. Plex-conjugation led \
to other quartics, but no general approach has been found. The most important \
factors are the quadratics, because they lead to polar forms; ",
 StyleBox["frag2",
  FontSlant->"Italic"],
 " was developed to help with their fragmentation."
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["frag2",
  FontSlant->"Italic"],
 " heuristically converts quadratic factors of loop tables into signed sums \
of squared terms, putting them into ",
 StyleBox["res",
  FontSlant->"Italic"],
 ", which is initialized as ",
 StyleBox["{}",
  FontSlant->"Italic"],
 ". ",
 StyleBox["polsort ",
  FontSlant->"Italic"],
 "is used to set up a matrix of coefficients for the expanded polynomial; if \
this is not a matrix the polynomial is rejected as asymmetrical. Polynomials \
higher than quadratic are returned unchanged. An ",
 StyleBox["addnew",
  FontSlant->"Italic"],
 " function is defined; it adds new terms to ",
 StyleBox["res",
  FontSlant->"Italic"],
 ", ignoring any already present. Factors of length = 1 ( and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["a", "2"]}], "-", 
   SuperscriptBox["b", "2"]}]],
  PageWidth->WindowWidth,
  InitializationCell->True],
 ") are passed through unchanged. Non-ternary terms are created with a \
positive first component. Ternary terms have a divisor ",
 StyleBox["d",
  FontSlant->"Italic"],
 "=2 and are handled next, with various adjustments. The result is compared \
with the original, and errors are fiddled. Incorrect results can be reported, \
so that manual correction can be attempted, as in Example D.2 (above)."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tAs linear factors are always signed sums of loop elements, they can be \
found for quite large groups after using ",
 StyleBox["Factor[Det[gmap[G,pow2]]]",
  FontSlant->"Italic"],
 " (abbreviated to ",
 StyleBox["fp[G,pow2]",
  FontSlant->"Italic"],
 "), which maps ",
 StyleBox["pow2",
  FontSlant->"Italic"],
 "= {a,1,2,4,8...} onto the table. The factors appear as \[PlusMinus]a\
\[PlusMinus]integer. ",
 StyleBox["linearFactor[f_,l_]",
  FontSlant->"Italic"],
 " then adds or subtracts decreasing powers of 2 from the integer and builds \
up the signed elements in the factor. Example D4 finds the two linear sizes \
for C3C4:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Ex. D4. C3C4 linearFactor identification.", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["fp[mp[\"C3C4\"], pow2]", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1593"}], "+", "a"}], ")"}]}], " ", 
  RowBox[{"(", 
   RowBox[{"2047", "+", "a"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"599479", "-", 
    RowBox[{"1171", " ", "a"}], "+", 
    SuperscriptBox["a", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"3160537", "-", 
    RowBox[{"442", " ", "a"}], "+", 
    SuperscriptBox["a", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"361839", "+", 
    RowBox[{"909", " ", "a"}], "+", 
    SuperscriptBox["a", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"203771700409", "+", 
    RowBox[{"113614798", " ", "a"}], "+", 
    RowBox[{"156399", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    RowBox[{"250", " ", 
     SuperscriptBox["a", "3"]}], "+", 
    SuperscriptBox["a", "4"]}], ")"}]}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["{j=.;linearFactor[-1593+a,12],linearFactor[2047+a,12]}", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", "h", 
    "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h", 
    "+", "i", "+", "j", "+", "k", "+", "l"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "\tQuadratic factors of small groups can be found explicitly, and ",
 StyleBox["frag",
  FontSlant->"Italic"],
 " will then help to simplify them."
}], "Text",
 PageWidth->WindowWidth],

Cell[" Ex. D4.1. Quadratic Factor identification.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["frag[fa[C3C3]]", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h", 
    "+", "i"}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "e", "-", "f", "+", "g", "-", 
         "h"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "b"}], "+", "c", "-", "d", "+", "e", "+", "g", "-", 
         "i"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "d", "+", "f", "+", "h", "-", "i"}], 
        ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "-", "d", "+", "f", "+", "g", "-", "h"}], 
        ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "-", "e", "+", "f", "+", "g", "-", 
         "i"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "e", "+", "h", "-", 
         "i"}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h"}], 
        ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c", "+", "d", "-", "f", "+", "g", "-", "i"}], 
        ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i"}], 
        ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], 
        ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], 
        ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "+", "e", "+", "f", "-", "g", "-", "h", "-", "i"}], 
        ")"}], "2"]}], ")"}]}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["fC4iC4c=frag[fa[mp[\"C4iC4c\"]]]", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"e", "-", "g"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"f", "-", "h"}], ")"}], "2"]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}]}], 
  "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tWhen factors for the determinant of a folded table such as C4iC4c (in the \
previous example) have been found, they can be \"unfolded\" to give the \
larger factors of the un-folded table (linearFactor giving the linear \
factors). C4iC4c is created by folding C4iC4 so the shape of C4iC4 was found \
in this way; :-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gd", "[", "\"\<C4iC4c\>\"", "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", ",", "10", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C4iC4c\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       SubscriptBox["2", "2"], ",", "16"}], "}"}], ",", "0", 
     ",", "\<\"ts[co[C4,C4,2]]\"\>", ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "24"}], "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
fC4iC4c/.{a->a-i,b->b-j,c->c-k,d->d-l,e->e-m,f->f-n,g->g-o,h->h-p}\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "c", "-", "i", "+", "k"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "d", "-", "j", "+", "l"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"e", "-", "g", "-", "m", "+", "o"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"f", "-", "h", "-", "n", "+", "p"}], ")"}], "2"]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
      "a", "-", "b", "+", "c", "-", "d", "-", "i", "+", "j", "-", "k", "+", 
       "l"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
      "e", "-", "f", "+", "g", "-", "h", "-", "m", "+", "n", "-", "o", "+", 
       "p"}], ")"}], "2"]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
      "a", "+", "b", "+", "c", "+", "d", "-", "i", "-", "j", "-", "k", "-", 
       "l"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
      "e", "+", "f", "+", "g", "+", "h", "-", "m", "-", "n", "-", "o", "-", 
       "p"}], ")"}], "2"]}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tSome quartic factors involve a fragment that is the squared sum of the \
squared elements; another fragment then may \"drop-out\":- \
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
Factor[fa[mp[\"C8c\"]]]
Factor[%-(a^2+b^2+c^2+d^2)^2]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["a", "4"], "+", 
  SuperscriptBox["b", "4"], "-", 
  RowBox[{"4", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "c"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["c", "2"]}], "+", 
  SuperscriptBox["c", "4"], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "d"}], "-", 
  RowBox[{"4", " ", "b", " ", 
   SuperscriptBox["c", "2"], " ", "d"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["d", "2"]}], "+", 
  RowBox[{"4", " ", "a", " ", "c", " ", 
   SuperscriptBox["d", "2"]}], "+", 
  SuperscriptBox["d", "4"]}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "b"}], "+", 
     RowBox[{"b", " ", "c"}], "-", 
     RowBox[{"a", " ", "d"}], "+", 
     RowBox[{"c", " ", "d"}]}], ")"}], "2"]}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "This is not the simplest shape, for the plex {a,-b,c,-d} gives ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["c", "2"], "+", 
      RowBox[{"2", " ", "b", " ", "d"}]}], ")"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      SuperscriptBox["d", "2"]}], ")"}], "2"]}]]]
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
Factor[fa[mp[\"C8r\"]]]
Factor[%-(a^2+b^2+c^2+d^2)^2]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["a", "4"], "+", 
  SuperscriptBox["b", "4"], "+", 
  RowBox[{"4", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "c"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["c", "2"]}], "+", 
  SuperscriptBox["c", "4"], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "d"}], "+", 
  RowBox[{"4", " ", "b", " ", 
   SuperscriptBox["c", "2"], " ", "d"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["d", "2"]}], "-", 
  RowBox[{"4", " ", "a", " ", "c", " ", 
   SuperscriptBox["d", "2"]}], "+", 
  SuperscriptBox["d", "4"]}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "b"}], "-", 
     RowBox[{"b", " ", "c"}], "+", 
     RowBox[{"a", " ", "d"}], "+", 
     RowBox[{"c", " ", "d"}]}], ")"}], "2"]}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tSome loops have plex-conjugates (see Section 7) that give products with \
many zero elements. These can often be used to deduce the fragmentation of \
some sizes. The signs of the conjugate have to be found:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["C4C4r Plex-Conjugate Quartic Fragmentation.", "Subsubsection",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
{hoopTimes[{a,b,c,d,e,f,g,h},{a,-b,-c,d,e,-f,-g,h},tst=\"C4C4r\"],\"\\\
nFactors\",fp[mp[tst]]}\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["g", "2"]}], ",", "0", ",", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["d", "2"], "-", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "d"}], "+", 
      RowBox[{"2", " ", "f", " ", "g"}], "-", 
      RowBox[{"2", " ", "e", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "-", 
      RowBox[{"2", " ", "c", " ", "g"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "b", " ", "f"}], "-", 
      RowBox[{"2", " ", "d", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "d", " ", "e"}], "-", 
      RowBox[{"2", " ", "c", " ", "f"}], "-", 
      RowBox[{"2", " ", "b", " ", "g"}], "+", 
      RowBox[{"2", " ", "a", " ", "h"}]}]}], "}"}], ",", "\<\"\\nFactors\"\>",
    ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"8109", "-", 
      RowBox[{"156", " ", "a"}], "+", 
      SuperscriptBox["a", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"5209", "-", 
      RowBox[{"10", " ", "a"}], "+", 
      SuperscriptBox["a", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"577", "+", 
      RowBox[{"2", " ", "a"}], "+", 
      SuperscriptBox["a", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"7949", "+", 
      RowBox[{"164", " ", "a"}], "+", 
      SuperscriptBox["a", "2"]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Some experimentation using ",
 StyleBox["fromAlph[Take[pow2,8]]",
  FontSlant->"Italic"],
 " led to the correct factors:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
Expand[{(b+d+e+g)^2+(a+c-f-h)^2,(a+b-c-d)^2+(e+f-g-h)^2, \
(a-b-c+d)^2+(e-f-g+h)^2,(b+d-e-g)^2+(a+c+f+h)^2}/.fromAlph[Take[pow2,8]]]\
\>", "Input",
 PageWidth->WindowWidth,
 FontFamily->"Courier New"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8109", "-", 
    RowBox[{"156", " ", "a"}], "+", 
    SuperscriptBox["a", "2"]}], ",", 
   RowBox[{"5209", "-", 
    RowBox[{"10", " ", "a"}], "+", 
    SuperscriptBox["a", "2"]}], ",", 
   RowBox[{"577", "+", 
    RowBox[{"2", " ", "a"}], "+", 
    SuperscriptBox["a", "2"]}], ",", 
   RowBox[{"7949", "+", 
    RowBox[{"164", " ", "a"}], "+", 
    SuperscriptBox["a", "2"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
This shape was not previously known, and was added to the databank on 17th \
Aug. 2003. \
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Fragmentation of Clifford Quartic sizes.", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["\<\
{\"Symbolic Factor for CL12\",tsts=fa[tst=cl[1,2]],\"\\nProduct with \
Plex-conjugate\",tstf=hoopTimes[{a,b,c,d,e,f,g,h},{a,-b,-c,-d,-e,-f,-g,h},tst]\
,\"\\nCheck the fragmentation\",
Expand[tsts[[1]]-(tstf[[1]]^2+tstf[[-1]]^2)]}\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Symbolic Factor for CL12\"\>", ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["d", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["d", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["d", "2"]}], "+", 
      SuperscriptBox["d", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["e", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["e", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["e", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["d", "2"], " ", 
       SuperscriptBox["e", "2"]}], "+", 
      SuperscriptBox["e", "4"], "-", 
      RowBox[{"8", " ", "c", " ", "d", " ", "e", " ", "f"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["f", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["f", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["f", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["d", "2"], " ", 
       SuperscriptBox["f", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["e", "2"], " ", 
       SuperscriptBox["f", "2"]}], "+", 
      SuperscriptBox["f", "4"], "+", 
      RowBox[{"8", " ", "b", " ", "d", " ", "e", " ", "g"}], "-", 
      RowBox[{"8", " ", "b", " ", "c", " ", "f", " ", "g"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["g", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["g", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["g", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["d", "2"], " ", 
       SuperscriptBox["g", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["e", "2"], " ", 
       SuperscriptBox["g", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["f", "2"], " ", 
       SuperscriptBox["g", "2"]}], "+", 
      SuperscriptBox["g", "4"], "-", 
      RowBox[{"8", " ", "a", " ", "d", " ", "e", " ", "h"}], "+", 
      RowBox[{"8", " ", "a", " ", "c", " ", "f", " ", "h"}], "-", 
      RowBox[{"8", " ", "a", " ", "b", " ", "g", " ", "h"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["h", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["h", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["h", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["d", "2"], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["e", "2"], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["f", "2"], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["g", "2"], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      SuperscriptBox["h", "4"]}], ")"}], "2"], 
   ",", "\<\"\\nProduct with Plex-conjugate\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "-", 
      SuperscriptBox["e", "2"], "-", 
      SuperscriptBox["f", "2"], "-", 
      SuperscriptBox["g", "2"], "-", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",",
      "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "d", " ", "e"}], "+", 
      RowBox[{"2", " ", "c", " ", "f"}], "-", 
      RowBox[{"2", " ", "b", " ", "g"}], "+", 
      RowBox[{"2", " ", "a", " ", "h"}]}]}], "}"}], 
   ",", "\<\"\\nCheck the fragmentation\"\>", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
{\"Symbolic Factor for CL3\",tsts=fa[tst=cl[3]],\"\\nProduct with \
plex-conjugate\",tstf=hoopTimes[{a,b,c,d,e,f,g,h},{a,-b,-c, \
-d,-e,-f,-g,h},tst],\"\\nCheck the fragmentation\", 
  Expand[tsts[[1]]-(tstf[[1]]^2+tstf[[-1]]^2)]}\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Symbolic Factor for CL3\"\>", ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["d", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["d", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["d", "2"]}], "+", 
      SuperscriptBox["d", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["e", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["e", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["e", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["d", "2"], " ", 
       SuperscriptBox["e", "2"]}], "+", 
      SuperscriptBox["e", "4"], "-", 
      RowBox[{"8", " ", "c", " ", "d", " ", "e", " ", "f"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["f", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["f", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["f", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["d", "2"], " ", 
       SuperscriptBox["f", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["e", "2"], " ", 
       SuperscriptBox["f", "2"]}], "+", 
      SuperscriptBox["f", "4"], "+", 
      RowBox[{"8", " ", "b", " ", "d", " ", "e", " ", "g"}], "-", 
      RowBox[{"8", " ", "b", " ", "c", " ", "f", " ", "g"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["g", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["g", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["g", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["d", "2"], " ", 
       SuperscriptBox["g", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["e", "2"], " ", 
       SuperscriptBox["g", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["f", "2"], " ", 
       SuperscriptBox["g", "2"]}], "+", 
      SuperscriptBox["g", "4"], "-", 
      RowBox[{"8", " ", "a", " ", "d", " ", "e", " ", "h"}], "+", 
      RowBox[{"8", " ", "a", " ", "c", " ", "f", " ", "h"}], "-", 
      RowBox[{"8", " ", "a", " ", "b", " ", "g", " ", "h"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["h", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["d", "2"], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["e", "2"], " ", 
       SuperscriptBox["h", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["f", "2"], " ", 
       SuperscriptBox["h", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["g", "2"], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      SuperscriptBox["h", "4"]}], ")"}], "2"], 
   ",", "\<\"\\nProduct with plex-conjugate\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "-", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "-", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",",
      "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "d", " ", "e"}], "+", 
      RowBox[{"2", " ", "c", " ", "f"}], "-", 
      RowBox[{"2", " ", "b", " ", "g"}], "+", 
      RowBox[{"2", " ", "a", " ", "h"}]}]}], "}"}], 
   ",", "\<\"\\nCheck the fragmentation\"\>", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
hoopTimes[{a,b,c,d,e,f,g,h},{a,-b,-c,-d,-e,-f,-g,h},cl[3,{2}]]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox["d", "2"], "-", 
    SuperscriptBox["e", "2"], "+", 
    SuperscriptBox["f", "2"], "-", 
    SuperscriptBox["g", "2"], "+", 
    SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "d", " ", "e"}], "+", 
    RowBox[{"2", " ", "c", " ", "f"}], "-", 
    RowBox[{"2", " ", "b", " ", "g"}], "+", 
    RowBox[{"2", " ", "a", " ", "h"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
{\"Numeric Factor for \
CL4\",tsts=fp[tst=cl[4]],tstf=hoopTimes[{a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p},{a,\
b,c,-d,e,-f,-g,-h,i,-j,-k,-l,-m,-n,-o,p},tst],\"\\nShape in \
DataBase\",sh[\"CL4\"]}\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Numeric Factor for CL4\"\>", ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"35345327484971257", "+", 
      RowBox[{"733986816", " ", "a"}], "-", 
      RowBox[{"357979754", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "4"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"], "+", 
      SuperscriptBox["i", "2"], "+", 
      SuperscriptBox["j", "2"], "+", 
      SuperscriptBox["k", "2"], "+", 
      SuperscriptBox["l", "2"], "+", 
      SuperscriptBox["m", "2"], "+", 
      SuperscriptBox["n", "2"], "+", 
      SuperscriptBox["o", "2"], "+", 
      SuperscriptBox["p", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      RowBox[{"2", " ", "c", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "f"}], "+", 
      RowBox[{"2", " ", "g", " ", "h"}], "+", 
      RowBox[{"2", " ", "i", " ", "j"}], "+", 
      RowBox[{"2", " ", "k", " ", "l"}], "+", 
      RowBox[{"2", " ", "m", " ", "n"}], "+", 
      RowBox[{"2", " ", "o", " ", "p"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "g"}], "-", 
      RowBox[{"2", " ", "f", " ", "h"}], "+", 
      RowBox[{"2", " ", "i", " ", "k"}], "-", 
      RowBox[{"2", " ", "j", " ", "l"}], "+", 
      RowBox[{"2", " ", "m", " ", "o"}], "-", 
      RowBox[{"2", " ", "n", " ", "p"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "-", 
      RowBox[{"2", " ", "b", " ", "f"}], "-", 
      RowBox[{"2", " ", "c", " ", "g"}], "+", 
      RowBox[{"2", " ", "d", " ", "h"}], "+", 
      RowBox[{"2", " ", "i", " ", "m"}], "-", 
      RowBox[{"2", " ", "j", " ", "n"}], "-", 
      RowBox[{"2", " ", "k", " ", "o"}], "+", 
      RowBox[{"2", " ", "l", " ", "p"}]}], ",", "0", ",", "0", ",", "0", ",", 
     
     RowBox[{
      RowBox[{"2", " ", "a", " ", "i"}], "-", 
      RowBox[{"2", " ", "b", " ", "j"}], "-", 
      RowBox[{"2", " ", "c", " ", "k"}], "+", 
      RowBox[{"2", " ", "d", " ", "l"}], "-", 
      RowBox[{"2", " ", "e", " ", "m"}], "+", 
      RowBox[{"2", " ", "f", " ", "n"}], "+", 
      RowBox[{"2", " ", "g", " ", "o"}], "-", 
      RowBox[{"2", " ", "h", " ", "p"}]}], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "h", " ", "i"}], "-", 
      RowBox[{"2", " ", "g", " ", "j"}], "+", 
      RowBox[{"2", " ", "f", " ", "k"}], "-", 
      RowBox[{"2", " ", "e", " ", "l"}], "-", 
      RowBox[{"2", " ", "d", " ", "m"}], "+", 
      RowBox[{"2", " ", "c", " ", "n"}], "-", 
      RowBox[{"2", " ", "b", " ", "o"}], "+", 
      RowBox[{"2", " ", "a", " ", "p"}]}]}], "}"}], 
   ",", "\<\"\\nShape in DataBase\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["d", "2"], "+", 
        SuperscriptBox["e", "2"], "+", 
        SuperscriptBox["f", "2"], "+", 
        SuperscriptBox["g", "2"], "+", 
        SuperscriptBox["h", "2"], "+", 
        SuperscriptBox["i", "2"], "+", 
        SuperscriptBox["j", "2"], "+", 
        SuperscriptBox["k", "2"], "+", 
        SuperscriptBox["l", "2"], "+", 
        SuperscriptBox["m", "2"], "+", 
        SuperscriptBox["n", "2"], "+", 
        SuperscriptBox["o", "2"], "+", 
        SuperscriptBox["p", "2"]}], ")"}], "2"], "-", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", " ", "i"}], "-", 
           RowBox[{"g", " ", "j"}], "+", 
           RowBox[{"f", " ", "k"}], "-", 
           RowBox[{"e", " ", "l"}], "-", 
           RowBox[{"d", " ", "m"}], "+", 
           RowBox[{"c", " ", "n"}], "-", 
           RowBox[{"b", " ", "o"}], "+", 
           RowBox[{"a", " ", "p"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", "i"}], "-", 
           RowBox[{"b", " ", "j"}], "-", 
           RowBox[{"c", " ", "k"}], "+", 
           RowBox[{"d", " ", "l"}], "-", 
           RowBox[{"e", " ", "m"}], "+", 
           RowBox[{"f", " ", "n"}], "+", 
           RowBox[{"g", " ", "o"}], "-", 
           RowBox[{"h", " ", "p"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", "e"}], "-", 
           RowBox[{"b", " ", "f"}], "-", 
           RowBox[{"c", " ", "g"}], "+", 
           RowBox[{"d", " ", "h"}], "+", 
           RowBox[{"i", " ", "m"}], "-", 
           RowBox[{"j", " ", "n"}], "-", 
           RowBox[{"k", " ", "o"}], "+", 
           RowBox[{"l", " ", "p"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", "c"}], "-", 
           RowBox[{"b", " ", "d"}], "+", 
           RowBox[{"e", " ", "g"}], "-", 
           RowBox[{"f", " ", "h"}], "+", 
           RowBox[{"i", " ", "k"}], "-", 
           RowBox[{"j", " ", "l"}], "+", 
           RowBox[{"m", " ", "o"}], "-", 
           RowBox[{"n", " ", "p"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", "b"}], "+", 
           RowBox[{"c", " ", "d"}], "+", 
           RowBox[{"e", " ", "f"}], "+", 
           RowBox[{"g", " ", "h"}], "+", 
           RowBox[{"i", " ", "j"}], "+", 
           RowBox[{"k", " ", "l"}], "+", 
           RowBox[{"m", " ", "n"}], "+", 
           RowBox[{"o", " ", "p"}]}], ")"}], "2"]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t(This is not the only plex-conjugate for CL4; See Polymorphs, Section \
18.3.)\n\tThe above result gave the first shape to be found for a 32-element \
group, CL4C2, by the expansion ",
 StyleBox["a\[ShortRightArrow] a-q",
  FontSlant->"Italic"],
 ", etc, and the ",
 StyleBox["linearFactor",
  FontSlant->"Italic"],
 " procedure. The procedure has failed to find 32-element Clifford algebra \
factors ."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Cubic Factor for A4", "Subsubsection",
 PageWidth->WindowWidth],

Cell["\<\
A4 is the smallest group with a cubic factor. The compact form of this \
factor, as the sum of six triple products, was obtained by a long process of \
trial and error. This involved repeatedly factorizing the determinant with 8 \
symbolic and 4 zero elements (more symbolic elements overloaded the available \
computer) to build up a pattern. It is shown below. It could be used to \
define the shape of A4C2 by unfolding, and might provide a starting point for \
the development of sh[\"S4\"]\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
(* Example A4 Shape *)
sh[\"A4\"]\
\>", "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h", 
    "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-", 
         "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-", 
         "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "+", "i",
          "-", "j", "+", "l"}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "+", "d", "-", "g", "-", "j"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "d", "+", "g", "-", "j"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "d", "-", "g", "+", "j"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"b", "+", "e", "-", "h", "-", "k"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "e", "+", "h", "-", "k"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "e", "-", "h", "+", "k"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "d", "+", "g", "-", "j"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "e", "-", "h", "+", "k"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"c", "+", "f", "-", "i", "-", "l"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "d", "-", "g", "+", "j"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", "e", "-", "h", "-", "k"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"c", "-", "f", "+", "i", "-", "l"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "+", "d", "-", "g", "-", "j"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "e", "+", "h", "-", "k"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"c", "-", "f", "-", "i", "+", "l"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", "f", "-", "i", "-", "l"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"c", "-", "f", "+", "i", "-", "l"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"c", "-", "f", "-", "i", "+", "l"}], ")"}]}]}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["17. Appendix E. Multi-phase & Power-Sinusoids.", "Section",
 PageWidth->PaperWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". Differential equations generate multi-phase and power-sinusoids, \
generalizing ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], TraditionalForm]]],
 "=1. Multi-phase sinusoids are exponents of generalized signs."
}], "Text",
 PageWidth->PaperWidth,
 FontSlant->"Italic"],

Cell[TextData[{
 "\tBanded sets of differential equations generate multi-phase sinusoids \
(just as ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["x", "1"], "."], TraditionalForm]]],
 StyleBox[" = a ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"2", ","}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    OverscriptBox[
     SubscriptBox["x", "2"], "."]}], TraditionalForm]]],
 StyleBox["= -a",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 ", equivalent to ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["x", "\[DoubleDot]"], TraditionalForm]]],
 " = -",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 "x, generates ordinary sinusoids). A simple set is the ",
 StyleBox["m",
  FontSlant->"Italic"],
 " equations (with ",
 StyleBox["m",
  FontSlant->"Italic"],
 "-1 being independent):- \n     ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       SubscriptBox["x", "j"], ",", "t"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"c", "'"}], "[", "t", "]"}], "+", 
      RowBox[{"a", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"j", "+", "k"}], ",", "m"}], "]"}]], "-", 
         SubscriptBox["x", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"j", "-", "k"}], ",", "m"}], "]"}]]}], ")"}]}]}]}], ",", 
    RowBox[{"j", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"0.", ".."}], " ", "m"}], "-", "1"}]}], ",", 
    RowBox[{"k", "<", 
     RowBox[{"m", "/", "2."}]}]}],
   FontFamily->"Times New Roman",
   FontWeight->"Plain"]], "Input"],
 "\nSubstituting the trial function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "j"], "=", 
   RowBox[{
    RowBox[{"c", "[", "t", "]"}], "+", 
    RowBox[{
     SubscriptBox["c", "1"], 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", "t"}], "+", "\[Phi]", "+", 
       RowBox[{"2", "j", " ", "k", " ", 
        RowBox[{"\[Pi]", "/", "m"}]}]}], "]"}]}]}]}]],
  FontFamily->"Times New Roman"],
 " leads to          ",
 Cell[BoxData[
  RowBox[{"        ", 
   RowBox[{
    SubscriptBox["x", "j"], "=", 
    RowBox[{
     RowBox[{"c", "[", "t", "]"}], "+", 
     RowBox[{
      SubscriptBox["\[Sum]", "p"], 
      RowBox[{
       SubscriptBox["c", "p"], 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"2", "a", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", "k", " ", 
            RowBox[{"\[Pi]", "/", "m"}]}], "]"}], " ", "t"}], "+", 
         SubscriptBox["\[Phi]", "p"], "+", 
         RowBox[{"2", "j", " ", "k", " ", 
          RowBox[{"\[Pi]", "/", "m"}]}]}], "]"}]}]}]}]}]}]], "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 ".\n",
 StyleBox["j",
  FontSlant->"Italic"],
 " is one of the ",
 StyleBox["m",
  FontSlant->"Italic"],
 " phases; c[t] gives freedom from the origin;",
 StyleBox[" ",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  SubscriptBox["c", "p"]],
  FontFamily->"Times New Roman"],
 " and ",
 Cell[BoxData[
  StyleBox[
   SubscriptBox["\[Phi]", "p"],
   FontFamily->"Times New Roman"]]],
 " are phase amplitude and phase offset constants which are subscripted \
because independent sets can arise; ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is a phase step. Sin[2k \[Pi]/m] is a constant that determines the \
frequency & period.  When ",
 StyleBox["m",
  FontSlant->"Italic"],
 "=4, ",
 StyleBox["k",
  FontSlant->"Italic"],
 " must be 1; folding then removes the c[t] term and reproduces the ordinary \
sinusoid equation-pair with double the amplitude, symmetrical about zero. \
Other values of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " and ",
 StyleBox["k",
  FontSlant->"Italic"],
 " give a frequency reduction.\n\n\tThe period is 2\[Pi]/Sin[2k \[Pi]/m], and \
the function is non-sinusoidal (constant) if 2/m is integral; ",
 StyleBox["m",
  FontSlant->"Italic"],
 "=12 gives half-spin with a period of 4\[Pi]. Spin-2 is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Sin", "2"], TraditionalForm]]],
 " with period \[Pi]; the spin-2 sinusoids (gravity waves?) are essentially \
non-negative."
}], "Text",
 PageWidth->PaperWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 TextJustification->0],

Cell[TextData[{
 "\tSome years ago I generalized ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], TraditionalForm]]],
 "=1 to give the multiphase identity ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], 
    RowBox[{"n", "=", 
     RowBox[{"m", "-", "1"}]}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     RowBox[{"\[Theta]", "+", 
      RowBox[{"2", "n", " ", 
       RowBox[{"\[Pi]", "/", "m"}]}]}], "]"}], "2"], TraditionalForm]]],
 "/",
 StyleBox["m",
  FontSlant->"Italic"],
 "\[Congruent]1. This is the basis for the conversion of sizes that are sums \
of squares into multi-phase sinusoidal orbits. On 17/11/2000 I ",
 "generalized",
 " this to other powers (I have not found a use for this, though it gives \
widely separated near-gaussian pulses). Firstly I found that the sum of \
fourth powers of ",
 StyleBox["m",
  FontSlant->"Italic"],
 "-phase sinusoids, apart from ",
 StyleBox["m",
  FontSlant->"Italic"],
 "={1,2,4}, is 3",
 StyleBox["m",
  FontSlant->"Italic"],
 "/8. Example E1 demonstrates this for 3, 5, & 6 phases. An arbitrary value \
of the angle \[Tau]=1.1 is employed because the simplification of the \
symbolic expressions is very slow in early versions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ":-"
}], "Text",
 PageWidth->PaperWidth],

Cell["Example E1. Sums of 4'th powers of multiphase sinusoids.", "Text",
 PageWidth->PaperWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tau", "=", "1.1"}], ";", 
  RowBox[{"{", 
   RowBox[{
   "\"\<Eight times the sum of\\n4'th power 3-phase sinusoids  =\>\"", ",", 
    RowBox[{"8", "*", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "tau", "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"]}], "]"}]}], ",", 
    "\"\<\\n4'th power 5-phase sinusoids  =\>\"", ",", 
    RowBox[{"8", "*", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "tau", "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "5"}]}]}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "5"}]}]}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"6", 
           RowBox[{"\[Pi]", "/", "5"}]}]}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"8", 
           RowBox[{"\[Pi]", "/", "5"}]}]}], "]"}], "4"]}], "]"}]}], ",", 
    "\"\<\\n4'th power 6-phase sinusoids  =\>\"", ",", 
    RowBox[{"8", "*", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "tau", "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"\[Pi]", "/", "3"}]}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", "\[Pi]"}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"tau", "+", 
          RowBox[{"5", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"]}], "]"}]}]}], 
   "}"}]}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Eight times the sum of\\n4'th power 3-phase sinusoids  =\"\>", 
   ",", "9.`", ",", "\<\"\\n4'th power 5-phase sinusoids  =\"\>", ",", 
   "15.000000000000005`", ",", "\<\"\\n4'th power 6-phase sinusoids  =\"\>", 
   ",", "17.999999999999993`"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tI developed this \"Power-Sinusoid\" identity as an empirical observation. \
The correct relationship was derived for me by John Thwaites (Fellow of Caius \
College, Cambridge) and is ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], 
    RowBox[{"n", "=", 
     RowBox[{"m", "-", "1"}]}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", "+", 
       RowBox[{"2", "n", " ", 
        RowBox[{"\[Pi]", "/", "m"}]}]}], "]"}], ")"}], 
    RowBox[{"2", "p"}]], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["4", 
    RowBox[{"-", "p"}]], TraditionalForm]]],
 StyleBox["m ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
      {
       RowBox[{"2", "p"}]},
      {"p"}
     }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
 ", {p<m if m is even, else p<2m}.  (Odd powers, (p+1)/2, sum to a second \
harmonic. If p exceeds the stated limit, the sum has a small high-harmonic \
ripple.) The ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
      {
       RowBox[{"2", "p"}]},
      {"p"}
     }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
 " term is the Binomial, sometimes written ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[InvisiblePrefixScriptBase]", 
     RowBox[{"2", "p"}]], 
    SubscriptBox["C", "p"]}], TraditionalForm]]],
 ".  Thwaites derived this relationship by converting to exponential form, \
performing a binomial expansion, and summing typical terms. This gives ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["4", 
    RowBox[{"-", "n"}]], TraditionalForm]]],
 "m ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
      {
       RowBox[{"2", "p"}]},
      {"r"}
     }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", 
    RowBox[{"2", 
     RowBox[{"j", "(", 
      RowBox[{"p", "-", "r"}], ")"}], "i"}]], TraditionalForm]]],
 " multiplied by a geometric series that is zero unless ",
 StyleBox["p = n",
  FontSlant->"Italic"],
 ", when it sums to ",
 StyleBox["m",
  FontSlant->"Italic"],
 " (or zero on replacing ",
 StyleBox["2p",
  FontSlant->"Italic"],
 " by an odd integer).\n\tExample E2 shows the 4'th power of the 3-phase \
sinusoids in red, green, and blue, and their sum (the straight line at y=9/8) \
in black. "
}], "Text",
 PageWidth->PaperWidth],

Cell["\<\
Example E2. Plots of 4'th powers of 3-phase sinusoids and their sum.\
\>", "Text",
 PageWidth->PaperWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Tau]", "]"}], "4"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"4", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "4"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "0"}], "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<Fig.1 4th Power Sinusoid Summation to 9/8\>\""}]}], "]"}], 
  ";"}]], "Input",
 PageWidth->PaperWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.0147151 0.523203 [
[.17539 .00222 -3 -9 ]
[.17539 .00222 3 0 ]
[.32696 .00222 -3 -9 ]
[.32696 .00222 3 0 ]
[.47854 .00222 -3 -9 ]
[.47854 .00222 3 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -3 -9 ]
[.78169 .00222 3 0 ]
[.93327 .00222 -3 -9 ]
[.93327 .00222 3 0 ]
[.01131 .11936 -18 -4.5 ]
[.01131 .11936 0 4.5 ]
[.01131 .224 -18 -4.5 ]
[.01131 .224 0 4.5 ]
[.01131 .32864 -18 -4.5 ]
[.01131 .32864 0 4.5 ]
[.01131 .43328 -18 -4.5 ]
[.01131 .43328 0 4.5 ]
[.01131 .53792 -6 -4.5 ]
[.01131 .53792 0 4.5 ]
[.5 .63053 -125 0 ]
[.5 .63053 125 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(1)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(2)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(3)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(4)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(5)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(6)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11936 m
.03006 .11936 L
s
[(0.2)] .01131 .11936 1 0 Mshowa
.02381 .224 m
.03006 .224 L
s
[(0.4)] .01131 .224 1 0 Mshowa
.02381 .32864 m
.03006 .32864 L
s
[(0.6)] .01131 .32864 1 0 Mshowa
.02381 .43328 m
.03006 .43328 L
s
[(0.8)] .01131 .43328 1 0 Mshowa
.02381 .53792 m
.03006 .53792 L
s
[(1)] .01131 .53792 1 0 Mshowa
.125 Mabswid
.02381 .04088 m
.02756 .04088 L
s
.02381 .06704 m
.02756 .06704 L
s
.02381 .0932 m
.02756 .0932 L
s
.02381 .14552 m
.02756 .14552 L
s
.02381 .17168 m
.02756 .17168 L
s
.02381 .19784 m
.02756 .19784 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27632 m
.02756 .27632 L
s
.02381 .30248 m
.02756 .30248 L
s
.02381 .3548 m
.02756 .3548 L
s
.02381 .38096 m
.02756 .38096 L
s
.02381 .40712 m
.02756 .40712 L
s
.02381 .45944 m
.02756 .45944 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51176 m
.02756 .51176 L
s
.02381 .56408 m
.02756 .56408 L
s
.02381 .59024 m
.02756 .59024 L
s
.02381 .6164 m
.02756 .6164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -186 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.1) show
99.000 12.750 moveto
(4) show
105.000 12.750 moveto
(th) show
123.000 12.750 moveto
(Power) show
159.000 12.750 moveto
(Sinusoid) show
213.000 12.750 moveto
(Summation) show
273.000 12.750 moveto
(to) show
291.000 12.750 moveto
(9) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
297.000 12.750 moveto
(\\220) show
303.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
309.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01473 L
.0352 .01473 L
.03638 .01474 L
.03746 .01475 L
.03873 .01476 L
.04011 .01478 L
.04141 .01481 L
.04262 .01484 L
.04521 .01492 L
.04765 .01503 L
.04984 .01516 L
.05221 .01535 L
.05481 .0156 L
.05754 .01596 L
.06244 .01683 L
.06507 .01745 L
.06746 .01812 L
.07283 .02005 L
.07781 .02246 L
.08253 .02537 L
.09309 .03456 L
.09906 .04164 L
.10458 .04956 L
.12324 .08714 L
.13387 .1164 L
.14385 .14895 L
.18253 .30899 L
.20218 .39506 L
.21257 .4364 L
.22367 .47478 L
.23443 .50446 L
.23951 .51549 L
.2442 .5238 L
.24891 .53028 L
.2514 .53291 L
.25402 .5351 L
.25512 .53583 L
.25631 .53649 L
.25733 .53696 L
.25844 .53737 L
.25974 .53771 L
Mistroke
.26098 .53788 L
.26218 .53791 L
.2633 .53783 L
.26459 .53759 L
.26524 .53741 L
.26595 .53717 L
.26721 .53664 L
.26839 .53601 L
.27105 .53412 L
.27389 .53141 L
.27911 .52458 L
.28386 .51634 L
.29343 .49426 L
.30248 .46727 L
.34086 .31085 L
.36028 .22546 L
.3817 .14296 L
.39147 .11184 L
.40199 .08365 L
.41185 .06236 L
.42101 .04685 L
.43061 .03468 L
.43568 .02975 L
.44109 .0255 L
.44679 .02203 L
.45216 .01957 L
.45699 .01793 L
.4595 .01726 L
.46221 .01666 L
.46477 .01619 L
.46711 .01584 L
.46949 .01555 L
.4717 .01534 L
.47426 .01514 L
.47705 .01499 L
.47951 .01489 L
.48075 .01485 L
.48212 .01482 L
.48345 .01479 L
.48484 .01477 L
.48604 .01475 L
.48734 .01474 L
.48875 .01473 L
.48954 .01473 L
.49026 .01472 L
.49093 .01472 L
.49166 .01472 L
.49298 .01472 L
.4942 .01472 L
.4949 .01472 L
Mistroke
.49555 .01472 L
.49687 .01472 L
.49761 .01472 L
.49828 .01472 L
.49948 .01472 L
.50079 .01472 L
.50203 .01472 L
.50318 .01472 L
.50447 .01472 L
.50511 .01472 L
.50583 .01472 L
.50708 .01472 L
.50826 .01472 L
.50897 .01472 L
.50965 .01472 L
.51091 .01473 L
.51162 .01473 L
.51227 .01474 L
.51376 .01475 L
.51494 .01476 L
.51605 .01478 L
.51737 .0148 L
.51859 .01483 L
.52105 .01491 L
.52235 .01496 L
.52371 .01502 L
.52594 .01516 L
.52832 .01534 L
.53261 .0158 L
.53523 .01619 L
.5377 .01664 L
.54233 .01773 L
.54696 .01924 L
.55206 .02144 L
.55738 .02448 L
.56236 .02809 L
.57126 .03674 L
.58081 .04963 L
.59095 .06791 L
.602 .09368 L
.62211 .1563 L
.66283 .32737 L
.68168 .40867 L
.70203 .4814 L
.70748 .49664 L
.71322 .51036 L
.71854 .52074 L
.7235 .52829 L
.72815 .53343 L
.73076 .53547 L
Mistroke
.73191 .53618 L
.73313 .5368 L
.73377 .53707 L
.73448 .53732 L
.73573 .53766 L
.73643 .53779 L
.73719 .53788 L
.7379 .53792 L
.73855 .53791 L
.73981 .53778 L
.74052 .53765 L
.74118 .53748 L
.74239 .53708 L
.74368 .5365 L
.74629 .53487 L
.74904 .53249 L
.75396 .52656 L
.75926 .51784 L
.76509 .50561 L
.77551 .4773 L
.78525 .44445 L
.82415 .2791 L
.84395 .19474 L
.8655 .11832 L
.87553 .09022 L
.88619 .06599 L
.89528 .04977 L
.90533 .03629 L
.91024 .03123 L
.91542 .02685 L
.91989 .02379 L
.92467 .02118 L
.92983 .01902 L
.93463 .01753 L
.93756 .01683 L
.94033 .01629 L
.94301 .01588 L
.94552 .01557 L
.94921 .01523 L
.95117 .0151 L
.95327 .01498 L
.95547 .0149 L
.95756 .01483 L
.95943 .01479 L
.96049 .01477 L
.96148 .01476 L
.96241 .01475 L
.96342 .01474 L
.96425 .01474 L
.96517 .01473 L
Mistroke
.96617 .01473 L
.96722 .01472 L
.9682 .01472 L
.96911 .01472 L
.97003 .01472 L
.9709 .01472 L
.97168 .01472 L
.97253 .01472 L
.97345 .01472 L
.97443 .01472 L
.97527 .01472 L
.97619 .01472 L
Mfstroke
0 1 0 r
.02381 .30902 m
.04262 .22634 L
.06244 .14916 L
.08255 .08851 L
.09396 .06319 L
.10458 .04536 L
.10961 .03871 L
.11508 .03269 L
.11989 .02833 L
.125 .02458 L
.12959 .02189 L
.13466 .01959 L
.13926 .01801 L
.14357 .0169 L
.14854 .016 L
.15134 .01563 L
.15395 .01536 L
.15646 .01516 L
.15873 .01503 L
.15999 .01497 L
.16135 .01491 L
.16263 .01487 L
.16382 .01484 L
.16606 .01479 L
.16724 .01477 L
.16851 .01475 L
.16984 .01474 L
.1711 .01473 L
.17224 .01473 L
.17347 .01472 L
.17453 .01472 L
.1757 .01472 L
.17693 .01472 L
.17808 .01472 L
.17915 .01472 L
.18013 .01472 L
.18121 .01472 L
.18234 .01472 L
.18358 .01472 L
.18428 .01472 L
.18492 .01472 L
.1861 .01472 L
.18735 .01472 L
.18846 .01472 L
.18951 .01472 L
.19066 .01472 L
.19189 .01472 L
.1932 .01473 L
.19394 .01473 L
.19462 .01474 L
Mistroke
.19588 .01475 L
.19722 .01476 L
.19853 .01478 L
.19977 .0148 L
.20209 .01486 L
.20433 .01494 L
.20669 .01505 L
.2087 .01517 L
.21092 .01534 L
.2133 .01558 L
.21585 .0159 L
.22045 .01668 L
.22303 .01725 L
.22575 .01799 L
.23065 .01968 L
.23592 .02212 L
.24173 .0257 L
.24674 .02964 L
.25212 .03489 L
.26187 .04736 L
.27146 .06385 L
.28195 .08707 L
.30306 .15064 L
.34367 .31978 L
.36244 .40142 L
.38277 .47592 L
.38818 .49174 L
.3939 .5062 L
.3992 .51734 L
.40416 .52567 L
.40879 .53156 L
.41139 .53404 L
.41376 .53577 L
.41511 .53653 L
.41636 .53709 L
.41773 .53753 L
.41842 .53769 L
.41918 .53782 L
.42046 .53792 L
.42117 .53791 L
.42183 .53785 L
.42304 .53765 L
.42432 .5373 L
.42555 .53682 L
.42689 .53614 L
.42931 .5345 L
.43167 .5324 L
.43385 .53002 L
.43879 .52308 L
.44404 .51347 L
Mistroke
.45277 .4926 L
.4624 .46335 L
.5027 .2969 L
.52125 .21608 L
.54149 .13934 L
.55246 .10529 L
.56264 .07911 L
.5723 .05914 L
.58274 .04263 L
.58825 .03587 L
.59332 .03073 L
.59807 .02677 L
.60328 .02328 L
.60796 .02082 L
.61233 .01903 L
.61694 .01759 L
.62189 .01647 L
.62445 .01604 L
.62718 .01567 L
.62951 .01542 L
.63207 .01521 L
.63482 .01503 L
.63637 .01496 L
.63778 .0149 L
.6404 .01483 L
.64171 .0148 L
.64314 .01477 L
.6445 .01476 L
.64579 .01474 L
.64694 .01473 L
.64819 .01473 L
.64884 .01472 L
.64955 .01472 L
.65029 .01472 L
.65099 .01472 L
.65223 .01472 L
.65293 .01472 L
.65357 .01472 L
.65481 .01472 L
.65595 .01472 L
.65721 .01472 L
.65791 .01472 L
.65855 .01472 L
.65972 .01472 L
.66098 .01472 L
.66217 .01472 L
.66327 .01472 L
.66454 .01472 L
.66574 .01472 L
.66682 .01472 L
Mistroke
.66799 .01472 L
.66926 .01473 L
.66991 .01473 L
.67062 .01473 L
.67187 .01474 L
.67304 .01476 L
.67421 .01477 L
.67533 .01479 L
.67743 .01483 L
.67968 .0149 L
.68215 .01501 L
.68487 .01517 L
.68734 .01536 L
.69019 .01566 L
.69287 .01602 L
.69765 .01689 L
.70035 .01754 L
.70283 .01826 L
.70752 .01996 L
.71256 .02236 L
.71731 .02528 L
.72164 .02855 L
.72672 .03322 L
.73225 .03944 L
.7423 .05412 L
.7517 .07215 L
.76207 .09722 L
.78307 .16442 L
.82326 .33499 L
.84173 .41402 L
.8522 .45352 L
.86194 .48488 L
.87162 .50965 L
.87704 .52035 L
.88197 .52795 L
.8845 .53104 L
.88718 .53369 L
.88857 .53483 L
.89011 .53587 L
.89153 .53664 L
.89282 .53719 L
.89413 .53759 L
.89537 .53782 L
.89668 .53792 L
.89743 .5379 L
.89811 .53784 L
.89937 .53762 L
.90051 .5373 L
.90183 .53678 L
.90307 .53615 L
Mistroke
.90548 .53451 L
.90773 .53252 L
.91285 .52633 L
.91784 .51813 L
.92318 .50708 L
.94166 .45279 L
.97619 .30902 L
Mfstroke
0 0 1 r
.02381 .30902 m
.04262 .39157 L
.06244 .46676 L
.07286 .49742 L
.08255 .51885 L
.08813 .52769 L
.09076 .53094 L
.0932 .5334 L
.096 .53558 L
.09748 .53644 L
.09824 .53681 L
.09905 .53714 L
.09976 .53739 L
.10041 .53757 L
.10168 .53782 L
.10239 .53789 L
.10317 .53792 L
.1039 .53789 L
.10458 .53783 L
.10587 .53759 L
.10651 .53741 L
.10722 .53717 L
.10848 .53664 L
.10966 .53601 L
.11231 .53413 L
.11515 .53142 L
.12035 .52462 L
.1251 .5164 L
.13466 .49437 L
.14371 .4674 L
.18204 .31126 L
.20142 .22601 L
.22282 .14346 L
.23257 .11234 L
.24307 .0841 L
.25292 .06273 L
.26209 .04714 L
.27166 .03492 L
.27672 .02995 L
.28213 .02567 L
.28781 .02216 L
.29318 .01967 L
.298 .018 L
.30052 .01732 L
.30323 .01671 L
.30578 .01623 L
.30812 .01587 L
.31049 .01558 L
.31269 .01536 L
.31525 .01516 L
Mistroke
.31803 .015 L
.32049 .0149 L
.32186 .01485 L
.3231 .01482 L
.32442 .01479 L
.32582 .01477 L
.32701 .01476 L
.32832 .01474 L
.32972 .01473 L
.33051 .01473 L
.33123 .01473 L
.3319 .01472 L
.33262 .01472 L
.33395 .01472 L
.33517 .01472 L
.33587 .01472 L
.33652 .01472 L
.33783 .01472 L
.33857 .01472 L
.33925 .01472 L
.34039 .01472 L
.34164 .01472 L
.34294 .01472 L
.34415 .01472 L
.34543 .01472 L
.34607 .01472 L
.34678 .01472 L
.34804 .01472 L
.34921 .01472 L
.34992 .01472 L
.3506 .01472 L
.35186 .01473 L
.35256 .01473 L
.35322 .01474 L
.3547 .01475 L
.35588 .01476 L
.35699 .01478 L
.35831 .0148 L
.35952 .01482 L
.36198 .0149 L
.36328 .01494 L
.36464 .01501 L
.36687 .01513 L
.36924 .01531 L
.37352 .01576 L
.37614 .01613 L
.37861 .01657 L
.38324 .01764 L
.38786 .0191 L
.39295 .02126 L
Mistroke
.39826 .02423 L
.40323 .02778 L
.41212 .03628 L
.42168 .049 L
.43179 .06703 L
.44283 .09252 L
.46292 .15466 L
.50359 .32509 L
.5224 .40644 L
.54274 .47971 L
.54817 .49512 L
.5539 .50907 L
.55921 .51969 L
.56416 .52748 L
.56881 .53286 L
.57141 .53504 L
.57378 .5365 L
.57513 .5371 L
.57638 .53751 L
.57703 .53767 L
.57775 .5378 L
.5785 .53788 L
.57921 .53792 L
.5805 .53786 L
.58168 .53768 L
.58297 .53733 L
.58363 .53709 L
.58434 .53679 L
.58688 .53535 L
.58963 .53314 L
.59223 .53043 L
.59462 .5274 L
.60396 .51096 L
.60881 .49964 L
.61415 .48518 L
.62492 .45023 L
.66528 .27972 L
.68387 .20017 L
.70412 .12656 L
.71512 .09456 L
.72531 .0704 L
.73505 .05217 L
.74046 .04401 L
.74542 .03765 L
.75574 .02758 L
.76117 .02379 L
.76689 .02073 L
.77187 .01874 L
.77652 .01737 L
.78162 .01629 L
Mistroke
.78448 .01585 L
.78707 .01554 L
.78937 .01532 L
.7919 .01513 L
.79455 .01498 L
.79702 .01489 L
.79821 .01485 L
.79933 .01482 L
.80145 .01478 L
.80263 .01476 L
.80373 .01475 L
.80493 .01474 L
.80621 .01473 L
.80689 .01473 L
.80762 .01472 L
.80891 .01472 L
.80963 .01472 L
.8103 .01472 L
.81103 .01472 L
.81182 .01472 L
.8125 .01472 L
.81324 .01472 L
.81394 .01472 L
.81459 .01472 L
.81581 .01472 L
.81711 .01472 L
.81827 .01472 L
.81953 .01472 L
.82072 .01472 L
.82181 .01472 L
.82301 .01472 L
.82433 .01472 L
.825 .01472 L
.82571 .01472 L
.82699 .01472 L
.82822 .01473 L
.82892 .01473 L
.82958 .01474 L
.8309 .01475 L
.83232 .01476 L
.83363 .01478 L
.83488 .01481 L
.83723 .01486 L
.83856 .01491 L
.83998 .01497 L
.84254 .0151 L
.84558 .01532 L
.84833 .01559 L
.85093 .01592 L
.85332 .01629 L
Mistroke
.85871 .01745 L
.86346 .01889 L
.86848 .02094 L
.87345 .0236 L
.87797 .02666 L
.88285 .03071 L
.88815 .0361 L
.89757 .04854 L
.90649 .06406 L
.92629 .11273 L
.94731 .18532 L
.97619 .30902 L
Mfstroke
0 0 0 r
.02381 .60332 m
.02846 .60332 L
.02952 .60332 L
.03068 .60332 L
.03178 .60332 L
.03279 .60332 L
.03399 .60332 L
.03527 .60332 L
.03635 .60332 L
.03754 .60332 L
.0388 .60332 L
.03951 .60332 L
.04016 .60332 L
.04145 .60332 L
.04262 .60332 L
.04384 .60332 L
.04514 .60332 L
.04634 .60332 L
.04748 .60332 L
.04812 .60332 L
.0488 .60332 L
.05003 .60332 L
.05134 .60332 L
.05209 .60332 L
.05278 .60332 L
.05745 .60332 L
.05987 .60332 L
.06051 .60332 L
.0612 .60332 L
.06244 .60332 L
.06314 .60332 L
.06378 .60332 L
.0645 .60332 L
.06526 .60332 L
.0665 .60332 L
.06721 .60332 L
.06787 .60332 L
.06857 .60332 L
.06933 .60332 L
.07005 .60332 L
.07072 .60332 L
.07149 .60332 L
.07231 .60332 L
.073 .60332 L
.07376 .60332 L
.07448 .60332 L
.07516 .60332 L
.07643 .60332 L
.07715 .60332 L
.07781 .60332 L
Mistroke
.0793 .60332 L
.08448 .60332 L
.10458 .60332 L
.11374 .60332 L
.12341 .60332 L
.13402 .60332 L
.14376 .60332 L
.154 .60332 L
.16521 .60332 L
.1854 .60332 L
.20658 .60332 L
.21145 .60332 L
.2139 .60332 L
.21661 .60332 L
.21773 .60332 L
.21891 .60332 L
.2202 .60332 L
.22139 .60332 L
.22243 .60332 L
.22353 .60332 L
.22475 .60332 L
.22587 .60332 L
.23081 .60332 L
.23324 .60332 L
.23547 .60332 L
.23674 .60332 L
.23739 .60332 L
.23809 .60332 L
.2388 .60332 L
.23956 .60332 L
.24028 .60332 L
.24093 .60332 L
.24215 .60332 L
.24284 .60332 L
.24348 .60332 L
.24465 .60332 L
.24589 .60332 L
.26483 .60332 L
.2845 .60332 L
.30255 .60332 L
.31196 .60332 L
.31669 .60332 L
.31799 .60332 L
.3187 .60332 L
.31938 .60332 L
.32069 .60332 L
.32187 .60332 L
.32308 .60332 L
.32376 .60332 L
.3244 .60332 L
Mistroke
.32569 .60332 L
.32635 .60332 L
.32708 .60332 L
.32836 .60332 L
.32958 .60332 L
.33077 .60332 L
.33187 .60332 L
.33256 .60332 L
.33329 .60332 L
.33399 .60332 L
.33463 .60332 L
.33584 .60332 L
.33713 .60332 L
.34272 .60332 L
.38071 .60332 L
.40024 .60332 L
.40155 .60332 L
.40226 .60332 L
.40293 .60332 L
.40366 .60332 L
.40445 .60332 L
.40586 .60332 L
.40711 .60332 L
.40842 .60332 L
.40911 .60332 L
.40986 .60332 L
.41118 .60332 L
.41368 .60332 L
.41434 .60332 L
.41506 .60332 L
.41635 .60332 L
.41766 .60332 L
.41887 .60332 L
.42116 .60332 L
.43098 .60332 L
.44153 .60332 L
.45149 .60332 L
.46058 .60332 L
.4617 .60332 L
.46291 .60332 L
.46404 .60332 L
.46509 .60332 L
.46632 .60332 L
.46761 .60332 L
.4687 .60332 L
.46989 .60332 L
.47121 .60332 L
.47194 .60332 L
.47261 .60332 L
.47383 .60332 L
Mistroke
.47515 .60332 L
.47646 .60332 L
.47766 .60332 L
.47881 .60332 L
.48003 .60332 L
.48426 .60332 L
.4866 .60332 L
.48881 .60332 L
.49006 .60332 L
.49077 .60332 L
.49142 .60332 L
.49381 .60332 L
.49849 .60332 L
.50356 .60332 L
.50495 .60332 L
.50642 .60332 L
.50767 .60332 L
.50838 .60332 L
.50905 .60332 L
.519 .60332 L
.52798 .60332 L
.52914 .60332 L
.53039 .60332 L
.53156 .60332 L
.53265 .60332 L
.53377 .60332 L
.535 .60332 L
.53627 .60332 L
.53761 .60332 L
.53893 .60332 L
.53967 .60332 L
.54034 .60332 L
.54156 .60332 L
.54225 .60332 L
.54289 .60332 L
.54411 .60332 L
.5454 .60332 L
.54653 .60332 L
.54777 .60332 L
.54845 .60332 L
.54919 .60332 L
.54988 .60332 L
.55053 .60332 L
.55128 .60332 L
.55207 .60332 L
.55282 .60332 L
.55349 .60332 L
.55418 .60332 L
.55481 .60332 L
.55551 .60332 L
Mistroke
.55624 .60332 L
.55748 .60332 L
.55818 .60332 L
.55884 .60332 L
.56009 .60332 L
.56145 .60332 L
.56273 .60332 L
.56392 .60332 L
.56855 .60332 L
.5736 .60332 L
.57895 .60332 L
.58834 .60332 L
.59327 .60332 L
.59846 .60332 L
.60302 .60332 L
.60427 .60332 L
.6056 .60332 L
.60686 .60332 L
.608 .60332 L
.60913 .60332 L
.61016 .60332 L
.6113 .60332 L
.6125 .60332 L
.61348 .60332 L
.61452 .60332 L
.61567 .60332 L
.61675 .60332 L
.61796 .60332 L
.61865 .60332 L
.6193 .60332 L
.62061 .60332 L
.62134 .60332 L
.62202 .60332 L
.62315 .60332 L
.62439 .60332 L
.62569 .60332 L
.6269 .60332 L
.62759 .60332 L
.62833 .60332 L
.62904 .60332 L
.62969 .60332 L
.63093 .60332 L
.63224 .60332 L
.63291 .60332 L
.63364 .60332 L
.63496 .60332 L
.63576 .60332 L
.63652 .60332 L
.6372 .60332 L
.63795 .60332 L
Mistroke
.63861 .60332 L
.63931 .60332 L
.6406 .60332 L
.64185 .60332 L
.643 .60332 L
.64425 .60332 L
.64496 .60332 L
.64562 .60332 L
.64631 .60332 L
.64695 .60332 L
.64769 .60332 L
.64838 .60332 L
.64955 .60332 L
.65079 .60332 L
.65185 .60332 L
.65302 .60332 L
.65427 .60332 L
.65497 .60332 L
.65562 .60332 L
.65681 .60332 L
.65806 .60332 L
.6593 .60332 L
.65999 .60332 L
.66064 .60332 L
.66182 .60332 L
.66306 .60332 L
.66418 .60332 L
.66523 .60332 L
.66638 .60332 L
.66761 .60332 L
.66892 .60332 L
.66966 .60332 L
.67034 .60332 L
.6716 .60332 L
.67294 .60332 L
.67426 .60332 L
.6755 .60332 L
.67661 .60332 L
.67781 .60332 L
.67896 .60332 L
.68003 .60332 L
.68121 .60332 L
.68247 .60332 L
.68738 .60332 L
.69618 .60332 L
.70113 .60332 L
.70243 .60332 L
.70317 .60332 L
.70384 .60332 L
.70514 .60332 L
Mistroke
.70638 .60332 L
.70769 .60332 L
.70843 .60332 L
.70912 .60332 L
.70989 .60332 L
.71058 .60332 L
.71139 .60332 L
.71214 .60332 L
.71279 .60332 L
.71347 .60332 L
.7147 .60332 L
.71602 .60332 L
.71676 .60332 L
.71746 .60332 L
.71871 .60332 L
.72007 .60332 L
.72254 .60332 L
.72718 .60332 L
.7298 .60332 L
.73044 .60332 L
.73113 .60332 L
.73188 .60332 L
.73259 .60332 L
.73386 .60332 L
.7352 .60332 L
.73635 .60332 L
.7376 .60332 L
.73892 .60332 L
.74013 .60332 L
.74076 .60332 L
.74146 .60332 L
.74219 .60332 L
.74288 .60332 L
.74413 .60332 L
.74528 .60332 L
.74591 .60332 L
.7466 .60332 L
.74786 .60332 L
.75719 .60332 L
.76245 .60332 L
.76806 .60332 L
.76936 .60332 L
.7701 .60332 L
.77078 .60332 L
.772 .60332 L
.7727 .60332 L
.77334 .60332 L
.77447 .60332 L
.77567 .60332 L
.77696 .60332 L
Mistroke
.77813 .60332 L
.77932 .60332 L
.78042 .60332 L
.78164 .60332 L
.78295 .60332 L
.78425 .60332 L
.7849 .60332 L
.78562 .60332 L
.78688 .60332 L
.78806 .60332 L
.79035 .60332 L
.7925 .60332 L
.79369 .60332 L
.79498 .60332 L
.79616 .60332 L
.79724 .60332 L
.79844 .60332 L
.79972 .60332 L
.80094 .60332 L
.80205 .60332 L
.80335 .60332 L
.80408 .60332 L
.80476 .60332 L
.80601 .60332 L
.8067 .60332 L
.80733 .60332 L
.81801 .60332 L
.82741 .60332 L
.83731 .60332 L
.83982 .60332 L
.84048 .60332 L
.8412 .60332 L
.8425 .60332 L
.8433 .60332 L
.84404 .60332 L
.84472 .60332 L
.84544 .60332 L
.84674 .60332 L
.84748 .60332 L
.84818 .60332 L
.84946 .60332 L
.85069 .60332 L
.85179 .60332 L
.85298 .60332 L
.85428 .60332 L
.85566 .60332 L
.85697 .60332 L
.85815 .60332 L
.85936 .60332 L
.86048 .60332 L
Mistroke
.86303 .60332 L
.8643 .60332 L
.86551 .60332 L
.86618 .60332 L
.86691 .60332 L
.86818 .60332 L
.8705 .60332 L
.87167 .60332 L
.87297 .60332 L
.87407 .60332 L
.87525 .60332 L
.87637 .60332 L
.8774 .60332 L
.87861 .60332 L
.87991 .60332 L
.88113 .60332 L
.88224 .60332 L
.88754 .60332 L
.89822 .60332 L
.89941 .60332 L
.90054 .60332 L
.90184 .60332 L
.90303 .60332 L
.90415 .60332 L
.90518 .60332 L
.90632 .60332 L
.90753 .60332 L
.9088 .60332 L
.91 .60332 L
.91107 .60332 L
.91223 .60332 L
.91354 .60332 L
.9142 .60332 L
.91492 .60332 L
.9162 .60332 L
.9174 .60332 L
.91807 .60332 L
.9188 .60332 L
.91949 .60332 L
.92013 .60332 L
.92262 .60332 L
.92822 .60332 L
.93819 .60332 L
.94268 .60332 L
.94752 .60332 L
.94975 .60332 L
.95209 .60332 L
.95305 .60332 L
.95408 .60332 L
.95521 .60332 L
Mistroke
.95627 .60332 L
.95692 .60332 L
.95761 .60332 L
.95885 .60332 L
.95949 .60332 L
.96018 .60332 L
.96093 .60332 L
.96164 .60332 L
.96289 .60332 L
.96359 .60332 L
.96424 .60332 L
.96542 .60332 L
.96671 .60332 L
.96795 .60332 L
.96911 .60332 L
.97034 .60332 L
.97103 .60332 L
.97167 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-0.869513, -0.0931986, \
0.0265826, 0.00770118}}]
}, Open  ]],

Cell["\<\
When the power exceeds the specified limit, a 6th harmonic ripple appears. \
This is cancelled by adding 3/32 Cos[6\[Tau]] in the following example.\
\>", "Text",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Tau]", "]"}], "6"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "6"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"4", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "6"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "6"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "6"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "6"], "+", 
       RowBox[{"3", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"6", "\[Tau]"}], "]"}], "/", "32"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "0"}], "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<Fig.1a 6th Power Sinusoid 6\[Tau] ripple cancellation.\>\""}]}], 
   "]"}], ";"}]], "Input",
 PageWidth->PaperWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.0147151 0.588604 [
[.17539 .00222 -3 -9 ]
[.17539 .00222 3 0 ]
[.32696 .00222 -3 -9 ]
[.32696 .00222 3 0 ]
[.47854 .00222 -3 -9 ]
[.47854 .00222 3 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -3 -9 ]
[.78169 .00222 3 0 ]
[.93327 .00222 -3 -9 ]
[.93327 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -149 0 ]
[.5 .63053 149 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(1)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(2)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(3)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(4)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(5)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(6)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -210 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.1) show
93.000 12.750 moveto
(a) show
105.000 12.750 moveto
(6) show
111.000 12.750 moveto
(th) show
129.000 12.750 moveto
(Power) show
165.000 12.750 moveto
(Sinusoid) show
219.000 12.750 moveto
(6) show
225.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
237.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ripple) show
279.000 12.750 moveto
(cancellation) show
351.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
357.000 12.750 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04396 .01472 L
.04519 .01472 L
.04654 .01472 L
.04797 .01472 L
.04922 .01473 L
.05038 .01473 L
.05165 .01474 L
.05302 .01474 L
.05423 .01475 L
.05555 .01476 L
.05795 .01479 L
.06028 .01482 L
.06244 .01487 L
.06486 .01493 L
.06745 .01502 L
.06991 .01514 L
.07216 .01527 L
.07465 .01546 L
.07738 .01573 L
.08023 .01608 L
.08288 .01648 L
.0857 .01702 L
.08837 .01764 L
.09337 .01916 L
.09875 .02143 L
.10458 .02483 L
.10947 .0286 L
.11404 .03302 L
.11948 .03957 L
.12446 .04696 L
.1346 .06681 L
.1455 .09625 L
Mistroke
.15537 .13086 L
.16452 .16973 L
.18526 .27862 L
.20409 .391 L
.22444 .50383 L
.23562 .5523 L
.24052 .56909 L
.24589 .58391 L
.24835 .58934 L
.25098 .5942 L
.25325 .59758 L
.25571 .60038 L
.25716 .60159 L
.2578 .60202 L
.2585 .60243 L
.25978 .60297 L
.26048 .60316 L
.26114 .60327 L
.26238 .6033 L
.26352 .60312 L
.26476 .60269 L
.26608 .60198 L
.26732 .60107 L
.26866 .59982 L
.27109 .59686 L
.27346 .59313 L
.27565 .58896 L
.28061 .57697 L
.28586 .56067 L
.29461 .52601 L
.30424 .47908 L
.34463 .24423 L
.36324 .15215 L
.37306 .11369 L
.3835 .08111 L
.38874 .0679 L
.39452 .05557 L
.40472 .03904 L
.40971 .03308 L
.41509 .02796 L
.42017 .02421 L
.42483 .02155 L
.42956 .01948 L
.43462 .01786 L
.43939 .01676 L
.44373 .01606 L
.44639 .01573 L
.44884 .01549 L
.45152 .01528 L
.45437 .01511 L
Mistroke
.45684 .015 L
.45916 .01492 L
.4617 .01486 L
.46313 .01483 L
.46443 .01481 L
.46697 .01478 L
.46836 .01476 L
.46967 .01475 L
.47201 .01474 L
.47333 .01473 L
.47454 .01473 L
.47586 .01472 L
.4771 .01472 L
.47845 .01472 L
.47991 .01472 L
.48064 .01472 L
.48143 .01472 L
.48213 .01472 L
.48287 .01472 L
.48354 .01472 L
.48428 .01472 L
.48558 .01472 L
.48684 .01472 L
.48748 .01472 L
.48818 .01472 L
.48942 .01472 L
.49057 .01472 L
.49127 .01472 L
.49193 .01472 L
.49317 .01472 L
.49386 .01472 L
.4945 .01472 L
.4952 .01472 L
.49594 .01472 L
.4971 .01472 L
.49834 .01472 L
.49951 .01472 L
.50058 .01472 L
.50183 .01472 L
.50253 .01472 L
.50319 .01472 L
.50439 .01472 L
.50567 .01472 L
.50692 .01472 L
.50763 .01472 L
.50829 .01472 L
.50899 .01472 L
.50962 .01472 L
.51036 .01472 L
.51105 .01472 L
Mistroke
.51228 .01472 L
.51342 .01472 L
.51467 .01472 L
.5153 .01472 L
.51599 .01472 L
.51673 .01472 L
.51744 .01472 L
.51876 .01472 L
.5195 .01472 L
.52019 .01472 L
.52175 .01472 L
.52311 .01472 L
.52435 .01472 L
.52579 .01473 L
.52714 .01473 L
.52959 .01475 L
.53083 .01476 L
.53219 .01477 L
.53459 .01479 L
.53683 .01483 L
.53948 .01489 L
.5419 .01496 L
.54468 .01507 L
.54732 .01521 L
.54969 .01537 L
.55191 .01556 L
.55455 .01584 L
.55697 .01616 L
.5619 .01702 L
.5645 .01763 L
.56722 .01839 L
.57178 .02001 L
.57602 .02198 L
.58067 .02476 L
.58564 .02858 L
.59097 .03381 L
.59588 .03985 L
.60698 .05854 L
.61676 .08184 L
.62713 .11436 L
.64669 .19845 L
.665 .29937 L
.68357 .41049 L
.70381 .51891 L
.70913 .54189 L
.71479 .56288 L
.71969 .57779 L
.72498 .59023 L
.72781 .59524 L
.73041 .5988 L
Mistroke
.7329 .60125 L
.73415 .60212 L
.73486 .60251 L
.73552 .60281 L
.73677 .60318 L
.73791 .60332 L
.73914 .60324 L
.73983 .60309 L
.74047 .60289 L
.74153 .60241 L
.7427 .60169 L
.74393 .60071 L
.74508 .59958 L
.74752 .59653 L
.74979 .5929 L
.75493 .58189 L
.75994 .56764 L
.76529 .54886 L
.7838 .46088 L
.80375 .34384 L
.82534 .21982 L
.83547 .16978 L
.84618 .12493 L
.85621 .09105 L
.86536 .06689 L
.87482 .04816 L
.88003 .04023 L
.88497 .0341 L
.89374 .02602 L
.8987 .02279 L
.90329 .02048 L
.90791 .01872 L
.9129 .01733 L
.91519 .01684 L
.9176 .0164 L
.92192 .0158 L
.92438 .01555 L
.92701 .01533 L
.92949 .01517 L
.93175 .01506 L
.9344 .01495 L
.93728 .01487 L
.94 .01482 L
.94251 .01478 L
.9446 .01476 L
.9465 .01475 L
.94755 .01474 L
.9487 .01474 L
.9498 .01473 L
.95079 .01473 L
Mistroke
.95274 .01472 L
.9538 .01472 L
.95481 .01472 L
.95568 .01472 L
.9566 .01472 L
.95761 .01472 L
.95854 .01472 L
.95964 .01472 L
.96064 .01472 L
.9618 .01472 L
.96289 .01472 L
.9639 .01472 L
.96484 .01472 L
.96587 .01472 L
.96696 .01472 L
.96805 .01472 L
.96922 .01472 L
.97033 .01472 L
.97135 .01472 L
.97247 .01472 L
.97371 .01472 L
.97499 .01472 L
.97619 .01472 L
Mfstroke
0 1 0 r
.02381 .26303 m
.04262 .16613 L
.0522 .12617 L
.06244 .09138 L
.07286 .0643 L
.08255 .0459 L
.08848 .03746 L
.09409 .03119 L
.09912 .02676 L
.10458 .02306 L
.10945 .02057 L
.11402 .0188 L
.11903 .01738 L
.12184 .01678 L
.12442 .01633 L
.12691 .01597 L
.12957 .01566 L
.13249 .0154 L
.1352 .01521 L
.13797 .01506 L
.14057 .01496 L
.14291 .01489 L
.14545 .01483 L
.14782 .0148 L
.14912 .01478 L
.15036 .01477 L
.15151 .01476 L
.15276 .01475 L
.15495 .01474 L
.1562 .01473 L
.15758 .01473 L
.15902 .01472 L
.16037 .01472 L
.16163 .01472 L
.16278 .01472 L
.16405 .01472 L
.16474 .01472 L
.16539 .01472 L
.16671 .01472 L
.1679 .01472 L
.1692 .01472 L
.16992 .01472 L
.1706 .01472 L
.17172 .01472 L
.17295 .01472 L
.17424 .01472 L
.17545 .01472 L
.17613 .01472 L
.17687 .01472 L
.17757 .01472 L
Mistroke
.17822 .01472 L
.17944 .01472 L
.18075 .01472 L
.18149 .01472 L
.18229 .01472 L
.18305 .01472 L
.18374 .01472 L
.18506 .01472 L
.18572 .01472 L
.18645 .01472 L
.18776 .01472 L
.18897 .01472 L
.1896 .01472 L
.1903 .01472 L
.19103 .01472 L
.19171 .01472 L
.19296 .01472 L
.1941 .01472 L
.19536 .01472 L
.19668 .01472 L
.1978 .01472 L
.19899 .01472 L
.20011 .01472 L
.20113 .01472 L
.20234 .01472 L
.20364 .01472 L
.20487 .01472 L
.206 .01472 L
.20721 .01473 L
.2085 .01473 L
.21085 .01474 L
.21227 .01475 L
.21363 .01476 L
.21617 .01478 L
.21747 .0148 L
.21884 .01482 L
.22132 .01487 L
.22398 .01494 L
.22693 .01506 L
.22927 .01517 L
.23183 .01534 L
.23451 .01556 L
.237 .01583 L
.24147 .01646 L
.24397 .01693 L
.24625 .01743 L
.25139 .01892 L
.25697 .02119 L
.26224 .02412 L
.2671 .02767 L
Mistroke
.27176 .03196 L
.27677 .03769 L
.28584 .0515 L
.29661 .07474 L
.30647 .10343 L
.32547 .18008 L
.3462 .29147 L
.36753 .41884 L
.38686 .52124 L
.39655 .56021 L
.40201 .57718 L
.40703 .58924 L
.40915 .59326 L
.41143 .59684 L
.41274 .59854 L
.41393 .59987 L
.41506 .60093 L
.41626 .60185 L
.41751 .60257 L
.41866 .60302 L
.4199 .60328 L
.42061 .60332 L
.42127 .60329 L
.42246 .60306 L
.42355 .60267 L
.42475 .60202 L
.42601 .6011 L
.42859 .59848 L
.43102 .59508 L
.43557 .58641 L
.44046 .57378 L
.44577 .55651 L
.46414 .47284 L
.48364 .3598 L
.50508 .23482 L
.5149 .18439 L
.52545 .13767 L
.53534 .10167 L
.5445 .07514 L
.55464 .05294 L
.56 .04395 L
.56569 .03621 L
.57113 .03036 L
.57625 .02605 L
.58084 .02302 L
.5858 .0205 L
.59074 .01863 L
.59534 .01736 L
.60039 .01636 L
.60322 .01596 L
Mistroke
.60579 .01566 L
.60831 .01543 L
.61099 .01524 L
.61392 .01508 L
.61663 .01497 L
.61914 .01489 L
.6215 .01484 L
.62409 .01479 L
.62554 .01478 L
.62687 .01476 L
.62816 .01475 L
.62937 .01475 L
.63163 .01473 L
.6329 .01473 L
.63407 .01473 L
.63536 .01472 L
.63671 .01472 L
.6378 .01472 L
.63896 .01472 L
.64006 .01472 L
.64107 .01472 L
.64224 .01472 L
.64352 .01472 L
.64473 .01472 L
.64585 .01472 L
.64703 .01472 L
.64831 .01472 L
.64952 .01472 L
.65062 .01472 L
.65185 .01472 L
.65254 .01472 L
.65319 .01472 L
.6545 .01472 L
.65523 .01472 L
.65589 .01472 L
.65656 .01472 L
.65726 .01472 L
.65853 .01472 L
.65923 .01472 L
.65989 .01472 L
.66061 .01472 L
.66138 .01472 L
.66205 .01472 L
.66277 .01472 L
.66409 .01472 L
.66538 .01472 L
.66657 .01472 L
.66786 .01472 L
.66851 .01472 L
.66922 .01472 L
Mistroke
.67048 .01472 L
.67166 .01472 L
.67237 .01472 L
.67305 .01472 L
.67431 .01472 L
.67502 .01472 L
.67568 .01472 L
.67639 .01472 L
.67716 .01472 L
.67834 .01472 L
.67946 .01472 L
.68078 .01472 L
.68199 .01472 L
.68319 .01473 L
.68449 .01473 L
.68586 .01473 L
.68712 .01474 L
.68829 .01475 L
.68955 .01476 L
.69184 .01478 L
.69407 .0148 L
.69613 .01484 L
.69835 .01489 L
.7008 .01496 L
.70335 .01507 L
.70574 .01519 L
.70833 .01536 L
.71073 .01557 L
.71337 .01585 L
.71617 .01622 L
.72087 .01707 L
.72354 .01771 L
.72606 .01842 L
.73071 .02009 L
.73498 .0221 L
.73966 .02494 L
.7446 .02878 L
.75413 .0392 L
.75946 .04709 L
.76431 .05577 L
.77375 .07717 L
.78267 .10346 L
.80265 .18481 L
.82109 .28389 L
.84141 .40526 L
.85135 .46219 L
.86045 .50908 L
.86917 .54706 L
.87377 .56371 L
.87868 .57849 L
Mistroke
.88142 .58532 L
.88389 .59059 L
.88642 .59504 L
.88873 .59831 L
.8911 .6008 L
.89234 .60178 L
.89366 .60255 L
.8948 .603 L
.89586 .60325 L
.89704 .60332 L
.89829 .60315 L
.89951 .60277 L
.9002 .60244 L
.90085 .60207 L
.90216 .60113 L
.90358 .59983 L
.90613 .5967 L
.90847 .59298 L
.91386 .58139 L
.91954 .56485 L
.92915 .52773 L
.93966 .47642 L
.97619 .26303 L
Mfstroke
0 0 1 r
.02381 .26303 m
.04262 .37453 L
.06244 .48743 L
.07216 .53339 L
.08255 .57143 L
.08562 .58006 L
.08852 .58703 L
.09135 .59266 L
.09396 .59682 L
.09643 .59983 L
.09768 .601 L
.09905 .60201 L
.09976 .60242 L
.10043 .60274 L
.1012 .60302 L
.10191 .6032 L
.10318 .60332 L
.10391 .60328 L
.10458 .60317 L
.10587 .60276 L
.10651 .60246 L
.10722 .60206 L
.10966 .6001 L
.11103 .5986 L
.1125 .59667 L
.11515 .59239 L
.12035 .58102 L
.1251 .56738 L
.13466 .53138 L
.14371 .48843 L
.18204 .26588 L
.20142 .16578 L
.21172 .12318 L
.22282 .08656 L
.23339 .06042 L
.23801 .05143 L
.24307 .04314 L
.25234 .03167 L
.25739 .02712 L
.26209 .0238 L
.26714 .02104 L
.27261 .01885 L
.27512 .01807 L
.27778 .01738 L
.28008 .01688 L
.28254 .01643 L
.28493 .01607 L
.28712 .01579 L
.2914 .01539 L
.29379 .01522 L
Mistroke
.29639 .01508 L
.29885 .01498 L
.30113 .0149 L
.30379 .01484 L
.30623 .0148 L
.3075 .01478 L
.3089 .01477 L
.31038 .01476 L
.31173 .01475 L
.31422 .01473 L
.31559 .01473 L
.31689 .01473 L
.31808 .01472 L
.31919 .01472 L
.32041 .01472 L
.3217 .01472 L
.32284 .01472 L
.3239 .01472 L
.32505 .01472 L
.32627 .01472 L
.32733 .01472 L
.32831 .01472 L
.3294 .01472 L
.33055 .01472 L
.33182 .01472 L
.33253 .01472 L
.33319 .01472 L
.33439 .01472 L
.33567 .01472 L
.33681 .01472 L
.33788 .01472 L
.33906 .01472 L
.34031 .01472 L
.34153 .01472 L
.34222 .01472 L
.34287 .01472 L
.34418 .01472 L
.34491 .01472 L
.34559 .01472 L
.34672 .01472 L
.34797 .01472 L
.34926 .01472 L
.35047 .01472 L
.35116 .01472 L
.35191 .01472 L
.35262 .01472 L
.35327 .01472 L
.35451 .01472 L
.35582 .01472 L
.35649 .01472 L
Mistroke
.35722 .01472 L
.35854 .01472 L
.35934 .01472 L
.3601 .01472 L
.36153 .01472 L
.3628 .01472 L
.36395 .01472 L
.36527 .01472 L
.36652 .01473 L
.36874 .01474 L
.37 .01474 L
.37115 .01475 L
.37358 .01477 L
.37496 .01478 L
.37625 .0148 L
.37886 .01484 L
.38164 .01491 L
.38421 .015 L
.38693 .01512 L
.38926 .01525 L
.39183 .01544 L
.39458 .0157 L
.39754 .01606 L
.4001 .01644 L
.4029 .01697 L
.40802 .01825 L
.4134 .02016 L
.41839 .02258 L
.42302 .02552 L
.42808 .02962 L
.43356 .03532 L
.43839 .04157 L
.4435 .04961 L
.45317 .06941 L
.46209 .09357 L
.48168 .16834 L
.5 .26301 L
.53884 .48848 L
.54898 .53605 L
.55433 .55688 L
.56003 .5752 L
.56285 .58269 L
.56551 .58873 L
.56809 .59363 L
.57047 .59726 L
.57273 .59994 L
.57387 .601 L
.57512 .60193 L
.57637 .60263 L
.57708 .60292 L
Mistroke
.57772 .60311 L
.57896 .60331 L
.58014 .60327 L
.58128 .60304 L
.58252 .60256 L
.58368 .60189 L
.58475 .6011 L
.58735 .59844 L
.58983 .59496 L
.59474 .5854 L
.6001 .57108 L
.60966 .53642 L
.61854 .49535 L
.65766 .26915 L
.67762 .16575 L
.68813 .12238 L
.69923 .08595 L
.70917 .06128 L
.71444 .05101 L
.72008 .04194 L
.72528 .0352 L
.73001 .03022 L
.73442 .02647 L
.73928 .02319 L
.74408 .0207 L
.74919 .01872 L
.75392 .01739 L
.75836 .01649 L
.76089 .0161 L
.76357 .01576 L
.76588 .01553 L
.76834 .01533 L
.77101 .01516 L
.77349 .01504 L
.77643 .01493 L
.77911 .01486 L
.78142 .01482 L
.78396 .01478 L
.78524 .01477 L
.78661 .01476 L
.7878 .01475 L
.78909 .01474 L
.79037 .01473 L
.79155 .01473 L
.79278 .01473 L
.7939 .01472 L
.79492 .01472 L
.79602 .01472 L
.79719 .01472 L
.79829 .01472 L
Mistroke
.79959 .01472 L
.8008 .01472 L
.8015 .01472 L
.80213 .01472 L
.80288 .01472 L
.80356 .01472 L
.80423 .01472 L
.80493 .01472 L
.80564 .01472 L
.80642 .01472 L
.80709 .01472 L
.80782 .01472 L
.80912 .01472 L
.81033 .01472 L
.81102 .01472 L
.81166 .01472 L
.81295 .01472 L
.81367 .01472 L
.81432 .01472 L
.8155 .01472 L
.81677 .01472 L
.81798 .01472 L
.81908 .01472 L
.82034 .01472 L
.82153 .01472 L
.8226 .01472 L
.82377 .01472 L
.82503 .01472 L
.82567 .01472 L
.82638 .01472 L
.82763 .01472 L
.8288 .01472 L
.82991 .01472 L
.83107 .01472 L
.83207 .01472 L
.83316 .01472 L
.83434 .01472 L
.8356 .01472 L
.83679 .01472 L
.83788 .01472 L
.83916 .01472 L
.84052 .01472 L
.84169 .01472 L
.84297 .01473 L
.84434 .01473 L
.84582 .01474 L
.84722 .01475 L
.84849 .01476 L
.85095 .01478 L
.85234 .0148 L
Mistroke
.85364 .01482 L
.856 .01486 L
.85853 .01493 L
.86113 .01502 L
.86389 .01516 L
.86624 .0153 L
.86882 .01551 L
.87159 .01579 L
.87457 .01618 L
.87994 .01715 L
.88254 .01778 L
.88536 .0186 L
.8905 .02054 L
.89549 .0231 L
.90012 .02618 L
.90475 .03007 L
.90975 .03531 L
.91879 .04808 L
.92402 .0577 L
.92954 .06982 L
.93939 .097 L
.95846 .17103 L
.97619 .26303 L
Mfstroke
0 0 0 r
.02381 .56653 m
.02846 .56653 L
.02952 .56653 L
.03068 .56653 L
.03178 .56653 L
.03279 .56653 L
.03399 .56653 L
.03527 .56653 L
.03635 .56653 L
.03754 .56653 L
.0388 .56653 L
.03951 .56653 L
.04016 .56653 L
.04145 .56653 L
.04262 .56653 L
.04384 .56653 L
.04514 .56653 L
.04634 .56653 L
.04748 .56653 L
.04812 .56653 L
.0488 .56653 L
.05003 .56653 L
.05134 .56653 L
.05209 .56653 L
.05278 .56653 L
.05403 .56653 L
.05522 .56653 L
.05629 .56653 L
.05745 .56653 L
.0587 .56653 L
.05934 .56653 L
.06004 .56653 L
.06128 .56653 L
.06244 .56653 L
.06374 .56653 L
.06444 .56653 L
.06511 .56653 L
.06642 .56653 L
.0676 .56653 L
.06884 .56653 L
.06954 .56653 L
.07019 .56653 L
.07084 .56653 L
.07157 .56653 L
.07232 .56653 L
.07302 .56653 L
.07428 .56653 L
.07547 .56653 L
.07655 .56653 L
.0777 .56653 L
Mistroke
.07895 .56653 L
.0801 .56653 L
.08081 .56653 L
.08148 .56653 L
.08272 .56653 L
.08399 .56653 L
.08471 .56653 L
.08539 .56653 L
.0861 .56653 L
.08674 .56653 L
.08749 .56653 L
.0882 .56653 L
.08945 .56653 L
.09061 .56653 L
.09188 .56653 L
.09258 .56653 L
.09323 .56653 L
.09388 .56653 L
.09457 .56653 L
.09526 .56653 L
.09602 .56653 L
.09667 .56653 L
.09737 .56653 L
.09863 .56653 L
.0994 .56653 L
.10023 .56653 L
.10102 .56653 L
.10175 .56653 L
.1024 .56653 L
.10312 .56653 L
.10388 .56653 L
.10458 .56653 L
.10584 .56653 L
.10647 .56653 L
.10717 .56653 L
.10841 .56653 L
.10958 .56653 L
.11024 .56653 L
.11094 .56653 L
.11219 .56653 L
.11284 .56653 L
.11354 .56653 L
.1143 .56653 L
.11501 .56653 L
.11629 .56653 L
.11701 .56653 L
.11768 .56653 L
.1189 .56653 L
.1202 .56653 L
.12135 .56653 L
Mistroke
.12244 .56653 L
.12491 .56653 L
.1273 .56653 L
.12848 .56653 L
.12958 .56653 L
.13056 .56653 L
.13162 .56653 L
.13279 .56653 L
.13385 .56653 L
.13622 .56653 L
.13688 .56653 L
.13756 .56653 L
.1388 .56653 L
.13995 .56653 L
.14102 .56653 L
.14219 .56653 L
.14346 .56653 L
.14468 .56653 L
.14538 .56653 L
.14602 .56653 L
.1467 .56653 L
.14743 .56653 L
.14875 .56653 L
.14989 .56653 L
.15113 .56653 L
.15243 .56653 L
.15364 .56653 L
.15496 .56653 L
.15571 .56653 L
.15639 .56653 L
.15766 .56653 L
.15829 .56653 L
.15899 .56653 L
.15974 .56653 L
.16054 .56653 L
.1613 .56653 L
.16199 .56653 L
.16266 .56653 L
.16339 .56653 L
.16407 .56653 L
.16471 .56653 L
.16598 .56653 L
.16669 .56653 L
.16735 .56653 L
.16856 .56653 L
.16983 .56653 L
.17097 .56653 L
.17204 .56653 L
.17321 .56653 L
.17446 .56653 L
Mistroke
.17516 .56653 L
.1758 .56653 L
.17651 .56653 L
.17725 .56653 L
.17791 .56653 L
.17862 .56653 L
.17989 .56653 L
.18112 .56653 L
.18225 .56653 L
.18484 .56653 L
.20381 .56653 L
.2051 .56653 L
.20582 .56653 L
.20649 .56653 L
.20901 .56653 L
.21043 .56653 L
.21114 .56653 L
.21192 .56653 L
.21258 .56653 L
.21328 .56653 L
.21456 .56653 L
.21584 .56653 L
.21652 .56653 L
.21724 .56653 L
.21855 .56653 L
.21977 .56653 L
.22453 .56653 L
.22568 .56653 L
.2269 .56653 L
.22805 .56653 L
.22909 .56653 L
.23027 .56653 L
.23139 .56653 L
.23259 .56653 L
.2339 .56653 L
.23453 .56653 L
.23523 .56653 L
.23596 .56653 L
.23664 .56653 L
.23786 .56653 L
.23916 .56653 L
.244 .56653 L
.26227 .56653 L
.26717 .56653 L
.2724 .56653 L
.27394 .56653 L
.2754 .56653 L
.27671 .56653 L
.27745 .56653 L
.27812 .56653 L
Mistroke
.27936 .56653 L
.28006 .56653 L
.28071 .56653 L
.28203 .56653 L
.28271 .56653 L
.28344 .56653 L
.28408 .56653 L
.28478 .56653 L
.28603 .56653 L
.28673 .56653 L
.28748 .56653 L
.28813 .56653 L
.28884 .56653 L
.29014 .56653 L
.29085 .56653 L
.29151 .56653 L
.29269 .56653 L
.29396 .56653 L
.2952 .56653 L
.2959 .56653 L
.29654 .56653 L
.29772 .56653 L
.29898 .56653 L
.30116 .56653 L
.30239 .56653 L
.30354 .56653 L
.30477 .56653 L
.30607 .56653 L
.30731 .56653 L
.30848 .56653 L
.30951 .56653 L
.31062 .56653 L
.31186 .56653 L
.31299 .56653 L
.31421 .56653 L
.31535 .56653 L
.3166 .56653 L
.3173 .56653 L
.31793 .56653 L
.31922 .56653 L
.31994 .56653 L
.32061 .56653 L
.32184 .56653 L
.32314 .56653 L
.32427 .56653 L
.32531 .56653 L
.32651 .56653 L
.32764 .56653 L
.32869 .56653 L
.32966 .56653 L
Mistroke
.33072 .56653 L
.33186 .56653 L
.33311 .56653 L
.33381 .56653 L
.33445 .56653 L
.33564 .56653 L
.3369 .56653 L
.33802 .56653 L
.33907 .56653 L
.34146 .56653 L
.34272 .56653 L
.34389 .56653 L
.34512 .56653 L
.34577 .56653 L
.34647 .56653 L
.34719 .56653 L
.34795 .56653 L
.34859 .56653 L
.3493 .56653 L
.34996 .56653 L
.35066 .56653 L
.35192 .56653 L
.3532 .56653 L
.35392 .56653 L
.35459 .56653 L
.35581 .56653 L
.35711 .56653 L
.35827 .56653 L
.35935 .56653 L
.36182 .56653 L
.36289 .56653 L
.36402 .56653 L
.36526 .56653 L
.36641 .56653 L
.36759 .56653 L
.3687 .56653 L
.36969 .56653 L
.37077 .56653 L
.37204 .56653 L
.37268 .56653 L
.37339 .56653 L
.37463 .56653 L
.37579 .56653 L
.37695 .56653 L
.37801 .56653 L
.37923 .56653 L
.38038 .56653 L
.38148 .56653 L
.38267 .56653 L
.384 .56653 L
Mistroke
.3852 .56653 L
.38646 .56653 L
.38717 .56653 L
.38783 .56653 L
.38903 .56653 L
.39032 .56653 L
.39151 .56653 L
.3928 .56653 L
.39402 .56653 L
.39514 .56653 L
.39615 .56653 L
.39726 .56653 L
.39842 .56653 L
.39951 .56653 L
.4008 .56653 L
.40152 .56653 L
.4022 .56653 L
.40344 .56653 L
.40475 .56653 L
.40592 .56653 L
.40702 .56653 L
.40823 .56653 L
.40953 .56653 L
.41084 .56653 L
.41157 .56653 L
.41226 .56653 L
.41299 .56653 L
.41365 .56653 L
.41442 .56653 L
.41514 .56653 L
.41642 .56653 L
.41714 .56653 L
.4178 .56653 L
.41899 .56653 L
.42028 .56653 L
.42151 .56653 L
.42265 .56653 L
.42491 .56653 L
.42999 .56653 L
.43256 .56653 L
.43497 .56653 L
.43562 .56653 L
.43631 .56653 L
.43706 .56653 L
.43776 .56653 L
.43908 .56653 L
.44028 .56653 L
.44141 .56653 L
.44248 .56653 L
.4436 .56653 L
Mistroke
.44483 .56653 L
.4459 .56653 L
.44704 .56653 L
.4481 .56653 L
.44908 .56653 L
.45022 .56653 L
.45144 .56653 L
.45253 .56653 L
.45366 .56653 L
.45492 .56653 L
.45608 .56653 L
.45736 .56653 L
.45808 .56653 L
.45873 .56653 L
.45992 .56653 L
.46104 .56653 L
.46227 .56653 L
.46358 .56653 L
.46424 .56653 L
.46496 .56653 L
.46627 .56653 L
.46754 .56653 L
.46872 .56653 L
.46993 .56653 L
.47106 .56653 L
.47208 .56653 L
.47318 .56653 L
.47439 .56653 L
.47566 .56653 L
.47674 .56653 L
.47793 .56653 L
.4786 .56653 L
.47933 .56653 L
.48002 .56653 L
.48066 .56653 L
.48194 .56653 L
.48313 .56653 L
.48442 .56653 L
.4851 .56653 L
.48584 .56653 L
.4866 .56653 L
.48733 .56653 L
.48799 .56653 L
.4887 .56653 L
.49002 .56653 L
.49122 .56653 L
.4939 .56653 L
.4951 .56653 L
.49639 .56653 L
.49761 .56653 L
Mistroke
.49874 .56653 L
.5 .56653 L
.50119 .56653 L
.50227 .56653 L
.50343 .56653 L
.5047 .56653 L
.50534 .56653 L
.50605 .56653 L
.5073 .56653 L
.50847 .56653 L
.50958 .56653 L
.51075 .56653 L
.51175 .56653 L
.51284 .56653 L
.51402 .56653 L
.51528 .56653 L
.51647 .56653 L
.51756 .56653 L
.51885 .56653 L
.51949 .56653 L
.52021 .56653 L
.52147 .56653 L
.52266 .56653 L
.52337 .56653 L
.52405 .56653 L
.52532 .56653 L
.52603 .56653 L
.52669 .56653 L
.52741 .56653 L
.52818 .56653 L
.5295 .56653 L
.53073 .56653 L
.53194 .56653 L
.53304 .56653 L
.53435 .56653 L
.53556 .56653 L
.53683 .56653 L
.5375 .56653 L
.53822 .56653 L
.53944 .56653 L
.54014 .56653 L
.54079 .56653 L
.54148 .56653 L
.54221 .56653 L
.54352 .56653 L
.54465 .56653 L
.54588 .56653 L
.54719 .56653 L
.54842 .56653 L
.54911 .56653 L
Mistroke
.54986 .56653 L
.55057 .56653 L
.55123 .56653 L
.55247 .56653 L
.55378 .56653 L
.55446 .56653 L
.55518 .56653 L
.5565 .56653 L
.5573 .56653 L
.55807 .56653 L
.55875 .56653 L
.5595 .56653 L
.56074 .56653 L
.5619 .56653 L
.56318 .56653 L
.5639 .56653 L
.56456 .56653 L
.56581 .56653 L
.56652 .56653 L
.56718 .56653 L
.56788 .56653 L
.56852 .56653 L
.56921 .56653 L
.56995 .56653 L
.57119 .56653 L
.57233 .56653 L
.57357 .56653 L
.57427 .56653 L
.57492 .56653 L
.57719 .56653 L
.57963 .56653 L
.58217 .56653 L
.5829 .56653 L
.58359 .56653 L
.58487 .56653 L
.58609 .56653 L
.58721 .56653 L
.58844 .56653 L
.58974 .56653 L
.59105 .56653 L
.59179 .56653 L
.59246 .56653 L
.59377 .56653 L
.595 .56653 L
.5957 .56653 L
.59644 .56653 L
.59707 .56653 L
.59777 .56653 L
.60077 .56653 L
.60205 .56653 L
Mistroke
.60277 .56653 L
.60342 .56653 L
.60469 .56653 L
.60588 .56653 L
.60711 .56653 L
.60781 .56653 L
.60845 .56653 L
.6091 .56653 L
.60981 .56653 L
.61056 .56653 L
.61126 .56653 L
.61249 .56653 L
.61319 .56653 L
.61383 .56653 L
.61502 .56653 L
.61628 .56653 L
.61752 .56653 L
.61869 .56653 L
.61974 .56653 L
.62087 .56653 L
.622 .56653 L
.62323 .56653 L
.62453 .56653 L
.62573 .56653 L
.62686 .56653 L
.62789 .56653 L
.62908 .56653 L
.6302 .56653 L
.63141 .56653 L
.6327 .56653 L
.6338 .56653 L
.63501 .56653 L
.6363 .56653 L
.63703 .56653 L
.6377 .56653 L
.63899 .56653 L
.64022 .56653 L
.64154 .56653 L
.64273 .56653 L
.64339 .56653 L
.6441 .56653 L
.64539 .56653 L
.64661 .56653 L
.64789 .56653 L
.64899 .56653 L
.6502 .56653 L
.65093 .56653 L
.65162 .56653 L
.65291 .56653 L
.65364 .56653 L
Mistroke
.65431 .56653 L
.65504 .56653 L
.65583 .56653 L
.65711 .56653 L
.65833 .56653 L
.65902 .56653 L
.65965 .56653 L
.66035 .56653 L
.66108 .56653 L
.66223 .56653 L
.66344 .56653 L
.66407 .56653 L
.66476 .56653 L
.66599 .56653 L
.66714 .56653 L
.66838 .56653 L
.66955 .56653 L
.67062 .56653 L
.67193 .56653 L
.67267 .56653 L
.67336 .56653 L
.67462 .56653 L
.67532 .56653 L
.67596 .56653 L
.67716 .56653 L
.67846 .56653 L
.67969 .56653 L
.68081 .56653 L
.68188 .56653 L
.68302 .56653 L
.68409 .56653 L
.68507 .56653 L
.68622 .56653 L
.68747 .56653 L
.68866 .56653 L
.68975 .56653 L
.69087 .56653 L
.69192 .56653 L
.69308 .56653 L
.69432 .56653 L
.69556 .56653 L
.69686 .56653 L
.69796 .56653 L
.69918 .56653 L
.69982 .56653 L
.7005 .56653 L
.70172 .56653 L
.70303 .56653 L
.70378 .56653 L
.70447 .56653 L
Mistroke
.70573 .56653 L
.70688 .56653 L
.70823 .56653 L
.70947 .56653 L
.71058 .56653 L
.71176 .56653 L
.71305 .56653 L
.71426 .56653 L
.7153 .56653 L
.71643 .56653 L
.71767 .56653 L
.71881 .56653 L
.72003 .56653 L
.72133 .56653 L
.72256 .56653 L
.72368 .56653 L
.725 .56653 L
.72574 .56653 L
.72642 .56653 L
.72768 .56653 L
.72832 .56653 L
.72902 .56653 L
.72973 .56653 L
.73041 .56653 L
.73169 .56653 L
.73318 .56653 L
.73391 .56653 L
.73457 .56653 L
.73577 .56653 L
.73706 .56653 L
.73773 .56653 L
.73846 .56653 L
.73977 .56653 L
.74101 .56653 L
.74215 .56653 L
.74345 .56653 L
.74469 .56653 L
.74584 .56653 L
.74691 .56653 L
.74804 .56653 L
.74928 .56653 L
.75053 .56653 L
.75123 .56653 L
.75188 .56653 L
.75305 .56653 L
.75428 .56653 L
.75553 .56653 L
.75622 .56653 L
.75687 .56653 L
.75764 .56653 L
Mistroke
.75834 .56653 L
.759 .56653 L
.75971 .56653 L
.76102 .56653 L
.76225 .56653 L
.763 .56653 L
.76371 .56653 L
.76434 .56653 L
.76504 .56653 L
.76572 .56653 L
.76645 .56653 L
.76775 .56653 L
.76854 .56653 L
.76929 .56653 L
.76995 .56653 L
.77067 .56653 L
.7719 .56653 L
.77259 .56653 L
.77324 .56653 L
.77454 .56653 L
.77527 .56653 L
.77594 .56653 L
.77713 .56653 L
.77843 .56653 L
.78078 .56653 L
.78192 .56653 L
.78312 .56653 L
.78444 .56653 L
.78564 .56653 L
.78782 .56653 L
.78906 .56653 L
.7902 .56653 L
.79086 .56653 L
.79156 .56653 L
.79284 .56653 L
.79408 .56653 L
.79523 .56653 L
.80059 .56653 L
.82162 .56653 L
.84202 .56653 L
.86107 .56653 L
.86559 .56653 L
.86669 .56653 L
.86788 .56653 L
.86918 .56653 L
.8704 .56653 L
.87104 .56653 L
.87174 .56653 L
.87247 .56653 L
.87315 .56653 L
Mistroke
.87437 .56653 L
.87567 .56653 L
.87699 .56653 L
.87823 .56653 L
.87934 .56653 L
.88055 .56653 L
.88162 .56653 L
.88277 .56653 L
.88403 .56653 L
.88521 .56653 L
.88585 .56653 L
.88654 .56653 L
.8878 .56653 L
.88902 .56653 L
.89016 .56653 L
.89131 .56653 L
.89241 .56653 L
.89339 .56653 L
.89445 .56653 L
.8956 .56653 L
.89683 .56653 L
.89787 .56653 L
.89902 .56653 L
.89967 .56653 L
.90038 .56653 L
.90167 .56653 L
.90293 .56653 L
.90409 .56653 L
.90535 .56653 L
.90606 .56653 L
.90673 .56653 L
.90744 .56653 L
.90808 .56653 L
.90879 .56653 L
.90953 .56653 L
.91071 .56653 L
.91196 .56653 L
.91305 .56653 L
.91422 .56653 L
.91494 .56653 L
.9156 .56653 L
.91691 .56653 L
.91809 .56653 L
.91935 .56653 L
.9205 .56653 L
.92155 .56653 L
.92276 .56653 L
.92391 .56653 L
.92497 .56653 L
.92596 .56653 L
Mistroke
.92703 .56653 L
.92818 .56653 L
.92945 .56653 L
.93016 .56653 L
.93081 .56653 L
.93201 .56653 L
.93328 .56653 L
.93442 .56653 L
.93548 .56653 L
.93663 .56653 L
.9379 .56653 L
.93914 .56653 L
.94046 .56653 L
.94169 .56653 L
.94284 .56653 L
.94353 .56653 L
.94419 .56653 L
.94542 .56653 L
.94611 .56653 L
.94675 .56653 L
.94745 .56653 L
.9482 .56653 L
.94946 .56653 L
.95013 .56653 L
.95083 .56653 L
.95212 .56653 L
.95331 .56653 L
.95445 .56653 L
.95552 .56653 L
.95669 .56653 L
.95794 .56653 L
.95916 .56653 L
.96029 .56653 L
.96153 .56653 L
.96284 .56653 L
.96398 .56653 L
.96505 .56653 L
.96622 .56653 L
.96749 .56653 L
.96854 .56653 L
.9697 .56653 L
.9709 .56653 L
.97203 .56653 L
.97619 .56653 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-0.704572, -0.0867256, \
0.0267559, 0.00689013}}]
}, Open  ]],

Cell["\<\
Odd power Summations with 3rd harmonics subtracted give zero:-\
\>", "Text",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Tau]", "]"}], "3"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "3"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"4", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "3"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "3"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "3"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "3"]}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "3"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "3"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "3"], "+", 
       RowBox[{"3", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"3", "\[Tau]"}], "]"}], "/", "4"}]}], "+", ".1"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "1"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "0"}], "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<Fig.1b 3rd Power Sinusoid Summation (offset .1)\>\""}]}], "]"}], 
  ";"}]], "Input",
 PageWidth->PaperWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309017 0.309017 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -143 0 ]
[.5 .63053 143 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -204 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.1) show
93.000 12.750 moveto
(b) show
105.000 12.750 moveto
(3) show
111.000 12.750 moveto
(rd) show
129.000 12.750 moveto
(Power) show
165.000 12.750 moveto
(Sinusoid) show
219.000 12.750 moveto
(Summation) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
279.000 12.750 moveto
(H) show
285.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(offset) show
327.000 12.750 moveto
(.1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
339.000 12.750 moveto
(L) show
345.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30903 L
.02954 .30903 L
.03053 .30904 L
.03163 .30906 L
.03279 .30908 L
.03395 .30911 L
.0352 .30915 L
.03746 .30924 L
.03884 .30932 L
.04016 .3094 L
.04262 .3096 L
.045 .30985 L
.04753 .31019 L
.0521 .31099 L
.05752 .31233 L
.06244 .31397 L
.06787 .31629 L
.07287 .31896 L
.08414 .32701 L
.09408 .33665 L
.10458 .34953 L
.12422 .38091 L
.14255 .41761 L
.18146 .50725 L
.20127 .55047 L
.21172 .57037 L
.22282 .58839 L
.23266 .60115 L
.23788 .60656 L
.24352 .61127 L
.24603 .61298 L
.24867 .61452 L
.25112 .61569 L
.25339 .61658 L
.25554 .61722 L
.25673 .61749 L
.25782 .6177 L
.25902 .61787 L
.26031 .61798 L
.26154 .61803 L
.26267 .61802 L
.26392 .61795 L
.26511 .61783 L
.26618 .61767 L
.26734 .61744 L
.26994 .61673 L
Mistroke
.27236 .61583 L
.27675 .61361 L
.28143 .61042 L
.28701 .60552 L
.29226 .59987 L
.30207 .58679 L
.32219 .55118 L
.34067 .5111 L
.38021 .41988 L
.40011 .37996 L
.41824 .35089 L
.42761 .33903 L
.43778 .32865 L
.44337 .32404 L
.44854 .32043 L
.45344 .31756 L
.45871 .31503 L
.46375 .31312 L
.46836 .31177 L
.47278 .31078 L
.47741 .31003 L
.47989 .30973 L
.48252 .30949 L
.48501 .30931 L
.48727 .3092 L
.48865 .30915 L
.48993 .30911 L
.49133 .30907 L
.49204 .30906 L
.49281 .30905 L
.49409 .30904 L
.4953 .30903 L
.49603 .30902 L
.49673 .30902 L
.49803 .30902 L
.49917 .30902 L
.50039 .30902 L
.50155 .30902 L
.50261 .30902 L
.50379 .30901 L
.50507 .30901 L
.50572 .309 L
.50642 .30899 L
.50767 .30898 L
.50899 .30895 L
.51043 .30892 L
.51178 .30887 L
.51304 .30882 L
.51541 .30869 L
.51792 .30851 L
Mistroke
.5201 .3083 L
.52244 .30802 L
.52668 .30736 L
.53172 .30625 L
.53633 .30488 L
.5411 .30308 L
.54618 .30067 L
.55533 .29496 L
.5662 .28563 L
.57606 .27463 L
.59532 .24613 L
.61614 .20598 L
.65717 .1119 L
.6776 .06728 L
.68758 .04825 L
.69667 .03314 L
.70546 .02091 L
.71501 .0106 L
.72026 .00637 L
.72256 .00484 L
.72511 .00339 L
.72734 .00233 L
.72974 .0014 L
.73107 .00099 L
.73228 .00068 L
.73343 .00044 L
.73467 .00024 L
.73595 9e-005 L
.73715 2e-005 L
.73833 0 L
.73941 3e-005 L
.74058 .00012 L
.74187 .00029 L
.74322 .00053 L
.74448 .00082 L
.74678 .00152 L
.74888 .00234 L
.7536 .00482 L
.75869 .00846 L
.76423 .01354 L
.77431 .02559 L
.79404 .05831 L
.81503 .10275 L
.85668 .19876 L
.87761 .24041 L
.88677 .25582 L
.89682 .27038 L
.9059 .28137 L
.91562 .29082 L
.92099 .29505 L
Mistroke
.92588 .29833 L
.93544 .30323 L
.94027 .30502 L
.94539 .30648 L
.94976 .3074 L
.95458 .30813 L
.95728 .30842 L
.95975 .30862 L
.96111 .30871 L
.9626 .3088 L
.96402 .30886 L
.96531 .3089 L
.96661 .30894 L
.96783 .30897 L
.96912 .30899 L
.96985 .30899 L
.97052 .309 L
.97164 .30901 L
.97287 .30901 L
.97416 .30902 L
.97536 .30902 L
.97619 .30902 L
Mfstroke
0 1 0 r
.02381 .50973 m
.06244 .42054 L
.08255 .38014 L
.0932 .3621 L
.10458 .34581 L
.11531 .33344 L
.12507 .32469 L
.12977 .32129 L
.13488 .31816 L
.14415 .31388 L
.14903 .31228 L
.15359 .31113 L
.1586 .31022 L
.16141 .30985 L
.16399 .30958 L
.16666 .30937 L
.16914 .30923 L
.17057 .30917 L
.17187 .30912 L
.17336 .30909 L
.17477 .30906 L
.17602 .30904 L
.17733 .30903 L
.17846 .30902 L
.17969 .30902 L
.18039 .30902 L
.18102 .30902 L
.18175 .30902 L
.18245 .30902 L
.18368 .30902 L
.18437 .30902 L
.18502 .30902 L
.1862 .30901 L
.18744 .30901 L
.18849 .309 L
.18965 .30899 L
.1909 .30897 L
.19224 .30894 L
.1935 .3089 L
.19465 .30886 L
.19688 .30876 L
.19929 .3086 L
.20158 .30841 L
.20368 .30819 L
.20845 .3075 L
.21116 .30697 L
.21369 .30639 L
.2188 .30491 L
.22428 .3028 L
.23442 .29734 L
Mistroke
.24015 .29324 L
.24546 .28875 L
.26556 .26538 L
.27616 .24901 L
.28612 .23123 L
.30474 .19287 L
.34335 .10356 L
.36293 .06173 L
.3733 .0427 L
.3844 .02562 L
.3899 .0186 L
.39511 .01293 L
.40018 .00835 L
.40486 .00499 L
.4093 .00258 L
.41154 .00167 L
.41401 .00089 L
.4153 .00057 L
.41648 .00035 L
.41777 .00017 L
.41842 .0001 L
.41913 5e-005 L
.42034 0 L
.42163 2e-005 L
.42284 .0001 L
.42394 .00022 L
.42514 .00041 L
.42626 .00064 L
.42881 .00134 L
.43129 .00228 L
.43395 .00356 L
.43877 .00658 L
.44316 .01011 L
.45385 .02164 L
.46398 .03613 L
.50227 .11354 L
.54302 .2069 L
.56325 .24585 L
.57316 .26169 L
.58226 .27411 L
.59092 .284 L
.6004 .29267 L
.60993 .29923 L
.61513 .30196 L
.61998 .30402 L
.62501 .3057 L
.62767 .30641 L
.63048 .30705 L
.63294 .30752 L
.63564 .30794 L
Mistroke
.63813 .30825 L
.64041 .30848 L
.64278 .30866 L
.64503 .30879 L
.64741 .30889 L
.64875 .30893 L
.65 .30896 L
.65118 .30898 L
.65229 .30899 L
.65328 .309 L
.65435 .30901 L
.65553 .30901 L
.65677 .30902 L
.65783 .30902 L
.65899 .30902 L
.66029 .30902 L
.6615 .30902 L
.66213 .30902 L
.66283 .30902 L
.66355 .30903 L
.66424 .30903 L
.66548 .30904 L
.66663 .30906 L
.66788 .30908 L
.6692 .30912 L
.67151 .3092 L
.67365 .30931 L
.676 .30947 L
.67851 .3097 L
.68122 .31002 L
.68415 .31045 L
.68948 .31154 L
.69466 .31302 L
.69943 .31479 L
.70914 .31977 L
.71821 .3263 L
.72817 .33574 L
.73886 .34866 L
.76005 .38257 L
.78015 .42344 L
.81842 .51192 L
.83979 .55761 L
.85913 .59039 L
.86885 .60255 L
.87395 .60762 L
.87934 .61191 L
.88406 .61476 L
.88674 .61599 L
.88924 .61688 L
.89042 .61721 L
Mistroke
.89154 .61747 L
.89256 .61767 L
.89363 .61783 L
.89481 .61795 L
.89589 .61802 L
.89705 .61803 L
.89834 .61799 L
.89962 .61788 L
.90082 .61771 L
.90213 .61747 L
.90353 .61713 L
.90612 .6163 L
.90847 .61531 L
.91324 .61264 L
.91774 .60931 L
.92776 .59919 L
.93861 .58433 L
.95688 .55163 L
.97619 .50973 L
Mfstroke
0 0 1 r
.02381 .1083 m
.04262 .06741 L
.06244 .03209 L
.07286 .01812 L
.08255 .00849 L
.08813 .00454 L
.09076 .0031 L
.0932 .002 L
.096 .00104 L
.09748 .00065 L
.09824 .00049 L
.09905 .00034 L
.09976 .00024 L
.10041 .00015 L
.10168 5e-005 L
.10239 1e-005 L
.10317 0 L
.1039 1e-005 L
.10458 4e-005 L
.10587 .00015 L
.10651 .00022 L
.10722 .00033 L
.10848 .00057 L
.10966 .00085 L
.11231 .00168 L
.11515 .00288 L
.12035 .00591 L
.1251 .00958 L
.13466 .0195 L
.14371 .03179 L
.16362 .06718 L
.18204 .10716 L
.22131 .19777 L
.241 .23738 L
.25906 .26652 L
.2683 .27834 L
.2784 .2888 L
.28856 .29679 L
.2941 .30015 L
.29926 .30269 L
.30431 .30467 L
.30978 .30631 L
.31229 .3069 L
.31495 .30742 L
.31725 .3078 L
.31972 .30814 L
.32211 .3084 L
.32429 .30859 L
.32648 .30873 L
.32857 .30884 L
Mistroke
.32974 .30888 L
.33099 .30892 L
.33206 .30895 L
.33323 .30897 L
.33394 .30898 L
.3346 .30899 L
.33589 .309 L
.33707 .30901 L
.3383 .30901 L
.33944 .30902 L
.34064 .30902 L
.34197 .30902 L
.34319 .30902 L
.34432 .30902 L
.34539 .30902 L
.34655 .30903 L
.34781 .30904 L
.34846 .30905 L
.34916 .30906 L
.35059 .30909 L
.35191 .30912 L
.35313 .30916 L
.35548 .30927 L
.35798 .30943 L
.36036 .30963 L
.36293 .30991 L
.3676 .31061 L
.37214 .31157 L
.37633 .31274 L
.38102 .3144 L
.38605 .31664 L
.39513 .32203 L
.40593 .33091 L
.41578 .34152 L
.43485 .36896 L
.4556 .40823 L
.49635 .5013 L
.51657 .54607 L
.53558 .58119 L
.54442 .59414 L
.55372 .60499 L
.5586 .60943 L
.56393 .61326 L
.56628 .61459 L
.56878 .61578 L
.57093 .6166 L
.5733 .61729 L
.57463 .61758 L
.57588 .61779 L
.5772 .61794 L
Mistroke
.57794 .61799 L
.57862 .61802 L
.57982 .61803 L
.58113 .61797 L
.58237 .61785 L
.58353 .61768 L
.58498 .6174 L
.58634 .61705 L
.5889 .61621 L
.59165 .615 L
.59462 .61337 L
.59972 .60976 L
.60511 .60488 L
.61476 .59354 L
.63442 .56142 L
.65276 .52325 L
.69168 .43312 L
.71151 .39134 L
.72196 .37221 L
.73307 .35462 L
.74291 .34156 L
.75378 .32999 L
.76366 .32199 L
.77293 .31652 L
.77763 .31443 L
.78277 .31262 L
.78814 .31121 L
.79071 .31069 L
.79313 .31028 L
.79538 .30996 L
.79782 .30968 L
.79985 .3095 L
.80208 .30934 L
.8045 .30921 L
.80582 .30916 L
.80705 .30912 L
.80819 .30909 L
.80926 .30907 L
.81051 .30905 L
.81164 .30903 L
.8128 .30903 L
.81402 .30902 L
.81466 .30902 L
.81536 .30902 L
.8166 .30902 L
.81776 .30902 L
.81901 .30902 L
.82019 .30902 L
.82126 .30901 L
.82195 .30901 L
Mistroke
.82258 .30901 L
.82328 .309 L
.82402 .30899 L
.82527 .30897 L
.82663 .30895 L
.82784 .30892 L
.82915 .30888 L
.8315 .30877 L
.83385 .30863 L
.83642 .30842 L
.83885 .30816 L
.84111 .30786 L
.84536 .30712 L
.8499 .30606 L
.85526 .30437 L
.86018 .30237 L
.87131 .29602 L
.88111 .28808 L
.89147 .27711 L
.9111 .24896 L
.92943 .21468 L
.96833 .12655 L
.97619 .1083 L
Mfstroke
1 0 1 r
.02381 .30902 m
.04262 .22472 L
.06244 .14857 L
.07286 .11775 L
.08255 .09629 L
.08813 .08746 L
.09076 .08421 L
.0932 .08176 L
.096 .07959 L
.09748 .07872 L
.09824 .07836 L
.09905 .07803 L
.09976 .07778 L
.10041 .0776 L
.10168 .07736 L
.10239 .07728 L
.10317 .07725 L
.1039 .07728 L
.10458 .07734 L
.10587 .07758 L
.10651 .07776 L
.10722 .078 L
.10848 .07853 L
.10966 .07916 L
.11231 .08103 L
.11515 .08373 L
.12035 .09052 L
.1251 .09874 L
.13466 .12081 L
.14371 .14792 L
.18204 .30672 L
.20142 .39364 L
.21172 .43555 L
.22282 .47483 L
.23339 .50483 L
.23801 .51535 L
.24307 .52487 L
.24787 .5319 L
.25234 .53664 L
.25481 .5385 L
.25705 .53971 L
.25829 .54019 L
.259 .5404 L
.25964 .54055 L
.26083 .54073 L
.26209 .54078 L
.2633 .54069 L
.26462 .54045 L
.26586 .54007 L
.26702 .53959 L
Mistroke
.2692 .53837 L
.27152 .53659 L
.27427 .53388 L
.27684 .53072 L
.28166 .52329 L
.29046 .50473 L
.29997 .47804 L
.31995 .40393 L
.34103 .31012 L
.36093 .22108 L
.37905 .15141 L
.3891 .12095 L
.3986 .09894 L
.40382 .08998 L
.40863 .08376 L
.41115 .08133 L
.41392 .0793 L
.41532 .07854 L
.41605 .07821 L
.41682 .07792 L
.41749 .0777 L
.41823 .07752 L
.41953 .07731 L
.42017 .07726 L
.42086 .07726 L
.42208 .07735 L
.42339 .0776 L
.42414 .07781 L
.42483 .07805 L
.42724 .07923 L
.4286 .08013 L
.42983 .08108 L
.43463 .08609 L
.43918 .09269 L
.44922 .11336 L
.46014 .14457 L
.47989 .21921 L
.50089 .31312 L
.52056 .40076 L
.53861 .46939 L
.54802 .4976 L
.55794 .52024 L
.56309 .52886 L
.56789 .53483 L
.57065 .53734 L
.57315 .53903 L
.57454 .53972 L
.57527 .54002 L
.57605 .54028 L
.57672 .54046 L
Mistroke
.57747 .54062 L
.57878 .54076 L
.58007 .54076 L
.58127 .54061 L
.58259 .54031 L
.58332 .54007 L
.58399 .53981 L
.58653 .53845 L
.58893 .53664 L
.59339 .53191 L
.59821 .52485 L
.6035 .51484 L
.60909 .50183 L
.61909 .47276 L
.65708 .31658 L
.67824 .22172 L
.69753 .14804 L
.70711 .1195 L
.71216 .10713 L
.71752 .0962 L
.7222 .08863 L
.72468 .08537 L
.72736 .08247 L
.72981 .08037 L
.73088 .07961 L
.73205 .07891 L
.73309 .07839 L
.7342 .07794 L
.73537 .07759 L
.73645 .07738 L
.73769 .07726 L
.73839 .07726 L
.73905 .0773 L
.73974 .07738 L
.74037 .07749 L
.7411 .07766 L
.74179 .07787 L
.74301 .07835 L
.74414 .07891 L
.74671 .08061 L
.74953 .08317 L
.75209 .08609 L
.75782 .09469 L
.76281 .10444 L
.7682 .1172 L
.77797 .14577 L
.81905 .3163 L
.83953 .40704 L
.84952 .44639 L
.85861 .47758 L
Mistroke
.86742 .50262 L
.87699 .52314 L
.88224 .53119 L
.88455 .53397 L
.88709 .53649 L
.88949 .53834 L
.89173 .5396 L
.89297 .54011 L
.8941 .54044 L
.89541 .54069 L
.89665 .54078 L
.89789 .54073 L
.89859 .54064 L
.89924 .54052 L
.90042 .54019 L
.90168 .53971 L
.90385 .53855 L
.90623 .53678 L
.90878 .53432 L
.91151 .53105 L
.91645 .52352 L
.92606 .50305 L
.93483 .47824 L
.95391 .40795 L
.97467 .31601 L
.97619 .30902 L
Mfstroke
0 0 0 r
.02381 .33992 m
.02499 .33992 L
.02605 .33992 L
.02729 .33992 L
.02846 .33992 L
.02946 .33992 L
.03053 .33992 L
.0317 .33992 L
.03279 .33992 L
.03395 .33992 L
.0352 .33992 L
.03638 .33992 L
.03746 .33992 L
.03873 .33992 L
.03944 .33992 L
.04011 .33992 L
.04132 .33992 L
.04262 .33992 L
.04327 .33992 L
.04396 .33992 L
.04519 .33992 L
.04588 .33992 L
.04652 .33992 L
.04722 .33992 L
.04797 .33992 L
.04862 .33992 L
.04933 .33992 L
.05061 .33992 L
.05186 .33992 L
.05302 .33992 L
.05414 .33992 L
.05519 .33992 L
.05634 .33992 L
.05759 .33992 L
.05882 .33992 L
.06012 .33992 L
.06123 .33992 L
.06244 .33992 L
.06315 .33992 L
.06381 .33992 L
.06453 .33992 L
.06529 .33992 L
.06657 .33992 L
.06729 .33992 L
.06797 .33992 L
.06924 .33992 L
.0704 .33992 L
.07103 .33992 L
.07173 .33992 L
.073 .33992 L
Mistroke
.07376 .33992 L
.07448 .33992 L
.07513 .33992 L
.07583 .33992 L
.0766 .33992 L
.0774 .33992 L
.07809 .33992 L
.07885 .33992 L
.07956 .33992 L
.0802 .33992 L
.08095 .33992 L
.08166 .33992 L
.08291 .33992 L
.08362 .33992 L
.08427 .33992 L
.08544 .33992 L
.08669 .33992 L
.08787 .33992 L
.08896 .33992 L
.09016 .33992 L
.09148 .33992 L
.09214 .33992 L
.09285 .33992 L
.09413 .33992 L
.09483 .33992 L
.09548 .33992 L
.09619 .33992 L
.09695 .33992 L
.09821 .33992 L
.09893 .33992 L
.09961 .33992 L
.10086 .33992 L
.10201 .33992 L
.10333 .33992 L
.10458 .33992 L
.10572 .33992 L
.10694 .33992 L
.1081 .33992 L
.10916 .33992 L
.11033 .33992 L
.11162 .33992 L
.11227 .33992 L
.11297 .33992 L
.11422 .33992 L
.11554 .33992 L
.11629 .33992 L
.11698 .33992 L
.11824 .33992 L
.11888 .33992 L
.11958 .33992 L
Mistroke
.1208 .33992 L
.1221 .33992 L
.12334 .33992 L
.12446 .33992 L
.1256 .33992 L
.12681 .33992 L
.12795 .33992 L
.12898 .33992 L
.1302 .33992 L
.13152 .33992 L
.13276 .33992 L
.13391 .33992 L
.13506 .33992 L
.13632 .33992 L
.1375 .33992 L
.1386 .33992 L
.13959 .33992 L
.14067 .33992 L
.14181 .33992 L
.14288 .33992 L
.14406 .33992 L
.14514 .33992 L
.14633 .33992 L
.14758 .33992 L
.14883 .33992 L
.14999 .33992 L
.15126 .33992 L
.15198 .33992 L
.15262 .33992 L
.15379 .33992 L
.15487 .33992 L
.15605 .33992 L
.1573 .33992 L
.15839 .33992 L
.1594 .33992 L
.16052 .33992 L
.16172 .33992 L
.16238 .33992 L
.16309 .33992 L
.16437 .33992 L
.16515 .33992 L
.16589 .33992 L
.16655 .33992 L
.16726 .33992 L
.16858 .33992 L
.16979 .33992 L
.17109 .33992 L
.17183 .33992 L
.17252 .33992 L
.1738 .33992 L
Mistroke
.17501 .33992 L
.1761 .33992 L
.17728 .33992 L
.17857 .33992 L
.17922 .33992 L
.17994 .33992 L
.1812 .33992 L
.18238 .33992 L
.18363 .33992 L
.18432 .33992 L
.18496 .33992 L
.18619 .33992 L
.18734 .33992 L
.188 .33992 L
.1887 .33992 L
.18994 .33992 L
.19064 .33992 L
.19129 .33992 L
.192 .33992 L
.19276 .33992 L
.19403 .33992 L
.19474 .33992 L
.19541 .33992 L
.19662 .33992 L
.19792 .33992 L
.19907 .33992 L
.20015 .33992 L
.20134 .33992 L
.20262 .33992 L
.2038 .33992 L
.20506 .33992 L
.20625 .33992 L
.20733 .33992 L
.20854 .33992 L
.20969 .33992 L
.21094 .33992 L
.21164 .33992 L
.21228 .33992 L
.21334 .33992 L
.21433 .33992 L
.21542 .33992 L
.21659 .33992 L
.21781 .33992 L
.21897 .33992 L
.22001 .33992 L
.22114 .33992 L
.22179 .33992 L
.22248 .33992 L
.2237 .33992 L
.22502 .33992 L
Mistroke
.22577 .33992 L
.22647 .33992 L
.22774 .33992 L
.22889 .33992 L
.22954 .33992 L
.23024 .33992 L
.23148 .33992 L
.23258 .33992 L
.23379 .33992 L
.23508 .33992 L
.23629 .33992 L
.23744 .33992 L
.23849 .33992 L
.23964 .33992 L
.24085 .33992 L
.24216 .33992 L
.24336 .33992 L
.24402 .33992 L
.24474 .33992 L
.24604 .33992 L
.24727 .33992 L
.24856 .33992 L
.24966 .33992 L
.25087 .33992 L
.25161 .33992 L
.2523 .33992 L
.2536 .33992 L
.25433 .33992 L
.25501 .33992 L
.25575 .33992 L
.25654 .33992 L
.25783 .33992 L
.25905 .33992 L
.25975 .33992 L
.26039 .33992 L
.26109 .33992 L
.26183 .33992 L
.26306 .33992 L
.26375 .33992 L
.26439 .33992 L
.26557 .33992 L
.26682 .33992 L
.26793 .33992 L
.26897 .33992 L
.27012 .33992 L
.27135 .33992 L
.27266 .33992 L
.27339 .33992 L
.27408 .33992 L
.27533 .33992 L
Mistroke
.27604 .33992 L
.27667 .33992 L
.27788 .33992 L
.27918 .33992 L
.28041 .33992 L
.28154 .33992 L
.2826 .33992 L
.28374 .33992 L
.28472 .33992 L
.28579 .33992 L
.28705 .33992 L
.28824 .33992 L
.28939 .33992 L
.29046 .33992 L
.2916 .33992 L
.29282 .33992 L
.29398 .33992 L
.29504 .33992 L
.29614 .33992 L
.29735 .33992 L
.29859 .33992 L
.29989 .33992 L
.30121 .33992 L
.30243 .33992 L
.30307 .33992 L
.30377 .33992 L
.3045 .33992 L
.30518 .33992 L
.30642 .33992 L
.30759 .33992 L
.30823 .33992 L
.30894 .33992 L
.31017 .33992 L
.3114 .33992 L
.31252 .33992 L
.31381 .33992 L
.31502 .33992 L
.31614 .33992 L
.31718 .33992 L
.31831 .33992 L
.31951 .33992 L
.32082 .33992 L
.32201 .33992 L
.32267 .33992 L
.32338 .33992 L
.32468 .33992 L
.3259 .33992 L
.32719 .33992 L
.32829 .33992 L
.32951 .33992 L
Mistroke
.33023 .33992 L
.33093 .33992 L
.33223 .33992 L
.33296 .33992 L
.33363 .33992 L
.33437 .33992 L
.33516 .33992 L
.33585 .33992 L
.33659 .33992 L
.33729 .33992 L
.33794 .33992 L
.33917 .33992 L
.34046 .33992 L
.34168 .33992 L
.34237 .33992 L
.343 .33992 L
.34417 .33992 L
.34541 .33992 L
.34652 .33992 L
.34756 .33992 L
.3487 .33992 L
.34993 .33992 L
.35116 .33992 L
.35186 .33992 L
.35251 .33992 L
.35382 .33992 L
.35455 .33992 L
.35522 .33992 L
.35642 .33992 L
.35772 .33992 L
.35895 .33992 L
.36008 .33992 L
.36114 .33992 L
.36227 .33992 L
.36334 .33992 L
.36432 .33992 L
.36546 .33992 L
.36671 .33992 L
.36789 .33992 L
.36898 .33992 L
.37021 .33992 L
.37138 .33992 L
.37242 .33992 L
.37355 .33992 L
.37478 .33992 L
.37608 .33992 L
.37719 .33992 L
.37841 .33992 L
.37963 .33992 L
.38092 .33992 L
Mistroke
.3816 .33992 L
.38234 .33992 L
.38366 .33992 L
.38489 .33992 L
.38559 .33992 L
.38622 .33992 L
.38739 .33992 L
.38863 .33992 L
.38974 .33992 L
.39093 .33992 L
.39206 .33992 L
.39308 .33992 L
.39428 .33992 L
.39558 .33992 L
.39681 .33992 L
.39794 .33992 L
.39914 .33992 L
.40027 .33992 L
.40159 .33992 L
.40278 .33992 L
.4041 .33992 L
.40484 .33992 L
.40553 .33992 L
.40678 .33992 L
.40748 .33992 L
.40811 .33992 L
.40878 .33992 L
.40949 .33992 L
.41077 .33992 L
.41148 .33992 L
.41214 .33992 L
.41287 .33992 L
.41365 .33992 L
.41432 .33992 L
.41505 .33992 L
.41574 .33992 L
.41638 .33992 L
.41758 .33992 L
.41886 .33992 L
.42006 .33992 L
.42138 .33992 L
.42262 .33992 L
.42377 .33992 L
.42492 .33992 L
.42595 .33992 L
.42714 .33992 L
.42827 .33992 L
.4295 .33992 L
.4308 .33992 L
.43191 .33992 L
Mistroke
.43313 .33992 L
.43444 .33992 L
.43518 .33992 L
.43585 .33992 L
.43716 .33992 L
.43839 .33992 L
.43944 .33992 L
.4406 .33992 L
.44181 .33992 L
.44294 .33992 L
.444 .33992 L
.44497 .33992 L
.44604 .33992 L
.44716 .33992 L
.4483 .33992 L
.44951 .33992 L
.45066 .33992 L
.45171 .33992 L
.45294 .33992 L
.45363 .33992 L
.45427 .33992 L
.45545 .33992 L
.45669 .33992 L
.4579 .33992 L
.45922 .33992 L
.46047 .33992 L
.46162 .33992 L
.46277 .33992 L
.4638 .33992 L
.465 .33992 L
.46613 .33992 L
.46677 .33992 L
.46746 .33992 L
.4687 .33992 L
.46999 .33992 L
.47073 .33992 L
.47141 .33992 L
.4726 .33992 L
.4739 .33992 L
.47513 .33992 L
.47626 .33992 L
.47731 .33992 L
.47829 .33992 L
.47937 .33992 L
.48053 .33992 L
.48169 .33992 L
.4829 .33992 L
.48393 .33992 L
.48506 .33992 L
.48631 .33992 L
Mistroke
.48745 .33992 L
.48876 .33992 L
.48999 .33992 L
.49114 .33992 L
.49219 .33992 L
.49335 .33992 L
.49457 .33992 L
.49579 .33992 L
.49648 .33992 L
.49711 .33992 L
.49828 .33992 L
.49952 .33992 L
.50058 .33992 L
.50169 .33992 L
.50291 .33992 L
.50403 .33992 L
.50522 .33992 L
.50652 .33992 L
.50773 .33992 L
.50886 .33992 L
.50955 .33992 L
.5102 .33992 L
.51143 .33992 L
.51275 .33992 L
.5135 .33992 L
.51418 .33992 L
.51524 .33992 L
.51637 .33992 L
.51744 .33992 L
.51842 .33992 L
.51956 .33992 L
.52081 .33992 L
.52199 .33992 L
.52308 .33992 L
.52431 .33992 L
.52547 .33992 L
.52652 .33992 L
.52764 .33992 L
.52888 .33992 L
.53018 .33992 L
.53129 .33992 L
.53251 .33992 L
.53373 .33992 L
.53502 .33992 L
.5357 .33992 L
.53644 .33992 L
.53775 .33992 L
.53899 .33992 L
.54032 .33992 L
.54147 .33992 L
Mistroke
.54272 .33992 L
.54395 .33992 L
.54509 .33992 L
.54629 .33992 L
.54758 .33992 L
.54878 .33992 L
.54991 .33992 L
.55093 .33992 L
.55203 .33992 L
.55333 .33992 L
.55455 .33992 L
.55525 .33992 L
.55588 .33992 L
.55662 .33992 L
.55732 .33992 L
.55873 .33992 L
.5595 .33992 L
.56022 .33992 L
.5609 .33992 L
.56164 .33992 L
.56292 .33992 L
.56413 .33992 L
.56542 .33992 L
.56651 .33992 L
.56772 .33992 L
.56902 .33992 L
.56976 .33992 L
.57042 .33992 L
.57172 .33992 L
.57295 .33992 L
.57409 .33992 L
.57533 .33992 L
.57649 .33992 L
.57756 .33992 L
.5788 .33992 L
.57946 .33992 L
.58016 .33992 L
.58144 .33992 L
.58264 .33992 L
.58333 .33992 L
.58397 .33992 L
.58467 .33992 L
.58541 .33992 L
.58665 .33992 L
.58736 .33992 L
.58802 .33992 L
.58926 .33992 L
.59038 .33992 L
.59168 .33992 L
.59291 .33992 L
Mistroke
.59397 .33992 L
.59513 .33992 L
.59635 .33992 L
.59749 .33992 L
.59856 .33992 L
.59954 .33992 L
.60061 .33992 L
.60174 .33992 L
.60289 .33992 L
.60411 .33992 L
.60527 .33992 L
.60632 .33992 L
.60756 .33992 L
.60826 .33992 L
.60891 .33992 L
.61009 .33992 L
.61135 .33992 L
.61255 .33992 L
.61387 .33992 L
.61512 .33992 L
.61627 .33992 L
.61741 .33992 L
.61845 .33992 L
.61965 .33992 L
.62077 .33992 L
.62201 .33992 L
.62331 .33992 L
.62442 .33992 L
.62564 .33992 L
.62696 .33992 L
.62769 .33992 L
.62837 .33992 L
.62967 .33992 L
.63091 .33992 L
.63196 .33992 L
.63312 .33992 L
.63433 .33992 L
.63547 .33992 L
.63652 .33992 L
.63749 .33992 L
.63856 .33992 L
.63968 .33992 L
.64082 .33992 L
.64204 .33992 L
.64319 .33992 L
.64424 .33992 L
.64547 .33992 L
.64616 .33992 L
.6468 .33992 L
.64797 .33992 L
Mistroke
.64922 .33992 L
.65043 .33992 L
.65158 .33992 L
.65277 .33992 L
.65409 .33992 L
.65478 .33992 L
.65541 .33992 L
.65611 .33992 L
.65684 .33992 L
.65806 .33992 L
.65875 .33992 L
.65939 .33992 L
.66064 .33992 L
.66183 .33992 L
.6629 .33992 L
.66405 .33992 L
.66531 .33992 L
.66595 .33992 L
.66665 .33992 L
.66788 .33992 L
.66904 .33992 L
.67016 .33992 L
.67137 .33992 L
.67253 .33992 L
.67359 .33992 L
.67465 .33992 L
.67561 .33992 L
.67672 .33992 L
.67776 .33992 L
.68013 .33992 L
.68133 .33992 L
.68264 .33992 L
.68385 .33992 L
.68499 .33992 L
.68602 .33992 L
.68714 .33992 L
.68835 .33992 L
.68947 .33992 L
.69069 .33992 L
.69198 .33992 L
.69308 .33992 L
.69412 .33992 L
.69526 .33992 L
.69649 .33992 L
.69772 .33992 L
.69842 .33992 L
.69906 .33992 L
.70037 .33992 L
.70111 .33992 L
.70177 .33992 L
Mistroke
.70297 .33992 L
.70426 .33992 L
.70548 .33992 L
.70661 .33992 L
.70782 .33992 L
.70911 .33992 L
.71033 .33992 L
.71145 .33992 L
.71275 .33992 L
.71349 .33992 L
.71417 .33992 L
.71543 .33992 L
.71613 .33992 L
.71676 .33992 L
.71744 .33992 L
.71815 .33992 L
.71943 .33992 L
.72014 .33992 L
.7208 .33992 L
.72153 .33992 L
.7223 .33992 L
.72297 .33992 L
.7237 .33992 L
.72439 .33992 L
.72503 .33992 L
.72623 .33992 L
.72751 .33992 L
.72866 .33992 L
.7299 .33992 L
.73121 .33992 L
.73242 .33992 L
.73356 .33992 L
.73459 .33992 L
.73578 .33992 L
.73691 .33992 L
.73814 .33992 L
.73944 .33992 L
.74055 .33992 L
.74177 .33992 L
.74308 .33992 L
.74381 .33992 L
.74449 .33992 L
.74579 .33992 L
.74703 .33992 L
.74807 .33992 L
.74923 .33992 L
.75044 .33992 L
.75157 .33992 L
.75263 .33992 L
.7536 .33992 L
Mistroke
.75578 .33992 L
.75695 .33992 L
.75819 .33992 L
.75936 .33992 L
.76043 .33992 L
.76163 .33992 L
.76276 .33992 L
.76399 .33992 L
.76468 .33992 L
.76532 .33992 L
.76657 .33992 L
.76776 .33992 L
.76882 .33992 L
.76998 .33992 L
.77123 .33992 L
.77241 .33992 L
.77306 .33992 L
.77377 .33992 L
.775 .33992 L
.77619 .33992 L
.77745 .33992 L
.77852 .33992 L
.7797 .33992 L
.78079 .33992 L
.78196 .33992 L
.78306 .33992 L
.78406 .33992 L
.78534 .33992 L
.78599 .33992 L
.7867 .33992 L
.78796 .33992 L
.78914 .33992 L
.78981 .33992 L
.79052 .33992 L
.7918 .33992 L
.7925 .33992 L
.79316 .33992 L
.79389 .33992 L
.79466 .33992 L
.79587 .33992 L
.79718 .33992 L
.79841 .33992 L
.79953 .33992 L
.80079 .33992 L
.80199 .33992 L
.80328 .33992 L
.80401 .33992 L
.80469 .33992 L
.80539 .33992 L
.80605 .33992 L
Mistroke
.80728 .33992 L
.80797 .33992 L
.8086 .33992 L
.8093 .33992 L
.81003 .33992 L
.81124 .33992 L
.81238 .33992 L
.81362 .33992 L
.81431 .33992 L
.81495 .33992 L
.81564 .33992 L
.81637 .33992 L
.81768 .33992 L
.81841 .33992 L
.8191 .33992 L
.81985 .33992 L
.82066 .33992 L
.82135 .33992 L
.8221 .33992 L
.82281 .33992 L
.82348 .33992 L
.82472 .33992 L
.82542 .33992 L
.82606 .33992 L
.82732 .33992 L
.82795 .33992 L
.82865 .33992 L
.82989 .33992 L
.83104 .33992 L
.83174 .33992 L
.8324 .33992 L
.83364 .33992 L
.83434 .33992 L
.83498 .33992 L
.83568 .33992 L
.83643 .33992 L
.83759 .33992 L
.83883 .33992 L
.84 .33992 L
.84108 .33992 L
.84227 .33992 L
.84358 .33992 L
.84424 .33992 L
.84494 .33992 L
.84621 .33992 L
.84686 .33992 L
.84755 .33992 L
.8488 .33992 L
.8501 .33992 L
.85085 .33992 L
Mistroke
.85154 .33992 L
.85274 .33992 L
.85406 .33992 L
.8553 .33992 L
.85645 .33992 L
.85715 .33992 L
.8579 .33992 L
.85862 .33992 L
.85927 .33992 L
.86051 .33992 L
.86183 .33992 L
.86251 .33992 L
.86324 .33992 L
.86456 .33992 L
.86536 .33992 L
.86612 .33992 L
.86681 .33992 L
.86755 .33992 L
.8688 .33992 L
.86997 .33992 L
.87125 .33992 L
.87191 .33992 L
.87263 .33992 L
.87334 .33992 L
.874 .33992 L
.87476 .33992 L
.87545 .33992 L
.87669 .33992 L
.87738 .33992 L
.87802 .33992 L
.8792 .33992 L
.88044 .33992 L
.8815 .33992 L
.88267 .33992 L
.88392 .33992 L
.88463 .33992 L
.88527 .33992 L
.88652 .33992 L
.8877 .33992 L
.88884 .33992 L
.89006 .33992 L
.89122 .33992 L
.89228 .33992 L
.89345 .33992 L
.89474 .33992 L
.89539 .33992 L
.89608 .33992 L
.89733 .33992 L
.89802 .33992 L
.89866 .33992 L
Mistroke
.89935 .33992 L
.90009 .33992 L
.90133 .33992 L
.90204 .33992 L
.9027 .33992 L
.90393 .33992 L
.90505 .33992 L
.90635 .33992 L
.90758 .33992 L
.90874 .33992 L
.90979 .33992 L
.911 .33992 L
.91214 .33992 L
.91321 .33992 L
.91418 .33992 L
.91525 .33992 L
.91638 .33992 L
.91753 .33992 L
.91875 .33992 L
.91991 .33992 L
.92096 .33992 L
.9222 .33992 L
.9229 .33992 L
.92354 .33992 L
.92473 .33992 L
.92599 .33992 L
.92713 .33992 L
.92837 .33992 L
.92967 .33992 L
.93088 .33992 L
.93202 .33992 L
.93305 .33992 L
.93424 .33992 L
.93536 .33992 L
.93659 .33992 L
.93789 .33992 L
.93899 .33992 L
.94021 .33992 L
.94152 .33992 L
.94226 .33992 L
.94293 .33992 L
.94423 .33992 L
.94547 .33992 L
.94662 .33992 L
.94767 .33992 L
.94887 .33992 L
.95001 .33992 L
.95106 .33992 L
.95203 .33992 L
.95309 .33992 L
Mistroke
.95422 .33992 L
.95535 .33992 L
.95657 .33992 L
.95772 .33992 L
.95876 .33992 L
.95999 .33992 L
.96069 .33992 L
.96133 .33992 L
.96259 .33992 L
.96375 .33992 L
.9645 .33992 L
.96522 .33992 L
.96598 .33992 L
.9668 .33992 L
.96752 .33992 L
.96829 .33992 L
.96901 .33992 L
.96967 .33992 L
.97051 .33992 L
.97128 .33992 L
.97213 .33992 L
.97303 .33992 L
.97381 .33992 L
.97453 .33992 L
.97533 .33992 L
.97619 .33992 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 PageWidth->PaperWidth,
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{83.1875, 312.563}, {497.063, 355.75}} -> {-3.88113, \
5.03173, 0.0283515, 0.0139067}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Tau]", "]"}], "5"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "5"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"4", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "5"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "5"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "5"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "5"]}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "5"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "5"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "5"], "+", 
       RowBox[{
        RowBox[{"15", "/", "16"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"3", "\[Tau]"}], "]"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "0"}], "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", "\"\<Fig.1c 5th Power Sinusoid Summation\>\""}]}],
    "]"}], ";"}]], "Input",
 PageWidth->PaperWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309017 0.309017 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -107 0 ]
[.5 .63053 107 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -168 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.1) show
93.000 12.750 moveto
(c) show
105.000 12.750 moveto
(5) show
111.000 12.750 moveto
(th) show
129.000 12.750 moveto
(Power) show
165.000 12.750 moveto
(Sinusoid) show
219.000 12.750 moveto
(Summation) show
273.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30903 L
.04396 .30903 L
.04519 .30903 L
.04654 .30904 L
.04797 .30905 L
.05038 .30907 L
.05174 .30908 L
.05302 .3091 L
.0554 .30913 L
.05757 .30918 L
.06007 .30925 L
.06244 .30933 L
.06486 .30944 L
.06753 .30959 L
.07013 .30978 L
.07293 .31003 L
.07793 .31063 L
.08263 .31141 L
.08821 .31269 L
.09408 .31454 L
.09909 .31661 L
.10458 .31947 L
.11485 .32684 L
.12419 .33618 L
.13497 .35054 L
.14514 .36785 L
.16515 .41226 L
.18361 .46262 L
.20396 .5215 L
.22301 .57065 L
.23238 .5899 L
.24128 .60401 L
.24618 .60982 L
Mistroke
.24877 .61228 L
.25153 .61443 L
.25408 .61598 L
.25639 .61701 L
.25751 .61738 L
.25871 .61769 L
.25985 .61789 L
.2609 .618 L
.26217 .61803 L
.26336 .61796 L
.26444 .61782 L
.26561 .61757 L
.26688 .6172 L
.26823 .61669 L
.27066 .61547 L
.27289 .614 L
.27499 .61232 L
.27976 .60747 L
.28496 .60061 L
.28972 .59295 L
.30044 .57147 L
.34011 .46287 L
.36012 .40859 L
.37827 .3686 L
.38839 .35123 L
.39792 .33818 L
.40799 .32768 L
.41362 .32314 L
.41889 .31967 L
.42838 .31505 L
.43341 .31332 L
.4388 .31191 L
.44151 .31135 L
.44445 .31084 L
.44705 .31047 L
.44981 .31014 L
.45229 .3099 L
.45503 .30968 L
.45986 .3094 L
.4622 .3093 L
.46476 .30922 L
.46744 .30915 L
.46993 .30911 L
.47228 .30908 L
.4744 .30906 L
.47558 .30905 L
.47686 .30904 L
.47918 .30903 L
.48048 .30903 L
.48169 .30902 L
Mistroke
.48302 .30902 L
.48445 .30902 L
.48516 .30902 L
.48594 .30902 L
.48663 .30902 L
.48736 .30902 L
.48808 .30902 L
.48874 .30902 L
.49002 .30902 L
.49131 .30902 L
.4925 .30902 L
.4938 .30902 L
.49446 .30902 L
.49518 .30902 L
.49639 .30902 L
.49769 .30902 L
.49891 .30902 L
.50003 .30902 L
.50121 .30902 L
.50232 .30902 L
.50353 .30902 L
.50484 .30902 L
.50614 .30902 L
.50679 .30902 L
.50751 .30902 L
.50877 .30902 L
.50995 .30902 L
.51115 .30902 L
.51228 .30902 L
.51329 .30902 L
.51439 .30901 L
.51559 .30901 L
.51686 .30901 L
.51794 .30901 L
.51913 .30901 L
.52052 .309 L
.52183 .309 L
.5243 .30898 L
.52568 .30897 L
.52696 .30896 L
.52846 .30895 L
.52986 .30893 L
.53241 .30888 L
.53472 .30883 L
.53721 .30876 L
.53989 .30865 L
.54228 .30853 L
.54483 .30837 L
.54943 .30797 L
.55225 .30766 L
Mistroke
.55491 .30729 L
.55989 .30641 L
.56514 .30514 L
.56999 .30359 L
.57532 .30141 L
.58097 .29844 L
.59037 .29176 L
.6005 .28172 L
.61005 .26916 L
.61879 .25485 L
.63777 .21463 L
.65849 .15917 L
.6798 .09755 L
.69912 .04756 L
.70879 .02773 L
.71388 .01918 L
.71926 .01173 L
.72397 .00664 L
.72647 .00452 L
.72914 .00268 L
.73041 .00198 L
.7316 .00141 L
.73277 .00095 L
.73385 .00061 L
.73487 .00035 L
.73595 .00015 L
.73704 4e-005 L
.73824 0 L
.73945 6e-005 L
.74059 .00021 L
.74183 .00047 L
.74315 .00086 L
.74455 .0014 L
.74586 .00202 L
.74833 .0035 L
.75276 .00716 L
.75758 .01254 L
.76843 .02962 L
.77843 .05069 L
.81782 .15952 L
.83761 .21265 L
.8557 .25174 L
.86567 .26845 L
.87513 .28107 L
.88513 .29118 L
.89078 .29558 L
.89602 .29891 L
.90111 .30152 L
.90661 .30374 L
.9118 .30534 L
Mistroke
.91658 .30646 L
.9209 .30723 L
.92563 .30785 L
.92802 .3081 L
.93058 .30831 L
.93519 .3086 L
.93774 .30871 L
.94044 .3088 L
.94274 .30886 L
.94529 .30891 L
.94801 .30895 L
.94954 .30897 L
.95095 .30898 L
.95354 .30899 L
.95484 .309 L
.95626 .30901 L
.9576 .30901 L
.95888 .30901 L
.96002 .30901 L
.96125 .30901 L
.9626 .30902 L
.96328 .30902 L
.96403 .30902 L
.96535 .30902 L
.96659 .30902 L
.96783 .30902 L
.96901 .30902 L
.97007 .30902 L
.97122 .30902 L
.97247 .30902 L
.9731 .30902 L
.9738 .30902 L
.97503 .30902 L
.97619 .30902 L
Mfstroke
0 1 0 r
.02381 .45955 m
.04262 .40869 L
.06244 .36555 L
.07286 .34834 L
.08255 .33573 L
.0932 .32542 L
.09916 .32108 L
.10458 .31792 L
.10941 .31566 L
.11454 .31376 L
.11891 .31249 L
.12373 .31141 L
.1289 .31056 L
.1318 .3102 L
.13446 .30993 L
.13692 .30972 L
.13961 .30954 L
.14216 .30941 L
.14451 .30931 L
.14706 .30922 L
.14982 .30916 L
.15226 .30911 L
.15483 .30908 L
.15713 .30906 L
.15929 .30904 L
.16052 .30904 L
.16165 .30903 L
.16285 .30903 L
.16418 .30902 L
.16548 .30902 L
.16686 .30902 L
.16814 .30902 L
.16934 .30902 L
.17003 .30902 L
.17075 .30902 L
.17204 .30902 L
.17276 .30902 L
.17343 .30902 L
.17417 .30902 L
.17495 .30902 L
.17627 .30902 L
.17702 .30902 L
.1777 .30902 L
.17896 .30902 L
.1796 .30902 L
.1803 .30902 L
.18151 .30902 L
.18281 .30902 L
.18403 .30902 L
.18516 .30902 L
Mistroke
.18645 .30902 L
.18766 .30902 L
.18876 .30902 L
.18994 .30902 L
.19123 .30902 L
.19188 .30902 L
.19259 .30902 L
.19385 .30902 L
.19503 .30902 L
.19621 .30902 L
.19734 .30901 L
.19835 .30901 L
.19945 .30901 L
.20064 .30901 L
.20191 .30901 L
.20299 .309 L
.20418 .309 L
.20549 .30899 L
.20687 .30898 L
.20933 .30897 L
.21071 .30895 L
.21198 .30893 L
.21488 .30889 L
.21743 .30883 L
.21974 .30876 L
.2224 .30865 L
.22492 .30852 L
.22956 .3082 L
.2322 .30795 L
.23466 .30767 L
.23964 .30694 L
.24497 .30584 L
.24993 .30447 L
.25462 .3028 L
.26343 .29849 L
.26801 .29554 L
.27307 .29163 L
.28332 .28139 L
.29281 .26883 L
.30173 .25413 L
.32189 .21076 L
.34039 .16101 L
.36089 .10165 L
.37998 .05144 L
.38944 .03126 L
.39838 .01627 L
.40332 .00994 L
.40593 .0072 L
.40868 .00477 L
.411 .00311 L
Mistroke
.41356 .00168 L
.41468 .00119 L
.41588 .00076 L
.41702 .00044 L
.41805 .00022 L
.41934 6e-005 L
.42056 0 L
.42165 3e-005 L
.42283 .00016 L
.42411 .00041 L
.42476 .00057 L
.42547 .00079 L
.42791 .00178 L
.43019 .00306 L
.43264 .00481 L
.43705 .00895 L
.44263 .01589 L
.4479 .02414 L
.45778 .04349 L
.49613 .14733 L
.51553 .20105 L
.52583 .22609 L
.53693 .2493 L
.54751 .2674 L
.5572 .28052 L
.56647 .29013 L
.57158 .29432 L
.57622 .29751 L
.58578 .30245 L
.59102 .30437 L
.59598 .30576 L
.60057 .30674 L
.6048 .30743 L
.60944 .30799 L
.61178 .3082 L
.61435 .3084 L
.61685 .30855 L
.61957 .30868 L
.62214 .30878 L
.62452 .30884 L
.62688 .3089 L
.62902 .30893 L
.63149 .30896 L
.63381 .30898 L
.63503 .30899 L
.63636 .309 L
.63775 .309 L
.63905 .30901 L
.64027 .30901 L
.64137 .30901 L
Mistroke
.64265 .30901 L
.64386 .30901 L
.64517 .30902 L
.64583 .30902 L
.64656 .30902 L
.64785 .30902 L
.64906 .30902 L
.64979 .30902 L
.65048 .30902 L
.65178 .30902 L
.65251 .30902 L
.65318 .30902 L
.65392 .30902 L
.65471 .30902 L
.65595 .30902 L
.65665 .30902 L
.65731 .30902 L
.65801 .30902 L
.65864 .30902 L
.65937 .30902 L
.66006 .30902 L
.66129 .30902 L
.66242 .30902 L
.66367 .30902 L
.66499 .30902 L
.6663 .30902 L
.66704 .30902 L
.66771 .30902 L
.66896 .30902 L
.67027 .30902 L
.67097 .30902 L
.67172 .30902 L
.67306 .30902 L
.67388 .30902 L
.67466 .30902 L
.67611 .30902 L
.67728 .30903 L
.67856 .30903 L
.67989 .30903 L
.68114 .30904 L
.68338 .30905 L
.68464 .30906 L
.68579 .30907 L
.68836 .3091 L
.68982 .30913 L
.69117 .30915 L
.69364 .30921 L
.69628 .30929 L
.69889 .3094 L
.70165 .30954 L
Mistroke
.70658 .30991 L
.70933 .31018 L
.7119 .3105 L
.71772 .31145 L
.72282 .31261 L
.72747 .314 L
.73283 .31607 L
.7379 .31857 L
.74757 .32502 L
.75246 .32925 L
.75784 .33475 L
.77627 .36097 L
.78638 .38046 L
.79565 .40135 L
.81651 .45684 L
.83707 .51636 L
.85618 .56662 L
.86567 .58686 L
.87463 .60185 L
.87959 .60818 L
.8822 .61091 L
.88496 .61333 L
.88728 .61498 L
.88983 .61639 L
.89095 .61688 L
.89216 .6173 L
.89329 .61761 L
.89433 .61782 L
.8955 .61797 L
.8966 .61803 L
.89781 .618 L
.89912 .61786 L
.90041 .6176 L
.90106 .61743 L
.90178 .61721 L
.90422 .6162 L
.90651 .61489 L
.90896 .61312 L
.91338 .60894 L
.91896 .60193 L
.92424 .59363 L
.93413 .57421 L
.97255 .47006 L
.97619 .45955 L
Mfstroke
0 0 1 r
.02381 .15848 m
.04262 .10396 L
.06244 .05161 L
.07216 .03091 L
.08255 .01401 L
.08562 .01021 L
.08852 .00714 L
.09135 .00467 L
.09396 .00285 L
.09643 .00153 L
.09768 .00101 L
.09905 .00057 L
.09976 .00039 L
.10043 .00025 L
.1012 .00013 L
.10191 5e-005 L
.10318 0 L
.10391 2e-005 L
.10458 7e-005 L
.10587 .00024 L
.10651 .00037 L
.10722 .00055 L
.10848 .00095 L
.10966 .00141 L
.11231 .00279 L
.11515 .00479 L
.12035 .00979 L
.1251 .01581 L
.13466 .03181 L
.14371 .05115 L
.18204 .15705 L
.20142 .20953 L
.21172 .23353 L
.22282 .25546 L
.23339 .27228 L
.24307 .28429 L
.25234 .29294 L
.25745 .29666 L
.26209 .29946 L
.26667 .30174 L
.27163 .30372 L
.27688 .30534 L
.28183 .3065 L
.28647 .30731 L
.29139 .30793 L
.29558 .3083 L
.29797 .30847 L
.3002 .30859 L
.30261 .3087 L
.30518 .30879 L
Mistroke
.30799 .30887 L
.3106 .30892 L
.31189 .30894 L
.31327 .30895 L
.3145 .30897 L
.31579 .30898 L
.31696 .30898 L
.31823 .30899 L
.32048 .309 L
.32173 .30901 L
.32291 .30901 L
.32397 .30901 L
.32512 .30901 L
.32637 .30901 L
.32705 .30901 L
.32769 .30902 L
.32883 .30902 L
.33008 .30902 L
.33117 .30902 L
.33232 .30902 L
.33331 .30902 L
.33438 .30902 L
.33555 .30902 L
.33679 .30902 L
.33796 .30902 L
.33902 .30902 L
.34022 .30902 L
.34134 .30902 L
.34257 .30902 L
.34388 .30902 L
.34455 .30902 L
.34527 .30902 L
.34657 .30902 L
.34785 .30902 L
.34903 .30902 L
.35012 .30902 L
.35115 .30902 L
.35228 .30902 L
.35349 .30902 L
.3547 .30902 L
.35597 .30902 L
.35706 .30902 L
.35824 .30902 L
.35965 .30902 L
.36097 .30903 L
.36216 .30903 L
.36345 .30904 L
.36486 .30904 L
.36635 .30905 L
.36764 .30906 L
Mistroke
.36902 .30908 L
.37149 .30911 L
.3738 .30915 L
.37654 .30922 L
.37905 .3093 L
.38156 .3094 L
.38383 .30952 L
.38627 .30968 L
.38891 .30989 L
.39362 .31039 L
.39805 .31104 L
.40331 .3121 L
.40885 .31363 L
.41359 .31533 L
.41878 .31769 L
.42403 .32068 L
.429 .32415 L
.43831 .33252 L
.44833 .34461 L
.45923 .3617 L
.47902 .40335 L
.50003 .45963 L
.51974 .51672 L
.5378 .56446 L
.54705 .5846 L
.55716 .60184 L
.56243 .60852 L
.56733 .61319 L
.57004 .61512 L
.5725 .61645 L
.57386 .61702 L
.57458 .61727 L
.57534 .61749 L
.57601 .61765 L
.57674 .6178 L
.57802 .61797 L
.57932 .61803 L
.58052 .61799 L
.58184 .61783 L
.58258 .61769 L
.58324 .61753 L
.58447 .61716 L
.58579 .61665 L
.58819 .61542 L
.59055 .61385 L
.59304 .6118 L
.59748 .60716 L
.60746 .59247 L
.61838 .57037 L
.65888 .45913 L
Mistroke
.67757 .40862 L
.69786 .36465 L
.70893 .34667 L
.71916 .33386 L
.72893 .32477 L
.73386 .32122 L
.73929 .31803 L
.74448 .3156 L
.74942 .31377 L
.75385 .31249 L
.75869 .3114 L
.76393 .31055 L
.76686 .31018 L
.76952 .30992 L
.772 .30971 L
.77469 .30953 L
.77724 .3094 L
.77957 .3093 L
.78194 .30923 L
.78448 .30916 L
.78684 .30912 L
.78907 .30909 L
.79032 .30907 L
.79166 .30906 L
.79406 .30904 L
.79539 .30904 L
.79665 .30903 L
.79802 .30903 L
.7995 .30902 L
.80082 .30902 L
.80205 .30902 L
.8034 .30902 L
.80416 .30902 L
.80485 .30902 L
.80552 .30902 L
.80624 .30902 L
.80702 .30902 L
.80775 .30902 L
.80905 .30902 L
.80979 .30902 L
.81048 .30902 L
.81178 .30902 L
.81302 .30902 L
.81413 .30902 L
.81534 .30902 L
.81665 .30902 L
.81738 .30902 L
.81805 .30902 L
.81934 .30902 L
.82056 .30902 L
Mistroke
.82172 .30902 L
.82297 .30902 L
.82415 .30902 L
.82523 .30902 L
.82649 .30902 L
.8272 .30902 L
.82785 .30902 L
.82906 .30902 L
.83034 .30902 L
.83156 .30901 L
.83288 .30901 L
.83412 .30901 L
.83525 .30901 L
.83651 .30901 L
.83789 .309 L
.83933 .309 L
.84067 .30899 L
.84183 .30898 L
.84308 .30898 L
.84535 .30895 L
.84757 .30892 L
.84961 .30889 L
.85182 .30884 L
.85425 .30877 L
.85678 .30867 L
.85915 .30856 L
.86414 .30823 L
.86696 .30797 L
.86958 .30767 L
.87437 .30697 L
.87947 .30594 L
.88401 .30473 L
.88828 .30329 L
.89801 .29869 L
.9027 .2957 L
.90782 .29178 L
.91816 .28148 L
.92774 .26882 L
.93666 .25412 L
.95708 .21009 L
.97566 .16001 L
.97619 .15848 L
Mfstroke
0 0 0 r
.02381 .30902 m
.04262 .20365 L
.06244 .10846 L
.07286 .06993 L
.08255 .04311 L
.08813 .03207 L
.09076 .02801 L
.0932 .02495 L
.096 .02223 L
.09748 .02115 L
.09824 .0207 L
.09905 .02028 L
.09976 .01998 L
.10041 .01975 L
.10168 .01944 L
.10239 .01935 L
.10317 .01931 L
.1039 .01934 L
.10458 .01943 L
.10587 .01972 L
.10651 .01995 L
.10722 .02024 L
.10848 .02091 L
.10966 .02169 L
.11231 .02403 L
.11515 .02741 L
.12035 .0359 L
.1251 .04617 L
.13466 .07376 L
.14371 .10765 L
.18204 .30615 L
.20142 .41479 L
.21172 .46719 L
.22282 .51628 L
.23339 .55379 L
.23801 .56693 L
.24307 .57883 L
.24787 .58762 L
.25234 .59354 L
.25481 .59587 L
.25705 .59738 L
.25829 .59798 L
.259 .59824 L
.25964 .59843 L
.26083 .59865 L
.26209 .59872 L
.2633 .59861 L
.26462 .5983 L
.26586 .59783 L
.26702 .59724 L
Mistroke
.2692 .59571 L
.27152 .59349 L
.27427 .59009 L
.27684 .58615 L
.28166 .57685 L
.29046 .55366 L
.29997 .5203 L
.31995 .42765 L
.34103 .31039 L
.36093 .1991 L
.37905 .112 L
.3891 .07394 L
.3986 .04642 L
.40382 .03522 L
.40863 .02745 L
.41115 .0244 L
.41392 .02187 L
.41532 .02092 L
.41605 .02051 L
.41682 .02014 L
.41749 .01987 L
.41823 .01964 L
.41953 .01938 L
.42017 .01933 L
.42086 .01932 L
.42208 .01943 L
.42339 .01974 L
.42414 .02001 L
.42483 .02031 L
.42724 .02179 L
.4286 .0229 L
.42983 .0241 L
.43463 .03036 L
.43918 .03861 L
.44922 .06444 L
.46014 .10346 L
.47989 .19675 L
.50089 .31414 L
.52056 .42369 L
.53861 .50948 L
.54802 .54474 L
.55794 .57305 L
.56309 .58382 L
.56789 .59128 L
.57065 .59442 L
.57315 .59653 L
.57454 .5974 L
.57527 .59777 L
.57605 .5981 L
.57672 .59832 L
Mistroke
.57747 .59852 L
.57878 .5987 L
.58007 .59869 L
.58127 .59851 L
.58259 .59813 L
.58332 .59783 L
.58399 .59751 L
.58653 .59581 L
.58893 .59355 L
.59339 .58764 L
.59821 .57881 L
.6035 .5663 L
.60909 .55003 L
.61909 .51369 L
.65708 .31846 L
.67824 .1999 L
.69753 .10779 L
.70711 .07212 L
.71216 .05666 L
.71752 .043 L
.7222 .03353 L
.72468 .02946 L
.72736 .02583 L
.72981 .0232 L
.73088 .02226 L
.73205 .02138 L
.73309 .02073 L
.7342 .02018 L
.73537 .01974 L
.73645 .01947 L
.73769 .01932 L
.73839 .01932 L
.73905 .01936 L
.73974 .01947 L
.74037 .01961 L
.7411 .01983 L
.74179 .02009 L
.74301 .02068 L
.74414 .02139 L
.74671 .02351 L
.74953 .0267 L
.75209 .03035 L
.75782 .0411 L
.76281 .05329 L
.7682 .06925 L
.77797 .10496 L
.81905 .31812 L
.83953 .43155 L
.84952 .48073 L
.85861 .51972 L
Mistroke
.86742 .55102 L
.87699 .57667 L
.88224 .58673 L
.88455 .59021 L
.88709 .59336 L
.88949 .59567 L
.89173 .59725 L
.89297 .59788 L
.8941 .5983 L
.89541 .59861 L
.89665 .59872 L
.89789 .59866 L
.89859 .59854 L
.89924 .59839 L
.90042 .59799 L
.90168 .59739 L
.90385 .59593 L
.90623 .59371 L
.90878 .59065 L
.91151 .58656 L
.91645 .57715 L
.92606 .55155 L
.93483 .52055 L
.95391 .43268 L
.97467 .31776 L
.97619 .30902 L
Mfstroke
1 0 0 r
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02946 .30902 L
.03053 .30902 L
.0317 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07166 .30902 L
.07236 .30902 L
.073 .30902 L
Mistroke
.07374 .30902 L
.07443 .30902 L
.07507 .30902 L
.07577 .30902 L
.07653 .30902 L
.07734 .30902 L
.07803 .30902 L
.07878 .30902 L
.0795 .30902 L
.08015 .30902 L
.08091 .30902 L
.08162 .30902 L
.08289 .30902 L
.08361 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13327 .30902 L
.13585 .30902 L
.13712 .30902 L
.1383 .30902 L
.13936 .30902 L
.14049 .30902 L
.14163 .30902 L
.14288 .30902 L
.14405 .30902 L
.1453 .30902 L
.14649 .30902 L
.14758 .30902 L
.14876 .30902 L
.15004 .30902 L
.15069 .30902 L
.15138 .30902 L
.15262 .30902 L
.1538 .30902 L
.15507 .30902 L
.15628 .30902 L
.15739 .30902 L
.15839 .30902 L
.15949 .30902 L
.16064 .30902 L
.16172 .30902 L
.163 .30902 L
.16372 .30902 L
.16439 .30902 L
.16562 .30902 L
.16693 .30902 L
.16821 .30902 L
.16942 .30902 L
.17051 .30902 L
.17168 .30902 L
.17298 .30902 L
.17371 .30902 L
.1744 .30902 L
.17512 .30902 L
.17578 .30902 L
Mistroke
.17654 .30902 L
.17726 .30902 L
.17854 .30902 L
.17972 .30902 L
.18037 .30902 L
.18108 .30902 L
.18238 .30902 L
.18364 .30902 L
.18481 .30902 L
.18589 .30902 L
.18704 .30902 L
.18769 .30902 L
.18839 .30902 L
.18966 .30902 L
.19091 .30902 L
.19205 .30902 L
.19313 .30902 L
.19415 .30902 L
.19526 .30902 L
.19645 .30902 L
.1977 .30902 L
.19888 .30902 L
.19994 .30902 L
.2011 .30902 L
.20237 .30902 L
.20357 .30902 L
.20426 .30902 L
.20499 .30902 L
.20629 .30902 L
.20756 .30902 L
.20828 .30902 L
.20895 .30902 L
.20967 .30902 L
.21033 .30902 L
.21109 .30902 L
.21181 .30902 L
.21301 .30902 L
.21428 .30902 L
.21537 .30902 L
.21657 .30902 L
.21785 .30902 L
.21857 .30902 L
.21923 .30902 L
.22051 .30902 L
.22172 .30902 L
.22297 .30902 L
.22367 .30902 L
.22432 .30902 L
.22551 .30902 L
.22676 .30902 L
Mistroke
.22789 .30902 L
.22894 .30902 L
.23009 .30902 L
.23133 .30902 L
.23265 .30902 L
.23339 .30902 L
.23408 .30902 L
.23534 .30902 L
.23598 .30902 L
.23668 .30902 L
.23789 .30902 L
.2392 .30902 L
.24042 .30902 L
.24156 .30902 L
.24264 .30902 L
.2438 .30902 L
.24508 .30902 L
.24624 .30902 L
.24745 .30902 L
.24877 .30902 L
.25002 .30902 L
.25116 .30902 L
.25229 .30902 L
.25352 .30902 L
.25468 .30902 L
.25576 .30902 L
.25673 .30902 L
.25779 .30902 L
.25891 .30902 L
.25996 .30902 L
.26113 .30902 L
.26221 .30902 L
.26339 .30902 L
.26464 .30902 L
.26588 .30902 L
.26704 .30902 L
.26831 .30902 L
.26902 .30902 L
.26967 .30902 L
.27083 .30902 L
.27191 .30902 L
.27306 .30902 L
.27434 .30902 L
.27544 .30902 L
.27648 .30902 L
.27757 .30902 L
.27875 .30902 L
.28003 .30902 L
.28074 .30902 L
.28139 .30902 L
Mistroke
.28216 .30902 L
.28289 .30902 L
.28356 .30902 L
.28428 .30902 L
.28491 .30902 L
.28561 .30902 L
.28634 .30902 L
.28702 .30902 L
.28823 .30902 L
.28953 .30902 L
.2908 .30902 L
.29152 .30902 L
.29218 .30902 L
.2934 .30902 L
.29469 .30902 L
.29585 .30902 L
.29693 .30902 L
.29812 .30902 L
.2994 .30902 L
.30066 .30902 L
.3018 .30902 L
.30312 .30902 L
.30436 .30902 L
.30551 .30902 L
.30657 .30902 L
.30774 .30902 L
.30897 .30902 L
.31022 .30902 L
.31091 .30902 L
.31155 .30902 L
.31279 .30902 L
.31396 .30902 L
.31462 .30902 L
.31532 .30902 L
.31658 .30902 L
.31736 .30902 L
.31809 .30902 L
.31874 .30902 L
.31945 .30902 L
.32077 .30902 L
.322 .30902 L
.32269 .30902 L
.32335 .30902 L
.32411 .30902 L
.3248 .30902 L
.32548 .30902 L
.3262 .30902 L
.3275 .30902 L
.32823 .30902 L
.3289 .30902 L
Mistroke
.32964 .30902 L
.33044 .30902 L
.33174 .30902 L
.33247 .30902 L
.33315 .30902 L
.33439 .30902 L
.33509 .30902 L
.33572 .30902 L
.33691 .30902 L
.3382 .30902 L
.33942 .30902 L
.34055 .30902 L
.34181 .30902 L
.343 .30902 L
.34407 .30902 L
.34524 .30902 L
.3465 .30902 L
.34714 .30902 L
.34785 .30902 L
.3491 .30902 L
.35027 .30902 L
.35138 .30902 L
.35255 .30902 L
.35355 .30902 L
.35464 .30902 L
.35582 .30902 L
.35708 .30902 L
.35827 .30902 L
.35935 .30902 L
.36064 .30902 L
.36129 .30902 L
.362 .30902 L
.36327 .30902 L
.36445 .30902 L
.36516 .30902 L
.36584 .30902 L
.36711 .30902 L
.36782 .30902 L
.36848 .30902 L
.3692 .30902 L
.36998 .30902 L
.37128 .30902 L
.37201 .30902 L
.37269 .30902 L
.37393 .30902 L
.37524 .30902 L
.37642 .30902 L
.37751 .30902 L
.37872 .30902 L
.38001 .30902 L
Mistroke
.38123 .30902 L
.38192 .30902 L
.38258 .30902 L
.38389 .30902 L
.38463 .30902 L
.3853 .30902 L
.38644 .30902 L
.38769 .30902 L
.38899 .30902 L
.3902 .30902 L
.39089 .30902 L
.39164 .30902 L
.39235 .30902 L
.393 .30902 L
.39424 .30902 L
.39555 .30902 L
.39623 .30902 L
.39697 .30902 L
.39766 .30902 L
.39831 .30902 L
.39906 .30902 L
.39986 .30902 L
.4006 .30902 L
.40127 .30902 L
.4025 .30902 L
.40319 .30902 L
.40382 .30902 L
.40623 .30902 L
.40739 .30902 L
.40848 .30902 L
.40962 .30902 L
.41086 .30902 L
.41152 .30902 L
.41223 .30902 L
.41352 .30902 L
.41479 .30902 L
.41595 .30902 L
.41721 .30902 L
.41792 .30902 L
.41859 .30902 L
.4193 .30902 L
.41994 .30902 L
.42069 .30902 L
.4214 .30902 L
.42264 .30902 L
.42334 .30902 L
.42399 .30902 L
.42517 .30902 L
.42642 .30902 L
.42755 .30902 L
Mistroke
.4286 .30902 L
.42975 .30902 L
.43098 .30902 L
.4323 .30902 L
.43304 .30902 L
.43373 .30902 L
.43499 .30902 L
.43562 .30902 L
.43633 .30902 L
.43754 .30902 L
.43884 .30902 L
.44007 .30902 L
.4412 .30902 L
.44227 .30902 L
.44342 .30902 L
.4444 .30902 L
.44548 .30902 L
.44674 .30902 L
.44793 .30902 L
.44909 .30902 L
.45016 .30902 L
.45128 .30902 L
.45234 .30902 L
.45349 .30902 L
.45474 .30902 L
.45604 .30902 L
.45727 .30902 L
.45838 .30902 L
.45959 .30902 L
.46024 .30902 L
.46092 .30902 L
.46215 .30902 L
.46347 .30902 L
.46422 .30902 L
.46491 .30902 L
.46618 .30902 L
.46734 .30902 L
.46797 .30902 L
.46867 .30902 L
.46993 .30902 L
.47105 .30902 L
.47229 .30902 L
.47358 .30902 L
.4748 .30902 L
.47593 .30902 L
.47696 .30902 L
.4781 .30902 L
.47929 .30902 L
.48061 .30902 L
.48181 .30902 L
Mistroke
.48247 .30902 L
.48319 .30902 L
.48449 .30902 L
.48571 .30902 L
.48701 .30902 L
.48811 .30902 L
.48932 .30902 L
.49006 .30902 L
.49075 .30902 L
.49205 .30902 L
.49278 .30902 L
.49346 .30902 L
.4942 .30902 L
.49499 .30902 L
.49628 .30902 L
.4975 .30902 L
.4982 .30902 L
.49884 .30902 L
.49954 .30902 L
.50028 .30902 L
.50151 .30902 L
.5022 .30902 L
.50284 .30902 L
.50402 .30902 L
.50527 .30902 L
.50638 .30902 L
.50743 .30902 L
.50857 .30902 L
.50981 .30902 L
.51111 .30902 L
.51185 .30902 L
.51253 .30902 L
.51379 .30902 L
.51449 .30902 L
.51513 .30902 L
.51633 .30902 L
.51763 .30902 L
.51886 .30902 L
.51999 .30902 L
.52106 .30902 L
.52219 .30902 L
.52327 .30902 L
.52425 .30902 L
.5254 .30902 L
.52665 .30902 L
.52783 .30902 L
.52892 .30902 L
.53004 .30902 L
.5311 .30902 L
.53225 .30902 L
Mistroke
.53349 .30902 L
.53473 .30902 L
.53603 .30902 L
.53714 .30902 L
.53835 .30902 L
.53967 .30902 L
.54089 .30902 L
.54153 .30902 L
.54223 .30902 L
.54296 .30902 L
.54364 .30902 L
.54428 .30902 L
.54498 .30902 L
.54625 .30902 L
.54749 .30902 L
.54863 .30902 L
.54978 .30902 L
.55081 .30902 L
.55201 .30902 L
.55314 .30902 L
.55435 .30902 L
.55546 .30902 L
.55668 .30902 L
.55797 .30902 L
.55928 .30902 L
.56047 .30902 L
.56113 .30902 L
.56185 .30902 L
.56315 .30902 L
.56436 .30902 L
.56565 .30902 L
.56676 .30902 L
.56797 .30902 L
.5687 .30902 L
.56939 .30902 L
.57069 .30902 L
.57142 .30902 L
.5721 .30902 L
.57284 .30902 L
.57363 .30902 L
.57431 .30902 L
.57506 .30902 L
.57576 .30902 L
.57641 .30902 L
.5777 .30902 L
.57893 .30902 L
.5801 .30902 L
.58138 .30902 L
.58254 .30902 L
.58362 .30902 L
Mistroke
.58478 .30902 L
.58606 .30902 L
.5867 .30902 L
.5874 .30902 L
.58865 .30902 L
.58976 .30902 L
.59096 .30902 L
.59222 .30902 L
.59339 .30902 L
.59449 .30902 L
.59549 .30902 L
.59665 .30902 L
.59774 .30902 L
.59903 .30902 L
.60024 .30902 L
.6015 .30902 L
.60217 .30902 L
.60289 .30902 L
.60417 .30902 L
.60538 .30902 L
.60646 .30902 L
.60765 .30902 L
.60832 .30902 L
.60904 .30902 L
.61035 .30902 L
.61114 .30902 L
.61186 .30902 L
.61252 .30902 L
.61322 .30902 L
.6145 .30902 L
.61569 .30902 L
.617 .30902 L
.61773 .30902 L
.6184 .30902 L
.61958 .30902 L
.62069 .30902 L
.6219 .30902 L
.62321 .30902 L
.62452 .30902 L
.62517 .30902 L
.62588 .30902 L
.62715 .30902 L
.62833 .30902 L
.62953 .30902 L
.63066 .30902 L
.63167 .30902 L
.63277 .30902 L
.63397 .30902 L
.63524 .30902 L
.63632 .30902 L
Mistroke
.63751 .30902 L
.63817 .30902 L
.6389 .30902 L
.64021 .30902 L
.6415 .30902 L
.64269 .30902 L
.64396 .30902 L
.64469 .30902 L
.64538 .30902 L
.6461 .30902 L
.64676 .30902 L
.64748 .30902 L
.64824 .30902 L
.64944 .30902 L
.65072 .30902 L
.65193 .30902 L
.65303 .30902 L
.65433 .30902 L
.65505 .30902 L
.65573 .30902 L
.65697 .30902 L
.65828 .30902 L
.65948 .30902 L
.6608 .30902 L
.66204 .30902 L
.66319 .30902 L
.66433 .30902 L
.66537 .30902 L
.66656 .30902 L
.66769 .30902 L
.66892 .30902 L
.67022 .30902 L
.67133 .30902 L
.67255 .30902 L
.67387 .30902 L
.6746 .30902 L
.67527 .30902 L
.67658 .30902 L
.67781 .30902 L
.67886 .30902 L
.68002 .30902 L
.68123 .30902 L
.68237 .30902 L
.68343 .30902 L
.6844 .30902 L
.68546 .30902 L
.68658 .30902 L
.68772 .30902 L
.68894 .30902 L
.69009 .30902 L
Mistroke
.69113 .30902 L
.69236 .30902 L
.69306 .30902 L
.6937 .30902 L
.69487 .30902 L
.69612 .30902 L
.69733 .30902 L
.69865 .30902 L
.69989 .30902 L
.70105 .30902 L
.70219 .30902 L
.70323 .30902 L
.70443 .30902 L
.70555 .30902 L
.70678 .30902 L
.70793 .30902 L
.70912 .30902 L
.71043 .30902 L
.71175 .30902 L
.71248 .30902 L
.71317 .30902 L
.71449 .30902 L
.71569 .30902 L
.71674 .30902 L
.71791 .30902 L
.71912 .30902 L
.72025 .30902 L
.72131 .30902 L
.72228 .30902 L
.72335 .30902 L
.72447 .30902 L
.72561 .30902 L
.72683 .30902 L
.72798 .30902 L
.72903 .30902 L
.73026 .30902 L
.73095 .30902 L
.73159 .30902 L
.73276 .30902 L
.73401 .30902 L
.73522 .30902 L
.73591 .30902 L
.73655 .30902 L
.73771 .30902 L
.73895 .30902 L
.74006 .30902 L
.7411 .30902 L
.74224 .30902 L
.74347 .30902 L
.7447 .30902 L
Mistroke
.7454 .30902 L
.74605 .30902 L
.74736 .30902 L
.7481 .30902 L
.74876 .30902 L
.74996 .30902 L
.75126 .30902 L
.75249 .30902 L
.75362 .30902 L
.75468 .30902 L
.75581 .30902 L
.75688 .30902 L
.75786 .30902 L
.759 .30902 L
.76025 .30902 L
.76143 .30902 L
.76252 .30902 L
.76375 .30902 L
.76491 .30902 L
.76596 .30902 L
.76708 .30902 L
.76832 .30902 L
.76962 .30902 L
.77073 .30902 L
.77195 .30902 L
.77325 .30902 L
.77446 .30902 L
.77509 .30902 L
.77579 .30902 L
.77651 .30902 L
.7772 .30902 L
.77844 .30902 L
.77959 .30902 L
.78084 .30902 L
.78216 .30902 L
.78328 .30902 L
.78447 .30902 L
.78559 .30902 L
.78661 .30902 L
.78781 .30902 L
.78911 .30902 L
.79034 .30902 L
.79147 .30902 L
.79268 .30902 L
.79398 .30902 L
.7952 .30902 L
.79632 .30902 L
.79762 .30902 L
.79836 .30902 L
.79905 .30902 L
Mistroke
.80029 .30902 L
.801 .30902 L
.80164 .30902 L
.80233 .30902 L
.80305 .30902 L
.80368 .30902 L
.80438 .30902 L
.80566 .30902 L
.80685 .30902 L
.80757 .30902 L
.80825 .30902 L
.80953 .30902 L
.81024 .30902 L
.8109 .30902 L
.81163 .30902 L
.8124 .30902 L
.8136 .30902 L
.81491 .30902 L
.81615 .30902 L
.81731 .30902 L
.81845 .30902 L
.81948 .30902 L
.82068 .30902 L
.8218 .30902 L
.82303 .30902 L
.82433 .30902 L
.82544 .30902 L
.82666 .30902 L
.82798 .30902 L
.82871 .30902 L
.82938 .30902 L
.83069 .30902 L
.83192 .30902 L
.83297 .30902 L
.83413 .30902 L
.83534 .30902 L
.83647 .30902 L
.83753 .30902 L
.8385 .30902 L
.83957 .30902 L
.84069 .30902 L
.84183 .30902 L
.84304 .30902 L
.84419 .30902 L
.84524 .30902 L
.84647 .30902 L
.84716 .30902 L
.8478 .30902 L
.84898 .30902 L
.85022 .30902 L
Mistroke
.85143 .30902 L
.85275 .30902 L
.85399 .30902 L
.85515 .30902 L
.85629 .30902 L
.85733 .30902 L
.85853 .30902 L
.85965 .30902 L
.86089 .30902 L
.86219 .30902 L
.8633 .30902 L
.86452 .30902 L
.86584 .30902 L
.86658 .30902 L
.86725 .30902 L
.86855 .30902 L
.86979 .30902 L
.87084 .30902 L
.872 .30902 L
.87321 .30902 L
.87435 .30902 L
.87541 .30902 L
.87638 .30902 L
.87744 .30902 L
.87856 .30902 L
.87971 .30902 L
.88092 .30902 L
.88208 .30902 L
.88312 .30902 L
.88435 .30902 L
.88504 .30902 L
.88568 .30902 L
.88686 .30902 L
.8881 .30902 L
.88931 .30902 L
.89 .30902 L
.89064 .30902 L
.8918 .30902 L
.89304 .30902 L
.89415 .30902 L
.89519 .30902 L
.89632 .30902 L
.89756 .30902 L
.8988 .30902 L
.9001 .30902 L
.90131 .30902 L
.90244 .30902 L
.90312 .30902 L
.90377 .30902 L
.90498 .30902 L
Mistroke
.90629 .30902 L
.90703 .30902 L
.90771 .30902 L
.90876 .30902 L
.90989 .30902 L
.91096 .30902 L
.91194 .30902 L
.91308 .30902 L
.91433 .30902 L
.91551 .30902 L
.9166 .30902 L
.91783 .30902 L
.91899 .30902 L
.92004 .30902 L
.92116 .30902 L
.92371 .30902 L
.92482 .30902 L
.92603 .30902 L
.92725 .30902 L
.9284 .30902 L
.92973 .30902 L
.93095 .30902 L
.93201 .30902 L
.93317 .30902 L
.93439 .30902 L
.93554 .30902 L
.93682 .30902 L
.93746 .30902 L
.93816 .30902 L
.9394 .30902 L
.94056 .30902 L
.94127 .30902 L
.94193 .30902 L
.94318 .30902 L
.94388 .30902 L
.94452 .30902 L
.94523 .30902 L
.94598 .30902 L
.94728 .30902 L
.94848 .30902 L
.94913 .30902 L
.94985 .30902 L
.95116 .30902 L
.95238 .30902 L
.95368 .30902 L
.9549 .30902 L
.95601 .30902 L
.9567 .30902 L
.95743 .30902 L
.95874 .30902 L
Mistroke
.95947 .30902 L
.96015 .30902 L
.9609 .30902 L
.96169 .30902 L
.96238 .30902 L
.96313 .30902 L
.96384 .30902 L
.96449 .30902 L
.96573 .30902 L
.96704 .30902 L
.96932 .30902 L
.97057 .30902 L
.97176 .30902 L
.97287 .30902 L
.97408 .30902 L
.97517 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-0.937211, -1.05724, \
0.0259283, 0.0127181}}]
}, Open  ]],

Cell[TextData[{
 "Hence ",
 Cell[BoxData[
  SubsuperscriptBox["\[Sum]", 
   RowBox[{"n", "=", "0"}], 
   RowBox[{"n", "=", "2"}]]]],
 Cell[BoxData[
  SuperscriptBox["Sin", "3"]]],
 "(\[Tau]+2n \[Pi]/3)=-3Sin[2\[Tau]]/4,\n ",
 Cell[BoxData[
  SubsuperscriptBox["\[Sum]", 
   RowBox[{"n", "=", "0"}], 
   RowBox[{"n", "=", "2"}]]]],
 Cell[BoxData[
  SuperscriptBox["Sin", "5"]]],
 "(\[Tau]+2n \[Pi]/3)=-15 Sin[3\[Tau]]/16.\n ",
 Cell[BoxData[
  SubsuperscriptBox["\[Sum]", 
   RowBox[{"n", "=", "0"}], 
   RowBox[{"n", "=", "2"}]]]],
 Cell[BoxData[
  SuperscriptBox["Sin", "7"]]],
 "(\[Tau]+2n \[Pi]/3)=-63 Sin[3\[Tau]]/64.\nAnother ripple arises with the \
9th and 11th powers -\n",
 Cell[BoxData[
  SubsuperscriptBox["\[Sum]", 
   RowBox[{"n", "=", "0"}], 
   RowBox[{"n", "=", "2"}]]]],
 Cell[BoxData[
  SuperscriptBox["Sin", "9"]]],
 "(\[Tau]+2n \[Pi]/3)=-63 Sin[3\[Tau]]/64+3/256 Sin[9\[Tau]].\n",
 Cell[BoxData[
  SubsuperscriptBox["\[Sum]", 
   RowBox[{"n", "=", "0"}], 
   RowBox[{"n", "=", "2"}]]]],
 Cell[BoxData[
  SuperscriptBox["Sin", "11"]]],
 "(\[Tau]+2n \[Pi]/3)=-495 Sin[3\[Tau]]/512+33/1024 Sin[9\[Tau]]."
}], "Text",
 PageWidth->PaperWidth],

Cell["\<\
The PlotRange is reduced to show that the terms sum exactly to zero after \
removing 3rd and 9th harmonics:-\
\>", "Text",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Tau]", "]"}], "9"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "9"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"4", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "9"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "9"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "9"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "9"]}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "9"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "9"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "9"], "+", 
       RowBox[{
        RowBox[{"63", "/", "64"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"3", "\[Tau]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"3", "/", "256"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"9", "\[Tau]"}], "]"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", ".001"}], ",", ".001"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "0"}], "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<Fig.1d 9th Power 3\[Tau] & 9\[Tau] ripple cancellation.\>\""}]}], 
   "]"}], ";"}]], "Input",
 PageWidth->PaperWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309017 309.017 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 0 -36 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .15451 -42 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .46353 -36 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .61803 -30 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -137 0 ]
[.5 .63053 137 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.001)] .01131 0 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.0005)] .01131 .15451 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.0005)] .01131 .46353 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.001)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -198 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.1) show
93.000 12.750 moveto
(d) show
105.000 12.750 moveto
(9) show
111.000 12.750 moveto
(th) show
129.000 12.750 moveto
(Power) show
165.000 12.750 moveto
(3) show
171.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
183.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
195.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
201.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
213.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ripple) show
255.000 12.750 moveto
(cancellation) show
327.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
333.000 12.750 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30903 L
.04652 .30903 L
.04722 .30903 L
.04797 .30904 L
.04862 .30904 L
.04933 .30905 L
.05061 .30907 L
.05186 .30909 L
.05302 .30912 L
.05414 .30917 L
.05519 .30922 L
.05634 .3093 L
.05759 .30941 L
.05882 .30955 L
.06012 .30975 L
.06123 .30998 L
.06244 .31029 L
.06381 .31074 L
.06529 .31139 L
.06669 .31219 L
.06797 .31313 L
.07041 .3156 L
.07164 .31728 L
.073 .31954 L
.07581 .32604 L
.07738 .33105 L
.07882 .33671 L
.08162 .35138 L
.08427 .37117 L
Mistroke
.08671 .39603 L
.08931 .43156 L
.09177 .47597 L
.09399 .52754 L
.09661 .6056 L
Mfstroke
.09661 .6056 m
.09693 .61803 L
s
.42688 .61803 m
.42884 .55446 L
.43117 .49491 L
.43335 .4508 L
.43563 .41475 L
.43815 .38444 L
.44071 .36164 L
.4434 .34436 L
.4457 .33376 L
.44822 .32545 L
.44964 .32192 L
.45093 .31932 L
.45233 .31703 L
.45384 .31507 L
.45524 .31365 L
.45653 .3126 L
.45783 .31176 L
.45907 .31113 L
.46024 .31066 L
.46151 .31025 L
.46268 .30995 L
.46375 .30974 L
.46501 .30955 L
.46635 .30939 L
.4676 .30929 L
.46877 .30921 L
.46988 .30916 L
.47104 .30912 L
.47204 .30909 L
.47313 .30907 L
.47431 .30905 L
.47557 .30904 L
.47676 .30903 L
.47784 .30903 L
.47913 .30902 L
.47977 .30902 L
.48049 .30902 L
.48175 .30902 L
.48293 .30902 L
.48364 .30902 L
.48432 .30902 L
.48559 .30902 L
.4863 .30902 L
.48696 .30902 L
.48768 .30902 L
.48845 .30902 L
.48976 .30902 L
.49049 .30902 L
.49116 .30902 L
.4924 .30902 L
Mistroke
.49372 .30902 L
.49489 .30902 L
.49599 .30902 L
.4972 .30902 L
.49849 .30902 L
.49971 .30902 L
.5004 .30902 L
.50105 .30902 L
.50236 .30902 L
.50309 .30902 L
.50377 .30902 L
.50491 .30902 L
.50615 .30902 L
.50745 .30902 L
.50866 .30902 L
.50935 .30902 L
.5101 .30902 L
.5108 .30902 L
.51146 .30902 L
.51269 .30902 L
.514 .30902 L
.51468 .30902 L
.51541 .30902 L
.51672 .30902 L
.51753 .30902 L
.51829 .30902 L
.51897 .30901 L
.51972 .30901 L
.52038 .30901 L
.52109 .30901 L
.52237 .30901 L
.52362 .309 L
.52477 .30899 L
.52602 .30898 L
.52673 .30897 L
.52739 .30896 L
.52873 .30892 L
.52948 .3089 L
.53016 .30887 L
.5314 .30881 L
.53254 .30874 L
.5338 .30863 L
.53513 .30847 L
.53629 .30828 L
.53737 .30807 L
.53856 .30777 L
.53984 .30735 L
.5411 .30683 L
.54224 .30623 L
.54347 .30543 L
Mistroke
.54481 .30435 L
.54605 .30309 L
.54719 .30168 L
.54943 .29804 L
.55068 .29537 L
.55185 .29239 L
.55325 .28811 L
.55452 .28339 L
.55712 .27079 L
.55855 .26177 L
.55991 .25156 L
.56245 .22719 L
.56515 .19189 L
.56746 .15201 L
.57001 .09477 L
.57274 .01449 L
Mfstroke
.57274 .01449 m
.57311 0 L
s
.90303 0 m
.90519 .06824 L
.90759 .12825 L
.9104 .18182 L
.91306 .21926 L
.91564 .24612 L
.91803 .26442 L
.92055 .27848 L
.9229 .28797 L
.92548 .29532 L
.92694 .29837 L
.92826 .30062 L
.92955 .30239 L
.93092 .30391 L
.93243 .30522 L
.93383 .30616 L
.93525 .3069 L
.9366 .30744 L
.93781 .30782 L
.93911 .30813 L
.94024 .30834 L
.94126 .30849 L
.94244 .30863 L
.94356 .30873 L
.94459 .3088 L
.94554 .30885 L
.94659 .3089 L
.9477 .30893 L
.94882 .30896 L
.95002 .30898 L
.95115 .30899 L
.95219 .309 L
.95334 .309 L
.9546 .30901 L
.95591 .30901 L
.95714 .30901 L
.95833 .30902 L
.95962 .30902 L
.96084 .30902 L
.96196 .30902 L
.96297 .30902 L
.96409 .30902 L
.96526 .30902 L
.96635 .30902 L
.96762 .30902 L
.96882 .30902 L
.96991 .30902 L
.97109 .30902 L
.97237 .30902 L
.97309 .30902 L
Mistroke
.97374 .30902 L
.975 .30902 L
.97619 .30902 L
Mfstroke
0 1 0 r
.10942 .61803 m
.10982 .60284 L
.11237 .52728 L
.11468 .47388 L
.11741 .42574 L
.12036 .38784 L
.12315 .36237 L
.12571 .34559 L
.12812 .33423 L
.13037 .32654 L
.13284 .32053 L
.13422 .31803 L
.13548 .31618 L
.13802 .31343 L
.13946 .31233 L
.14078 .31154 L
.14204 .31094 L
.14322 .3105 L
.14445 .31014 L
.1458 .30983 L
.14698 .30963 L
.14824 .30946 L
.14942 .30934 L
.1505 .30926 L
.15177 .30919 L
.15243 .30916 L
.15314 .30913 L
.15444 .30909 L
.15564 .30907 L
.15686 .30905 L
.15818 .30904 L
.15943 .30903 L
.16056 .30903 L
.16126 .30902 L
.1619 .30902 L
.1626 .30902 L
.16335 .30902 L
.16406 .30902 L
.16473 .30902 L
.16599 .30902 L
.16706 .30902 L
.16824 .30902 L
.16947 .30902 L
.17062 .30902 L
.1717 .30902 L
.17268 .30902 L
.17381 .30902 L
.17488 .30902 L
.17604 .30902 L
.17728 .30902 L
Mistroke
.17833 .30902 L
.17949 .30902 L
.18073 .30902 L
.18143 .30902 L
.18207 .30902 L
.18325 .30902 L
.18449 .30902 L
.18573 .30902 L
.18643 .30902 L
.18707 .30902 L
.18826 .30902 L
.18951 .30902 L
.19063 .30902 L
.19168 .30902 L
.19283 .30902 L
.19406 .30902 L
.19537 .30902 L
.19612 .30902 L
.1968 .30902 L
.19806 .30902 L
.1987 .30902 L
.1994 .30902 L
.20061 .30902 L
.20191 .30901 L
.20314 .30901 L
.20427 .30901 L
.20534 .30901 L
.20648 .309 L
.20756 .30899 L
.20854 .30898 L
.2097 .30896 L
.21095 .30893 L
.21213 .3089 L
.21322 .30885 L
.21435 .30879 L
.2154 .30871 L
.21656 .3086 L
.2178 .30845 L
.2191 .30823 L
.22033 .30797 L
.22144 .30766 L
.22265 .30725 L
.22398 .30666 L
.22521 .30597 L
.22655 .30502 L
.22797 .30375 L
.23036 .30078 L
.23172 .29852 L
.23298 .29593 L
.23534 .28956 L
Mistroke
.2375 .28156 L
.23999 .26887 L
.24234 .25243 L
.24487 .22849 L
.24756 .19388 L
.24986 .1548 L
.25239 .09888 L
.2551 .02038 L
Mfstroke
.2551 .02038 m
.25564 0 L
s
.58557 0 m
.58799 .07552 L
.59012 .12804 L
.59237 .17224 L
.59483 .20967 L
.59711 .23597 L
.59956 .25734 L
.6022 .27404 L
.60469 .28527 L
.60696 .29263 L
.60834 .29605 L
.60962 .29864 L
.61115 .30113 L
.61253 .30291 L
.61508 .3053 L
.61649 .30623 L
.61781 .30691 L
.61897 .30738 L
.62022 .30778 L
.6213 .30805 L
.62247 .30829 L
.62385 .3085 L
.62515 .30865 L
.62642 .30875 L
.62759 .30883 L
.62882 .30888 L
.62997 .30892 L
.63124 .30895 L
.63195 .30897 L
.6326 .30898 L
.63384 .30899 L
.63454 .309 L
.63519 .309 L
.63651 .30901 L
.63725 .30901 L
.63791 .30901 L
.63907 .30901 L
.64029 .30902 L
.64133 .30902 L
.64248 .30902 L
.64371 .30902 L
.64441 .30902 L
.64504 .30902 L
.64626 .30902 L
.64743 .30902 L
.64851 .30902 L
.64966 .30902 L
.65064 .30902 L
.65172 .30902 L
.65288 .30902 L
Mistroke
.65413 .30902 L
.65531 .30902 L
.6564 .30902 L
.65767 .30902 L
.65887 .30902 L
.65995 .30902 L
.66112 .30902 L
.6624 .30902 L
.66304 .30902 L
.66375 .30902 L
.665 .30902 L
.66618 .30902 L
.66735 .30902 L
.66847 .30902 L
.66947 .30902 L
.67057 .30902 L
.67175 .30902 L
.67302 .30902 L
.67421 .30902 L
.67529 .30902 L
.67658 .30902 L
.67724 .30902 L
.67795 .30902 L
.67922 .30902 L
.68041 .30902 L
.68112 .30903 L
.6818 .30903 L
.68308 .30904 L
.68379 .30904 L
.68445 .30905 L
.68517 .30906 L
.68594 .30907 L
.68714 .3091 L
.68826 .30913 L
.68959 .30919 L
.69081 .30926 L
.69201 .30936 L
.69333 .3095 L
.6947 .30969 L
.69598 .30994 L
.69725 .31026 L
.69861 .3107 L
.69976 .31118 L
.70103 .31184 L
.70239 .31274 L
.70386 .31399 L
.7065 .31718 L
.70778 .31928 L
.70917 .3221 L
.71039 .32512 L
Mistroke
.7117 .32899 L
.71416 .33855 L
.71644 .35077 L
.71886 .36829 L
.72147 .39409 L
.72393 .42687 L
.7262 .46611 L
.72825 .51091 L
.73049 .57227 L
Mfstroke
.73049 .57227 m
.73169 .61803 L
s
0 0 1 r
.26819 0 m
.26929 .03912 L
.27167 .10512 L
.27403 .15631 L
.27617 .19268 L
.27864 .22512 L
.28096 .24815 L
.2835 .26691 L
.28619 .28104 L
.28848 .28962 L
.291 .2963 L
.29242 .2991 L
.29371 .30116 L
.2951 .30295 L
.29661 .30448 L
.29801 .30558 L
.2993 .30638 L
.30054 .30699 L
.30185 .3075 L
.30301 .30785 L
.30427 .30815 L
.30543 .30836 L
.3065 .30851 L
.30777 .30866 L
.30892 .30875 L
.31025 .30883 L
.3115 .30889 L
.3126 .30893 L
.31376 .30895 L
.31476 .30897 L
.31585 .30899 L
.31702 .309 L
.31828 .309 L
.31947 .30901 L
.32055 .30901 L
.32183 .30901 L
.32247 .30901 L
.32318 .30902 L
.32444 .30902 L
.32562 .30902 L
.32629 .30902 L
.327 .30902 L
.32827 .30902 L
.32898 .30902 L
.32964 .30902 L
.33036 .30902 L
.33113 .30902 L
.33243 .30902 L
.33316 .30902 L
.33384 .30902 L
Mistroke
.33507 .30902 L
.33639 .30902 L
.33756 .30902 L
.33866 .30902 L
.33987 .30902 L
.34117 .30902 L
.34185 .30902 L
.3425 .30902 L
.34371 .30902 L
.34501 .30902 L
.34574 .30902 L
.34641 .30902 L
.34754 .30902 L
.34878 .30902 L
.35007 .30902 L
.35128 .30902 L
.35197 .30902 L
.35271 .30902 L
.35342 .30902 L
.35407 .30902 L
.3553 .30902 L
.35661 .30902 L
.35728 .30902 L
.35801 .30902 L
.35932 .30902 L
.36008 .30902 L
.36088 .30902 L
.36157 .30902 L
.36232 .30902 L
.36297 .30902 L
.36367 .30903 L
.36496 .30903 L
.3662 .30904 L
.36735 .30906 L
.3686 .30908 L
.3693 .30909 L
.36996 .30911 L
.3713 .30915 L
.37205 .30919 L
.37273 .30922 L
.37396 .30931 L
.37511 .30941 L
.37636 .30956 L
.3777 .30977 L
.37897 .31004 L
.38017 .31037 L
.38241 .31123 L
.38358 .31184 L
.38483 .31267 L
.38709 .31469 L
Mistroke
.38847 .31636 L
.38977 .31833 L
.39221 .32327 L
.39346 .3266 L
.39479 .33085 L
.39716 .34076 L
.39972 .35561 L
.40254 .37864 L
.40495 .40549 L
.40714 .43749 L
.40968 .48549 L
.41209 .54475 L
Mfstroke
.41209 .54475 m
.41421 .61803 L
s
.7443 .61803 m
.74686 .53861 L
.74964 .47325 L
.75261 .42162 L
.75542 .38643 L
.75798 .36308 L
.76055 .34606 L
.76293 .33467 L
.76555 .32581 L
.76687 .32245 L
.76833 .31944 L
.77076 .31572 L
.77213 .31419 L
.77339 .31306 L
.7757 .31154 L
.77686 .31098 L
.77814 .3105 L
.77945 .31012 L
.78067 .30984 L
.782 .30961 L
.78341 .30943 L
.78463 .30932 L
.78578 .30924 L
.78704 .30917 L
.78839 .30912 L
.78959 .30909 L
.79089 .30906 L
.79212 .30905 L
.79326 .30904 L
.79439 .30903 L
.79542 .30903 L
.7966 .30902 L
.79772 .30902 L
.79893 .30902 L
.79962 .30902 L
.80027 .30902 L
.80156 .30902 L
.80229 .30902 L
.80296 .30902 L
.80414 .30902 L
.80543 .30902 L
.80665 .30902 L
.80778 .30902 L
.80907 .30902 L
.81028 .30902 L
.81098 .30902 L
.81162 .30902 L
.81232 .30902 L
.81305 .30902 L
.81372 .30902 L
Mistroke
.81444 .30902 L
.81573 .30902 L
.81652 .30902 L
.81726 .30902 L
.81793 .30902 L
.81866 .30902 L
.81989 .30902 L
.82101 .30902 L
.82231 .30902 L
.82355 .30902 L
.82468 .30902 L
.82574 .30902 L
.82689 .30902 L
.82812 .30902 L
.82883 .30902 L
.82948 .30902 L
.83019 .30902 L
.83094 .30902 L
.8322 .30902 L
.83292 .30902 L
.83359 .30902 L
.83484 .30902 L
.83598 .30902 L
.83729 .30901 L
.83854 .30901 L
.83975 .30901 L
.84044 .309 L
.84108 .309 L
.84238 .30899 L
.84311 .30898 L
.84378 .30897 L
.84497 .30895 L
.84626 .30892 L
.84749 .30888 L
.84863 .30883 L
.85006 .30873 L
.85141 .30861 L
.85262 .30846 L
.85393 .30825 L
.85536 .30794 L
.85687 .3075 L
.85816 .307 L
.85958 .3063 L
.86088 .30547 L
.86209 .30451 L
.86338 .30323 L
.86481 .30145 L
.86722 .29738 L
.86854 .29443 L
.86977 .29107 L
Mistroke
.87211 .28287 L
.87425 .27265 L
.8766 .25756 L
.87907 .23604 L
.88157 .2068 L
.88424 .1648 L
.88676 .11224 L
.88906 .05088 L
Mfstroke
.88906 .05088 m
.89054 0 L
s
0 0 0 r
.02381 .30879 m
0 0 rlineto s
.02381 .30879 m
.02386 0 L
s
.18249 0 m
.1826 .61803 L
s
.34122 .61803 m
.34133 0 L
s
.49998 0 m
.50009 .61803 L
s
.65886 .61803 m
.65897 0 L
s
.81743 0 m
.81754 .61803 L
s
.97613 .61803 m
.97619 .30925 L
s
1 0 0 r
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02946 .30902 L
.03053 .30902 L
.0317 .30902 L
.03279 .30902 L
.03394 .30902 L
.03504 .30902 L
.03631 .30902 L
.03746 .30902 L
.03874 .30902 L
.03946 .30902 L
.04012 .30902 L
.04133 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11763 .30902 L
.11832 .30902 L
Mistroke
.11958 .30902 L
.1208 .30902 L
.12191 .30902 L
.12322 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21537 .30902 L
.21605 .30902 L
.21731 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24008 .30902 L
.24111 .30902 L
.24223 .30902 L
.24337 .30902 L
.24458 .30902 L
.24572 .30902 L
.24674 .30902 L
.24797 .30902 L
.24866 .30902 L
.24929 .30902 L
.25046 .30902 L
.2517 .30902 L
.25284 .30902 L
.25391 .30902 L
.25509 .30902 L
.25635 .30902 L
.25759 .30902 L
.25829 .30902 L
.25894 .30902 L
.26013 .30902 L
.2614 .30902 L
.26253 .30902 L
.2636 .30902 L
.26476 .30902 L
.26602 .30902 L
.26726 .30902 L
.26797 .30902 L
.26862 .30902 L
.26932 .30902 L
.26995 .30902 L
.27068 .30902 L
.27137 .30902 L
.2726 .30902 L
.27373 .30902 L
.27497 .30902 L
.27629 .30902 L
.27742 .30902 L
.27847 .30902 L
.27967 .30902 L
.28081 .30902 L
.28187 .30902 L
.28284 .30902 L
Mistroke
.28391 .30902 L
.28506 .30902 L
.28631 .30902 L
.28702 .30902 L
.28766 .30902 L
.28886 .30902 L
.29012 .30902 L
.29125 .30902 L
.29231 .30902 L
.29347 .30902 L
.29471 .30902 L
.29593 .30902 L
.29663 .30902 L
.29728 .30902 L
.29859 .30902 L
.29933 .30902 L
.3 .30902 L
.30114 .30902 L
.30238 .30902 L
.30368 .30902 L
.30489 .30902 L
.30558 .30902 L
.30633 .30902 L
.30704 .30902 L
.3077 .30902 L
.30893 .30902 L
.31024 .30902 L
.31092 .30902 L
.31165 .30902 L
.31297 .30902 L
.31377 .30902 L
.31453 .30902 L
.31522 .30902 L
.31596 .30902 L
.31662 .30902 L
.31733 .30902 L
.31862 .30902 L
.31987 .30902 L
.32102 .30902 L
.32227 .30902 L
.32298 .30902 L
.32364 .30902 L
.32434 .30902 L
.32497 .30902 L
.32571 .30902 L
.3264 .30902 L
.32757 .30902 L
.32882 .30902 L
.32988 .30902 L
.33104 .30902 L
Mistroke
.3323 .30902 L
.333 .30902 L
.33364 .30902 L
.33489 .30902 L
.33608 .30902 L
.33732 .30902 L
.33802 .30902 L
.33867 .30902 L
.33985 .30902 L
.3411 .30902 L
.34223 .30902 L
.34327 .30902 L
.34442 .30902 L
.34566 .30902 L
.34697 .30902 L
.34771 .30902 L
.3484 .30902 L
.34966 .30902 L
.3503 .30902 L
.351 .30902 L
.35219 .30902 L
.35331 .30902 L
.35396 .30902 L
.35465 .30902 L
.35587 .30902 L
.35702 .30902 L
.35807 .30902 L
.35927 .30902 L
.36042 .30902 L
.36147 .30902 L
.36244 .30902 L
.36351 .30902 L
.36465 .30902 L
.36579 .30902 L
.36687 .30902 L
.36814 .30902 L
.36931 .30902 L
.37052 .30902 L
.37184 .30902 L
.37309 .30902 L
.37425 .30902 L
.37554 .30902 L
.37619 .30902 L
.3769 .30902 L
.37816 .30902 L
.37934 .30902 L
.38005 .30902 L
.38073 .30902 L
.38199 .30902 L
.3827 .30902 L
Mistroke
.38335 .30902 L
.38407 .30902 L
.38483 .30902 L
.38601 .30902 L
.38728 .30902 L
.38847 .30902 L
.38957 .30902 L
.39079 .30902 L
.39148 .30902 L
.39212 .30902 L
.39341 .30902 L
.39414 .30902 L
.3948 .30902 L
.39596 .30902 L
.39719 .30902 L
.39824 .30902 L
.39939 .30902 L
.40063 .30902 L
.40133 .30902 L
.40197 .30902 L
.4032 .30902 L
.40437 .30902 L
.40546 .30902 L
.40662 .30902 L
.40771 .30902 L
.4087 .30902 L
.40987 .30902 L
.41113 .30902 L
.41232 .30902 L
.41341 .30902 L
.41468 .30902 L
.41588 .30902 L
.41696 .30902 L
.41813 .30902 L
.41941 .30902 L
.42005 .30902 L
.42076 .30902 L
.42201 .30902 L
.42318 .30902 L
.42436 .30902 L
.42548 .30902 L
.42648 .30902 L
.42757 .30902 L
.42876 .30902 L
.43002 .30902 L
.43121 .30902 L
.43229 .30902 L
.43359 .30902 L
.43424 .30902 L
.43496 .30902 L
Mistroke
.43624 .30902 L
.43741 .30902 L
.43812 .30902 L
.43879 .30902 L
.4395 .30902 L
.44027 .30902 L
.44094 .30902 L
.44166 .30902 L
.44294 .30902 L
.44413 .30902 L
.4454 .30902 L
.44661 .30902 L
.44771 .30902 L
.44894 .30902 L
.44963 .30902 L
.45028 .30902 L
.45158 .30902 L
.45231 .30902 L
.45298 .30902 L
.45417 .30902 L
.45528 .30902 L
.45651 .30902 L
.45782 .30902 L
.45848 .30902 L
.4592 .30902 L
.46051 .30902 L
.46178 .30902 L
.46296 .30902 L
.46416 .30902 L
.46529 .30902 L
.46631 .30902 L
.46741 .30902 L
.46862 .30902 L
.46989 .30902 L
.47097 .30902 L
.47216 .30902 L
.47283 .30902 L
.47356 .30902 L
.47488 .30902 L
.47616 .30902 L
.47735 .30902 L
.47864 .30902 L
.47937 .30902 L
.48005 .30902 L
.48077 .30902 L
.48143 .30902 L
.48215 .30902 L
.48292 .30902 L
.48413 .30902 L
.48526 .30902 L
Mistroke
.48595 .30902 L
.4866 .30902 L
.48781 .30902 L
.4891 .30902 L
.49028 .30902 L
.49158 .30902 L
.49223 .30902 L
.49295 .30902 L
.49425 .30902 L
.49546 .30902 L
.49678 .30902 L
.49744 .30902 L
.49818 .30902 L
.49941 .30902 L
.5001 .30902 L
.50074 .30902 L
.50198 .30902 L
.50314 .30902 L
.50418 .30902 L
.5053 .30902 L
.50654 .30902 L
.50767 .30902 L
.50884 .30902 L
.51012 .30902 L
.51132 .30902 L
.51244 .30902 L
.51364 .30902 L
.51493 .30902 L
.51615 .30902 L
.51727 .30902 L
.51795 .30902 L
.5186 .30902 L
.51935 .30902 L
.52003 .30902 L
.52126 .30902 L
.52189 .30902 L
.52259 .30902 L
.52325 .30902 L
.52396 .30902 L
.52522 .30902 L
.52594 .30902 L
.52671 .30902 L
.52744 .30902 L
.5281 .30902 L
.52939 .30902 L
.53012 .30902 L
.53079 .30902 L
.53203 .30902 L
.53334 .30902 L
.53448 .30902 L
Mistroke
.53572 .30902 L
.53702 .30902 L
.53823 .30902 L
.53937 .30902 L
.5404 .30902 L
.54159 .30902 L
.54272 .30902 L
.54394 .30902 L
.54524 .30902 L
.54635 .30902 L
.54757 .30902 L
.54888 .30902 L
.54961 .30902 L
.55028 .30902 L
.55159 .30902 L
.55282 .30902 L
.55398 .30902 L
.55502 .30902 L
.55623 .30902 L
.55736 .30902 L
.55842 .30902 L
.55939 .30902 L
.56045 .30902 L
.56157 .30902 L
.56271 .30902 L
.56393 .30902 L
.56498 .30902 L
.56612 .30902 L
.56682 .30902 L
.56746 .30902 L
.56873 .30902 L
.56988 .30902 L
.57111 .30902 L
.57231 .30902 L
.57362 .30902 L
.57486 .30902 L
.57602 .30902 L
.57716 .30902 L
.57819 .30902 L
.57938 .30902 L
.58051 .30902 L
.58174 .30902 L
.58304 .30902 L
.58415 .30902 L
.58537 .30902 L
.58668 .30902 L
.5874 .30902 L
.58809 .30902 L
.58872 .30902 L
.58942 .30902 L
Mistroke
.59063 .30902 L
.59176 .30902 L
.59282 .30902 L
.59398 .30902 L
.59523 .30902 L
.59648 .30902 L
.59779 .30902 L
.59891 .30902 L
.60013 .30902 L
.60126 .30902 L
.60233 .30902 L
.60356 .30902 L
.60469 .30902 L
.60573 .30902 L
.60673 .30902 L
.60788 .30902 L
.60892 .30902 L
.61007 .30902 L
.61131 .30902 L
.61247 .30902 L
.61355 .30902 L
.61482 .30902 L
.61601 .30902 L
.61667 .30902 L
.61739 .30902 L
.61864 .30902 L
.61988 .30902 L
.62059 .30902 L
.62125 .30902 L
.62194 .30902 L
.62257 .30902 L
.62331 .30902 L
.624 .30902 L
.62522 .30902 L
.62636 .30902 L
.6276 .30902 L
.62893 .30902 L
.63006 .30902 L
.6311 .30902 L
.63225 .30902 L
.63345 .30902 L
.6345 .30902 L
.63548 .30902 L
.63655 .30902 L
.6377 .30902 L
.63895 .30902 L
.63966 .30902 L
.64031 .30902 L
.6415 .30902 L
.64277 .30902 L
Mistroke
.64383 .30902 L
.64496 .30902 L
.64621 .30902 L
.64737 .30902 L
.64869 .30902 L
.64993 .30902 L
.65122 .30902 L
.6519 .30902 L
.65264 .30902 L
.65388 .30902 L
.65519 .30902 L
.6563 .30902 L
.65752 .30902 L
.65827 .30902 L
.65897 .30902 L
.66029 .30902 L
.66103 .30902 L
.66171 .30902 L
.66245 .30902 L
.66325 .30902 L
.66455 .30902 L
.66578 .30902 L
.66648 .30902 L
.66713 .30902 L
.66787 .30902 L
.66858 .30902 L
.66984 .30902 L
.67099 .30902 L
.67163 .30902 L
.67231 .30902 L
.67356 .30902 L
.67473 .30902 L
.67597 .30902 L
.67703 .30902 L
.67819 .30902 L
.67889 .30902 L
.67956 .30902 L
.68081 .30902 L
.68151 .30902 L
.68216 .30902 L
.68287 .30902 L
.68362 .30902 L
.6849 .30902 L
.68609 .30902 L
.68733 .30902 L
.68798 .30902 L
.68869 .30902 L
.69 .30902 L
.69125 .30902 L
.69236 .30902 L
Mistroke
.69357 .30902 L
.69471 .30902 L
.69591 .30902 L
.69693 .30902 L
.69806 .30902 L
.69937 .30902 L
.70057 .30902 L
.70124 .30902 L
.70196 .30902 L
.70328 .30902 L
.7045 .30902 L
.70581 .30902 L
.70704 .30902 L
.70816 .30902 L
.70931 .30902 L
.71052 .30902 L
.71157 .30902 L
.71269 .30902 L
.71389 .30902 L
.71502 .30902 L
.71571 .30902 L
.71636 .30902 L
.71758 .30902 L
.71865 .30902 L
.71979 .30902 L
.72076 .30902 L
.72183 .30902 L
.72297 .30902 L
.72421 .30902 L
.72537 .30902 L
.72644 .30902 L
.72772 .30902 L
.72893 .30902 L
.73002 .30902 L
.7312 .30902 L
.73248 .30902 L
.73313 .30902 L
.73384 .30902 L
.73509 .30902 L
.73627 .30902 L
.73735 .30902 L
.73853 .30902 L
.73965 .30902 L
.74068 .30902 L
.74187 .30902 L
.74315 .30902 L
.74422 .30902 L
.7454 .30902 L
.74671 .30902 L
.74736 .30902 L
Mistroke
.74808 .30902 L
.74936 .30902 L
.75054 .30902 L
.75126 .30902 L
.75194 .30902 L
.75322 .30902 L
.75393 .30902 L
.75459 .30902 L
.75532 .30902 L
.75608 .30902 L
.75727 .30902 L
.75855 .30902 L
.75976 .30902 L
.76086 .30902 L
.76215 .30902 L
.76288 .30902 L
.76356 .30902 L
.7648 .30902 L
.76612 .30902 L
.76736 .30902 L
.76807 .30902 L
.76873 .30902 L
.76942 .30902 L
.77006 .30902 L
.77079 .30902 L
.77148 .30902 L
.77271 .30902 L
.77385 .30902 L
.77448 .30902 L
.77517 .30902 L
.77642 .30902 L
.77707 .30902 L
.77776 .30902 L
.77898 .30902 L
.77968 .30902 L
.78034 .30902 L
.78105 .30902 L
.78181 .30902 L
.78256 .30902 L
.78336 .30902 L
.78412 .30902 L
.78482 .30902 L
.78545 .30902 L
.78615 .30902 L
.78687 .30902 L
.78755 .30902 L
.78871 .30902 L
.78994 .30902 L
.79065 .30902 L
.79129 .30902 L
Mistroke
.79254 .30902 L
.79371 .30902 L
.79498 .30902 L
.79618 .30902 L
.79728 .30902 L
.79855 .30902 L
.79926 .30902 L
.79994 .30902 L
.80064 .30902 L
.80129 .30902 L
.80203 .30902 L
.80274 .30902 L
.80398 .30902 L
.80513 .30902 L
.80639 .30902 L
.80702 .30902 L
.80772 .30902 L
.80893 .30902 L
.81021 .30902 L
.81094 .30902 L
.81161 .30902 L
.81292 .30902 L
.81414 .30902 L
.81546 .30902 L
.81671 .30902 L
.81785 .30902 L
.81897 .30902 L
.82 .30902 L
.82114 .30902 L
.82236 .30902 L
.82364 .30902 L
.82485 .30902 L
.82594 .30902 L
.82713 .30902 L
.82841 .30902 L
.82962 .30902 L
.83032 .30902 L
.83095 .30902 L
.83165 .30902 L
.83238 .30902 L
.83305 .30902 L
.83376 .30902 L
.83505 .30902 L
.83584 .30902 L
.83658 .30902 L
.83725 .30902 L
.83797 .30902 L
.83918 .30902 L
.83986 .30902 L
.8405 .30902 L
Mistroke
.8418 .30902 L
.84252 .30902 L
.84319 .30902 L
.84437 .30902 L
.84566 .30902 L
.8468 .30902 L
.848 .30902 L
.84864 .30902 L
.84934 .30902 L
.85056 .30902 L
.85125 .30902 L
.85199 .30902 L
.85269 .30902 L
.85333 .30902 L
.85456 .30902 L
.85526 .30902 L
.8559 .30902 L
.85709 .30902 L
.85834 .30902 L
.86285 .30902 L
.86771 .30902 L
.86902 .30902 L
.86968 .30902 L
.87039 .30902 L
.87167 .30902 L
.87286 .30902 L
.87408 .30902 L
.87519 .30902 L
.87648 .30902 L
.87769 .30902 L
.87832 .30902 L
.87902 .30902 L
.87975 .30902 L
.88044 .30902 L
.88166 .30902 L
.88297 .30902 L
.8837 .30902 L
.8845 .30902 L
.88526 .30902 L
.88596 .30902 L
.88659 .30902 L
.88728 .30902 L
.88801 .30902 L
.88869 .30902 L
.88986 .30902 L
.89111 .30902 L
.8923 .30902 L
.89337 .30902 L
.89464 .30902 L
.89535 .30902 L
Mistroke
.89601 .30902 L
.89722 .30902 L
.8985 .30902 L
.89973 .30902 L
.90104 .30902 L
.90228 .30902 L
.90342 .30902 L
.90411 .30902 L
.90475 .30902 L
.90545 .30902 L
.9062 .30902 L
.90691 .30902 L
.90759 .30902 L
.90884 .30902 L
.90991 .30902 L
.91109 .30902 L
.91224 .30902 L
.91347 .30902 L
.91462 .30902 L
.91567 .30902 L
.91673 .30902 L
.91773 .30902 L
.91889 .30902 L
.92012 .30902 L
.92117 .30902 L
.92233 .30902 L
.92349 .30902 L
.92472 .30902 L
.92543 .30902 L
.92608 .30902 L
.92734 .30902 L
.92855 .30902 L
.92987 .30902 L
.93111 .30902 L
.93226 .30902 L
.93345 .30902 L
.93477 .30902 L
.93549 .30902 L
.93616 .30902 L
.93743 .30902 L
.93854 .30902 L
.93974 .30902 L
.94103 .30902 L
.94222 .30902 L
.94335 .30902 L
.94438 .30902 L
.94557 .30902 L
.94669 .30902 L
.9479 .30902 L
.94859 .30902 L
Mistroke
.94923 .30902 L
.95053 .30902 L
.95126 .30902 L
.95192 .30902 L
.9531 .30902 L
.95438 .30902 L
.9556 .30902 L
.95672 .30902 L
.95801 .30902 L
.95922 .30902 L
.95991 .30902 L
.96055 .30902 L
.96128 .30902 L
.96197 .30902 L
.96264 .30902 L
.96336 .30902 L
.96464 .30902 L
.96542 .30902 L
.96617 .30902 L
.96683 .30902 L
.96755 .30902 L
.96858 .30902 L
.96955 .30902 L
.97061 .30902 L
.97175 .30902 L
.97294 .30902 L
.97407 .30902 L
.97509 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-1.33052, -0.00121461, \
0.0297151, 1.45756}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Tau]", "]"}], "11"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"2", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "11"], ",", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"4", 
          RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "11"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "11"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "11"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "11"]}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Tau]", "]"}], "11"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "11"], "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Tau]", "+", 
          RowBox[{"4", 
           RowBox[{"\[Pi]", "/", "3"}]}]}], "]"}], "11"], "+", 
       RowBox[{
        RowBox[{"495", "/", "512"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"3", "\[Tau]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"33", "/", "1024"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"9", "\[Tau]"}], "]"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", ".0001"}], ",", ".0001"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "0"}], "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<Fig.1e 11th Power 3\[Tau] & 9\[Tau] ripple cancellation.\>\""}]}], 
   "]"}], ";"}]], "Input",
 PageWidth->PaperWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309017 3090.17 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 0 -42 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .15451 -48 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .46353 -42 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .61803 -36 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -140 0 ]
[.5 .63053 140 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-0.0001)] .01131 0 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.00005)] .01131 .15451 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.00005)] .01131 .46353 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.0001)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -201 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.1) show
93.000 12.750 moveto
(e) show
105.000 12.750 moveto
(11) show
117.000 12.750 moveto
(th) show
135.000 12.750 moveto
(Power) show
171.000 12.750 moveto
(3) show
177.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
189.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
201.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
207.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
219.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ripple) show
261.000 12.750 moveto
(cancellation) show
333.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
339.000 12.750 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30903 L
.05061 .30903 L
.05186 .30904 L
.05302 .30906 L
.05414 .30908 L
.05519 .3091 L
.05634 .30914 L
.05759 .30921 L
.05882 .3093 L
.06012 .30943 L
.06123 .30959 L
.06244 .30983 L
.06381 .31019 L
.06529 .31075 L
.06669 .31149 L
.06797 .31241 L
.06914 .3135 L
.07041 .31505 L
.07175 .31716 L
.073 .31972 L
.07445 .3236 L
.07584 .3284 L
.07708 .33388 L
.07843 .3414 L
Mistroke
.0799 .35181 L
.08146 .36608 L
.08294 .38331 L
.08427 .40278 L
.08555 .42551 L
.08689 .45471 L
.0893 .52358 L
Mfstroke
.0893 .52358 m
.09163 .61803 L
s
.43214 .61803 m
.43453 .52276 L
.43591 .48053 L
.43716 .4489 L
.43853 .42043 L
.43996 .39612 L
.44126 .37837 L
.44268 .3627 L
.44518 .34266 L
.44659 .33459 L
.44809 .32793 L
.44952 .32311 L
.45081 .31972 L
.45212 .31706 L
.45332 .31514 L
.45465 .31353 L
.45605 .31224 L
.45727 .3114 L
.45841 .3108 L
.45966 .3103 L
.46101 .30991 L
.46234 .30963 L
.46355 .30945 L
.46421 .30937 L
.46494 .3093 L
.46625 .30921 L
.46748 .30914 L
.46878 .3091 L
.46989 .30907 L
.47111 .30905 L
.47185 .30904 L
.47255 .30904 L
.47386 .30903 L
.47459 .30903 L
.47527 .30902 L
.47602 .30902 L
.47681 .30902 L
.47812 .30902 L
.47934 .30902 L
.48004 .30902 L
.48069 .30902 L
.48139 .30902 L
.48214 .30902 L
.48339 .30902 L
.48454 .30902 L
.48586 .30902 L
.4871 .30902 L
.48826 .30902 L
.48932 .30902 L
.49049 .30902 L
Mistroke
.49173 .30902 L
.49297 .30902 L
.49367 .30902 L
.49431 .30902 L
.49555 .30902 L
.49673 .30902 L
.49739 .30902 L
.49809 .30902 L
.49936 .30902 L
.50013 .30902 L
.50086 .30902 L
.50152 .30902 L
.50222 .30902 L
.50347 .30902 L
.5046 .30902 L
.50591 .30902 L
.50715 .30902 L
.5083 .30902 L
.50935 .30902 L
.51052 .30902 L
.51175 .30902 L
.51298 .30902 L
.51368 .30902 L
.51431 .30902 L
.51548 .30902 L
.51671 .30902 L
.51737 .30902 L
.51807 .30902 L
.51933 .30902 L
.5201 .30902 L
.52083 .30902 L
.52148 .30902 L
.52219 .30902 L
.5235 .30901 L
.52473 .30901 L
.52544 .30901 L
.52608 .30901 L
.52682 .309 L
.52752 .309 L
.5282 .30899 L
.52892 .30898 L
.53022 .30896 L
.53094 .30894 L
.53162 .30892 L
.53236 .3089 L
.53316 .30886 L
.5344 .30879 L
.5357 .30867 L
.5369 .30852 L
.53802 .30834 L
Mistroke
.53935 .30803 L
.54056 .30765 L
.54195 .30706 L
.54327 .30629 L
.54441 .30541 L
.54565 .30418 L
.54682 .30269 L
.54788 .30098 L
.54913 .29845 L
.55049 .29491 L
.55177 .29061 L
.55297 .28561 L
.55431 .27853 L
.55558 .27018 L
.55794 .24889 L
.55927 .23284 L
.56049 .21481 L
.56182 .1909 L
.56325 .1594 L
.56546 .09562 L
.56752 .01532 L
Mfstroke
.56752 .01532 m
.56781 0 L
s
.90842 0 m
.9098 .06212 L
.91198 .13412 L
.91453 .19412 L
.91598 .21922 L
.91732 .238 L
.91977 .26354 L
.92114 .2739 L
.92239 .2814 L
.92371 .28776 L
.9251 .29302 L
.92629 .29655 L
.92759 .29961 L
.929 .30213 L
.93051 .30414 L
.93193 .30554 L
.93322 .30649 L
.93453 .3072 L
.93573 .30769 L
.93706 .30809 L
.93846 .30839 L
.93968 .30858 L
.94082 .3087 L
.94207 .30881 L
.94278 .30885 L
.94342 .30888 L
.94448 .30892 L
.94548 .30895 L
.94638 .30897 L
.94735 .30898 L
.94841 .30899 L
.94953 .309 L
.95048 .30901 L
.95154 .30901 L
.95252 .30901 L
.95342 .30901 L
.95445 .30902 L
.95543 .30902 L
.95634 .30902 L
.95718 .30902 L
.9581 .30902 L
.95908 .30902 L
.96024 .30902 L
.9613 .30902 L
.96247 .30902 L
.96371 .30902 L
.96478 .30902 L
.96579 .30902 L
.96689 .30902 L
.96806 .30902 L
Mistroke
.96911 .30902 L
.97025 .30902 L
.97132 .30902 L
.97232 .30902 L
.97321 .30902 L
.9742 .30902 L
.97523 .30902 L
.97619 .30902 L
Mfstroke
0 1 0 r
.11471 .61803 m
.11487 .60958 L
.11632 .54951 L
.11764 .50431 L
.11907 .46425 L
.12062 .42913 L
.12205 .40318 L
.12338 .38376 L
.12464 .36873 L
.12599 .35561 L
.12724 .34586 L
.12839 .33857 L
.13064 .3279 L
.13183 .32378 L
.13314 .32022 L
.1345 .31734 L
.13577 .31528 L
.13713 .31359 L
.1384 .31239 L
.13955 .31156 L
.1408 .31088 L
.14215 .31032 L
.14359 .3099 L
.14481 .30964 L
.14547 .30954 L
.14616 .30944 L
.14746 .3093 L
.14866 .30921 L
.14939 .30917 L
.15008 .30914 L
.15138 .3091 L
.15261 .30907 L
.15375 .30905 L
.155 .30904 L
.15632 .30903 L
.15743 .30902 L
.15862 .30902 L
.15974 .30902 L
.16075 .30902 L
.16195 .30902 L
.16325 .30902 L
.16448 .30902 L
.16561 .30902 L
.16681 .30902 L
.1681 .30902 L
.16932 .30902 L
.17043 .30902 L
.17167 .30902 L
.17237 .30902 L
.17302 .30902 L
Mistroke
.17434 .30902 L
.17508 .30902 L
.17575 .30902 L
.17642 .30902 L
.17713 .30902 L
.1784 .30902 L
.17911 .30902 L
.17978 .30902 L
.1805 .30902 L
.18128 .30902 L
.18195 .30902 L
.18268 .30902 L
.18337 .30902 L
.18401 .30902 L
.18522 .30902 L
.1865 .30902 L
.18764 .30902 L
.18888 .30902 L
.19017 .30902 L
.19138 .30902 L
.19251 .30902 L
.19354 .30902 L
.19473 .30902 L
.19586 .30902 L
.19708 .30902 L
.19837 .30902 L
.19948 .30902 L
.2007 .30902 L
.202 .30902 L
.20274 .30902 L
.20341 .30902 L
.20471 .30902 L
.20595 .30901 L
.2071 .30901 L
.20814 .30901 L
.20935 .309 L
.21048 .30899 L
.21153 .30898 L
.2125 .30897 L
.21356 .30894 L
.21469 .30891 L
.21582 .30886 L
.21704 .30878 L
.21819 .30868 L
.21923 .30855 L
.22046 .30836 L
.22179 .30806 L
.22305 .30767 L
.22422 .30719 L
.2254 .30655 L
Mistroke
.22664 .30567 L
.2277 .30471 L
.22886 .30337 L
.23011 .30152 L
.23145 .29895 L
.23271 .29582 L
.23386 .29226 L
.23609 .28274 L
.23735 .27545 L
.23851 .26719 L
.24064 .24713 L
.24172 .23407 L
.2429 .21691 L
.24428 .19255 L
.24558 .16429 L
.24803 .09438 L
.2494 .04342 L
Mfstroke
.2494 .04342 m
.25038 0 L
s
.59098 0 m
.592 .04885 L
.59342 .10048 L
.59471 .13922 L
.59591 .1695 L
.59721 .19677 L
.59843 .21792 L
.59958 .23438 L
.60178 .25884 L
.60295 .26865 L
.6042 .27723 L
.60552 .28443 L
.60676 .28987 L
.60789 .29384 L
.6091 .29725 L
.61013 .2996 L
.61128 .30171 L
.61329 .30442 L
.61443 .30551 L
.61565 .30641 L
.61681 .30707 L
.61787 .30754 L
.61914 .30796 L
.62034 .30826 L
.62142 .30846 L
.62259 .30862 L
.62387 .30875 L
.62451 .3088 L
.62522 .30884 L
.62647 .3089 L
.62765 .30894 L
.62882 .30897 L
.62994 .30898 L
.63094 .30899 L
.63204 .309 L
.63322 .30901 L
.63449 .30901 L
.63568 .30901 L
.63676 .30902 L
.63805 .30902 L
.63871 .30902 L
.63942 .30902 L
.64069 .30902 L
.64188 .30902 L
.64259 .30902 L
.64327 .30902 L
.64455 .30902 L
.64526 .30902 L
.64592 .30902 L
.64664 .30902 L
Mistroke
.64741 .30902 L
.6486 .30902 L
.64987 .30902 L
.65108 .30902 L
.65218 .30902 L
.65341 .30902 L
.6541 .30902 L
.65475 .30902 L
.65605 .30902 L
.65678 .30902 L
.65745 .30902 L
.65864 .30902 L
.65976 .30902 L
.66098 .30902 L
.6623 .30902 L
.66296 .30902 L
.66367 .30902 L
.66498 .30902 L
.66625 .30902 L
.66743 .30902 L
.66864 .30902 L
.66977 .30902 L
.67079 .30902 L
.67189 .30902 L
.67309 .30902 L
.67436 .30902 L
.67545 .30902 L
.67664 .30902 L
.67731 .30902 L
.67803 .30902 L
.67872 .30902 L
.67936 .30902 L
.68056 .30902 L
.68184 .30902 L
.68249 .30902 L
.6832 .30902 L
.68448 .30903 L
.68526 .30903 L
.68601 .30904 L
.68667 .30904 L
.6874 .30905 L
.68872 .30907 L
.68992 .3091 L
.69058 .30912 L
.6913 .30914 L
.6926 .30921 L
.69383 .3093 L
.69512 .30944 L
.69622 .3096 L
.69744 .30984 L
Mistroke
.69874 .31019 L
.69994 .31064 L
.70126 .31129 L
.70267 .31223 L
.70388 .31332 L
.70502 .31463 L
.70628 .31648 L
.70763 .31906 L
.70876 .32181 L
.70999 .32558 L
.71119 .33018 L
.71248 .33633 L
.71368 .34353 L
.71478 .35149 L
.71693 .37196 L
.71823 .38833 L
.71961 .40973 L
.72208 .4613 L
.72346 .49916 L
.72475 .54197 L
.72625 .60263 L
Mfstroke
.72625 .60263 m
.72656 .61803 L
s
0 0 1 r
.27348 0 m
.27426 .03756 L
.27658 .11996 L
.27902 .18202 L
.28031 .20692 L
.28149 .2257 L
.28276 .24241 L
.28414 .25711 L
.28541 .26805 L
.28659 .27627 L
.28891 .28828 L
.2902 .29309 L
.29141 .29667 L
.29274 .29974 L
.29417 .30227 L
.29559 .30415 L
.29709 .3056 L
.29836 .30652 L
.29975 .30726 L
.30108 .30778 L
.3023 .30813 L
.30364 .30841 L
.30431 .30852 L
.30506 .30861 L
.3063 .30874 L
.307 .3088 L
.30764 .30884 L
.30888 .3089 L
.31006 .30894 L
.31118 .30896 L
.31238 .30898 L
.3134 .30899 L
.31453 .309 L
.31574 .30901 L
.31704 .30901 L
.31827 .30901 L
.3194 .30902 L
.32062 .30902 L
.32193 .30902 L
.32316 .30902 L
.32428 .30902 L
.32559 .30902 L
.32633 .30902 L
.32702 .30902 L
.32828 .30902 L
.32891 .30902 L
.32961 .30902 L
.33033 .30902 L
.33101 .30902 L
.33229 .30902 L
Mistroke
.333 .30902 L
.33366 .30902 L
.33439 .30902 L
.33517 .30902 L
.33584 .30902 L
.33657 .30902 L
.33726 .30902 L
.33789 .30902 L
.3391 .30902 L
.34037 .30902 L
.34159 .30902 L
.34228 .30902 L
.34292 .30902 L
.34409 .30902 L
.34533 .30902 L
.34644 .30902 L
.34748 .30902 L
.34862 .30902 L
.34985 .30902 L
.35109 .30902 L
.35179 .30902 L
.35244 .30902 L
.35375 .30902 L
.35449 .30902 L
.35516 .30902 L
.35636 .30902 L
.35766 .30902 L
.35889 .30902 L
.36002 .30902 L
.36108 .30902 L
.36221 .30902 L
.36328 .30902 L
.36426 .30902 L
.36541 .30902 L
.36666 .30903 L
.36784 .30903 L
.36893 .30904 L
.37017 .30905 L
.37133 .30907 L
.37237 .30909 L
.3735 .30913 L
.37473 .30919 L
.37603 .30928 L
.37714 .30938 L
.37836 .30954 L
.37967 .30977 L
.38088 .31008 L
.38221 .31053 L
.38362 .31119 L
.38485 .31196 L
Mistroke
.38599 .3129 L
.38725 .31424 L
.3886 .31612 L
.38979 .31828 L
.3911 .32128 L
.39232 .3249 L
.39347 .32908 L
.39562 .33976 L
.39683 .34773 L
.39792 .35651 L
.39923 .36936 L
.40062 .38624 L
.4031 .42728 L
.40448 .45771 L
.40577 .49224 L
.40727 .54145 L
.4087 .59858 L
Mfstroke
.4087 .59858 m
.40907 .61803 L
s
.74962 .61803 m
.7499 .60436 L
.75128 .54797 L
.75253 .50535 L
.75497 .44113 L
.75629 .4149 L
.75768 .39234 L
.76017 .36241 L
.76156 .35031 L
.76286 .34129 L
.76428 .33346 L
.7658 .327 L
.76711 .32272 L
.76854 .31911 L
.76989 .31652 L
.77114 .31467 L
.77226 .31337 L
.77349 .31225 L
.77479 .31137 L
.776 .31074 L
.77718 .31028 L
.77843 .30992 L
.77962 .30966 L
.7807 .30949 L
.78197 .30934 L
.78268 .30928 L
.78334 .30923 L
.78455 .30916 L
.78584 .30911 L
.78706 .30908 L
.78838 .30905 L
.78963 .30904 L
.79077 .30903 L
.79146 .30903 L
.7921 .30903 L
.7928 .30902 L
.79355 .30902 L
.79426 .30902 L
.79493 .30902 L
.79619 .30902 L
.79727 .30902 L
.79845 .30902 L
.79968 .30902 L
.80083 .30902 L
.8019 .30902 L
.80288 .30902 L
.80402 .30902 L
.80509 .30902 L
.80625 .30902 L
.80748 .30902 L
Mistroke
.80853 .30902 L
.80969 .30902 L
.81094 .30902 L
.81163 .30902 L
.81227 .30902 L
.81352 .30902 L
.8147 .30902 L
.81594 .30902 L
.81664 .30902 L
.81728 .30902 L
.81846 .30902 L
.81972 .30902 L
.82084 .30902 L
.82189 .30902 L
.82304 .30902 L
.82427 .30902 L
.82558 .30902 L
.82632 .30902 L
.82701 .30902 L
.82827 .30902 L
.82891 .30902 L
.82961 .30902 L
.83082 .30902 L
.83212 .30902 L
.83335 .30902 L
.83448 .30902 L
.83555 .30902 L
.8367 .30902 L
.83777 .30902 L
.83876 .30902 L
.83991 .30901 L
.84116 .30901 L
.84234 .30901 L
.84343 .30901 L
.84456 .309 L
.84561 .30899 L
.84677 .30898 L
.84801 .30895 L
.84931 .30892 L
.85055 .30887 L
.85165 .3088 L
.85286 .3087 L
.8542 .30855 L
.85542 .30835 L
.85677 .30804 L
.85819 .30759 L
.85942 .30705 L
.86057 .30639 L
.86184 .30544 L
.8632 .30408 L
Mistroke
.8644 .30251 L
.86571 .30029 L
.86695 .2976 L
.86809 .29447 L
.87026 .28638 L
.87135 .28092 L
.87256 .27355 L
.87388 .2635 L
.87528 .25024 L
.87777 .21772 L
.87916 .19332 L
.88045 .16557 L
.88196 .12578 L
.88338 .07953 L
Mfstroke
.88338 .07953 m
.88523 0 L
s
0 0 0 r
.02381 .30691 m
0 0 rlineto s
.02381 .30691 m
.02382 0 L
s
.18254 0 m
.18255 .61803 L
s
.3412 .61803 m
.34121 0 L
s
.49997 0 m
.49999 .61803 L
s
.65877 .61803 m
.65878 0 L
s
.81746 0 m
.81747 .61803 L
s
.97618 .61803 m
.97619 .31113 L
s
1 0 0 r
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.05302 .30902 L
.05416 .30902 L
.05539 .30902 L
.05655 .30902 L
.0576 .30902 L
.05879 .30902 L
.05991 .30902 L
.06112 .30902 L
.06244 .30902 L
.06309 .30902 L
.06381 .30902 L
.06456 .30902 L
.06526 .30902 L
.06652 .30902 L
.06717 .30902 L
.06787 .30902 L
.06914 .30902 L
.06983 .30902 L
.07048 .30902 L
.07163 .30902 L
.07287 .30902 L
.07363 .30902 L
.07432 .30902 L
.07509 .30902 L
.07591 .30902 L
.07661 .30902 L
.07727 .30902 L
.078 .30902 L
.07877 .30902 L
.07946 .30902 L
.08021 .30902 L
.08092 .30902 L
Mistroke
.08158 .30902 L
.08282 .30902 L
.08414 .30902 L
.10458 .30902 L
.10583 .30902 L
.10654 .30902 L
.10718 .30902 L
.10842 .30902 L
.1096 .30902 L
.11081 .30902 L
.11212 .30902 L
.11282 .30902 L
.11356 .30902 L
.11419 .30902 L
.11489 .30902 L
.11564 .30902 L
.11633 .30902 L
.11709 .30902 L
.11789 .30902 L
.11858 .30902 L
.11923 .30902 L
.11994 .30902 L
.1207 .30902 L
.12139 .30902 L
.12214 .30902 L
.12284 .30902 L
.12349 .30902 L
.12473 .30902 L
.12603 .30902 L
.12726 .30902 L
.12843 .30902 L
.12907 .30902 L
.12978 .30902 L
.131 .30902 L
.13217 .30902 L
.13342 .30902 L
.13448 .30902 L
.13565 .30902 L
.13631 .30902 L
.13702 .30902 L
.13827 .30902 L
.13897 .30902 L
.13962 .30902 L
.14033 .30902 L
.1411 .30902 L
.14176 .30902 L
.14247 .30902 L
.14378 .30902 L
.14504 .30902 L
.14621 .30902 L
Mistroke
.14746 .30902 L
.14865 .30902 L
.14972 .30902 L
.15088 .30902 L
.15214 .30902 L
.15284 .30902 L
.15348 .30902 L
.15472 .30902 L
.15589 .30902 L
.157 .30902 L
.15816 .30902 L
.15916 .30902 L
.16025 .30902 L
.16142 .30902 L
.16268 .30902 L
.16387 .30902 L
.16495 .30902 L
.16623 .30902 L
.16688 .30902 L
.16759 .30902 L
.16885 .30902 L
.17003 .30902 L
.17071 .30902 L
.17142 .30902 L
.17269 .30902 L
.1734 .30902 L
.17406 .30902 L
.17478 .30902 L
.17555 .30902 L
.17685 .30902 L
.17758 .30902 L
.17826 .30902 L
.1795 .30902 L
.18081 .30902 L
.18198 .30902 L
.18308 .30902 L
.18429 .30902 L
.18558 .30902 L
.18627 .30902 L
.18692 .30902 L
.18813 .30902 L
.18944 .30902 L
.19017 .30902 L
.19085 .30902 L
.19198 .30902 L
.19322 .30902 L
.19452 .30902 L
.19573 .30902 L
.19641 .30902 L
.19716 .30902 L
Mistroke
.19787 .30902 L
.19852 .30902 L
.19975 .30902 L
.20106 .30902 L
.20174 .30902 L
.20247 .30902 L
.20378 .30902 L
.20458 .30902 L
.20534 .30902 L
.20603 .30902 L
.20678 .30902 L
.20743 .30902 L
.20814 .30902 L
.20942 .30902 L
.21067 .30902 L
.21182 .30902 L
.21307 .30902 L
.21377 .30902 L
.21444 .30902 L
.21513 .30902 L
.21577 .30902 L
.2165 .30902 L
.2172 .30902 L
.21837 .30902 L
.21961 .30902 L
.22184 .30902 L
.22299 .30902 L
.22423 .30902 L
.22495 .30902 L
.2256 .30902 L
.22688 .30902 L
.22816 .30902 L
.22936 .30902 L
.23044 .30902 L
.23162 .30902 L
.23289 .30902 L
.23408 .30902 L
.23531 .30902 L
.23597 .30902 L
.23668 .30902 L
.23795 .30902 L
.23916 .30902 L
.24024 .30902 L
.24142 .30902 L
.24252 .30902 L
.24369 .30902 L
.2448 .30902 L
.2458 .30902 L
.2471 .30902 L
.24775 .30902 L
Mistroke
.24847 .30902 L
.24974 .30902 L
.25092 .30902 L
.25164 .30902 L
.25232 .30902 L
.2536 .30902 L
.25431 .30902 L
.25497 .30902 L
.25569 .30902 L
.25646 .30902 L
.25765 .30902 L
.25877 .30902 L
.25942 .30902 L
.26011 .30902 L
.26133 .30902 L
.26261 .30902 L
.2638 .30902 L
.2651 .30902 L
.26583 .30902 L
.26649 .30902 L
.26769 .30902 L
.26881 .30902 L
.27004 .30902 L
.27135 .30902 L
.27201 .30902 L
.27273 .30902 L
.27404 .30902 L
.27532 .30902 L
.2765 .30902 L
.27759 .30902 L
.27862 .30902 L
.27974 .30902 L
.28096 .30902 L
.28216 .30902 L
.28343 .30902 L
.28452 .30902 L
.28571 .30902 L
.28638 .30902 L
.28711 .30902 L
.2878 .30902 L
.28843 .30902 L
.28964 .30902 L
.29091 .30902 L
.29157 .30902 L
.29228 .30902 L
.29356 .30902 L
.29434 .30902 L
.29509 .30902 L
.29575 .30902 L
.29648 .30902 L
Mistroke
.2978 .30902 L
.299 .30902 L
.29966 .30902 L
.30038 .30902 L
.30168 .30902 L
.30291 .30902 L
.3042 .30902 L
.3053 .30902 L
.30652 .30902 L
.30782 .30902 L
.30903 .30902 L
.30966 .30902 L
.31035 .30902 L
.31108 .30902 L
.31176 .30902 L
.31301 .30902 L
.31415 .30902 L
.3154 .30902 L
.31672 .30902 L
.31784 .30902 L
.31903 .30902 L
.32015 .30902 L
.32117 .30902 L
.32237 .30902 L
.32367 .30902 L
.3249 .30902 L
.32603 .30902 L
.32724 .30902 L
.32853 .30902 L
.32975 .30902 L
.33087 .30902 L
.33218 .30902 L
.33292 .30902 L
.3336 .30902 L
.33486 .30902 L
.33556 .30902 L
.33619 .30902 L
.33687 .30902 L
.33758 .30902 L
.33886 .30902 L
.33957 .30902 L
.34023 .30902 L
.34096 .30902 L
.34173 .30902 L
.34241 .30902 L
.34314 .30902 L
.34383 .30902 L
.34446 .30902 L
.34567 .30902 L
.34695 .30902 L
Mistroke
.34815 .30902 L
.34946 .30902 L
.3507 .30902 L
.35185 .30902 L
.35299 .30902 L
.35403 .30902 L
.35522 .30902 L
.35635 .30902 L
.35758 .30902 L
.35888 .30902 L
.35999 .30902 L
.3612 .30902 L
.36252 .30902 L
.36325 .30902 L
.36392 .30902 L
.36523 .30902 L
.36646 .30902 L
.3676 .30902 L
.36867 .30902 L
.36978 .30902 L
.37101 .30902 L
.37207 .30902 L
.37304 .30902 L
.3741 .30902 L
.37522 .30902 L
.37636 .30902 L
.37758 .30902 L
.37873 .30902 L
.37978 .30902 L
.381 .30902 L
.3817 .30902 L
.38234 .30902 L
.38351 .30902 L
.38476 .30902 L
.38597 .30902 L
.38728 .30902 L
.38853 .30902 L
.38968 .30902 L
.39082 .30902 L
.39186 .30902 L
.39306 .30902 L
.39418 .30902 L
.39542 .30902 L
.39672 .30902 L
.39783 .30902 L
.39905 .30902 L
.40036 .30902 L
.4011 .30902 L
.40177 .30902 L
.40308 .30902 L
Mistroke
.40431 .30902 L
.40536 .30902 L
.40652 .30902 L
.40773 .30902 L
.40887 .30902 L
.40993 .30902 L
.4109 .30902 L
.41196 .30902 L
.41308 .30902 L
.41424 .30902 L
.4153 .30902 L
.41658 .30902 L
.41773 .30902 L
.41894 .30902 L
.42025 .30902 L
.42148 .30902 L
.42262 .30902 L
.42377 .30902 L
.42502 .30902 L
.42621 .30902 L
.4273 .30902 L
.42857 .30902 L
.42929 .30902 L
.42993 .30902 L
.43117 .30902 L
.43233 .30902 L
.4414 .30902 L
.44392 .30902 L
.44459 .30902 L
.4453 .30902 L
.44658 .30902 L
.44777 .30902 L
.44885 .30902 L
.45012 .30902 L
.45133 .30902 L
.45263 .30902 L
.45328 .30902 L
.454 .30902 L
.45528 .30902 L
.45647 .30902 L
.45719 .30902 L
.45788 .30902 L
.45916 .30902 L
.45988 .30902 L
.46054 .30902 L
.46127 .30902 L
.46205 .30902 L
.46329 .30902 L
.464 .30902 L
.46465 .30902 L
Mistroke
.46534 .30902 L
.46608 .30902 L
.46676 .30902 L
.46741 .30902 L
.46863 .30902 L
.46977 .30902 L
.47101 .30902 L
.47233 .30902 L
.47365 .30902 L
.47438 .30902 L
.47506 .30902 L
.47631 .30902 L
.47762 .30902 L
.47832 .30902 L
.47907 .30902 L
.47977 .30902 L
.48041 .30902 L
.48116 .30902 L
.48198 .30902 L
.48275 .30902 L
.48346 .30902 L
.48462 .30902 L
.48587 .30902 L
.48705 .30902 L
.48812 .30902 L
.48938 .30902 L
.4901 .30902 L
.49076 .30902 L
.49197 .30902 L
.49326 .30902 L
.49396 .30902 L
.4946 .30902 L
.49531 .30902 L
.49606 .30902 L
.49732 .30902 L
.49803 .30902 L
.4987 .30902 L
.49994 .30902 L
.50108 .30902 L
.50239 .30902 L
.50363 .30902 L
.50477 .30902 L
.506 .30902 L
.50717 .30902 L
.50823 .30902 L
.50941 .30902 L
.5107 .30902 L
.51136 .30902 L
.51205 .30902 L
.51331 .30902 L
Mistroke
.51395 .30902 L
.51464 .30902 L
.51539 .30902 L
.51608 .30902 L
.51732 .30902 L
.51803 .30902 L
.51869 .30902 L
.51992 .30902 L
.52105 .30902 L
.52234 .30902 L
.52357 .30902 L
.52463 .30902 L
.52579 .30902 L
.52701 .30902 L
.52816 .30902 L
.52922 .30902 L
.5302 .30902 L
.53127 .30902 L
.5324 .30902 L
.53355 .30902 L
.53477 .30902 L
.53593 .30902 L
.53698 .30902 L
.53822 .30902 L
.53892 .30902 L
.53957 .30902 L
.54075 .30902 L
.54201 .30902 L
.54321 .30902 L
.54453 .30902 L
.54577 .30902 L
.54692 .30902 L
.54924 .30902 L
.55038 .30902 L
.55142 .30902 L
.55266 .30902 L
.55331 .30902 L
.554 .30902 L
.55511 .30902 L
.55633 .30902 L
.55763 .30902 L
.55836 .30902 L
.55903 .30902 L
.56032 .30902 L
.56155 .30902 L
.56269 .30902 L
.56376 .30902 L
.56488 .30902 L
.56611 .30902 L
.56717 .30902 L
Mistroke
.56814 .30902 L
.5692 .30902 L
.57032 .30902 L
.57146 .30902 L
.57268 .30902 L
.57383 .30902 L
.57488 .30902 L
.57611 .30902 L
.5768 .30902 L
.57744 .30902 L
.57861 .30902 L
.57986 .30902 L
.58107 .30902 L
.58239 .30902 L
.58364 .30902 L
.58479 .30902 L
.58594 .30902 L
.58698 .30902 L
.58817 .30902 L
.5893 .30902 L
.59054 .30902 L
.59184 .30902 L
.59296 .30902 L
.59418 .30902 L
.59549 .30902 L
.59623 .30902 L
.5969 .30902 L
.59821 .30902 L
.59944 .30902 L
.6005 .30902 L
.60166 .30902 L
.60287 .30902 L
.60401 .30902 L
.60507 .30902 L
.60604 .30902 L
.60716 .30902 L
.60822 .30902 L
.60937 .30902 L
.61059 .30902 L
.61174 .30902 L
.61278 .30902 L
.61401 .30902 L
.6147 .30902 L
.61534 .30902 L
.61652 .30902 L
.61776 .30902 L
.61898 .30902 L
.61966 .30902 L
.6203 .30902 L
.62147 .30902 L
Mistroke
.62271 .30902 L
.62382 .30902 L
.62486 .30902 L
.626 .30902 L
.62723 .30902 L
.62846 .30902 L
.62981 .30902 L
.63049 .30902 L
.63121 .30902 L
.63252 .30902 L
.63383 .30902 L
.63507 .30902 L
.63618 .30902 L
.63738 .30902 L
.63852 .30902 L
.63959 .30902 L
.64076 .30902 L
.64201 .30902 L
.64333 .30902 L
.64458 .30902 L
.6457 .30902 L
.64692 .30902 L
.64808 .30902 L
.64913 .30902 L
.65034 .30902 L
.65148 .30902 L
.65254 .30902 L
.65351 .30902 L
.65458 .30902 L
.65571 .30902 L
.65694 .30902 L
.65763 .30902 L
.65827 .30902 L
.65944 .30902 L
.66068 .30902 L
.66174 .30902 L
.66286 .30902 L
.66409 .30902 L
.66521 .30902 L
.6664 .30902 L
.6677 .30902 L
.66892 .30902 L
.67004 .30902 L
.67074 .30902 L
.6714 .30902 L
.67262 .30902 L
.67395 .30902 L
.67469 .30902 L
.67538 .30902 L
.67643 .30902 L
Mistroke
.67755 .30902 L
.67878 .30902 L
.67992 .30902 L
.68097 .30902 L
.68196 .30902 L
.68305 .30902 L
.68422 .30902 L
.68548 .30902 L
.68612 .30902 L
.68681 .30902 L
.68804 .30902 L
.68919 .30902 L
.69033 .30902 L
.69138 .30902 L
.69258 .30902 L
.69372 .30902 L
.6949 .30902 L
.69614 .30902 L
.69721 .30902 L
.69838 .30902 L
.69963 .30902 L
.70034 .30902 L
.70099 .30902 L
.70224 .30902 L
.70343 .30902 L
.70452 .30902 L
.70568 .30902 L
.70678 .30902 L
.70777 .30902 L
.70896 .30902 L
.71008 .30902 L
.71124 .30902 L
.71251 .30902 L
.71379 .30902 L
.71451 .30902 L
.71517 .30902 L
.71643 .30902 L
.71762 .30902 L
.71828 .30902 L
.71899 .30902 L
.72026 .30902 L
.72097 .30902 L
.72163 .30902 L
.72236 .30902 L
.72314 .30902 L
.72436 .30902 L
.72505 .30902 L
.72569 .30902 L
.72698 .30902 L
.72771 .30902 L
Mistroke
.72837 .30902 L
.72955 .30902 L
.73083 .30902 L
.73204 .30902 L
.73316 .30902 L
.73441 .30902 L
.7356 .30902 L
.73667 .30902 L
.73783 .30902 L
.73909 .30902 L
.7398 .30902 L
.74044 .30902 L
.74168 .30902 L
.74285 .30902 L
.74396 .30902 L
.74513 .30902 L
.74613 .30902 L
.74721 .30902 L
.74838 .30902 L
.74946 .30902 L
.75075 .30902 L
.75192 .30902 L
.75321 .30902 L
.75385 .30902 L
.75457 .30902 L
.75583 .30902 L
.75701 .30902 L
.75768 .30902 L
.7584 .30902 L
.75967 .30902 L
.76038 .30902 L
.76104 .30902 L
.76176 .30902 L
.76253 .30902 L
.76383 .30902 L
.76456 .30902 L
.76524 .30902 L
.76648 .30902 L
.76779 .30902 L
.76897 .30902 L
.77007 .30902 L
.77127 .30902 L
.77256 .30902 L
.77378 .30902 L
.77447 .30902 L
.77512 .30902 L
.77643 .30902 L
.77716 .30902 L
.77784 .30902 L
.77897 .30902 L
Mistroke
.78022 .30902 L
.78151 .30902 L
.78272 .30902 L
.78341 .30902 L
.78416 .30902 L
.78487 .30902 L
.78552 .30902 L
.78676 .30902 L
.78807 .30902 L
.78874 .30902 L
.78947 .30902 L
.79079 .30902 L
.79159 .30902 L
.79235 .30902 L
.79304 .30902 L
.79378 .30902 L
.79444 .30902 L
.79515 .30902 L
.79643 .30902 L
.79768 .30902 L
.79883 .30902 L
.80008 .30902 L
.80079 .30902 L
.80145 .30902 L
.80215 .30902 L
.80279 .30902 L
.80352 .30902 L
.80421 .30902 L
.80538 .30902 L
.80662 .30902 L
.80768 .30902 L
.80885 .30902 L
.81011 .30902 L
.81081 .30902 L
.81145 .30902 L
.81264 .30902 L
.8139 .30902 L
.81513 .30902 L
.81583 .30902 L
.81647 .30902 L
.81763 .30902 L
.8189 .30902 L
.82005 .30902 L
.82111 .30902 L
.82224 .30902 L
.82345 .30902 L
.82476 .30902 L
.8255 .30902 L
.82619 .30902 L
.82745 .30902 L
Mistroke
.82815 .30902 L
.82878 .30902 L
.83002 .30902 L
.83132 .30902 L
.83244 .30902 L
.83365 .30902 L
.83479 .30902 L
.83601 .30902 L
.83716 .30902 L
.83821 .30902 L
.83942 .30902 L
.84073 .30902 L
.84198 .30902 L
.84312 .30902 L
.84419 .30902 L
.84518 .30902 L
.84627 .30902 L
.84744 .30902 L
.84867 .30902 L
.84984 .30902 L
.85088 .30902 L
.85203 .30902 L
.85267 .30902 L
.85336 .30902 L
.85458 .30902 L
.85589 .30902 L
.85664 .30902 L
.85734 .30902 L
.8586 .30902 L
.85975 .30902 L
.86039 .30902 L
.86108 .30902 L
.86234 .30902 L
.86346 .30902 L
.8647 .30902 L
.86599 .30902 L
.8672 .30902 L
.86833 .30902 L
.86936 .30902 L
.8705 .30902 L
.87169 .30902 L
.87301 .30902 L
.8742 .30902 L
.87486 .30902 L
.87558 .30902 L
.87688 .30902 L
.8781 .30902 L
.87939 .30902 L
.88049 .30902 L
.88171 .30902 L
Mistroke
.88244 .30902 L
.88313 .30902 L
.88443 .30902 L
.88516 .30902 L
.88584 .30902 L
.88658 .30902 L
.88737 .30902 L
.88805 .30902 L
.8888 .30902 L
.8895 .30902 L
.89015 .30902 L
.89137 .30902 L
.89266 .30902 L
.89389 .30902 L
.89458 .30902 L
.89522 .30902 L
.89639 .30902 L
.89763 .30902 L
.89875 .30902 L
.89979 .30902 L
.90093 .30902 L
.90216 .30902 L
.90281 .30902 L
.9035 .30902 L
.90475 .30902 L
.90605 .30902 L
.90679 .30902 L
.90747 .30902 L
.90867 .30902 L
.90997 .30902 L
.9112 .30902 L
.91233 .30902 L
.91339 .30902 L
.91438 .30902 L
.91553 .30902 L
.91658 .30902 L
.91774 .30902 L
.91899 .30902 L
.92016 .30902 L
.92125 .30902 L
.92237 .30902 L
.92342 .30902 L
.92457 .30902 L
.92582 .30902 L
.92705 .30902 L
.92835 .30902 L
.92946 .30902 L
.93068 .30902 L
.93199 .30902 L
.93321 .30902 L
Mistroke
.93389 .30902 L
.93454 .30902 L
.93521 .30902 L
.93595 .30902 L
.9372 .30902 L
.93835 .30902 L
.93898 .30902 L
.93967 .30902 L
.94093 .30902 L
.94216 .30902 L
.94327 .30902 L
.94456 .30902 L
.94577 .30902 L
.94689 .30902 L
.94792 .30902 L
.94906 .30902 L
.95026 .30902 L
.95156 .30902 L
.95275 .30902 L
.95341 .30902 L
.95412 .30902 L
.95542 .30902 L
.95664 .30902 L
.95793 .30902 L
.95903 .30902 L
.96024 .30902 L
.96093 .30902 L
.96166 .30902 L
.96296 .30902 L
.96369 .30902 L
.96436 .30902 L
.9651 .30902 L
.96589 .30902 L
.96658 .30902 L
.96732 .30902 L
.96802 .30902 L
.96867 .30902 L
.9699 .30902 L
.9712 .30902 L
.97244 .30902 L
.97313 .30902 L
.97378 .30902 L
.97504 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-1.63782, -0.00013263, \
0.0324029, 1.5894}}]
}, Open  ]],

Cell[TextData[{
 "\tWhen the power is large, the phases take the form of isolated pulses of \
near-Gaussian form, approaching ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", 
    RowBox[{
     RowBox[{"-", "n"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["k", "2"], "(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Pi]", "/", "2"}], "k"}], " ", "-", "t"}], ")"}], "2"], 
      "/", "2"}]}]], TraditionalForm]]],
 " as the power (and number of phases) tends to infinity. Example E3 compares \
the Gaussian expression with the 10'th power of a 12-phase sinusoid. Higher \
powers give closer approximations. Note the analogy with ",
 StyleBox["JacobiCN",
  FontSlant->"Italic"],
 " periodic pulse solitonic solutions to the KdV non-linear PDE. They go to \
",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["Sech",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 " pulses as the period becomes infinite. Modulated Gaussian pulses are \
dispersive wave-packet solutions to the Schroedinger equation; I have found \
neither a power-sinusoid analogue nor a non-dispersive variation."
}], "Text",
 PageWidth->PaperWidth],

Cell[TextData[{
 "Example E3. Plotting ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     RowBox[{"12", " ", "t"}], "]"}], "10"], TraditionalForm]]],
 " & Exp[-",
 Cell[BoxData[
  FormBox[
   RowBox[{"12", "*", 
    SuperscriptBox["10", "2"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Pi]", "/", "20"}], "-", "t"}], ")"}], "2"]}], 
   TraditionalForm]]],
 "/2]."
}], "Text",
 PageWidth->PaperWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pp", "=", "12"}], ";", 
  RowBox[{"kk", "=", "10"}], ";", 
  RowBox[{"s1210", "=", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"kk", " ", "t"}], "]"}], "^", "pp"}]}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1210", ",", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "pp"}], " ", 
        RowBox[{
         SuperscriptBox["kk", "2"], "/", "2"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Pi]", "/", "2"}], "/", "kk"}], "-", "t"}], ")"}], "^", 
         "2"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Pi]", "/", "2"}], "/", "kk"}], "-", 
       RowBox[{".9", "/", "kk"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Pi]", "/", "2"}], "/", "kk"}], "+", 
       RowBox[{".9", "/", "kk"}]}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Fig.2 \!\(\*
StyleBox[\"Power\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"Sinusoid\",
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*
StyleBox[\"Gauss\",
FontColor->RGBColor[0, 1, 0]]\)\>\""}]}], "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.331109 5.29101 0 0.618034 [
[.06572 -0.0125 -15 -9 ]
[.06572 -0.0125 15 0 ]
[.33027 -0.0125 -15 -9 ]
[.33027 -0.0125 15 0 ]
[.46254 -0.0125 -12 -9 ]
[.46254 -0.0125 12 0 ]
[.59482 -0.0125 -15 -9 ]
[.59482 -0.0125 15 0 ]
[.72709 -0.0125 -9 -9 ]
[.72709 -0.0125 9 0 ]
[.85937 -0.0125 -15 -9 ]
[.85937 -0.0125 15 0 ]
[.99164 -0.0125 -12 -9 ]
[.99164 -0.0125 12 0 ]
[.18549 .12361 -18 -4.5 ]
[.18549 .12361 0 4.5 ]
[.18549 .24721 -18 -4.5 ]
[.18549 .24721 0 4.5 ]
[.18549 .37082 -18 -4.5 ]
[.18549 .37082 0 4.5 ]
[.18549 .49443 -18 -4.5 ]
[.18549 .49443 0 4.5 ]
[.18549 .61803 -6 -4.5 ]
[.18549 .61803 0 4.5 ]
[.5 .63053 -89 0 ]
[.5 .63053 89 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06572 0 m
.06572 .00625 L
s
[(0.075)] .06572 -0.0125 0 1 Mshowa
.33027 0 m
.33027 .00625 L
s
[(0.125)] .33027 -0.0125 0 1 Mshowa
.46254 0 m
.46254 .00625 L
s
[(0.15)] .46254 -0.0125 0 1 Mshowa
.59482 0 m
.59482 .00625 L
s
[(0.175)] .59482 -0.0125 0 1 Mshowa
.72709 0 m
.72709 .00625 L
s
[(0.2)] .72709 -0.0125 0 1 Mshowa
.85937 0 m
.85937 .00625 L
s
[(0.225)] .85937 -0.0125 0 1 Mshowa
.99164 0 m
.99164 .00625 L
s
[(0.25)] .99164 -0.0125 0 1 Mshowa
.125 Mabswid
.09217 0 m
.09217 .00375 L
s
.11863 0 m
.11863 .00375 L
s
.14508 0 m
.14508 .00375 L
s
.17154 0 m
.17154 .00375 L
s
.22445 0 m
.22445 .00375 L
s
.2509 0 m
.2509 .00375 L
s
.27736 0 m
.27736 .00375 L
s
.30381 0 m
.30381 .00375 L
s
.35672 0 m
.35672 .00375 L
s
.38318 0 m
.38318 .00375 L
s
.40963 0 m
.40963 .00375 L
s
.43609 0 m
.43609 .00375 L
s
.489 0 m
.489 .00375 L
s
.51545 0 m
.51545 .00375 L
s
.54191 0 m
.54191 .00375 L
s
.56836 0 m
.56836 .00375 L
s
.62127 0 m
.62127 .00375 L
s
.64773 0 m
.64773 .00375 L
s
.67418 0 m
.67418 .00375 L
s
.70064 0 m
.70064 .00375 L
s
.75355 0 m
.75355 .00375 L
s
.78 0 m
.78 .00375 L
s
.80646 0 m
.80646 .00375 L
s
.83291 0 m
.83291 .00375 L
s
.88582 0 m
.88582 .00375 L
s
.91228 0 m
.91228 .00375 L
s
.93873 0 m
.93873 .00375 L
s
.96519 0 m
.96519 .00375 L
s
.03926 0 m
.03926 .00375 L
s
.01281 0 m
.01281 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.19799 .12361 m
.20424 .12361 L
s
[(0.2)] .18549 .12361 1 0 Mshowa
.19799 .24721 m
.20424 .24721 L
s
[(0.4)] .18549 .24721 1 0 Mshowa
.19799 .37082 m
.20424 .37082 L
s
[(0.6)] .18549 .37082 1 0 Mshowa
.19799 .49443 m
.20424 .49443 L
s
[(0.8)] .18549 .49443 1 0 Mshowa
.19799 .61803 m
.20424 .61803 L
s
[(1)] .18549 .61803 1 0 Mshowa
.125 Mabswid
.19799 .0309 m
.20174 .0309 L
s
.19799 .0618 m
.20174 .0618 L
s
.19799 .09271 m
.20174 .09271 L
s
.19799 .15451 m
.20174 .15451 L
s
.19799 .18541 m
.20174 .18541 L
s
.19799 .21631 m
.20174 .21631 L
s
.19799 .27812 m
.20174 .27812 L
s
.19799 .30902 m
.20174 .30902 L
s
.19799 .33992 m
.20174 .33992 L
s
.19799 .40172 m
.20174 .40172 L
s
.19799 .43262 m
.20174 .43262 L
s
.19799 .46353 m
.20174 .46353 L
s
.19799 .52533 m
.20174 .52533 L
s
.19799 .55623 m
.20174 .55623 L
s
.19799 .58713 m
.20174 .58713 L
s
.25 Mabswid
.19799 0 m
.19799 .61803 L
s
gsave
.5 .63053 -150 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.2) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Power) show
135.000 12.750 moveto
(Sinusoid) show
189.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
207.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
(Gauss) show
237.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .00206 m
.03279 .00265 L
.04262 .00345 L
.06244 .00574 L
.07298 .0074 L
.08426 .00962 L
.10458 .01499 L
.1148 .0185 L
.12589 .02305 L
.14603 .03355 L
.16586 .04724 L
.18689 .06602 L
.22473 .11256 L
.26501 .18163 L
.30379 .26554 L
.34501 .36656 L
.38472 .46379 L
.42291 .54388 L
.44259 .5758 L
.45351 .59002 L
.46356 .60068 L
.47384 .60903 L
.47925 .61236 L
.48201 .61376 L
.48497 .61505 L
.48757 .61599 L
.48994 .6167 L
.49233 .61725 L
.49459 .61765 L
.49586 .61781 L
.49656 .61788 L
.49721 .61793 L
.49837 .618 L
.49964 .61803 L
.50031 .61803 L
.50102 .61802 L
.50229 .61796 L
.50299 .61792 L
.50365 .61786 L
.50514 .61768 L
.50642 .61749 L
.50777 .61724 L
.51019 .61666 L
.5128 .61587 L
.51566 .61479 L
.5208 .61233 L
.5256 .60941 L
.53456 .6024 L
.54419 .59268 L
.56536 .56383 L
Mistroke
.58546 .52812 L
.62371 .44386 L
.6644 .34298 L
.70359 .24849 L
.74522 .16219 L
.76613 .12646 L
.78534 .09847 L
.82394 .05576 L
.8428 .04081 L
.86348 .0282 L
.88303 .01933 L
.90396 .01249 L
.91416 .00997 L
.92524 .00772 L
.93482 .00614 L
.94537 .00472 L
.96033 .00319 L
.96851 .00255 L
.97619 .00206 L
Mfstroke
0 1 0 r
.02381 .00479 m
.04262 .00698 L
.06244 .01021 L
.08255 .01476 L
.10458 .02166 L
.12415 .02993 L
.14509 .04155 L
.16639 .0569 L
.18653 .07523 L
.22495 .12213 L
.26581 .19078 L
.30517 .27395 L
.343 .3644 L
.38329 .46155 L
.42206 .54259 L
.44319 .57674 L
.45292 .58936 L
.46328 .60043 L
.46863 .60514 L
.47367 .60892 L
.47858 .61198 L
.48309 .61426 L
.48739 .61593 L
.48955 .61659 L
.49192 .61717 L
.49431 .6176 L
.49564 .61778 L
.49686 .6179 L
.498 .61798 L
.49923 .61803 L
.5004 .61803 L
.50148 .61801 L
.50265 .61794 L
.50389 .61783 L
.50495 .61771 L
.50611 .61754 L
.5087 .61703 L
.5111 .6164 L
.51547 .61487 L
.52014 .61268 L
.52569 .60935 L
.53094 .60549 L
.54074 .59643 L
.56076 .57102 L
.57921 .54027 L
.61861 .45715 L
.6565 .36563 L
.69684 .26938 L
.73566 .18796 L
.77694 .11943 L
Mistroke
.79757 .09264 L
.8167 .07201 L
.83641 .05465 L
.85495 .04153 L
.87551 .0301 L
.89413 .02214 L
.91425 .01562 L
.93273 .01117 L
.95159 .00781 L
.97227 .00519 L
.97619 .00479 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 PageWidth->PaperWidth,
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{83.1875, 312.563}, {525.438, 384.125}} -> {-0.032774, \
3.13959, 0.000783378, 0.00670653}}]
}, Open  ]],

Cell[TextData[{
 "\tThe power-sinusoid travelling pulse ",
 StyleBox["V=(a Sin[",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sum]", 
    RowBox[{"x", ",", "y", ",", ".."}]], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox["kx*(x+xi-jx*t)]",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[")", "p"], TraditionalForm]],
  FontSlant->"Italic"],
 " is a solution of the non-linear TXY.. differential equation ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["V", "\[DoubleDot]"], TraditionalForm]]],
 StyleBox["=(1-1/p) ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["V", "."], "2"], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox["/V + pV",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sum]", 
    RowBox[{"x", ",", "y", ",", ".."}]], TraditionalForm]],
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"jx", " ", "kx"}], ")"}], "2"], TraditionalForm]],
  FontSlant->"Italic"],
 ", which reduces to the TX fixed power sinusoid ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["V", "\[DoubleDot]"], TraditionalForm]]],
 " = ",
 StyleBox["(1-1/p)",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox[
     OverscriptBox["V", "."], "2"]}], TraditionalForm]]],
 "/",
 StyleBox["V",
  FontSlant->"Italic"],
 " +",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", " ", 
    SuperscriptBox["\[Omega]", "2"]}], TraditionalForm]]],
 StyleBox["V",
  FontSlant->"Italic"],
 ". Example E4 compares the integration (red) with the 12th. power sinusoid, \
which has been shifted up slightly for clarity (green). As the function and \
derivatives become zero when t\[RightArrow]\[Pi], the integration blows up \
beyond this point. An integration procedure that sets very small values to \
zero would generate a single pulse resembling a wavelet."
}], "Text",
 PageWidth->PaperWidth],

Cell[TextData[{
 "Example E4. Power-sinusoid ",
 StyleBox["Differential Equation solution",
  FontColor->RGBColor[1, 0, 0]],
 " & ",
 StyleBox["Sin[x]^12+.05",
  FontColor->RGBColor[0, 1, 0]],
 "."
}], "Text",
 PageWidth->PaperWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pp", "=", "12"}], ";", 
  RowBox[{"kk", "=", "1"}], ";", 
  RowBox[{"startvals", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"kk", " ", "t"}], "]"}], "^", "pp"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"kk", " ", "t"}], "]"}], "^", "pp"}], ",", "t"}], "]"}]}], 
    "}"}]}], ";", 
  RowBox[{"sv", "=", 
   RowBox[{"startvals", "/.", 
    RowBox[{"t", "\[Rule]", 
     RowBox[{"\[Pi]", "/", "4"}]}]}]}], ";", 
  RowBox[{"solution", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[DoublePrime]",
          MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"1", "/", "12"}]}], ")"}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}], "2"], "/", 
           RowBox[{"y", "[", "x", "]"}]}]}], "-", 
         RowBox[{"12", 
          RowBox[{"y", "[", "x", "]"}]}]}]}], ",", 
       RowBox[{
        RowBox[{"y", "[", 
         RowBox[{"\[Pi]", "/", "4"}], "]"}], "==", 
        RowBox[{"sv", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{"\[Pi]", "/", "4"}], "]"}], "\[Equal]", 
        RowBox[{"sv", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", "y", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"\[Pi]", "/", "4"}], ",", "5"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"y", "[", "x", "]"}], "/.", "solution"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], "^", "12"}], "+", ".05"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", ".8", ",", "5"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", ".02"}], ",", "1.05"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", "\"\<Fig.3 Power-Sinusoid Integration\>\""}]}], 
   "]"}], ";"}]], "Input",
 PageWidth->PaperWidth,
 CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.011552 0.577602 [
[.21429 -0.00095 -3 -9 ]
[.21429 -0.00095 3 0 ]
[.40476 -0.00095 -3 -9 ]
[.40476 -0.00095 3 0 ]
[.59524 -0.00095 -3 -9 ]
[.59524 -0.00095 3 0 ]
[.78571 -0.00095 -3 -9 ]
[.78571 -0.00095 3 0 ]
[.97619 -0.00095 -3 -9 ]
[.97619 -0.00095 3 0 ]
[.01131 .12707 -18 -4.5 ]
[.01131 .12707 0 4.5 ]
[.01131 .24259 -18 -4.5 ]
[.01131 .24259 0 4.5 ]
[.01131 .35811 -18 -4.5 ]
[.01131 .35811 0 4.5 ]
[.01131 .47363 -18 -4.5 ]
[.01131 .47363 0 4.5 ]
[.01131 .58915 -6 -4.5 ]
[.01131 .58915 0 4.5 ]
[.5 .63053 -98 0 ]
[.5 .63053 98 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01155 m
.21429 .0178 L
s
[(1)] .21429 -0.00095 0 1 Mshowa
.40476 .01155 m
.40476 .0178 L
s
[(2)] .40476 -0.00095 0 1 Mshowa
.59524 .01155 m
.59524 .0178 L
s
[(3)] .59524 -0.00095 0 1 Mshowa
.78571 .01155 m
.78571 .0178 L
s
[(4)] .78571 -0.00095 0 1 Mshowa
.97619 .01155 m
.97619 .0178 L
s
[(5)] .97619 -0.00095 0 1 Mshowa
.125 Mabswid
.0619 .01155 m
.0619 .0153 L
s
.1 .01155 m
.1 .0153 L
s
.1381 .01155 m
.1381 .0153 L
s
.17619 .01155 m
.17619 .0153 L
s
.25238 .01155 m
.25238 .0153 L
s
.29048 .01155 m
.29048 .0153 L
s
.32857 .01155 m
.32857 .0153 L
s
.36667 .01155 m
.36667 .0153 L
s
.44286 .01155 m
.44286 .0153 L
s
.48095 .01155 m
.48095 .0153 L
s
.51905 .01155 m
.51905 .0153 L
s
.55714 .01155 m
.55714 .0153 L
s
.63333 .01155 m
.63333 .0153 L
s
.67143 .01155 m
.67143 .0153 L
s
.70952 .01155 m
.70952 .0153 L
s
.74762 .01155 m
.74762 .0153 L
s
.82381 .01155 m
.82381 .0153 L
s
.8619 .01155 m
.8619 .0153 L
s
.9 .01155 m
.9 .0153 L
s
.9381 .01155 m
.9381 .0153 L
s
.25 Mabswid
0 .01155 m
1 .01155 L
s
.02381 .12707 m
.03006 .12707 L
s
[(0.2)] .01131 .12707 1 0 Mshowa
.02381 .24259 m
.03006 .24259 L
s
[(0.4)] .01131 .24259 1 0 Mshowa
.02381 .35811 m
.03006 .35811 L
s
[(0.6)] .01131 .35811 1 0 Mshowa
.02381 .47363 m
.03006 .47363 L
s
[(0.8)] .01131 .47363 1 0 Mshowa
.02381 .58915 m
.03006 .58915 L
s
[(1)] .01131 .58915 1 0 Mshowa
.125 Mabswid
.02381 .04043 m
.02756 .04043 L
s
.02381 .06931 m
.02756 .06931 L
s
.02381 .09819 m
.02756 .09819 L
s
.02381 .15595 m
.02756 .15595 L
s
.02381 .18483 m
.02756 .18483 L
s
.02381 .21371 m
.02756 .21371 L
s
.02381 .27147 m
.02756 .27147 L
s
.02381 .30035 m
.02756 .30035 L
s
.02381 .32923 m
.02756 .32923 L
s
.02381 .38699 m
.02756 .38699 L
s
.02381 .41587 m
.02756 .41587 L
s
.02381 .44475 m
.02756 .44475 L
s
.02381 .50251 m
.02756 .50251 L
s
.02381 .53139 m
.02756 .53139 L
s
.02381 .56027 m
.02756 .56027 L
s
.02381 .61803 m
.02756 .61803 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.3) show
99.000 12.750 moveto
(Power) show
129.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sinusoid) show
189.000 12.750 moveto
(Integration) show
255.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.17619 .02228 m
.18009 .02511 L
.18373 .02827 L
.19199 .03768 L
.20004 .0505 L
.20864 .06906 L
.21817 .09644 L
.22718 .12963 L
.24404 .2112 L
.27631 .41277 L
.29264 .50713 L
.29712 .52836 L
.30193 .54816 L
.30644 .5635 L
.31063 .5747 L
.31285 .57938 L
.31486 .58285 L
.3171 .58583 L
.31833 .58706 L
.31948 .58797 L
.32051 .58856 L
.32159 .58896 L
.32251 .58913 L
.32352 .58913 L
.32461 .58891 L
.32523 .58868 L
.32578 .58842 L
.32687 .58773 L
.32789 .58688 L
.3298 .58476 L
.33182 .58178 L
.33546 .57453 L
.33937 .56411 L
.34369 .54964 L
.35217 .51312 L
.35994 .47187 L
.37746 .36289 L
.3947 .25333 L
.41074 .16575 L
.42622 .10189 L
.43488 .07549 L
.44275 .05682 L
.45114 .04183 L
.45887 .03176 L
.46291 .02769 L
.46735 .02401 L
.47196 .02095 L
.47634 .01865 L
.48042 .01695 L
.48488 .01551 L
Mistroke
.48892 .01449 L
.49267 .01376 L
.49714 .0131 L
.50117 .01266 L
.50342 .01246 L
.50584 .01229 L
.50796 .01216 L
.51022 .01204 L
.51437 .01188 L
.51823 .01177 L
.52059 .01172 L
.52282 .01169 L
.52701 .01164 L
.52915 .01162 L
.53142 .0116 L
.53338 .01159 L
.53549 .01158 L
.53775 .01157 L
.53988 .01157 L
.5424 .01156 L
.54471 .01156 L
.54681 .01156 L
.54871 .01156 L
.5509 .01156 L
.55297 .01155 L
.55489 .01155 L
.55665 .01155 L
.55859 .01155 L
.56064 .01155 L
.56172 .01155 L
.56271 .01155 L
.56377 .01155 L
.56493 .01155 L
.56599 .01155 L
.56698 .01155 L
.56893 .01155 L
.57001 .01155 L
.57103 .01155 L
.57224 .01155 L
.57335 .01155 L
.57444 .01155 L
.5756 .01155 L
.57677 .01155 L
.57804 .01155 L
.57914 .01155 L
.58016 .01155 L
.58128 .01155 L
.58247 .01155 L
.5835 .01155 L
.58446 .01155 L
Mistroke
.58552 .01155 L
.58611 .01155 L
.58666 .01155 L
.58766 .01155 L
.58875 .01155 L
.58972 .01155 L
.59075 .01155 L
.59176 .01155 L
.59271 .01155 L
.59357 .01155 L
.59449 .01155 L
.59559 .01155 L
.59662 .01155 L
.59721 .01155 L
.59774 .01155 L
.59836 .01155 L
.59895 .01155 L
.59952 .01155 L
.60012 .01155 L
.6012 .01155 L
.60181 .01155 L
.60237 .01155 L
.60298 .01155 L
.60366 .01155 L
.60469 .01155 L
.60577 .01155 L
.60678 .01155 L
.60771 .01155 L
.60882 .01155 L
.60983 .01155 L
.61099 .01155 L
.61208 .01155 L
.61305 .01155 L
.6141 .01155 L
.61508 .01155 L
.61598 .01155 L
.61703 .01155 L
.61817 .01155 L
.61925 .01155 L
.62026 .01156 L
.62139 .01156 L
.62246 .01156 L
.62445 .01156 L
.62557 .01156 L
.62659 .01157 L
.62771 .01157 L
.62891 .01158 L
.63077 .01159 L
.63251 .0116 L
.63457 .01162 L
Mistroke
.63645 .01165 L
.63841 .01169 L
.64054 .01175 L
.64255 .01183 L
.64441 .01192 L
.64645 .01206 L
.64832 .01222 L
.65048 .01247 L
.65253 .01277 L
.65441 .01313 L
.65616 .01355 L
.66013 .01489 L
.6624 .01597 L
.66453 .01726 L
.66852 .02062 L
.67075 .02318 L
.67281 .02609 L
.67524 .03034 L
.67746 .03515 L
.6814 .04644 L
.68563 .0636 L
.68955 .08572 L
.69326 .11385 L
.69758 .15784 L
.70157 .2123 L
.70596 .29136 L
.71061 .40322 L
.71472 .53121 L
Mfstroke
.71472 .53121 m
.71694 .61803 L
s
0 1 0 r
.17619 .05116 m
.18009 .05399 L
.18373 .05715 L
.19199 .06656 L
.20004 .07938 L
.20864 .09794 L
.21817 .12532 L
.22718 .15851 L
.24404 .24008 L
.27631 .44165 L
.29264 .53601 L
.29712 .55724 L
.30193 .57704 L
.30644 .59238 L
.31063 .60358 L
.31285 .60826 L
.31486 .61173 L
.3171 .61471 L
.31833 .61594 L
.31948 .61685 L
.32051 .61744 L
.32159 .61784 L
.32251 .61801 L
.32352 .61801 L
.32461 .61779 L
.32523 .61756 L
.32578 .6173 L
.32687 .61661 L
.32789 .61576 L
.3298 .61364 L
.33182 .61066 L
.33546 .6034 L
.33937 .59299 L
.34369 .57852 L
.35217 .542 L
.35994 .50075 L
.37746 .39177 L
.3947 .28221 L
.41074 .19463 L
.42622 .13077 L
.43488 .10437 L
.44275 .0857 L
.45114 .07071 L
.45887 .06064 L
.46291 .05657 L
.46735 .05289 L
.47196 .04983 L
.47634 .04753 L
.48042 .04583 L
.48488 .04439 L
Mistroke
.48892 .04337 L
.49267 .04264 L
.49714 .04198 L
.50117 .04154 L
.50342 .04134 L
.50584 .04117 L
.50796 .04104 L
.51022 .04092 L
.51437 .04076 L
.51823 .04065 L
.52059 .0406 L
.52282 .04057 L
.52701 .04052 L
.52915 .0405 L
.53142 .04048 L
.53338 .04047 L
.53549 .04046 L
.53775 .04045 L
.53988 .04045 L
.5424 .04044 L
.54471 .04044 L
.54681 .04044 L
.54871 .04044 L
.5509 .04044 L
.55297 .04043 L
.55489 .04043 L
.55665 .04043 L
.55859 .04043 L
.56064 .04043 L
.56172 .04043 L
.56271 .04043 L
.56377 .04043 L
.56493 .04043 L
.56599 .04043 L
.56698 .04043 L
.56893 .04043 L
.57001 .04043 L
.57103 .04043 L
.57224 .04043 L
.57335 .04043 L
.57444 .04043 L
.5756 .04043 L
.57677 .04043 L
.57804 .04043 L
.57914 .04043 L
.58016 .04043 L
.58128 .04043 L
.58247 .04043 L
.5835 .04043 L
.58446 .04043 L
Mistroke
.58552 .04043 L
.58666 .04043 L
.58766 .04043 L
.58875 .04043 L
.58979 .04043 L
.59075 .04043 L
.5917 .04043 L
.59256 .04043 L
.59356 .04043 L
.59449 .04043 L
.59551 .04043 L
.59609 .04043 L
.59663 .04043 L
.59773 .04043 L
.59834 .04043 L
.5989 .04043 L
.59989 .04043 L
.60098 .04043 L
.602 .04043 L
.60294 .04043 L
.60403 .04043 L
.60505 .04043 L
.60564 .04043 L
.60617 .04043 L
.60676 .04043 L
.60738 .04043 L
.60794 .04043 L
.60854 .04043 L
.60962 .04043 L
.61029 .04043 L
.61091 .04043 L
.61147 .04043 L
.61208 .04043 L
.61312 .04043 L
.61407 .04043 L
.61516 .04043 L
.6162 .04043 L
.62004 .04043 L
.62458 .04043 L
.62679 .04043 L
.62783 .04043 L
.62879 .04043 L
.62981 .04043 L
.6309 .04043 L
.63187 .04043 L
.63289 .04043 L
.63397 .04043 L
.63497 .04043 L
.63607 .04043 L
.63669 .04043 L
Mistroke
.63725 .04043 L
.63783 .04043 L
.63843 .04043 L
.63952 .04043 L
.64013 .04043 L
.6407 .04043 L
.64132 .04043 L
.64199 .04043 L
.64256 .04043 L
.64319 .04043 L
.64378 .04043 L
.64433 .04043 L
.64537 .04043 L
.64647 .04043 L
.64751 .04043 L
.64811 .04043 L
.64866 .04043 L
.64977 .04043 L
.6504 .04043 L
.65097 .04043 L
.65199 .04043 L
.65309 .04043 L
.65414 .04043 L
.65511 .04043 L
.65622 .04043 L
.65726 .04043 L
.6584 .04043 L
.65905 .04043 L
.65964 .04043 L
.66076 .04043 L
.66198 .04043 L
.66326 .04043 L
.66445 .04043 L
.66551 .04043 L
.66666 .04043 L
.66774 .04043 L
.66874 .04043 L
.67063 .04043 L
.67159 .04043 L
.67264 .04043 L
.67482 .04043 L
.67604 .04043 L
.67716 .04043 L
.6782 .04043 L
.67933 .04043 L
.68139 .04043 L
.68251 .04043 L
.68354 .04043 L
.68465 .04043 L
.68586 .04043 L
Mistroke
.68791 .04043 L
.69007 .04043 L
.69204 .04043 L
.69414 .04044 L
.69613 .04044 L
.69794 .04044 L
.7002 .04044 L
.70228 .04044 L
.70457 .04045 L
.707 .04046 L
.7091 .04046 L
.71107 .04047 L
.71324 .04048 L
.71557 .0405 L
.71759 .04052 L
.71974 .04054 L
.72362 .0406 L
.726 .04065 L
.72824 .04071 L
.73243 .04085 L
.73458 .04094 L
.73686 .04106 L
.74094 .04134 L
.74533 .04175 L
.75016 .04238 L
.75455 .04317 L
.75871 .04416 L
.76245 .04529 L
.76652 .04684 L
.77093 .04897 L
.77563 .05186 L
.78004 .05526 L
.78408 .05907 L
.79193 .06871 L
.8004 .08315 L
.80787 .10003 L
.81575 .12265 L
.8323 .18811 L
.84772 .27034 L
.88048 .47736 L
.88907 .52589 L
.89838 .56945 L
.90266 .58535 L
.90718 .59901 L
.91105 .60787 L
.91325 .6117 L
.9153 .61449 L
.91635 .6156 L
.91747 .61655 L
.91852 .61724 L
Mistroke
.91947 .61768 L
.92006 .61786 L
.9206 .61797 L
.92119 .61803 L
.92182 .61802 L
.92287 .61783 L
.92347 .61763 L
.92403 .61738 L
.9251 .61673 L
.92612 .61592 L
.92803 .61386 L
.93008 .61089 L
.93232 .60677 L
.93624 .59739 L
.9404 .58453 L
.94788 .55464 L
.96248 .47645 L
.97619 .38961 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 PageWidth->PaperWidth,
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{83.1875, 312.563}, {227.125, 85.8125}} -> {-2.94829, \
0.670836, 0.0213697, 0.00704709}}]
}, Open  ]],

Cell[TextData[{
 "\tThe non-linearity disappears if ",
 StyleBox["p",
  FontSlant->"Italic"],
 "=1, simplifying to the standard sinusoid equation ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["V", "\[DoubleDot]"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Omega]", "2"], TraditionalForm]]],
 StyleBox["V",
  FontSlant->"Italic"],
 ". "
}], "Text",
 PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["18. Appendix F. Plex-conjugation.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary.",
  FontSlant->"Plain"],
 " Loops with sizes that are the signed sum of squared elements have \
conjugates, pairs of vectors whose product is the vector size followed by \
zeroes. The complex conjugate is the archetype: (a+\[ImaginaryI] b)(a-\
\[ImaginaryI] b)= (",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["a", "2"], "+", 
   SuperscriptBox["b", "2"]}]]],
 "+\[ImaginaryI] 0). Some other loops have \"plex-conjugates\" that give hoop \
products (usually with many zeroes) that are related to the sizes. A number \
of compact sizes have been found via such conjugates. \"Polymorphic\" \
conjugates & shape formulations have been obtained for some hoops. Ternary \
conjugates have inverted element pairs,\[DoubleStruckCapitalJ]\
\[LeftRightArrow]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], TraditionalForm]]],
 " instead of negated elements \[ImaginaryI]\[LeftRightArrow]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ImaginaryI]", "3"], TraditionalForm]]],
 ". Quasi-group products conserve the sum of their elements."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["18.1. Complex Conjugates.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tComplex, Quaternion, & Octonion numbers have \"complex conjugates\"; a \
squared \"length\" is obtained on multiplying a vector by its complex \
conjugate. This actually gives the ",
 StyleBox["size",
  FontSlant->"Italic"],
 " of the vector, which also appears as the first element of the (hoop) \
product of the vector and its conjugate; the other elements become zero. The \
same is true for P4, CL2, & higher Cayley-Dickson non-associative algebras \
such as Sed, as well as \[DoubleStruckCapitalC], \[DoubleStruckCapitalH], & \
\[DoubleStruckCapitalO], as can be seen in Example F1. These are all the \
loops known to me with shapes that are signed sums of squared elements. ",
 "Lounesto",
 " [3, p15] calls the CL2 conjugate the Clifford-conjugate."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example F1. Multiplication by complex conjugates give sizes.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "b"}]}], "}"}], ",", "\"\<C4c\>\""}], "]"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}], ",", 
      RowBox[{"-", "d"}]}], "}"}], ",", "\"\<Qr\>\""}], "]"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "+", 
    SuperscriptBox["d", "2"]}], ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}], ",", 
      RowBox[{"-", "d"}]}], "}"}], ",", "\"\<P4\>\""}], "]"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox["d", "2"]}], ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}], ",", 
      RowBox[{"-", "d"}]}], "}"}], ",", "\"\<CL2\>\""}], "]"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox["d", "2"]}], ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}], ",", 
      RowBox[{"-", "d"}], ",", 
      RowBox[{"-", "e"}], ",", 
      RowBox[{"-", "f"}], ",", 
      RowBox[{"-", "g"}], ",", 
      RowBox[{"-", "h"}]}], "}"}], ",", "\"\<Octc\>\""}], "]"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "+", 
    SuperscriptBox["d", "2"], "+", 
    SuperscriptBox["e", "2"], "+", 
    SuperscriptBox["f", "2"], "+", 
    SuperscriptBox["g", "2"], "+", 
    SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", ",", 
      "o", ",", "p"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}], ",", 
      RowBox[{"-", "d"}], ",", 
      RowBox[{"-", "e"}], ",", 
      RowBox[{"-", "f"}], ",", 
      RowBox[{"-", "g"}], ",", 
      RowBox[{"-", "h"}], ",", 
      RowBox[{"-", "i"}], ",", 
      RowBox[{"-", "j"}], ",", 
      RowBox[{"-", "k"}], ",", 
      RowBox[{"-", "l"}], ",", 
      RowBox[{"-", "m"}], ",", 
      RowBox[{"-", "n"}], ",", 
      RowBox[{"-", "o"}], ",", 
      RowBox[{"-", "p"}]}], "}"}], ",", "\"\<Sed\>\""}], "]"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "+", 
    SuperscriptBox["d", "2"], "+", 
    SuperscriptBox["e", "2"], "+", 
    SuperscriptBox["f", "2"], "+", 
    SuperscriptBox["g", "2"], "+", 
    SuperscriptBox["h", "2"], "+", 
    SuperscriptBox["i", "2"], "+", 
    SuperscriptBox["j", "2"], "+", 
    SuperscriptBox["k", "2"], "+", 
    SuperscriptBox["l", "2"], "+", 
    SuperscriptBox["m", "2"], "+", 
    SuperscriptBox["n", "2"], "+", 
    SuperscriptBox["o", "2"], "+", 
    SuperscriptBox["p", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.2. Plex-conjugates.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tOther loops have \"plex-conjugates\" that may give a number of zeroes in \
the hoop product. The non-zero products are related to the sizes. Sizes can \
sometimes be identified, if they are not already known, with the aid of \
plex-conjugates and knowledge of the number and order of the factors in the \
shape (provided by ",
 StyleBox["fa",
  FontSlant->"Italic"],
 " or ",
 StyleBox["fp",
  FontSlant->"Italic"],
 "). Example F2 demonstrates this. The pattern of signs of the conjugate have \
to be discovered in each case. For CL3 the plex-conjugate that gives two \
non-zero terms gives the shape directly, as the sum of the squares of the two \
non-zero elements in the product:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example F2.  Plex-conjugate defining shape. CL3.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "\"\<CL3 {a,b,c,d,e,f,g,h}\[Times]{a,-b,-c,-d,-e,-f,-g,h}=\>\"", ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "g"}], ",", "h"}], "}"}], ",", 
      RowBox[{"tst", "=", "\"\<CL3\>\""}]}], "]"}], ",", 
    "\[IndentingNewLine]", "\"\<\\nFactors after \!\(\*
StyleBox[\"Alph\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"substitution\",
FontSlant->\"Plain\"]\)\>\"", ",", 
    RowBox[{"fp", "[", 
     RowBox[{"mp", "[", "tst", "]"}], "]"}], ",", "\[IndentingNewLine]", 
    "\"\<\\nShape\>\"", ",", 
    RowBox[{"sh", "[", "tst", "]"}], ",", "\"\<\\nShape found from \!\(\*
StyleBox[\"plex\",
FontSlant->\"Italic\"]\) gives the correct factor\\n\>\"", ",", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"sh", "[", "tst", "]"}], "]"}], "/.", 
     RowBox[{"fromAlph", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"pow2", ",", "8"}], "]"}], "]"}]}]}], "}"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL3 {a,b,c,d,e,f,g,h}\[Times]{a,-b,-c,-d,-e,-f,-g,h}=\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "-", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "-", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",",
      "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "d", " ", "e"}], "+", 
      RowBox[{"2", " ", "c", " ", "f"}], "-", 
      RowBox[{"2", " ", "b", " ", "g"}], "+", 
      RowBox[{"2", " ", "a", " ", "h"}]}]}], "}"}], 
   ",", "\<\"\\nFactors after \\!\\(\\* \
StyleBox[\\\"Alph\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"substitution\\\",\\nFontSlant->\\\"Plain\\\"]\\)\"\>", ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"8235257", "-", 
      RowBox[{"16384", " ", "a"}], "+", 
      RowBox[{"10646", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "2"], ",", "\<\"\\nShape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "d"}], " ", "e"}], "+", 
         RowBox[{"c", " ", "f"}], "-", 
         RowBox[{"b", " ", "g"}], "+", 
         RowBox[{"a", " ", "h"}]}], ")"}], "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["d", "2"], "-", 
        SuperscriptBox["e", "2"], "+", 
        SuperscriptBox["f", "2"], "+", 
        SuperscriptBox["g", "2"], "-", 
        SuperscriptBox["h", "2"]}], ")"}], "2"]}], "}"}], 
   ",", "\<\"\\nShape found from \\!\\(\\* \
StyleBox[\\\"plex\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives the correct \
factor\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"8235257", "-", 
     RowBox[{"16384", " ", "a"}], "+", 
     RowBox[{"10646", " ", 
      SuperscriptBox["a", "2"]}], "+", 
     SuperscriptBox["a", "4"]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tPlex-conjugate products for CL4, CL13 & CL04 have six non-zero terms that \
give the shapes directly - as the squared sum of the squared elements minus \
the squares of the other non-zero products. (As ",
 StyleBox["pow2",
  FontSlant->"Italic"],
 " gives anomalous results with some Clifford algebras a different \
substitution is used.) Only CL4 is shown:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example F3.  Plex-conjugate defining shape. CL4.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"subs", "=", 
    RowBox[{"{", 
     RowBox[{
     "a", ",", "1", ",", "3", ",", "2", ",", "7", ",", "5", ",", "41", ",", 
      "11", ",", "13", ",", "29", ",", "17", ",", "19", ",", "31", ",", "61", 
      ",", "37", ",", "43"}], "}"}]}], ";", 
   RowBox[{"sbs", "=", 
    RowBox[{"fromAlph", "[", "subs", "]"}]}], ";", 
   RowBox[{"{", 
    RowBox[{
    "\"\<{a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p}\[Times]{a,b,c,-d,e,-f,-g,-h,i,-j,-\
k,-l,-m,-n,-o,p} using CL4 is\>\"", ",", 
     RowBox[{"fcl4", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",",
           "h", ",", "i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n", 
          ",", "o", ",", "p"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"-", "d"}], ",", "e", ",", 
          RowBox[{"-", "f"}], ",", 
          RowBox[{"-", "g"}], ",", 
          RowBox[{"-", "h"}], ",", "i", ",", 
          RowBox[{"-", "j"}], ",", 
          RowBox[{"-", "k"}], ",", 
          RowBox[{"-", "l"}], ",", 
          RowBox[{"-", "m"}], ",", 
          RowBox[{"-", "n"}], ",", 
          RowBox[{"-", "o"}], ",", "p"}], "}"}], ",", 
        RowBox[{"tst", "=", "\"\<CL4\>\""}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "\"\<\\nFactors after a substitution\>\"", ",", 
     RowBox[{"fp", "[", 
      RowBox[{
       RowBox[{"mp", "[", "tst", "]"}], ",", "subs"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     "\"\<\\nThe shape is the first factor squared, minus the other factors \
squared, giving, after the same substitution \>\"", ",", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"fcl4", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"fcl4", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"fcl4", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"fcl4", "[", 
           RowBox[{"[", "5", "]"}], "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"fcl4", "[", 
           RowBox[{"[", "9", "]"}], "]"}], "^", "2"}], "-", 
         RowBox[{
          RowBox[{"fcl4", "[", 
           RowBox[{"[", "16", "]"}], "]"}], "^", "2"}]}], ")"}], "/.", 
       "sbs"}], "]"}]}], "}"}]}], TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"{a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p}\[Times]{a,b,c,-d,e,-f,-g,-h,\
i,-j,-k,-l,-m,-n,-o,p} using CL4 is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"], "+", 
      SuperscriptBox["i", "2"], "+", 
      SuperscriptBox["j", "2"], "+", 
      SuperscriptBox["k", "2"], "+", 
      SuperscriptBox["l", "2"], "+", 
      SuperscriptBox["m", "2"], "+", 
      SuperscriptBox["n", "2"], "+", 
      SuperscriptBox["o", "2"], "+", 
      SuperscriptBox["p", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      RowBox[{"2", " ", "c", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "f"}], "+", 
      RowBox[{"2", " ", "g", " ", "h"}], "+", 
      RowBox[{"2", " ", "i", " ", "j"}], "+", 
      RowBox[{"2", " ", "k", " ", "l"}], "+", 
      RowBox[{"2", " ", "m", " ", "n"}], "+", 
      RowBox[{"2", " ", "o", " ", "p"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "g"}], "-", 
      RowBox[{"2", " ", "f", " ", "h"}], "+", 
      RowBox[{"2", " ", "i", " ", "k"}], "-", 
      RowBox[{"2", " ", "j", " ", "l"}], "+", 
      RowBox[{"2", " ", "m", " ", "o"}], "-", 
      RowBox[{"2", " ", "n", " ", "p"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "-", 
      RowBox[{"2", " ", "b", " ", "f"}], "-", 
      RowBox[{"2", " ", "c", " ", "g"}], "+", 
      RowBox[{"2", " ", "d", " ", "h"}], "+", 
      RowBox[{"2", " ", "i", " ", "m"}], "-", 
      RowBox[{"2", " ", "j", " ", "n"}], "-", 
      RowBox[{"2", " ", "k", " ", "o"}], "+", 
      RowBox[{"2", " ", "l", " ", "p"}]}], ",", "0", ",", "0", ",", "0", ",", 
     
     RowBox[{
      RowBox[{"2", " ", "a", " ", "i"}], "-", 
      RowBox[{"2", " ", "b", " ", "j"}], "-", 
      RowBox[{"2", " ", "c", " ", "k"}], "+", 
      RowBox[{"2", " ", "d", " ", "l"}], "-", 
      RowBox[{"2", " ", "e", " ", "m"}], "+", 
      RowBox[{"2", " ", "f", " ", "n"}], "+", 
      RowBox[{"2", " ", "g", " ", "o"}], "-", 
      RowBox[{"2", " ", "h", " ", "p"}]}], ",", "0", ",", "0", ",", "0", ",", 
     "0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "h", " ", "i"}], "-", 
      RowBox[{"2", " ", "g", " ", "j"}], "+", 
      RowBox[{"2", " ", "f", " ", "k"}], "-", 
      RowBox[{"2", " ", "e", " ", "l"}], "-", 
      RowBox[{"2", " ", "d", " ", "m"}], "+", 
      RowBox[{"2", " ", "c", " ", "n"}], "-", 
      RowBox[{"2", " ", "b", " ", "o"}], "+", 
      RowBox[{"2", " ", "a", " ", "p"}]}]}], "}"}], 
   ",", "\<\"\\nFactors after a substitution\"\>", ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"18354868", "+", 
      RowBox[{"306416", " ", "a"}], "+", 
      RowBox[{"14592", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "4"], 
   ",", "\<\"\\nThe shape is the first factor squared, minus the other \
factors squared, giving, after the same substitution \"\>", ",", 
   RowBox[{"18354868", "+", 
    RowBox[{"306416", " ", "a"}], "+", 
    RowBox[{"14592", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["a", "4"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["The relation between plex-conjugate products is often less \
obvious",
  FontSize->12,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 ":"
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["Example F5.  Plex-conjugate and related sizes.  O4.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell["\<\
\tHere each of the four sizes can be expressed as the sum of two squares, \
which are equal to the scalar term res[[1]], combined with signed sums of the \
remaining terms.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "\"\<{a,b,c,d,e,f,g,h}\[Times]{a,b,c,d,-e,-f,-g,-h}, using O4 is\>\"", ",",
     
    RowBox[{"res", "=", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
         "h"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", 
         RowBox[{"-", "e"}], ",", 
         RowBox[{"-", "f"}], ",", 
         RowBox[{"-", "g"}], ",", 
         RowBox[{"-", "h"}]}], "}"}], ",", 
       RowBox[{"tst", "=", "\"\<O4\>\""}]}], "]"}]}], ",", 
    "\[IndentingNewLine]", "\"\<\\nFactors\>\"", ",", 
    RowBox[{"fp", "[", 
     RowBox[{"mp", "[", "tst", "]"}], "]"}], ",", "\[IndentingNewLine]", 
    "\"\<\\nShape\>\"", ",", 
    RowBox[{"sh", "[", "tst", "]"}]}], "}"}], TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"{a,b,c,d,e,f,g,h}\[Times]{a,b,c,d,-e,-f,-g,-h}, using O4\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      RowBox[{"2", " ", "c", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "f"}], "+", 
      RowBox[{"2", " ", "g", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      RowBox[{"2", " ", "b", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "g"}], "+", 
      RowBox[{"2", " ", "f", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "d"}], "+", 
      RowBox[{"2", " ", "f", " ", "g"}], "+", 
      RowBox[{"2", " ", "e", " ", "h"}]}], ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", "\<\"\\nFactors\"\>", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"5209", "-", 
      RowBox[{"10", " ", "a"}], "+", 
      SuperscriptBox["a", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1609", "-", 
      RowBox[{"6", " ", "a"}], "+", 
      SuperscriptBox["a", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"577", "+", 
      RowBox[{"2", " ", "a"}], "+", 
      SuperscriptBox["a", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"14449", "+", 
      RowBox[{"14", " ", "a"}], "+", 
      SuperscriptBox["a", "2"]}], ")"}]}], ",", "\<\"\\nShape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "f", "-", "g", "+", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "+", "f", "-", "g", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"]}]}], "}"}]}],
   "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c", "+", "d"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"e", "-", "f", "-", "g", "+", "h"}], ")"}], "2"], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "+", 
     RowBox[{"res", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "+", 
     RowBox[{"res", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "4", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"e", "-", "f", "+", "g", "-", "h"}], ")"}], "2"], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "+", 
     RowBox[{"res", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "+", 
     RowBox[{"res", "[", 
      RowBox[{"[", "4", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c", "-", "d"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"e", "+", "f", "-", "g", "-", "h"}], ")"}], "2"], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "+", 
     RowBox[{"res", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "+", 
     RowBox[{"res", "[", 
      RowBox[{"[", "4", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"e", "+", "f", "+", "g", "+", "h"}], ")"}], "2"], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "-", 
     RowBox[{"res", "[", 
      RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["Example F6.  Plex-conjugate and related sizes.  CL03. ", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell["\<\
\tHere there are two sizes and two non-zero terms (the scalar and trivector \
parts). The sizes are their sum and difference. The same is true for CL21.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "\"\<{a,b,c,d,e,f,g,h}\[Times]{a,-b,-c,-d,-e,-f,-g,h}, using CL03 is\>\"", 
    ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "g"}], ",", "h"}], "}"}], ",", 
      RowBox[{"tst", "=", "\"\<CL03\>\""}]}], "]"}], ",", 
    "\[IndentingNewLine]", "\"\<\\nShape\>\"", ",", 
    RowBox[{"sh", "[", "tst", "]"}]}], "}"}], TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"{a,b,c,d,e,f,g,h}\[Times]{a,-b,-c,-d,-e,-f,-g,h}, using CL03 \
is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",",
      "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "d", " ", "e"}], "+", 
      RowBox[{"2", " ", "c", " ", "f"}], "-", 
      RowBox[{"2", " ", "b", " ", "g"}], "+", 
      RowBox[{"2", " ", "a", " ", "h"}]}]}], "}"}], ",", "\<\"\\nShape\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "+", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "h"}], ")"}], "2"]}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["Example F7.  Plex-conjugate and related sizes.  CL21.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "\"\<{a,b,c,d,e,f,g,h},{a,-b,-c,-d,-e,-f,-g,h}, using CL21 is\>\"", ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}], ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "g"}], ",", "h"}], "}"}], ",", 
      RowBox[{"tst", "=", "\"\<CL21\>\""}]}], "]"}], ",", 
    "\[IndentingNewLine]", "\"\<\\nShape\>\"", ",", 
    RowBox[{"sh", "[", "tst", "]"}]}], "}"}], TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"{a,b,c,d,e,f,g,h},{a,-b,-c,-d,-e,-f,-g,h}, using CL21 is\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["d", "2"], "-", 
      SuperscriptBox["e", "2"], "-", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",",
      "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "d", " ", "e"}], "+", 
      RowBox[{"2", " ", "c", " ", "f"}], "-", 
      RowBox[{"2", " ", "b", " ", "g"}], "+", 
      RowBox[{"2", " ", "a", " ", "h"}]}]}], "}"}], ",", "\<\"\\nShape\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "-", "e"}], ")"}], "2"]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "+", "e"}], ")"}], "2"]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "h"}], ")"}], "2"]}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "Some ternary algebras have plex-conjugates with reversed pairs of \
elements",
 ", \[DoubleStruckCapitalJ]\[LeftRightArrow]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], TraditionalForm]]],
 ", and the product has repeated, instead of zero, elements."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example F8.  Ternary Plex-conjugate and related sizes.  C3.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\"\<{a,b,c},{a,c,b}, using C3 is\>\"", ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "c", ",", "b"}], "}"}], ",", 
      RowBox[{"tst", "=", "\"\<C3\>\""}]}], "]"}], ",", 
    "\[IndentingNewLine]", "\"\<\\nShape\>\"", ",", 
    RowBox[{"Expand", "[", 
     RowBox[{"sh", "[", "tst", "]"}], "]"}]}], "}"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"{a,b,c},{a,c,b}, using C3 is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"a", " ", "b"}], "+", 
      RowBox[{"a", " ", "c"}], "+", 
      RowBox[{"b", " ", "c"}]}], ",", 
     RowBox[{
      RowBox[{"a", " ", "b"}], "+", 
      RowBox[{"a", " ", "c"}], "+", 
      RowBox[{"b", " ", "c"}]}]}], "}"}], ",", "\<\"\\nShape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c"}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"a", " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"a", " ", "c"}], "-", 
      RowBox[{"b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Example F9.  Conjugate Plex-conjugate and related sizes. g2401c.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"tst", "=", 
     RowBox[{"mp", "[", 
      RowBox[{"6", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"tst", "//", "tf"}], ",", "\"\<Shape \>\"", ",", 
   RowBox[{"sh", "[", "gmn", "]"}], ",", "\"\<\\nPlex \>\"", ",", "plex"}], 
  "}"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"D3C2c\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6"},
        {"2", "1", "4", "3", 
         RowBox[{"-", "6"}], 
         RowBox[{"-", "5"}]},
        {"3", "5", "1", "6", "2", "4"},
        {"4", 
         RowBox[{"-", "6"}], "2", 
         RowBox[{"-", "5"}], "1", "3"},
        {"5", "3", "6", "1", 
         RowBox[{"-", "4"}], 
         RowBox[{"-", "2"}]},
        {"6", 
         RowBox[{"-", "4"}], "5", 
         RowBox[{"-", "2"}], "3", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"Shape \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], ",", 
     RowBox[{"a", "+", "b", "-", "c", "-", "d", "-", "e", "+", "f"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "-", "e"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "e"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "f"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "+", "f"}], ")"}], "2"]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nPlex \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "c", ",", "b", ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}], ",", 
     RowBox[{"-", "f"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ff", "=", 
  RowBox[{"fa", "[", "tst", "]"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"\[ImaginaryI]", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     RowBox[{"a", " ", "b"}], "+", 
     SuperscriptBox["b", "2"], "-", 
     RowBox[{"a", " ", "c"}], "-", 
     RowBox[{"b", " ", "c"}], "+", 
     SuperscriptBox["c", "2"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["d", "2"]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "d", " ", "e"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["e", "2"]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "d", " ", "f"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "e", " ", "f"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["f", "2"]}]}], ")"}], "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    RowBox[{"2", " ", "a", " ", "b"}], "+", 
    SuperscriptBox["b", "2"], "+", 
    RowBox[{"2", " ", "a", " ", "c"}], "+", 
    RowBox[{"2", " ", "b", " ", "c"}], "+", 
    SuperscriptBox["c", "2"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["d", "2"]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "d", " ", "e"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["e", "2"]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "d", " ", "f"}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "e", " ", "f"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["f", "2"]}]}], ")"}]}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res", "=", 
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
    ",", "plex", ",", "gmn"}], "]"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["d", "2"]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["e", "2"]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["f", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "b"}], "+", 
    RowBox[{"a", " ", "c"}], "+", 
    RowBox[{"b", " ", "c"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "d", " ", "e"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "d", " ", "f"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "e", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "b"}], "+", 
    RowBox[{"a", " ", "c"}], "+", 
    RowBox[{"b", " ", "c"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "d", " ", "e"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "d", " ", "f"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "e", " ", "f"}]}], ",", "0", ",", "0", ",", 
   "0"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
The conjugate of the repeated factor is the difference between the first two \
elements of the product:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   SuperscriptBox["a", "2"], "-", 
   RowBox[{"a", " ", "b"}], "+", 
   SuperscriptBox["b", "2"], "-", 
   RowBox[{"a", " ", "c"}], "-", 
   RowBox[{"b", " ", "c"}], "+", 
   SuperscriptBox["c", "2"], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["d", "2"]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", "d", " ", "e"}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["e", "2"]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", "d", " ", "f"}], "+", 
   RowBox[{"\[ImaginaryI]", " ", "e", " ", "f"}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["f", "2"]}], "-", 
   RowBox[{"res", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "+", 
   RowBox[{"res", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["0"], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
The conjugate of the other factor is the sum of the elements of the product:-\
\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   SuperscriptBox["a", "2"], "+", 
   RowBox[{"2", " ", "a", " ", "b"}], "+", 
   SuperscriptBox["b", "2"], "+", 
   RowBox[{"2", " ", "a", " ", "c"}], "+", 
   RowBox[{"2", " ", "b", " ", "c"}], "+", 
   SuperscriptBox["c", "2"], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["d", "2"]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "d", " ", "e"}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["e", "2"]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "d", " ", "f"}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "e", " ", "f"}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["f", "2"]}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"res", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "+", 
     RowBox[{"res", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "+", 
     RowBox[{"res", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["0"], "Output",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.3. Polymorphs.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tSome quartic shapes are polymorphic, with different plex-conjugates \
leading to different fragmented formulations of the shape. These correspond \
to the different involutions. ",
 "Lounesto",
 " p86 mentions grade involution, reversion, and Clifford conjugation.\n\t\
Example F1 showed that CL3 has a shape consisting of the sum of two squares. \
Example F9 shows three polymorphs, each being the signed sum of 4 squares. In \
these case, four zeroes occur in the sizes of a plex-conjugate. The \
appropriately signed sums of squares of the sizes is then shown to match the \
determinant of the CL3 table, as found by ",
 StyleBox["fp",
  FontSlant->"Italic"],
 ".  (CL4 and CL04 dimorphs have also been found.)"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example F9.  Plex-conjugate Polymorphs. CL3.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\"\<Conjugate {a,b,c,-d,e,-f,-g,-h}\>\"", ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c", ",", 
        RowBox[{"-", "d"}], ",", "e", ",", 
        RowBox[{"-", "f"}], ",", 
        RowBox[{"-", "g"}], ",", 
        RowBox[{"-", "h"}]}], "}"}], ",", 
      RowBox[{"tst", "=", "\"\<CL3\>\""}]}], "]"}], ",", 
    "\"\<\\n Det    \>\"", ",", 
    RowBox[{"fp", "[", 
     RowBox[{"mp", "[", "tst", "]"}], "]"}], ",", 
    "\"\<1st Shape is (\!\(\*SuperscriptBox[\(a\), \
\(2\)]\)+\!\(\*SuperscriptBox[\(b\), \(2\)]\)+\!\(\*SuperscriptBox[\(c\), \(2\
\)]\)+\!\(\*SuperscriptBox[\(d\), \(2\)]\)+\!\(\*SuperscriptBox[\(e\), \(2\)]\
\)+\!\(\*SuperscriptBox[\(f\), \(2\)]\)+\!\(\*SuperscriptBox[\(g\), \(2\)]\)+\
\!\(\*SuperscriptBox[\(h\), \(2\)]\))^2-(2 a b+2 c d+2 e f+2 g h)^2-(2 a c-2 \
b d+2 e g-2 f h)^2-(2 a e-2 b f-2 c g+2 d h)^2\>\"", ",", 
    "\[IndentingNewLine]", "\"\<\\nFactor OK\>\"", ",", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["d", "2"], "+", 
          SuperscriptBox["e", "2"], "+", 
          SuperscriptBox["f", "2"], "+", 
          SuperscriptBox["g", "2"], "+", 
          SuperscriptBox["h", "2"]}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "b"}], "+", 
          RowBox[{"2", " ", "c", " ", "d"}], "+", 
          RowBox[{"2", " ", "e", " ", "f"}], "+", 
          RowBox[{"2", " ", "g", " ", "h"}]}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "c"}], "-", 
          RowBox[{"2", " ", "b", " ", "d"}], "+", 
          RowBox[{"2", " ", "e", " ", "g"}], "-", 
          RowBox[{"2", " ", "f", " ", "h"}]}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "e"}], "-", 
          RowBox[{"2", " ", "b", " ", "f"}], "-", 
          RowBox[{"2", " ", "c", " ", "g"}], "+", 
          RowBox[{"2", " ", "d", " ", "h"}]}], ")"}], "^", "2"}]}], "]"}], "/.",
      
     RowBox[{"fromAlph", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"pow2", ",", "8"}], "]"}], "]"}]}], ",", 
    "\[IndentingNewLine]", "\"\<\\n\\nConjugate {a,-b,-c,-d,e,f,g,-h}\>\"", 
    ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}], ",", "e", ",", "f", ",", "g", ",", 
        RowBox[{"-", "h"}]}], "}"}]}], "]"}], ",", 
    "\"\<2nd Shape is (\!\(\*SuperscriptBox[\(a\), \
\(2\)]\)-\!\(\*SuperscriptBox[\(b\), \(2\)]\)-\!\(\*SuperscriptBox[\(c\), \(2\
\)]\)+\!\(\*SuperscriptBox[\(d\), \(2\)]\)+\!\(\*SuperscriptBox[\(e\), \(2\)]\
\)-\!\(\*SuperscriptBox[\(f\), \(2\)]\)-\!\(\*SuperscriptBox[\(g\), \(2\)]\)+\
\!\(\*SuperscriptBox[\(h\), \(2\)]\))^2-(2 a e+2 b f+2 c g+2 d h)^2+(2 b e+2 \
a f+2 d g+2 c h)^2+(2 c e-2 d f+2 a g-2 b h)^2\>\"", ",", 
    "\[IndentingNewLine]", "\"\<\\nFactor OK\>\"", ",", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["d", "2"], "+", 
          SuperscriptBox["e", "2"], "-", 
          SuperscriptBox["f", "2"], "-", 
          SuperscriptBox["g", "2"], "+", 
          SuperscriptBox["h", "2"]}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "e"}], "+", 
          RowBox[{"2", " ", "b", " ", "f"}], "+", 
          RowBox[{"2", " ", "c", " ", "g"}], "+", 
          RowBox[{"2", " ", "d", " ", "h"}]}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "b", " ", "e"}], "+", 
          RowBox[{"2", " ", "a", " ", "f"}], "+", 
          RowBox[{"2", " ", "d", " ", "g"}], "+", 
          RowBox[{"2", " ", "c", " ", "h"}]}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "c", " ", "e"}], "-", 
          RowBox[{"2", " ", "d", " ", "f"}], "+", 
          RowBox[{"2", " ", "a", " ", "g"}], "-", 
          RowBox[{"2", " ", "b", " ", "h"}]}], ")"}], "^", "2"}]}], "]"}], "/.",
      
     RowBox[{"fromAlph", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"pow2", ",", "8"}], "]"}], "]"}]}], ",", 
    "\"\<\\n\\nConjugate {a,-b,-c,-d,e,f,g,-h}\>\"", ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}], ",", "e", ",", "f", ",", "g", ",", 
        RowBox[{"-", "h"}]}], "}"}]}], "]"}], ",", 
    "\"\<3rd Shape is(\!\(\*SuperscriptBox[\(a\), \
\(2\)]\)-\!\(\*SuperscriptBox[\(b\), \(2\)]\)-\!\(\*SuperscriptBox[\(c\), \(2\
\)]\)+\!\(\*SuperscriptBox[\(d\), \(2\)]\)+\!\(\*SuperscriptBox[\(e\), \(2\)]\
\)-\!\(\*SuperscriptBox[\(f\), \(2\)]\)-\!\(\*SuperscriptBox[\(g\), \(2\)]\)+\
\!\(\*SuperscriptBox[\(h\), \(2\)]\))^2-(2 a e+2 b f+2 c g+2 d h)^2+(2 b e+2 \
a f+2 d g+2 c h)^2+(2 c e-2 d f+2 a g-2 b h)^2\>\"", ",", 
    "\[IndentingNewLine]", "\"\<\\nFactor OK\>\"", ",", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["d", "2"], "+", 
          SuperscriptBox["e", "2"], "-", 
          SuperscriptBox["f", "2"], "-", 
          SuperscriptBox["g", "2"], "+", 
          SuperscriptBox["h", "2"]}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "e"}], "+", 
          RowBox[{"2", " ", "b", " ", "f"}], "+", 
          RowBox[{"2", " ", "c", " ", "g"}], "+", 
          RowBox[{"2", " ", "d", " ", "h"}]}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "b", " ", "e"}], "+", 
          RowBox[{"2", " ", "a", " ", "f"}], "+", 
          RowBox[{"2", " ", "d", " ", "g"}], "+", 
          RowBox[{"2", " ", "c", " ", "h"}]}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "c", " ", "e"}], "-", 
          RowBox[{"2", " ", "d", " ", "f"}], "+", 
          RowBox[{"2", " ", "a", " ", "g"}], "-", 
          RowBox[{"2", " ", "b", " ", "h"}]}], ")"}], "^", "2"}]}], "]"}], "/.",
      
     RowBox[{"fromAlph", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"pow2", ",", "8"}], "]"}], "]"}]}], ",", 
    "\"\<\\n\\nConjugate {a,-b,c,d,-e,-f,g,-h}\>\"", ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}], ",", "c", ",", "d", ",", 
        RowBox[{"-", "e"}], ",", 
        RowBox[{"-", "f"}], ",", "g", ",", 
        RowBox[{"-", "h"}]}], "}"}]}], "]"}], ",", 
    "\"\<4th Shape is (\!\(\*SuperscriptBox[\(a\), \
\(2\)]\)-\!\(\*SuperscriptBox[\(b\), \(2\)]\)+\!\(\*SuperscriptBox[\(c\), \(2\
\)]\)-\!\(\*SuperscriptBox[\(d\), \(2\)]\)-\!\(\*SuperscriptBox[\(e\), \(2\)]\
\)+\!\(\*SuperscriptBox[\(f\), \(2\)]\)-\!\(\*SuperscriptBox[\(g\), \(2\)]\)+\
\!\(\*SuperscriptBox[\(h\), \(2\)]\))^2-(2 a c+2 b d-2 e g-2 f h)^2+(2 b c+2 \
a d-2 f g-2 e h)^2+(2 c e-2 d f-2 a g+2 b h)^2\>\"", ",", 
    "\[IndentingNewLine]", "\"\<\\nFactor OK\>\"", ",", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"], "-", 
          SuperscriptBox["d", "2"], "-", 
          SuperscriptBox["e", "2"], "+", 
          SuperscriptBox["f", "2"], "-", 
          SuperscriptBox["g", "2"], "+", 
          SuperscriptBox["h", "2"]}], ")"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "c"}], "+", 
          RowBox[{"2", " ", "b", " ", "d"}], "-", 
          RowBox[{"2", " ", "e", " ", "g"}], "-", 
          RowBox[{"2", " ", "f", " ", "h"}]}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "b", " ", "c"}], "+", 
          RowBox[{"2", " ", "a", " ", "d"}], "-", 
          RowBox[{"2", " ", "f", " ", "g"}], "-", 
          RowBox[{"2", " ", "e", " ", "h"}]}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "c", " ", "e"}], "-", 
          RowBox[{"2", " ", "d", " ", "f"}], "-", 
          RowBox[{"2", " ", "a", " ", "g"}], "+", 
          RowBox[{"2", " ", "b", " ", "h"}]}], ")"}], "^", "2"}]}], "]"}], "/.",
      
     RowBox[{"fromAlph", "[", 
      RowBox[{"Take", "[", 
       RowBox[{"pow2", ",", "8"}], "]"}], "]"}]}]}], "}"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Conjugate {a,b,c,-d,e,-f,-g,-h}\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      RowBox[{"2", " ", "c", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "f"}], "+", 
      RowBox[{"2", " ", "g", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "g"}], "-", 
      RowBox[{"2", " ", "f", " ", "h"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "-", 
      RowBox[{"2", " ", "b", " ", "f"}], "-", 
      RowBox[{"2", " ", "c", " ", "g"}], "+", 
      RowBox[{"2", " ", "d", " ", "h"}]}], ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", "\<\"\\n Det    \"\>", ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"8235257", "-", 
      RowBox[{"16384", " ", "a"}], "+", 
      RowBox[{"10646", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "2"], 
   ",", "\<\"1st Shape is \
(\\!\\(a\\^2\\)+\\!\\(b\\^2\\)+\\!\\(c\\^2\\)+\\!\\(d\\^2\\)+\\!\\(e\\^2\\)+\\\
!\\(f\\^2\\)+\\!\\(g\\^2\\)+\\!\\(h\\^2\\))^2-(2 a b+2 c d+2 e f+2 g h)^2-(2 \
a c-2 b d+2 e g-2 f h)^2-(2 a e-2 b f-2 c g+2 d h)^2\"\>", 
   ",", "\<\"\\nFactor OK\"\>", ",", 
   RowBox[{"8235257", "-", 
    RowBox[{"16384", " ", "a"}], "+", 
    RowBox[{"10646", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["a", "4"]}], 
   ",", "\<\"\\n\\nConjugate {a,-b,-c,-d,e,f,g,-h}\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "-", 
      SuperscriptBox["f", "2"], "-", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "+", 
      RowBox[{"2", " ", "b", " ", "f"}], "+", 
      RowBox[{"2", " ", "c", " ", "g"}], "+", 
      RowBox[{"2", " ", "d", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "b", " ", "e"}], "+", 
      RowBox[{"2", " ", "a", " ", "f"}], "+", 
      RowBox[{"2", " ", "d", " ", "g"}], "+", 
      RowBox[{"2", " ", "c", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "c", " ", "e"}], "-", 
      RowBox[{"2", " ", "d", " ", "f"}], "+", 
      RowBox[{"2", " ", "a", " ", "g"}], "-", 
      RowBox[{"2", " ", "b", " ", "h"}]}], ",", "0"}], "}"}], 
   ",", "\<\"2nd Shape is \
(\\!\\(a\\^2\\)-\\!\\(b\\^2\\)-\\!\\(c\\^2\\)+\\!\\(d\\^2\\)+\\!\\(e\\^2\\)-\\\
!\\(f\\^2\\)-\\!\\(g\\^2\\)+\\!\\(h\\^2\\))^2-(2 a e+2 b f+2 c g+2 d h)^2+(2 \
b e+2 a f+2 d g+2 c h)^2+(2 c e-2 d f+2 a g-2 b h)^2\"\>", 
   ",", "\<\"\\nFactor OK\"\>", ",", 
   RowBox[{"8235257", "-", 
    RowBox[{"16384", " ", "a"}], "+", 
    RowBox[{"10646", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["a", "4"]}], 
   ",", "\<\"\\n\\nConjugate {a,-b,-c,-d,e,f,g,-h}\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "-", 
      SuperscriptBox["f", "2"], "-", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "+", 
      RowBox[{"2", " ", "b", " ", "f"}], "+", 
      RowBox[{"2", " ", "c", " ", "g"}], "+", 
      RowBox[{"2", " ", "d", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "b", " ", "e"}], "+", 
      RowBox[{"2", " ", "a", " ", "f"}], "+", 
      RowBox[{"2", " ", "d", " ", "g"}], "+", 
      RowBox[{"2", " ", "c", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "c", " ", "e"}], "-", 
      RowBox[{"2", " ", "d", " ", "f"}], "+", 
      RowBox[{"2", " ", "a", " ", "g"}], "-", 
      RowBox[{"2", " ", "b", " ", "h"}]}], ",", "0"}], "}"}], 
   ",", "\<\"3rd Shape \
is(\\!\\(a\\^2\\)-\\!\\(b\\^2\\)-\\!\\(c\\^2\\)+\\!\\(d\\^2\\)+\\!\\(e\\^2\\)-\
\\!\\(f\\^2\\)-\\!\\(g\\^2\\)+\\!\\(h\\^2\\))^2-(2 a e+2 b f+2 c g+2 d \
h)^2+(2 b e+2 a f+2 d g+2 c h)^2+(2 c e-2 d f+2 a g-2 b h)^2\"\>", 
   ",", "\<\"\\nFactor OK\"\>", ",", 
   RowBox[{"8235257", "-", 
    RowBox[{"16384", " ", "a"}], "+", 
    RowBox[{"10646", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["a", "4"]}], 
   ",", "\<\"\\n\\nConjugate {a,-b,c,d,-e,-f,g,-h}\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["d", "2"], "-", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "-", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      RowBox[{"2", " ", "b", " ", "d"}], "-", 
      RowBox[{"2", " ", "e", " ", "g"}], "-", 
      RowBox[{"2", " ", "f", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "d"}], "-", 
      RowBox[{"2", " ", "f", " ", "g"}], "-", 
      RowBox[{"2", " ", "e", " ", "h"}]}], ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c", " ", "e"}], "+", 
      RowBox[{"2", " ", "d", " ", "f"}], "+", 
      RowBox[{"2", " ", "a", " ", "g"}], "-", 
      RowBox[{"2", " ", "b", " ", "h"}]}], ",", "0"}], "}"}], 
   ",", "\<\"4th Shape is \
(\\!\\(a\\^2\\)-\\!\\(b\\^2\\)+\\!\\(c\\^2\\)-\\!\\(d\\^2\\)-\\!\\(e\\^2\\)+\\\
!\\(f\\^2\\)-\\!\\(g\\^2\\)+\\!\\(h\\^2\\))^2-(2 a c+2 b d-2 e g-2 f h)^2+(2 \
b c+2 a d-2 f g-2 e h)^2+(2 c e-2 d f-2 a g+2 b h)^2\"\>", 
   ",", "\<\"\\nFactor OK\"\>", ",", 
   RowBox[{"8235257", "-", 
    RowBox[{"16384", " ", "a"}], "+", 
    RowBox[{"10646", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["a", "4"]}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Conjugate {a,b,c,-d,e,-f,-g,-h}\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "+", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      RowBox[{"2", " ", "c", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "f"}], "+", 
      RowBox[{"2", " ", "g", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "d"}], "+", 
      RowBox[{"2", " ", "e", " ", "g"}], "-", 
      RowBox[{"2", " ", "f", " ", "h"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "-", 
      RowBox[{"2", " ", "b", " ", "f"}], "-", 
      RowBox[{"2", " ", "c", " ", "g"}], "+", 
      RowBox[{"2", " ", "d", " ", "h"}]}], ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", "\<\"\\n Det    \"\>", ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"8235257", "-", 
      RowBox[{"16384", " ", "a"}], "+", 
      RowBox[{"10646", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["a", "4"]}], ")"}], "2"], 
   ",", "\<\"1st Shape is \
(\\!\\(a\\^2\\)+\\!\\(b\\^2\\)+\\!\\(c\\^2\\)+\\!\\(d\\^2\\)+\\!\\(e\\^2\\)+\\\
!\\(f\\^2\\)+\\!\\(g\\^2\\)+\\!\\(h\\^2\\))^2-(2 a b+2 c d+2 e f+2 g h)^2-(2 \
a c-2 b d+2 e g-2 f h)^2-(2 a e-2 b f-2 c g+2 d h)^2\"\>", 
   ",", "\<\"\\nFactor OK\"\>", ",", 
   RowBox[{"8235257", "-", 
    RowBox[{"16384", " ", "a"}], "+", 
    RowBox[{"10646", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["a", "4"]}], 
   ",", "\<\"\\n\\nConjugate {a,-b,-c,-d,e,f,g,-h}\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "+", 
      SuperscriptBox["d", "2"], "+", 
      SuperscriptBox["e", "2"], "-", 
      SuperscriptBox["f", "2"], "-", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "e"}], "+", 
      RowBox[{"2", " ", "b", " ", "f"}], "+", 
      RowBox[{"2", " ", "c", " ", "g"}], "+", 
      RowBox[{"2", " ", "d", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "b", " ", "e"}], "+", 
      RowBox[{"2", " ", "a", " ", "f"}], "+", 
      RowBox[{"2", " ", "d", " ", "g"}], "+", 
      RowBox[{"2", " ", "c", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "c", " ", "e"}], "-", 
      RowBox[{"2", " ", "d", " ", "f"}], "+", 
      RowBox[{"2", " ", "a", " ", "g"}], "-", 
      RowBox[{"2", " ", "b", " ", "h"}]}], ",", "0"}], "}"}], 
   ",", "\<\"2nd Shape is \
(\\!\\(a\\^2\\)-\\!\\(b\\^2\\)-\\!\\(c\\^2\\)+\\!\\(d\\^2\\)+\\!\\(e\\^2\\)-\\\
!\\(f\\^2\\)-\\!\\(g\\^2\\)+\\!\\(h\\^2\\))^2-(2 a e+2 b f+2 c g+2 d h)^2+(2 \
b e+2 a f+2 d g+2 c h)^2+(2 c e-2 d f+2 a g-2 b h)^2\"\>", 
   ",", "\<\"\\nFactor OK\"\>", ",", 
   RowBox[{"8235257", "-", 
    RowBox[{"16384", " ", "a"}], "+", 
    RowBox[{"10646", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["a", "4"]}], 
   ",", "\<\"\\n\\nConjugate {a,-b,c,d,-e,-f,g,-h}\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "-", 
      SuperscriptBox["d", "2"], "-", 
      SuperscriptBox["e", "2"], "+", 
      SuperscriptBox["f", "2"], "-", 
      SuperscriptBox["g", "2"], "+", 
      SuperscriptBox["h", "2"]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      RowBox[{"2", " ", "b", " ", "d"}], "-", 
      RowBox[{"2", " ", "e", " ", "g"}], "-", 
      RowBox[{"2", " ", "f", " ", "h"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "d"}], "-", 
      RowBox[{"2", " ", "f", " ", "g"}], "-", 
      RowBox[{"2", " ", "e", " ", "h"}]}], ",", "0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c", " ", "e"}], "+", 
      RowBox[{"2", " ", "d", " ", "f"}], "+", 
      RowBox[{"2", " ", "a", " ", "g"}], "-", 
      RowBox[{"2", " ", "b", " ", "h"}]}], ",", "0"}], "}"}], 
   ",", "\<\"4th Shape is \
(\\!\\(a\\^2\\)-\\!\\(b\\^2\\)+\\!\\(c\\^2\\)-\\!\\(d\\^2\\)-\\!\\(e\\^2\\)+\\\
!\\(f\\^2\\)-\\!\\(g\\^2\\)+\\!\\(h\\^2\\))^2-(2 a c+2 b d-2 e g-2 f h)^2+(2 \
b c+2 a d-2 f g-2 e h)^2+(2 c e-2 d f-2 a g+2 b h)^2\"\>", 
   ",", "\<\"\\nFactor OK\"\>", ",", 
   RowBox[{"8235257", "-", 
    RowBox[{"16384", " ", "a"}], "+", 
    RowBox[{"10646", " ", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["a", "4"]}]}], "}"}]], "Output",
 PageWidth->WindowWidth,
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.4. Database Plexes, chirality.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tA number of plex vecs (involutions) have been included in the shapes in \
the database. Some only give one of several sizes as functions of plex \
products, others give a different formulation of the shape, which is included \
as a comment in the ",
 StyleBox["sh",
  FontSlant->"Italic"],
 " definition. More work is needed. The following plex conjugate was \
discovered on 8/12/3, and reverses ",
 StyleBox["bc",
  FontSlant->"Italic"],
 " to ",
 StyleBox["cb",
  FontSlant->"Italic"],
 ", ",
 StyleBox["ef",
  FontSlant->"Italic"],
 " to ",
 StyleBox["fe",
  FontSlant->"Italic"],
 "; it gives the two quadratic shapes for C3C2. Other ternary conjugates were \
then found; pairs of elements are interchanged instead of being negated."
}], "Text",
 PageWidth->WindowWidth],

Cell["Example F10.  Chiral Plex-conjugate. C3C2.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"pr", "=", 
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "b", ",", "d", ",", "f", ",", "e"}], "}"}], 
    ",", "\"\<C3C2\>\""}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shh", "=", 
   RowBox[{"sh", "[", "\"\<C3C2\>\"", "]"}]}], ";", 
  RowBox[{"Expand", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"pr", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "-", 
      RowBox[{"pr", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "+", 
      RowBox[{"pr", "[", 
       RowBox[{"[", "4", "]"}], "]"}], "-", 
      RowBox[{"pr", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "-", 
      RowBox[{"shh", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"pr", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "-", 
      RowBox[{"pr", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "-", 
      RowBox[{"pr", "[", 
       RowBox[{"[", "4", "]"}], "]"}], "+", 
      RowBox[{"pr", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "-", 
      RowBox[{"shh", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], "]"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "+", 
    SuperscriptBox["d", "2"], "+", 
    SuperscriptBox["e", "2"], "+", 
    SuperscriptBox["f", "2"]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "b"}], "+", 
    RowBox[{"a", " ", "c"}], "+", 
    RowBox[{"b", " ", "c"}], "+", 
    RowBox[{"d", " ", "e"}], "+", 
    RowBox[{"d", " ", "f"}], "+", 
    RowBox[{"e", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "b"}], "+", 
    RowBox[{"a", " ", "c"}], "+", 
    RowBox[{"b", " ", "c"}], "+", 
    RowBox[{"d", " ", "e"}], "+", 
    RowBox[{"d", " ", "f"}], "+", 
    RowBox[{"e", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", "a", " ", "d"}], "+", 
    RowBox[{"2", " ", "b", " ", "e"}], "+", 
    RowBox[{"2", " ", "c", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"b", " ", "d"}], "+", 
    RowBox[{"c", " ", "d"}], "+", 
    RowBox[{"a", " ", "e"}], "+", 
    RowBox[{"c", " ", "e"}], "+", 
    RowBox[{"a", " ", "f"}], "+", 
    RowBox[{"b", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"b", " ", "d"}], "+", 
    RowBox[{"c", " ", "d"}], "+", 
    RowBox[{"a", " ", "e"}], "+", 
    RowBox[{"c", " ", "e"}], "+", 
    RowBox[{"a", " ", "f"}], "+", 
    RowBox[{"b", " ", "f"}]}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["D3 still not sorted:-", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"pr", "=", 
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "f"}], ",", "e", ",", 
      RowBox[{"-", "d"}], ",", "c", ",", 
      RowBox[{"-", "b"}]}], " ", "}"}], ",", "\"\<D3\>\""}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"shh", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"sh", "[", "\"\<D3\>\"", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"pr", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "4", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "5", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "6", "]"}], "]"}], "-", 
    RowBox[{"shh", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox["d", "2"], "+", 
    SuperscriptBox["e", "2"], "-", 
    RowBox[{"2", " ", "b", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "b"}], "-", 
    RowBox[{"b", " ", "c"}], "-", 
    RowBox[{"a", " ", "f"}], "+", 
    RowBox[{"c", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"a", " ", "c"}], "+", 
    RowBox[{"a", " ", "e"}], "+", 
    RowBox[{"c", " ", "e"}], "-", 
    RowBox[{"2", " ", "d", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"b", " ", "c"}], "-", 
    RowBox[{"b", " ", "e"}], "-", 
    RowBox[{"c", " ", "f"}], "+", 
    RowBox[{"e", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "c"}], "-", 
    RowBox[{"2", " ", "b", " ", "d"}], "+", 
    RowBox[{"a", " ", "e"}], "+", 
    RowBox[{"c", " ", "e"}], "-", 
    SuperscriptBox["f", "2"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "b"}], "+", 
    RowBox[{"b", " ", "e"}], "+", 
    RowBox[{"a", " ", "f"}], "-", 
    RowBox[{"e", " ", "f"}]}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"], "-", 
    RowBox[{"a", " ", "c"}], "+", 
    SuperscriptBox["c", "2"], "+", 
    RowBox[{"b", " ", "d"}], "-", 
    SuperscriptBox["d", "2"], "-", 
    RowBox[{"a", " ", "e"}], "-", 
    RowBox[{"c", " ", "e"}], "+", 
    SuperscriptBox["e", "2"], "+", 
    RowBox[{"b", " ", "f"}], "+", 
    RowBox[{"d", " ", "f"}], "-", 
    SuperscriptBox["f", "2"]}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "c"}], "-", 
     RowBox[{"b", " ", "d"}], "+", 
     RowBox[{"a", " ", "e"}], "+", 
     RowBox[{"c", " ", "e"}], "-", 
     RowBox[{"b", " ", "f"}], "-", 
     RowBox[{"d", " ", "f"}]}], ")"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"pr", "=", 
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "b"}], ",", "e", ",", 
      RowBox[{"-", "f"}], ",", "c", ",", 
      RowBox[{"-", "d"}]}], " ", "}"}], ",", "\"\<D3\>\""}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"shh", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"sh", "[", "\"\<D3\>\"", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"pr", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "4", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "5", "]"}], "]"}], "+", 
    RowBox[{"pr", "[", 
     RowBox[{"[", "6", "]"}], "]"}], "-", 
    RowBox[{"shh", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "+", 
    SuperscriptBox["e", "2"], "-", 
    RowBox[{"2", " ", "d", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "c"}], " ", "d"}], "+", 
    RowBox[{"d", " ", "e"}], "+", 
    RowBox[{"c", " ", "f"}], "-", 
    RowBox[{"e", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "c"}], "-", 
    RowBox[{"2", " ", "b", " ", "d"}], "+", 
    RowBox[{"a", " ", "e"}], "+", 
    RowBox[{"c", " ", "e"}], "-", 
    SuperscriptBox["f", "2"]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "d"}], "-", 
    RowBox[{"d", " ", "e"}], "-", 
    RowBox[{"a", " ", "f"}], "+", 
    RowBox[{"e", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "c"}], "-", 
    SuperscriptBox["d", "2"], "+", 
    RowBox[{"a", " ", "e"}], "+", 
    RowBox[{"c", " ", "e"}], "-", 
    RowBox[{"2", " ", "b", " ", "f"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "d"}], "+", 
    RowBox[{"c", " ", "d"}], "+", 
    RowBox[{"a", " ", "f"}], "-", 
    RowBox[{"c", " ", "f"}]}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    SuperscriptBox["b", "2"], "-", 
    RowBox[{"a", " ", "c"}], "+", 
    SuperscriptBox["c", "2"], "+", 
    RowBox[{"b", " ", "d"}], "-", 
    SuperscriptBox["d", "2"], "-", 
    RowBox[{"a", " ", "e"}], "-", 
    RowBox[{"c", " ", "e"}], "+", 
    SuperscriptBox["e", "2"], "+", 
    RowBox[{"b", " ", "f"}], "+", 
    RowBox[{"d", " ", "f"}], "-", 
    SuperscriptBox["f", "2"]}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "c"}], "-", 
     RowBox[{"b", " ", "d"}], "+", 
     RowBox[{"a", " ", "e"}], "+", 
     RowBox[{"c", " ", "e"}], "-", 
     RowBox[{"b", " ", "f"}], "-", 
     RowBox[{"d", " ", "f"}]}], ")"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sh", "[", "\"\<D3\>\"", "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "e"}], ")"}], "2"]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "d"}], ")"}], "2"]}], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "-", "f"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "b"}], "+", "f"}], ")"}], "2"]}], ")"}]}]}]}], 
  "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.3. Quasi-group products conserve the sums of elements.", "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
Quasi-group Cayley Tables have the sum of elements as a determinant factor. \
(Proof. The sum of elements is a factor of the row created by adding all \
other rows to the first row.) This is confirmed for a few non-conservative \
tables:- \
\>", "Text",
 PageWidth->WindowWidth],

Cell["Example F11.  Product factorisation.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "n"}], ",", "o", ",", 
       RowBox[{"p", "-", "q"}]}], "}"}], ",", "\"\<C5n\>\""}], "]"}]}], 
  "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "n"}], ",", "o", ",", "p", ",", "q", ",", 
       RowBox[{"-", "r"}]}], "}"}], ",", "\"\<C6n\>\""}], "]"}]}], 
  "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "n"}], ",", "o", ",", "p", ",", "q", ",", 
       RowBox[{"-", "r"}]}], "}"}], ",", "\"\<C6an\>\""}], "]"}]}], 
  "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
       "h", ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "n"}], ",", "o", ",", "p", ",", "q", ",", 
       RowBox[{"-", "r"}], ",", "s", ",", "t", ",", "u", ",", 
       RowBox[{"-", "v"}], ",", "w", ",", "x"}], "}"}], ",", 
     "\"\<Alt12n\>\""}], "]"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell["This is untrue for all signed tables that have been tested:-", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"e", ",", "f", ",", "g", ",", "h"}], "}"}], ",", "\"\<Qr\>\""}],
     "]"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"e", ",", "f", ",", "g", ",", "h"}], "}"}], ",", 
     "\"\<Q4n\>\""}], "]"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
       "h"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "n"}], ",", "o", ",", "p", ",", "q", ",", 
       RowBox[{"-", "r"}], ",", "s", ",", "t"}], "}"}], ",", "\"\<O4\>\""}], 
    "]"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", "m"}], "+", 
  RowBox[{"b", " ", "m"}], "+", 
  RowBox[{"c", " ", "m"}], "+", 
  RowBox[{"d", " ", "m"}], "+", 
  RowBox[{"e", " ", "m"}], "+", 
  RowBox[{"f", " ", "m"}], "+", 
  RowBox[{"g", " ", "m"}], "+", 
  RowBox[{"h", " ", "m"}], "-", 
  RowBox[{"a", " ", "n"}], "-", 
  RowBox[{"b", " ", "n"}], "-", 
  RowBox[{"c", " ", "n"}], "-", 
  RowBox[{"d", " ", "n"}], "-", 
  RowBox[{"e", " ", "n"}], "-", 
  RowBox[{"f", " ", "n"}], "-", 
  RowBox[{"g", " ", "n"}], "-", 
  RowBox[{"h", " ", "n"}], "+", 
  RowBox[{"a", " ", "o"}], "+", 
  RowBox[{"b", " ", "o"}], "+", 
  RowBox[{"c", " ", "o"}], "+", 
  RowBox[{"d", " ", "o"}], "+", 
  RowBox[{"e", " ", "o"}], "+", 
  RowBox[{"f", " ", "o"}], "+", 
  RowBox[{"g", " ", "o"}], "+", 
  RowBox[{"h", " ", "o"}], "+", 
  RowBox[{"a", " ", "p"}], "+", 
  RowBox[{"b", " ", "p"}], "+", 
  RowBox[{"c", " ", "p"}], "+", 
  RowBox[{"d", " ", "p"}], "+", 
  RowBox[{"e", " ", "p"}], "+", 
  RowBox[{"f", " ", "p"}], "+", 
  RowBox[{"g", " ", "p"}], "+", 
  RowBox[{"h", " ", "p"}], "+", 
  RowBox[{"a", " ", "q"}], "+", 
  RowBox[{"b", " ", "q"}], "+", 
  RowBox[{"c", " ", "q"}], "+", 
  RowBox[{"d", " ", "q"}], "-", 
  RowBox[{"e", " ", "q"}], "-", 
  RowBox[{"f", " ", "q"}], "-", 
  RowBox[{"g", " ", "q"}], "-", 
  RowBox[{"h", " ", "q"}], "-", 
  RowBox[{"a", " ", "r"}], "-", 
  RowBox[{"b", " ", "r"}], "-", 
  RowBox[{"c", " ", "r"}], "-", 
  RowBox[{"d", " ", "r"}], "+", 
  RowBox[{"e", " ", "r"}], "+", 
  RowBox[{"f", " ", "r"}], "+", 
  RowBox[{"g", " ", "r"}], "+", 
  RowBox[{"h", " ", "r"}], "+", 
  RowBox[{"a", " ", "s"}], "+", 
  RowBox[{"b", " ", "s"}], "+", 
  RowBox[{"c", " ", "s"}], "+", 
  RowBox[{"d", " ", "s"}], "-", 
  RowBox[{"e", " ", "s"}], "-", 
  RowBox[{"f", " ", "s"}], "-", 
  RowBox[{"g", " ", "s"}], "-", 
  RowBox[{"h", " ", "s"}], "+", 
  RowBox[{"a", " ", "t"}], "+", 
  RowBox[{"b", " ", "t"}], "+", 
  RowBox[{"c", " ", "t"}], "+", 
  RowBox[{"d", " ", "t"}], "-", 
  RowBox[{"e", " ", "t"}], "-", 
  RowBox[{"f", " ", "t"}], "-", 
  RowBox[{"g", " ", "t"}], "-", 
  RowBox[{"h", " ", "t"}]}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
       "h"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "n"}], ",", "o", ",", "p", ",", "q", ",", 
       RowBox[{"-", "r"}], ",", "s", ",", "t"}], "}"}], ",", "\"\<P8\>\""}], 
    "]"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", "m"}], "+", 
  RowBox[{"b", " ", "m"}], "+", 
  RowBox[{"c", " ", "m"}], "+", 
  RowBox[{"d", " ", "m"}], "+", 
  RowBox[{"e", " ", "m"}], "+", 
  RowBox[{"f", " ", "m"}], "+", 
  RowBox[{"g", " ", "m"}], "+", 
  RowBox[{"h", " ", "m"}], "-", 
  RowBox[{"a", " ", "n"}], "-", 
  RowBox[{"b", " ", "n"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "c", " ", "n"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "d", " ", "n"}], "-", 
  RowBox[{"e", " ", "n"}], "-", 
  RowBox[{"f", " ", "n"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "g", " ", "n"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "h", " ", "n"}], "+", 
  RowBox[{"a", " ", "o"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "b", " ", "o"}], "+", 
  RowBox[{"c", " ", "o"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "d", " ", "o"}], "+", 
  RowBox[{"e", " ", "o"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "f", " ", "o"}], "+", 
  RowBox[{"g", " ", "o"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "h", " ", "o"}], "+", 
  RowBox[{"a", " ", "p"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "b", " ", "p"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "c", " ", "p"}], "+", 
  RowBox[{"d", " ", "p"}], "+", 
  RowBox[{"e", " ", "p"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "f", " ", "p"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "g", " ", "p"}], "+", 
  RowBox[{"h", " ", "p"}], "+", 
  RowBox[{"a", " ", "q"}], "+", 
  RowBox[{"b", " ", "q"}], "+", 
  RowBox[{"c", " ", "q"}], "+", 
  RowBox[{"d", " ", "q"}], "+", 
  RowBox[{"e", " ", "q"}], "+", 
  RowBox[{"f", " ", "q"}], "+", 
  RowBox[{"g", " ", "q"}], "+", 
  RowBox[{"h", " ", "q"}], "-", 
  RowBox[{"a", " ", "r"}], "-", 
  RowBox[{"b", " ", "r"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "c", " ", "r"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "d", " ", "r"}], "-", 
  RowBox[{"e", " ", "r"}], "-", 
  RowBox[{"f", " ", "r"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "g", " ", "r"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "h", " ", "r"}], "+", 
  RowBox[{"a", " ", "s"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "b", " ", "s"}], "+", 
  RowBox[{"c", " ", "s"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "d", " ", "s"}], "+", 
  RowBox[{"e", " ", "s"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "f", " ", "s"}], "+", 
  RowBox[{"g", " ", "s"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "h", " ", "s"}], "+", 
  RowBox[{"a", " ", "t"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "c", " ", "t"}], "+", 
  RowBox[{"d", " ", "t"}], "+", 
  RowBox[{"e", " ", "t"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "f", " ", "t"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "g", " ", "t"}], "+", 
  RowBox[{"h", " ", "t"}]}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Plus", "@@", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
       "h", ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"-", "b"}], ",", "c", ",", "c", ",", "e", ",", 
       RowBox[{"-", "f"}], ",", "g", ",", "h", ",", "i", ",", 
       RowBox[{"-", "j"}], ",", "k", ",", "l"}], "}"}], ",", "\"\<C3Qr\>\""}],
     "]"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["a", "2"], "-", 
  SuperscriptBox["b", "2"], "+", 
  RowBox[{"3", " ", "a", " ", "c"}], "+", 
  RowBox[{"b", " ", "c"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["c", "2"]}], "+", 
  RowBox[{"a", " ", "d"}], "-", 
  RowBox[{"b", " ", "d"}], "+", 
  RowBox[{"2", " ", "a", " ", "e"}], "+", 
  RowBox[{"c", " ", "e"}], "-", 
  RowBox[{"d", " ", "e"}], "-", 
  SuperscriptBox["e", "2"], "-", 
  RowBox[{"2", " ", "b", " ", "f"}], "-", 
  RowBox[{"c", " ", "f"}], "+", 
  RowBox[{"d", " ", "f"}], "+", 
  SuperscriptBox["f", "2"], "+", 
  RowBox[{"2", " ", "a", " ", "g"}], "+", 
  RowBox[{"3", " ", "c", " ", "g"}], "-", 
  RowBox[{"d", " ", "g"}], "-", 
  RowBox[{"2", " ", "f", " ", "g"}], "-", 
  SuperscriptBox["g", "2"], "+", 
  RowBox[{"2", " ", "a", " ", "h"}], "+", 
  RowBox[{"3", " ", "c", " ", "h"}], "-", 
  RowBox[{"d", " ", "h"}], "-", 
  RowBox[{"2", " ", "f", " ", "h"}], "-", 
  RowBox[{"2", " ", "g", " ", "h"}], "-", 
  SuperscriptBox["h", "2"], "+", 
  RowBox[{"2", " ", "a", " ", "i"}], "+", 
  RowBox[{"3", " ", "c", " ", "i"}], "-", 
  RowBox[{"d", " ", "i"}], "-", 
  RowBox[{"2", " ", "f", " ", "i"}], "-", 
  RowBox[{"2", " ", "g", " ", "i"}], "-", 
  RowBox[{"2", " ", "h", " ", "i"}], "-", 
  SuperscriptBox["i", "2"], "-", 
  RowBox[{"2", " ", "b", " ", "j"}], "-", 
  RowBox[{"c", " ", "j"}], "-", 
  RowBox[{"d", " ", "j"}], "-", 
  RowBox[{"2", " ", "e", " ", "j"}], "+", 
  RowBox[{"2", " ", "g", " ", "j"}], "+", 
  RowBox[{"2", " ", "h", " ", "j"}], "+", 
  RowBox[{"2", " ", "i", " ", "j"}], "+", 
  SuperscriptBox["j", "2"], "+", 
  RowBox[{"2", " ", "a", " ", "k"}], "+", 
  RowBox[{"c", " ", "k"}], "+", 
  RowBox[{"d", " ", "k"}], "+", 
  RowBox[{"2", " ", "f", " ", "k"}], "-", 
  SuperscriptBox["k", "2"], "+", 
  RowBox[{"2", " ", "a", " ", "l"}], "+", 
  RowBox[{"c", " ", "l"}], "+", 
  RowBox[{"d", " ", "l"}], "+", 
  RowBox[{"2", " ", "f", " ", "l"}], "-", 
  RowBox[{"2", " ", "k", " ", "l"}], "-", 
  SuperscriptBox["l", "2"]}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["19. Appendix G. Rotations in various dimensions.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tClassical (Euler) \"rigid rotation\" only occurs in the complex plane for \
2D, in the imaginary quaternions for 3D, and the imaginary octonions for 7D. \
It is implemented (for real or complex vector lists, axes of rotation, and \
angles) by ",
 StyleBox["rotateQOP",
  FontSlant->"Italic"],
 " for the quaternion, octonion, and Pauli-\[Sigma] algebra; the Pauli \
algebra gives the same result as the quaternion algebra, with the direction \
of rotation reversed. Example G1 rotates sets of arbitrary vectors about \
arbitrary axes in each of these algebras, and checks that the effect of \
rotation is additive. (As expected, testing an extension of the procedure to \
the 16-element non-conservative Sedenion algebra did not give additive \
15-dimension rotation.)"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example G1. Rigid rotations in 3 & 7 dimensions.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\"\<Rotation of vec\>\"", ",", 
    RowBox[{"v4", " ", "=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"4.", ",", "6.", ",", "7", ",", 
        RowBox[{"-", "1"}]}], "}"}], "}"}]}], ",", 
    "\"\<\\nabout axis  ax =\>\"", ",", 
    RowBox[{"ax", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1."}], ",", "9.", ",", 
       RowBox[{"-", "3"}]}], "}"}]}], ",", 
    "\"\<by \[Pi]/4 using Qr or -\[Pi]/4 using P4 gives the same result\>\"", 
    ",", 
    RowBox[{"q1", "=", 
     RowBox[{"rotateQOP", "[", 
      RowBox[{"v4", ",", 
       RowBox[{"ax", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1."}], ",", "9.", ",", 
          RowBox[{"-", "3"}]}], "}"}]}], ",", 
       RowBox[{"\[Pi]", "/", "4."}], ",", "\"\<Qr\>\""}], "]"}]}], ",", 
    RowBox[{"q1", "=", 
     RowBox[{"rotateQOP", "[", 
      RowBox[{"v4", ",", 
       RowBox[{"ax", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1."}], ",", "9.", ",", 
          RowBox[{"-", "3"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"-", "\[Pi]"}], "/", "4."}], ",", "\"\<P4\>\""}], "]"}]}], 
    ",", "\[IndentingNewLine]", "\"\<Qr Rotates back correctly\>\"", ",", 
    RowBox[{
     RowBox[{"rotateQOP", "[", 
      RowBox[{"q1", ",", "ax", ",", 
       RowBox[{
        RowBox[{"-", "\[Pi]"}], "/", "4."}], ",", "\"\<Qr\>\""}], "]"}], 
     "\[Equal]", "v4"}], ",", "\[IndentingNewLine]", 
    "\"\<\\n P4 reverses Qr           \>\"", ",", 
    RowBox[{
     RowBox[{"rotateQOP", "[", 
      RowBox[{"q1", ",", "ax", ",", 
       RowBox[{"\[Pi]", "/", "4."}], ",", "\"\<P4\>\""}], "]"}], "\[Equal]", 
     "v4"}], ",", "\[IndentingNewLine]", 
    "\"\<\\n A further rotation by .4 gives \>\"", ",", 
    RowBox[{"rotateQOP", "[", 
     RowBox[{"q1", ",", "ax", ",", ".4", ",", "\"\<Qr\>\""}], "]"}], ",", 
    "\"\<\\nthe same as rotating by \[Pi]/4+.4\>\"", ",", 
    RowBox[{"rotateQOP", "[", 
     RowBox[{"v4", ",", 
      RowBox[{"ax", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1."}], ",", "9.", ",", 
         RowBox[{"-", "3"}]}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"\[Pi]", "/", "4"}], "+", ".4"}], ",", "\"\<Qr\>\""}], "]"}]}],
    "}"}], TraditionalForm]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Rotation of vec\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"4.`", ",", "6.`", ",", "7", ",", 
      RowBox[{"-", "1"}]}], "}"}], "}"}], ",", "\<\"\\nabout axis  ax =\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.`"}], ",", "9.`", ",", 
     RowBox[{"-", "3"}]}], "}"}], 
   ",", "\<\"by \[Pi]/4 using Qr or -\[Pi]/4 using P4 gives the same result\"\
\>", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "4.000000000000001`", ",", "3.160025099117093`", ",", 
      "8.096168842041752`", ",", "3.235164826419561`"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "4.`", ",", "4.939023459103737`", ",", "5.279421438729568`", ",", 
      RowBox[{"-", "5.808076836845873`"}]}], "}"}], "}"}], 
   ",", "\<\"Qr Rotates back correctly\"\>", ",", "False", 
   ",", "\<\"\\n P4 reverses Qr           \"\>", ",", "True", 
   ",", "\<\"\\n A further rotation by .4 gives \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "4.`", ",", "5.984425242712861`", ",", "6.17306095479756`", ",", 
      RowBox[{"-", "3.4756255498449393`"}]}], "}"}], "}"}], 
   ",", "\<\"\\nthe same as rotating by \[Pi]/4+.4\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "3.9999999999999996`", ",", "0.6784224879601769`", ",", 
      "8.180425161798041`", ",", "4.315134656074065`"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tMany hoops have polar forms that describe rotations, with angles adding on \
multiplication. The simplest is \"Terplex\", based on the C3 group. This \
rotates about the {1,1,1} axis. Example G2 converts {1,2,4} to the C3 polar \
form {7,7,2.42787}. Subtracting \[Pi]/4 and reverting to vector form gives \
the same effect as quaternion rotation of {1,1,2,4} by \[Pi]/4 about {1,1,1}.
\tNote that the Euler procedure is to pre- and post-multiply by a \
half-rotation and its conjugate. Hoop rotation is a single multiplication \
using the full angle.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example G2. Rotations in C3 match Quaternion rotations about {1,1,1}.\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\"\<C3 Polar form of {1,2,4} is\>\"", ",", 
    RowBox[{"toPolar", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.", ",", "2.", ",", "4"}], "}"}], ",", "\"\<C3\>\""}], "]"}],
     ",", "\[IndentingNewLine]", "\"\<\\n Rotate by -\[Pi]/4        \>\"", 
    ",", 
    RowBox[{"toVector", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7.", ",", "7.", ",", 
        RowBox[{"2.42787", "-", 
         RowBox[{"\[Pi]", "/", "4"}]}]}], "}"}], ",", "\"\<C3\>\""}], "]"}], 
    ",", "\[IndentingNewLine]", "\"\<\\n Qr rotation by \[Pi]/4\>\"", ",", 
    RowBox[{"rotateQOP", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"1.", ",", "1.", ",", "2.", ",", "4."}], "}"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1.", ",", "1.", ",", "1."}], "}"}], ",", 
      RowBox[{"\[Pi]", "/", "4."}], ",", "\"\<Qr\>\""}], "]"}]}], "}"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C3 Polar form of {1,2,4} is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"7.`", ",", "7.`", ",", "2.4278682746450277`"}], "}"}], 
   ",", "\<\"\\n Rotate by -\[Pi]/4        \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "2.2070178372524802`", ",", "0.8728879079979885`", ",", 
     "3.920094254749531`"}], "}"}], ",", "\<\"\\n Qr rotation by \[Pi]/4\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "1.`", ",", "0.5740277108235441`", ",", "3.3223759443294067`", ",", 
      "3.103596344847049`"}], "}"}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "\tThe hoops O4, Octi, C4C4r, C2D4r, QC2cO8, KiC4r, CL21, CL03 define \
different rotations in 4D; O8, O8a, C4KC2r & C8Kr define different rotations \
in  8D. (Of these, only O4, Octi, C2D4r, CL21, CL03 have ",
 StyleBox["toPol",
  FontSlant->"Italic"],
 " & ",
 StyleBox["toVec",
  FontSlant->"Italic"],
 " in the database.)"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example G3. O4 Rotations.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{
     "2.", ",", "1", ",", "3", ",", "3", ",", "5", ",", "4", ",", "6", ",", 
      "2."}], "}"}]}], ";", 
   RowBox[{"{", 
    RowBox[{"\"\<A= \>\"", ",", "A", ",", "\"\<\\nPolar A \>\"", ",", 
     RowBox[{"pA", "=", 
      RowBox[{"toPolar", "[", 
       RowBox[{"A", ",", "\"\<O4\>\""}], "]"}]}], ",", 
     "\"\<\\n Rotated by angles 1,-.1,.2,.3 gives vector\>\"", ",", 
     RowBox[{"vA1", "=", 
      RowBox[{"toVec", "[", 
       RowBox[{
        RowBox[{"pA", "+", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0", ",", 
           RowBox[{"-", ".1"}], ",", "0", ",", ".2", ",", "0", ",", ".3"}], 
          "}"}]}], ",", "\"\<O4\>\""}], "]"}]}], ",", 
     "\"\<\\n The Rotated Polar is\>\"", ",", 
     RowBox[{"rA", "=", 
      RowBox[{"toPolar", "[", 
       RowBox[{"vA1", ",", "\"\<O4\>\""}], "]"}]}], ",", 
     "\"\<\\n Radii unchanged, Angles altered correctly\>\"", ",", 
     RowBox[{"Chop", "[", 
      RowBox[{"pA", "-", "rA"}], "]"}]}], "}"}]}], TraditionalForm]], "Input",\

 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A= \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "2.`", ",", "1", ",", "3", ",", "3", ",", "5", ",", "4", ",", "6", ",", 
     "2.`"}], "}"}], ",", "\<\"\\nPolar A \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"10.`", ",", 
     RowBox[{"-", "1.2490457723982544`"}], ",", "26.`", ",", 
     "1.373400766945016`", ",", "10.`", ",", "2.819842099193151`", ",", 
     "370.`", ",", "1.0838970949836275`"}], "}"}], 
   ",", "\<\"\\n Rotated by angles 1,-.1,.2,.3 gives vector\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.2485505833432229`", ",", 
     RowBox[{"-", "1.030892671058775`"}], ",", "1.2856274853567013`", ",", 
     "2.070899491246533`", ",", "5.845053059372548`", ",", 
     "3.7971773208991593`", ",", "6.042741733042781`", ",", 
     "3.215430061772869`"}], "}"}], ",", "\<\"\\n The Rotated Polar is\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"10.000000000000004`", ",", 
     RowBox[{"-", "0.2490457723982545`"}], ",", "25.999999999999982`", ",", 
     "1.2734007669450158`", ",", "10.000000000000002`", ",", 
     "3.019842099193151`", ",", "370.`", ",", "1.3838970949836276`"}], "}"}], 
   ",", "\<\"\\n Radii unchanged, Angles altered correctly\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.9999999999999999`"}], ",", "0", ",", 
     "0.10000000000000009`", ",", "0", ",", 
     RowBox[{"-", "0.20000000000000018`"}], ",", "0", ",", 
     RowBox[{"-", "0.30000000000000004`"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tThe above are all \"central rotations\" without offsets; all the sizes are \
quadratic. Many loops have \"offset rotations\" in which the shapes include \
linear sizes that displace the centre of rotation from the origin.
\tMixed polar-hypolar rotations can be defined for various hoops; the \
database contains those for C4, P4, C4C2r, C3C2, D3, D4, & Q8. Example 40 \
shows rotation in D3 & C3C2, with two offsets (o & O here) and two related \
angles.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["Example G4. D3, C3C2 Rotations.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "\"\<D3 vector form of {o,O,\!\(\*SuperscriptBox[\(p\), \(2\)]\),\[Phi],\!\
\(\*SuperscriptBox[\(q\), \(2\)]\),\[Psi]} is\>\"", ",", 
    RowBox[{
     RowBox[{"toVec", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"o", ",", "O", ",", 
         SuperscriptBox["p", "2"], ",", "\[Phi]", ",", 
         SuperscriptBox["q", "2"], ",", "\[Psi]"}], "}"}], ",", 
       "\"\<D3\>\""}], "]"}], "/.", 
     RowBox[{
      SqrtBox[
       SuperscriptBox["any_", "2"]], "\[Rule]", "any"}]}], ",", 
    "\[IndentingNewLine]", "\"\<\\nC3C2 vector form is\\n\>\"", ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"toVec", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"o", ",", "O", ",", 
         SuperscriptBox["p", "2"], ",", "\[Phi]", ",", 
         SuperscriptBox["q", "2"], ",", "\[Psi]"}], "}"}], ",", 
       "\"\<C3C2\>\""}], "]"}], "/.", 
     RowBox[{
      SqrtBox[
       SuperscriptBox["any_", "2"]], "\[Rule]", "any"}]}]}], "}"}], 
  TraditionalForm]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"D3 vector form of {o,O,\\!\\(p\\^2\\),\[Phi],\\!\\(q\\^2\\),\
\[Psi]} is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "+", "O", "+", 
        RowBox[{"4", " ", "p", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "o"}], "+", "O", "+", 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Psi]"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "+", "O", "+", 
        RowBox[{"4", " ", "p", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "\[Phi]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "o"}], "+", "O", "+", 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "\[Phi]", "+", "\[Psi]"}],
           "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "+", "O", "+", 
        RowBox[{"4", " ", "p", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "\[Phi]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "o"}], "+", "O", "+", 
        RowBox[{"4", " ", "q", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "\[Phi]", "+", "\[Psi]"}],
           "]"}]}]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nC3C2 vector form is\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "+", "O", "+", 
        RowBox[{"2", " ", "p", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "+", "O", "+", 
        RowBox[{"2", " ", "p", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "\[Phi]"}], "]"}]}], "+", 
        
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "\[Psi]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "+", "O", "+", 
        RowBox[{"2", " ", "p", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "\[Phi]"}], "]"}]}], "+", 
        
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "\[Psi]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "-", "O", "+", 
        RowBox[{"2", " ", "p", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "-", "O", "+", 
        RowBox[{"2", " ", "p", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "\[Phi]"}], "]"}]}], "-", 
        
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "3"], "+", "\[Psi]"}], "]"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"o", "-", "O", "+", 
        RowBox[{"2", " ", "p", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "\[Phi]"}], "]"}]}], "-", 
        
        RowBox[{"2", " ", "q", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"4", " ", "\[Pi]"}], "3"], "+", "\[Psi]"}], "]"}]}]}], 
       ")"}]}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Geometric algebra uses Clifford algebras to handle rotations and other \
geometric operations. Under development.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["20. Appendix H. Nonassociative & non-Abelian algebras.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["Hoops", "Subsection",
 FontFamily->"Times New Roman"],

Cell["\<\
\tOctonions are the best-known non-associative algebra; they are \"square \
associative\" or \"alternative\", aa.b=a.ab. Their compositions with cyclic \
groups are also alternative and conservative. Because I knew of no other \
non-associative Moufang loops, I conjectured that conservation resulted from \
the Moufang property. On 4/5/6 I obtained the \"Loops\" package (in [6]) and \
found a list of Noncommutative Moufang loops. The database now contains all \
12 with fewer than 28 elements. Only two (Oct and D4M2, related to split \
octonions Octi) are conservative:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"conservativeQ", "[", "D3Mn", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "D4M1n", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "Oct", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "D4M2", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "D4M4n", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "D4M5n", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "D5Mn", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "D3C2Mn", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "A4Mn", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "Q12M3n", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "Q12M4n", "]"}], ",", 
   RowBox[{"conservativeQ", "[", "Q12M5n", "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "False", ",", "False", ",", "True", ",", "True", ",", "False", ",", "False",
    ",", "False", ",", "False", ",", "False", ",", "False", ",", "False", ",",
    "False"}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "\tNoncommutative (nonAbelian) group determinants such as D3 have repeated \
factors, which are conserved but which only appear once in the inverse \
denominators. (As Eigenvectors they have differnt signs .) In April 2006, I \
conjectured that a different, noncommutative (NC), formulation might yield a \
new conserved angle. NC versions of ",
 StyleBox["ge & det",
  FontSlant->"Italic"],
 " were developed. No progress has been made with NC powers.\n\tThe next \
example has vectors selected to give prime sizes; as no extra conserved \
values appear, the search for new radius/conserved angle does not look \
promising:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<If A & B are\>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{"3", ",", "5", ",", "0", ",", "4", ",", "3", ",", "2"}], "}"}]}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{"7", ",", "5", ",", "1", ",", "5", ",", "3", ",", "2"}], "}"}]}],
    ",", "\"\<\\n In D3, AB is\>\"", ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B", ",", "\"\<D3\>\""}], "]"}]}], ",", 
   "\[IndentingNewLine]", "\"\<\\n the factors of Det[A] are\>\"", ",", 
   RowBox[{"FactorInteger", "[", 
    RowBox[{"Det", "[", 
     RowBox[{"gmap", "[", 
      RowBox[{"D3", ",", "A"}], "]"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<\\n the factors of Det[B] are\>\"", ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FactorInteger", "[", 
    RowBox[{"Det", "[", 
     RowBox[{"gmap", "[", 
      RowBox[{"D3", ",", "B"}], "]"}], "]"}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<\\n the factors of Det[AB] are\>\"", ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FactorInteger", "[", 
    RowBox[{"-", 
     RowBox[{"Det", "[", 
      RowBox[{"gmap", "[", 
       RowBox[{"D3", ",", "AB"}], "]"}], "]"}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\"\<\\nThe shapes of A & B are\>\"", ",", 
   RowBox[{"shape", "[", "A", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"shape", "[", "B", "]"}], ",", 
   "\"\<\\nand the shape of AB has factors\>\"", ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"FactorInteger", "[", 
    RowBox[{"shape", "[", "AB", "]"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"If A & B are\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5", ",", "0", ",", "4", ",", "3", ",", "2"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "5", ",", "1", ",", "5", ",", "3", ",", "2"}], "}"}], 
   ",", "\<\"\\n In D3, AB is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"73", ",", "75", ",", "52", ",", "66", ",", "73", ",", "52"}], 
    "}"}], ",", "\<\"\\n the factors of Det[A] are\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "1"}], "}"}]}], "}"}], 
   ",", "\<\"\\n the factors of Det[B] are\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"19", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", "1"}], "}"}]}], "}"}], 
   ",", "\<\"\\n the factors of Det[AB] are\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", "1"}], "}"}]}], "}"}], 
   ",", "\<\"\\nThe shapes of A & B are\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"17", ",", 
     RowBox[{"-", "5"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"23", ",", 
     RowBox[{"-", "1"}], ",", "19"}], "}"}], 
   ",", "\<\"\\nand the shape of AB has factors\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"17", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"23", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"5", ",", "1"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], "}"}]], "Output",\

 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "The quadratic is squared, giving repeated factors (2,2) in A, (19,2) in B. \
The inverse only involves the unsquared quadratic, with the divisor being \
23*1*19, not 23*1*",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["19", "2"], TraditionalForm]]],
 ". It does not use the ordinary partial-fraction formulation for repeated \
factors, but confirms the generality of the specific partial fraction \
formulation used in ",
 StyleBox["hoopIn",
  FontSlant->"Italic"],
 StyleBox["verse",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hoopInverse", "[", "B", "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["7", "437"], ",", 
   FractionBox["53", "437"], ",", 
   RowBox[{"-", 
    FractionBox["85", "437"]}], ",", 
   FractionBox["53", "437"], ",", 
   RowBox[{"-", 
    FractionBox["131", "437"]}], ",", 
   FractionBox["122", "437"]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
As the quadratic is a repeated factor that involves three positive and three \
negative squared fragments, the pseudo-polar form is expressed as:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toPolar", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
  "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"c", "-", "e"}], ")"}], "2"]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "d"}], ")"}], "2"]}], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "f"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "-", "f"}], ")"}], "2"]}], ")"}]}]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "a"}], "-", "c", "-", "e"}], ",", 
     RowBox[{
      SuperscriptBox["3", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", " ", "c"}], "+", "e"}], ")"}]}]}], "]"}], ",", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "e"}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "b"}], "-", "d", "-", "f"}], ",", 
     RowBox[{
      SuperscriptBox["3", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", " ", "d"}], "+", "f"}], ")"}]}]}], "]"}]}], 
  "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
with two three-phase systems. The conserved size has to be split into two \
components, neither of which are conserved. \
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"toPolar", "[", "A", "]"}], ",", 
    RowBox[{"toPolar", "[", "B", "]"}], ",", 
    RowBox[{"toPolar", "[", "AB", "]"}]}], "}"}], "//", "N"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"17.`", ",", 
     RowBox[{"-", "5.`"}], ",", "2.`", ",", "1.0471975511965976`", ",", "9.`",
      ",", 
     RowBox[{"-", "0.7137243789447656`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"23.`", ",", 
     RowBox[{"-", "1.`"}], ",", "19.`", ",", "0.3334731722518321`", ",", 
     "28.`", ",", 
     RowBox[{"-", "1.0471975511965976`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "391.`", ",", "5.`", ",", "38.`", ",", "1.0471975511965976`", ",", 
     "441.`", ",", 
     RowBox[{"-", "0.6484568061226152`"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Curiosity - angles of \[Pi]/3?? Specific to the chosen vectors; others give \
general angles:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"AB", "=", 
  RowBox[{"hoopTimes", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}], ",", "4", ",", "3", ",", "7", ",", "0"}], "}"}]}],
      ")"}], ",", 
    RowBox[{"(", 
     RowBox[{"B", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "9", ",", "1", ",", "5", ",", "3", ",", 
        "4"}], "}"}]}], ")"}], ",", "\"\<D3\>\""}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FactorInteger", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"gmap", "[", 
    RowBox[{"D3", ",", "A"}], "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FactorInteger", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"gmap", "[", 
    RowBox[{"D3", ",", "B"}], "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FactorInteger", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"gmap", "[", 
    RowBox[{"D3", ",", "AB"}], "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"shape", "[", "A", "]"}], "\[IndentingNewLine]", 
 RowBox[{"shape", "[", "B", "]"}], "\[IndentingNewLine]", 
 RowBox[{"shape", "[", "AB", "]"}], "\[IndentingNewLine]", 
 RowBox[{"FactorInteger", "[", "%", "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"13", ",", "69", ",", "29", ",", "54", ",", 
   RowBox[{"-", "12"}], ",", "94"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13", ",", "1"}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"7", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19", ",", "1"}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19", ",", "1"}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"13", ",", "11", ",", "8"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"19", ",", 
   RowBox[{"-", "17"}], ",", "7"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"247", ",", 
   RowBox[{"-", "187"}], ",", "56"}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"13", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"toPolar", "[", "A", "]"}], ",", 
    RowBox[{"toPolar", "[", "B", "]"}], ",", 
    RowBox[{"toPolar", "[", "AB", "]"}]}], "}"}], "//", "N"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "13.`", ",", "11.`", ",", "8.`", ",", "2.6179938779914944`", ",", "27.`", 
     ",", 
     RowBox[{"-", "2.5030329574907877`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19.`", ",", 
     RowBox[{"-", "17.`"}], ",", "7.`", ",", "2.808119481337961`", ",", 
     "28.`", ",", 
     RowBox[{"-", "0.19012560334646675`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"247.`", ",", 
     RowBox[{"-", "187.`"}], ",", "56.`", ",", 
     RowBox[{"-", "1.444732972701484`"}], ",", "1281.`", ",", 
     "1.714143895700262`"}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tNon-commutative algebras have Lie and Jordan products, and include Clifford \
algebras. These are under investigation.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Geometric & Clifford-like Algebras", "Subsection"],

Cell[TextData[{
 StyleBox["\tCliffordG.m",
  FontSlant->"Italic"],
 " will provide a rudimentary Geometric Algebra package (not included in \
GroupLoopHoop6.m). It is based on [11], and uses normal hoop multiplication, \
with AB = A\[CenterDot]B+A",
 Cell[BoxData["\[Wedge]"]],
 "B = Inner[A,B] + Outer[A,B] = Jordan[A,B] + Lie[A.B]. For commutative hoops \
Wedge product is zero.  [12] provides a readable introduction, & [3] is \
recommended. See also [13 to 18]. \n\tA summary follows:-\n\tGeometric \
Algebra was developed (and named) by Grassmann. It is more general than the \
material developed (many years later) by Gibbs as vector dot and cross \
products. Clifford  and Hestenes extended and applied the subject. It has \
suffered from a surfeit of conflicting nomenclature. I attempt to correlate \
this via a glossary, and by providing common aliases when first introducing a \
concept, whilst fitting it into Hoop Algebras.\n\tThe basic elements are my \
\"univectors\" (aka gammas, generators, relators, vectors) such as ",
 StyleBox["et",
  FontSlant->"Italic"],
 ", ",
 StyleBox["ex, ey, ez, e\[Tau].",
  FontSlant->"Italic"],
 " These are unit orthogonal basis vectors. Some authors confusingly call \
them vectors whilst still using the same name for Hamilton's original \
concept, which is typified by ",
 Cell[BoxData[
  SubscriptBox["V", "3"]]],
 "={\[Alpha] ex, \[Beta] ey, \[Gamma] ez} & ",
 Cell[BoxData[
  SubscriptBox["V", "4"]]],
 "={\[Alpha] ex, \[Beta] ey, \[Gamma] ez, \[Tau] e\[Tau]}. (Greek letters \
indicate scalars.) These are points in 3D space and 4D spacetime, and also \
lines from the origin.\n\tUnivectors are group generators that square to \
\[PlusMinus]1 and anticommute, ey\[SmallCircle]ex=-ex\[SmallCircle]ey. \
Bivectors, trivectors, etc. are geometric products of univectors, and \
(together with 1) constitute the full basis of a Clifford-like algebra. \
\[Alpha]ex\[SmallCircle]\[Beta]ey is a directed plane of area \
\[Alpha]\[Beta], but has no shape (it is not a parallelogram); \[Alpha]ex\
\[SmallCircle]\[Beta]ey\[SmallCircle]\[Gamma]ez is an oriented volume \
\[Alpha]\[Beta]\[Gamma], again with no shape. The number of en's in an \
element is its \"grade\" (dimensionality);  the full basis can be partitioned \
into \"blades\", sets of the same grade. A \"multivector\" is a general \
vector partitioned into grades i.e. into subspaces of a single \
dimensionality; it is a compactified representation that often simplifies \
proofs and calculations.\n\tThe procedure ",
 StyleBox["clf[p,q]",
  FontSlant->"Italic"],
 " creates CLpq, the hoops that define Clifford Algebras:-"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"clf", "[", "3", "]"}], "//", "tf"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8"},
     {"2", "1", "4", "3", "6", "5", "8", "7"},
     {"3", 
      RowBox[{"-", "4"}], "1", 
      RowBox[{"-", "2"}], "7", 
      RowBox[{"-", "8"}], "5", 
      RowBox[{"-", "6"}]},
     {"4", 
      RowBox[{"-", "3"}], "2", 
      RowBox[{"-", "1"}], "8", 
      RowBox[{"-", "7"}], "6", 
      RowBox[{"-", "5"}]},
     {"5", 
      RowBox[{"-", "6"}], 
      RowBox[{"-", "7"}], "8", "1", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], "4"},
     {"6", 
      RowBox[{"-", "5"}], 
      RowBox[{"-", "8"}], "7", "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}], "3"},
     {"7", "8", 
      RowBox[{"-", "5"}], 
      RowBox[{"-", "6"}], "3", "4", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}]},
     {"8", "7", 
      RowBox[{"-", "6"}], 
      RowBox[{"-", "5"}], "4", "3", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe following table relates Clifford algebras to the corresponding hoops, \
and notes whether the tables are identical (yes) or isotopic (iso) to the \
protoloop. Each algebra is 2-folded from a \"parent\" loop. As most parents \
have several 2-fold symmetries, several \"isotopic\" algebras can be obtained \
from the same parent. Only the identical case is shown if it is known. The ",
 StyleBox["clf",
  FontSlant->"Italic"],
 " procedure creates the tables."
}], "Text"],

Cell[BoxData[GridBox[{
   {"Basis", "Hoop", "Identical", "Parent", "Algebra"},
   {"x", "C2", "yes", "K", "Real"},
   {
    RowBox[{"-", "x"}], "C4c", "yes", "C4", "Complex"},
   {
    RowBox[{"   ", 
     RowBox[{"x", "     ", "y", " "}]}], "CL2", "yes", "D4", 
    RowBox[{"2", "D", " ", "space"}]},
   {
    RowBox[{"   ", 
     RowBox[{"x", " ", "-", "y", " "}]}], "CL11", "yes", "D4", 
    RowBox[{"2", "D", " ", "space"}]},
   {
    RowBox[{
     RowBox[{"-", "x"}], "-", "y"}], "Qr", "yes", "Q8", "Quaternion"},
   {
    RowBox[{"x", " ", "y", " ", "z"}], "CL3", "yes", "P16", 
    RowBox[{"3", "D", " ", "space"}]},
   {
    RowBox[{
     RowBox[{"x", " ", "y"}], " ", "-", "z"}], "CL21", "yes", "D4C2", " "},
   {
    RowBox[{
     RowBox[{"-", "x"}], " ", "-", "y", " ", "-", "z"}], "CL03", "yes", 
    "Q8C2", " "},
   {
    RowBox[{"x", " ", "-", 
     RowBox[{"y", "  ", "z"}]}], "C2D4r", "iso", "D4C2", " "},
   {
    RowBox[{"t", " ", "-", "x", " ", "-", "y", " ", "-", "z"}], "CL13", "yes",
     "Cl4C2", "spaceTime"},
   {
    RowBox[{
     RowBox[{"w", " ", "x"}], " ", "-", "y", " ", "-", "z"}], "CL22", "yes", 
    "CL31C2", " "},
   {
    RowBox[{
     RowBox[{"x", " ", "y", " ", "z"}], " ", "-", "\[Tau]"}], "CL31", "yes", 
    "CL31C2", "spacetime"},
   {
    RowBox[{"w", " ", "x", " ", "y", " ", "z"}], "CL4", "yes", "CL4C2", " "},
   {
    RowBox[{"w", " ", "-", "x", " ", "-", 
     RowBox[{"y", " ", "z"}]}], "r31s", "?", "CL31C2", " "},
   {
    RowBox[{"w", " ", "-", 
     RowBox[{"x", " ", "y"}], " ", "-", "z"}], "r31u", "?", "CL31C2", " "},
   {
    RowBox[{
     RowBox[{
      RowBox[{"-", "w"}], "  ", "x"}], " ", "-", 
     RowBox[{"y", " ", "z"}]}], "r31t", "?", "Cl31C2", " "},
   {
    RowBox[{"w", " ", "-", "x", " ", "-", 
     RowBox[{"y", " ", "z"}]}], "r31u", "?", "CL31C2", " "},
   {
    RowBox[{"t", " ", "x", " ", "y", " ", "z", " ", "\[Tau]"}], 
    RowBox[{"CL5", "?"}], "yes", "CL5C2", " "}
  }]], "Text"],

Cell["\<\
Note that CL11 is shorthand for Clifford(1,1), and is not in the hoop \
database as it is isomorphic to CL2.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["21. References.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "1. S Wolfram, The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Book, CUP, 1999."
}], "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["\<\
2. J.D.H. Smith, A.B. Romanowska, Post-Modern Algebra, Wiley Interscience \
1999.\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["\<\
3. P. Lounesto, Clifford Algebras & Spinors 2nd ed., Cambridge University \
Press 2001.\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell[TextData[{
 "4. G. ",
 StyleBox["Frobenius, Uber die Primfactoren der Gruppendeterminante, \
Sitzungsber.Preuss. Akad. Wiss. Berlin Phys. Math,KL. 1896,(985-1021) (not \
seen, but quoted from Ref[10 p236].)", "RefAuthorFN"]
}], "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell[TextData[{
 StyleBox["5. ", "RefAuthorFN"],
 "http://library.wolfram.com/infocenter/MathSource/4894 R.H.Beresford \
2003-6."
}], "EndNote",
 PageWidth->WindowWidth,
 CellTags->"CT"],

Cell["\<\
6. [GAP99] The Gap Group. GAP --- Groups, Algorithms, and Programming, \
Version 4.4.7;  St Andrews, 2006. (http://www.gap-system.org) \
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"FV"],

Cell["\<\
7. C. M. Davenport 2000, http://home.usit.net/~cmdaven/hyprcplex.htm\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell[TextData[{
 "8. H.-D. Ebbinghaus et al, Numbers, Springer-Verlag N.Y. ",
 StyleBox["1991.", "RefAuthorFN"]
}], "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell[TextData[{
 StyleBox["9.", "RefAuthorFN"],
 " J.J.Hamilton, Hypercomplex numbers and the description of spin states, \
J.Math.Phys. ",
 StyleBox["38",
  FontWeight->"Bold"],
 "(10) Oct. 1997. pp4914-4928"
}], "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["\<\
10. B. L. van der Waerden, A History of Algebra, Chapter 12. Springer 1985\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell[TextData[{
 "12. Terje Vold, ",
 ButtonBox["http://library.wolfram.com/infocenter/Conferences/6951/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://library.wolfram.com/infocenter/Conferences/6951/"], None}]
}], "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["\<\
13. Jaap Suter, \
http://web.archive.org/web/20040610223908/home.student.utwente.nl/j.suter/ga_\
primer.pdf\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["\<\
14. Ian C. G. Bell, http://www.iancgbell.clara.net/maths/geoalg1.htm\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["\<\
15. Chris Doran, Anthony Lasenby, Geometric algebra for Physicists, CUP, \
Cambridge England 2003 516.35\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["\<\
16. G. Sommer (Ed), Geometric Computing with Clifford Algebras, Springer, \
2001 512.57.\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["17. C. Perwass, Clucalc, http://www.clucalc.info/", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"],

Cell["\<\
18. M. Hohenwarter et al, Geogebra, www.geogebra.org
\
\>", "EndNote",
 PageWidth->WindowWidth,
 CellTags->"MT2"]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{1025, 748},
WindowMargins->{{85, Automatic}, {Automatic, 50}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], 
   Cell[
    TextData["25/1/2007"]], 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}},
PageHeaderLines->{Inherited, False},
ShowSelection->True,
Magnification->2,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3426322660-2087744"->{
  Cell[139411, 4189, 3085, 44, 444, "Print",
   CellTags->"Info3426322660-2087744"]},
 "Info3426322661-8039262"->{
  Cell[143448, 4272, 672, 10, 213, "Print",
   CellTags->"Info3426322661-8039262"]},
 "Info3426322661-4802284"->{
  Cell[144123, 4284, 398, 6, 147, "Print",
   CellTags->"Info3426322661-4802284"]},
 "Info3426322661-3580866"->{
  Cell[146296, 4360, 421, 6, 180, "Print",
   CellTags->"Info3426322661-3580866"]},
 "Info3426322665-2472452"->{
  Cell[220097, 6437, 193, 3, 80, "Print",
   CellTags->"Info3426322665-2472452"]},
 "Info3426325327-2735175"->{
  Cell[312155, 9041, 288, 5, 147, "Print",
   CellTags->"Info3426325327-2735175"]},
 "Info3426326367-7958013"->{
  Cell[433073, 12476, 280, 4, 147, "Print",
   CellTags->"Info3426326367-7958013"]},
 "Info3362457282-3716175"->{
  Cell[433356, 12482, 322, 6, 146, "Print",
   CellTags->"Info3362457282-3716175"]},
 "Info3426326367-8704009"->{
  Cell[433826, 12500, 276, 4, 147, "Print",
   CellTags->"Info3426326367-8704009"]},
 "Info3362457286-9933190"->{
  Cell[434105, 12506, 318, 6, 146, "Print",
   CellTags->"Info3362457286-9933190"]},
 "MT2"->{
  Cell[1513720, 49992, 166, 7, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1513889, 50001, 151, 5, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1514043, 50008, 157, 5, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1514203, 50015, 286, 7, 72, "EndNote",
   CellTags->"MT2"],
  Cell[1514888, 50039, 138, 4, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1515029, 50045, 169, 5, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1515201, 50052, 267, 9, 72, "EndNote",
   CellTags->"MT2"],
  Cell[1515471, 50063, 144, 4, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1515618, 50069, 281, 8, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1515902, 50079, 177, 6, 72, "EndNote",
   CellTags->"MT2"],
  Cell[1516082, 50087, 138, 4, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1516223, 50093, 174, 5, 72, "EndNote",
   CellTags->"MT2"],
  Cell[1516400, 50100, 158, 5, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1516561, 50107, 111, 2, 43, "EndNote",
   CellTags->"MT2"],
  Cell[1516675, 50111, 123, 5, 72, "EndNote",
   CellTags->"MT2"]},
 "CT"->{
  Cell[1514492, 50024, 186, 6, 43, "EndNote",
   CellTags->"CT"]},
 "FV"->{
  Cell[1514681, 50032, 204, 5, 72, "EndNote",
   CellTags->"FV"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3426322660-2087744", 1517628, 50147},
 {"Info3426322661-8039262", 1517743, 50150},
 {"Info3426322661-4802284", 1517857, 50153},
 {"Info3426322661-3580866", 1517970, 50156},
 {"Info3426322665-2472452", 1518083, 50159},
 {"Info3426325327-2735175", 1518195, 50162},
 {"Info3426326367-7958013", 1518308, 50165},
 {"Info3362457282-3716175", 1518422, 50168},
 {"Info3426326367-8704009", 1518536, 50171},
 {"Info3362457286-9933190", 1518650, 50174},
 {"MT2", 1518745, 50177},
 {"CT", 1519760, 50208},
 {"FV", 1519836, 50211}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 263, 8, 367, "Title"],
Cell[856, 33, 203, 6, 156, "Subtitle"],
Cell[1062, 41, 126, 2, 56, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1213, 47, 240, 12, 140, "Section"],
Cell[1456, 61, 529, 16, 154, "Text"],
Cell[1988, 79, 23, 0, 57, "Input"],
Cell[2014, 81, 84, 2, 57, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2135, 88, 167, 4, 237, "Section"],
Cell[2305, 94, 161, 5, 55, "Text"],
Cell[2469, 101, 1903, 25, 781, "Text"],
Cell[4375, 128, 3455, 60, 1277, "Text"],
Cell[7833, 190, 701, 17, 254, "Text"],
Cell[8537, 209, 2179, 94, 426, "Text"],
Cell[10719, 305, 1051, 28, 289, "Text"],
Cell[11773, 335, 2052, 62, 490, "Text"],
Cell[13828, 399, 1379, 42, 354, "Text"],
Cell[15210, 443, 2448, 36, 1045, "Text"],
Cell[17661, 481, 1709, 43, 517, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19407, 529, 180, 6, 140, "Section"],
Cell[CellGroupData[{
Cell[19612, 539, 92, 2, 72, "Subsection"],
Cell[19707, 543, 3739, 67, 1408, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23483, 615, 208, 5, 72, "Subsection"],
Cell[23694, 622, 4080, 125, 949, "Text"],
Cell[27777, 749, 7964, 203, 2071, "Text"],
Cell[35744, 954, 246, 9, 88, "Text"],
Cell[35993, 965, 61648, 2095, 433, "Text"],
Cell[97644, 3062, 3254, 71, 1078, "Text"],
Cell[100901, 3135, 2417, 49, 716, "Text"],
Cell[103321, 3186, 3088, 72, 946, "Text"],
Cell[106412, 3260, 1171, 30, 352, "Text"],
Cell[107586, 3292, 833, 20, 287, "Text"],
Cell[108422, 3314, 1051, 28, 288, "Text"],
Cell[109476, 3344, 1162, 32, 320, "Text"],
Cell[110641, 3378, 2351, 46, 781, "Text"],
Cell[112995, 3426, 647, 10, 286, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113679, 3441, 104, 2, 72, "Subsection"],
Cell[113786, 3445, 4479, 148, 1046, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[118314, 3599, 192, 4, 139, "Section"],
Cell[118509, 3605, 726, 15, 253, "Text"],
Cell[119238, 3622, 1527, 32, 517, "Text"],
Cell[120768, 3656, 1243, 20, 484, "Text"],
Cell[122014, 3678, 1662, 42, 517, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123713, 3725, 125, 2, 75, "Section"],
Cell[123841, 3729, 636, 12, 253, "Text"],
Cell[CellGroupData[{
Cell[124502, 3745, 136, 2, 72, "Subsection"],
Cell[124641, 3749, 5346, 155, 1346, "Text"],
Cell[129990, 3906, 87, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[130102, 3912, 465, 11, 38, "Input",
 CellOpen->False],
Cell[130570, 3925, 3913, 106, 657, "Output"]
}, Open  ]],
Cell[134498, 4034, 445, 15, 121, "Text"],
Cell[134946, 4051, 113, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[135084, 4057, 383, 9, 38, "Input",
 CellOpen->False],
Cell[135470, 4068, 2996, 83, 492, "Output"]
}, Open  ]],
Cell[138481, 4154, 731, 23, 220, "Text"],
Cell[139215, 4179, 123, 3, 54, "Text"],
Cell[CellGroupData[{
Cell[139363, 4186, 45, 1, 57, "Input"],
Cell[139411, 4189, 3085, 44, 444, "Print",
 CellTags->"Info3426322660-2087744"]
}, Open  ]],
Cell[142511, 4236, 385, 9, 154, "Text"],
Cell[142899, 4247, 133, 3, 54, "Text"],
Cell[CellGroupData[{
Cell[143057, 4254, 184, 7, 38, "Input",
 CellOpen->False],
Cell[143244, 4263, 179, 5, 57, "Output"],
Cell[CellGroupData[{
Cell[143448, 4272, 672, 10, 213, "Print",
 CellTags->"Info3426322661-8039262"],
Cell[144123, 4284, 398, 6, 147, "Print",
 CellTags->"Info3426322661-4802284"]
}, Open  ]]
}, Open  ]],
Cell[144548, 4294, 234, 10, 88, "Text"],
Cell[144785, 4306, 391, 9, 154, "Text"],
Cell[145179, 4317, 203, 6, 86, "Text"],
Cell[CellGroupData[{
Cell[145407, 4327, 103, 5, 38, "Input",
 CellOpen->False],
Cell[145513, 4334, 645, 18, 43, "Print"],
Cell[146161, 4354, 132, 4, 57, "Output"],
Cell[146296, 4360, 421, 6, 180, "Print",
 CellTags->"Info3426322661-3580866"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[146766, 4372, 107, 2, 72, "Subsection"],
Cell[146876, 4376, 447, 8, 187, "Text"],
Cell[CellGroupData[{
Cell[147348, 4388, 178, 7, 54, "Subsubsection"],
Cell[147529, 4397, 783, 24, 220, "Text"],
Cell[148315, 4423, 875, 27, 126, "Input",
 Evaluatable->False],
Cell[149193, 4452, 181, 7, 56, "Text"],
Cell[CellGroupData[{
Cell[149399, 4463, 608, 19, 38, "Input",
 CellOpen->False],
Cell[150010, 4484, 1967, 53, 202, "Output"]
}, Open  ]],
Cell[151992, 4540, 370, 12, 121, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152399, 4557, 179, 7, 54, "Subsubsection"],
Cell[152581, 4566, 719, 21, 187, "Text"],
Cell[153303, 4589, 4413, 108, 602, "Input",
 Evaluatable->False],
Cell[157719, 4699, 522, 19, 154, "Text"],
Cell[158244, 4720, 182, 7, 56, "Text"],
Cell[CellGroupData[{
Cell[158451, 4731, 2563, 96, 38, "Input",
 CellOpen->False],
Cell[161017, 4829, 6954, 135, 946, "Output"]
}, Open  ]],
Cell[167986, 4967, 167, 4, 88, "Text"],
Cell[168156, 4973, 182, 7, 56, "Text"],
Cell[CellGroupData[{
Cell[168363, 4984, 2920, 108, 38, "Input",
 CellOpen->False],
Cell[171286, 5094, 5776, 112, 389, "Output"]
}, Open  ]],
Cell[177077, 5209, 705, 15, 286, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177819, 5229, 185, 7, 54, "Subsubsection"],
Cell[178007, 5238, 706, 15, 253, "Text"],
Cell[178716, 5255, 4297, 125, 381, "Input",
 Evaluatable->False],
Cell[183016, 5382, 475, 11, 154, "Text"],
Cell[183494, 5395, 176, 7, 56, "Text"],
Cell[CellGroupData[{
Cell[183695, 5406, 2071, 64, 38, "Input",
 CellOpen->False],
Cell[185769, 5472, 16348, 454, 754, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[202166, 5932, 180, 7, 54, "Subsubsection"],
Cell[202349, 5941, 2199, 68, 418, "Text"],
Cell[204551, 6011, 9066, 247, 908, "Input",
 Evaluatable->False],
Cell[213620, 6260, 1532, 47, 253, "Text"],
Cell[215155, 6309, 175, 5, 54, "Text"],
Cell[CellGroupData[{
Cell[215355, 6318, 1529, 52, 38, "Input",
 CellOpen->False],
Cell[216887, 6372, 3122, 57, 494, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220046, 6434, 48, 1, 57, "Input"],
Cell[220097, 6437, 193, 3, 80, "Print",
 CellTags->"Info3426322665-2472452"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[220339, 6446, 180, 7, 54, "Subsubsection"],
Cell[220522, 6455, 950, 19, 287, "Text"],
Cell[221475, 6476, 114, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[221614, 6482, 11117, 346, 38, "Input",
 CellOpen->False],
Cell[232734, 6830, 3562, 69, 423, "Output"]
}, Open  ]],
Cell[236311, 6902, 313, 8, 54, "Text"],
Cell[CellGroupData[{
Cell[236649, 6914, 3089, 102, 38, "Input",
 CellOpen->False],
Cell[239741, 7018, 1739, 32, 219, "Output"]
}, Open  ]],
Cell[241495, 7053, 114, 2, 54, "Text"],
Cell[241612, 7057, 376, 8, 121, "Text"],
Cell[241991, 7067, 2164, 62, 194, "Input",
 Evaluatable->False],
Cell[244158, 7131, 297, 11, 88, "Text"],
Cell[244458, 7144, 1290, 40, 160, "Input",
 Evaluatable->False],
Cell[245751, 7186, 34, 0, 55, "Text"],
Cell[CellGroupData[{
Cell[245810, 7190, 1730, 51, 194, "Input"],
Cell[247543, 7243, 35, 0, 57, "Output"]
}, Open  ]],
Cell[247593, 7246, 72, 0, 55, "Text"],
Cell[CellGroupData[{
Cell[247690, 7250, 2133, 60, 194, "Input"],
Cell[249826, 7312, 35, 0, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[249910, 7318, 178, 6, 54, "Subsubsection"],
Cell[250091, 7326, 707, 11, 220, "Text"],
Cell[250801, 7339, 693, 16, 187, "Text"],
Cell[251497, 7357, 127, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[251649, 7365, 310, 7, 38, "Input",
 CellOpen->False],
Cell[251962, 7374, 5395, 156, 317, "Output"]
}, Open  ]],
Cell[257372, 7533, 522, 15, 122, "Text"],
Cell[CellGroupData[{
Cell[257919, 7552, 430, 14, 57, "Input"],
Cell[258352, 7568, 3067, 92, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[261456, 7665, 355, 11, 92, "Input"],
Cell[261814, 7678, 47, 0, 82, "Output"],
Cell[261864, 7680, 41, 0, 82, "Output"]
}, Open  ]],
Cell[261920, 7683, 368, 10, 121, "Text"],
Cell[CellGroupData[{
Cell[262313, 7697, 420, 13, 92, "Input"],
Cell[262736, 7712, 196, 6, 82, "Output"]
}, Open  ]],
Cell[262947, 7721, 922, 26, 220, "Text"],
Cell[263872, 7749, 136, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[264033, 7757, 697, 20, 38, "Input",
 CellOpen->False],
Cell[264733, 7779, 2849, 81, 502, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[267631, 7866, 164, 4, 86, "Subsubsection"],
Cell[267798, 7872, 1100, 24, 385, "Text"],
Cell[268901, 7898, 107, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[269033, 7904, 1121, 30, 38, "Input",
 CellOpen->False],
Cell[270157, 7936, 3698, 107, 737, "Output"]
}, Open  ]],
Cell[273870, 8046, 873, 17, 286, "Text"],
Cell[274746, 8065, 107, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[274878, 8071, 7053, 204, 38, "Input",
 CellOpen->False],
Cell[281934, 8277, 2041, 32, 1044, "Output"]
}, Open  ]],
Cell[283990, 8312, 297, 6, 121, "Text"],
Cell[284290, 8320, 945, 14, 319, "Text"],
Cell[285238, 8336, 99, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[285362, 8342, 3452, 86, 38, "Input",
 CellOpen->False],
Cell[288817, 8430, 1153, 17, 636, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[290031, 8454, 117, 2, 72, "Subsection"],
Cell[290151, 8458, 1808, 51, 452, "Text"],
Cell[291962, 8511, 109, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[292096, 8517, 648, 14, 38, "Input",
 CellOpen->False],
Cell[292747, 8533, 1397, 30, 423, "Output"]
}, Open  ]],
Cell[294159, 8566, 1023, 26, 319, "Text"],
Cell[295185, 8594, 120, 3, 54, "Text",
 Evaluatable->False],
Cell[295308, 8599, 10834, 264, 1166, "Input",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[306191, 8869, 129, 2, 139, "Section"],
Cell[306323, 8873, 788, 14, 286, "Text"],
Cell[CellGroupData[{
Cell[307136, 8891, 109, 2, 72, "Subsection"],
Cell[307248, 8895, 915, 20, 319, "Text"],
Cell[308166, 8917, 709, 19, 220, "Text"],
Cell[308878, 8938, 113, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[309016, 8944, 874, 23, 38, "Input",
 CellOpen->False],
Cell[309893, 8969, 2171, 64, 351, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312101, 9038, 51, 1, 57, "Input"],
Cell[312155, 9041, 288, 5, 147, "Print",
 CellTags->"Info3426325327-2735175"]
}, Open  ]],
Cell[312458, 9049, 1316, 30, 418, "Text"],
Cell[313777, 9081, 110, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[313912, 9087, 156, 5, 144, "Input"],
Cell[314071, 9094, 5219, 142, 366, "Output"],
Cell[319293, 9238, 3032, 94, 436, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322362, 9337, 134, 4, 115, "Input"],
Cell[322499, 9343, 1095, 35, 140, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323631, 9383, 136, 4, 115, "Input"],
Cell[323770, 9389, 1089, 35, 140, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[324896, 9429, 138, 4, 115, "Input"],
Cell[325037, 9435, 1089, 35, 140, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326163, 9475, 174, 5, 144, "Input"],
Cell[326340, 9482, 5746, 158, 328, "Output"],
Cell[332089, 9642, 3366, 100, 601, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335492, 9747, 205, 5, 115, "Input"],
Cell[335700, 9754, 1753, 51, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337490, 9810, 205, 5, 115, "Input"],
Cell[337698, 9817, 1852, 55, 153, "Output"]
}, Open  ]],
Cell[339565, 9875, 618, 15, 187, "Text"],
Cell[340186, 9892, 107, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[340318, 9898, 355, 8, 38, "Input",
 CellOpen->False],
Cell[340676, 9908, 1005, 25, 262, "Output"]
}, Open  ]],
Cell[341696, 9936, 149, 4, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341882, 9945, 102, 2, 72, "Subsection"],
Cell[341987, 9949, 2118, 31, 847, "Text"],
Cell[344108, 9982, 105, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[344238, 9988, 5153, 169, 38, "Input",
 CellOpen->False],
Cell[349394, 10159, 19128, 526, 3154, "Output"]
}, Open  ]],
Cell[368537, 10688, 390, 7, 187, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[368964, 10700, 239, 10, 72, "Subsection"],
Cell[369206, 10712, 769, 13, 286, "Text"],
Cell[369978, 10727, 377, 9, 154, "Text"],
Cell[370358, 10738, 523, 9, 220, "Text"],
Cell[370884, 10749, 563, 9, 220, "Text"],
Cell[371450, 10760, 950, 16, 319, "Text"],
Cell[372403, 10778, 689, 16, 220, "Text"],
Cell[373095, 10796, 700, 15, 286, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[373832, 10816, 128, 2, 72, "Subsection"],
Cell[373963, 10820, 784, 20, 253, "Text"],
Cell[374750, 10842, 97, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[374872, 10848, 3862, 147, 38, "Input",
 CellOpen->False],
Cell[378737, 10997, 6681, 156, 569, "Output"]
}, Open  ]],
Cell[385433, 11156, 1288, 24, 451, "Text"],
Cell[386724, 11182, 110, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[386859, 11188, 378, 12, 38, "Input",
 CellOpen->False],
Cell[387240, 11202, 5909, 166, 752, "Output"]
}, Open  ]],
Cell[393164, 11371, 388, 7, 187, "Text"],
Cell[393555, 11380, 318, 6, 154, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[393922, 11392, 97, 2, 139, "Section"],
Cell[394022, 11396, 1532, 38, 323, "Text"],
Cell[CellGroupData[{
Cell[395579, 11438, 125, 2, 72, "Subsection"],
Cell[395707, 11442, 2485, 44, 716, "Text"],
Cell[398195, 11488, 92, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[398312, 11494, 1669, 34, 330, "Input"],
Cell[399984, 11530, 3944, 89, 693, "Output"]
}, Open  ]],
Cell[403943, 11622, 663, 17, 154, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[404643, 11644, 120, 2, 72, "Subsection"],
Cell[404766, 11648, 1011, 31, 253, "Text"],
Cell[405780, 11681, 405, 11, 154, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406222, 11697, 131, 2, 72, "Subsection"],
Cell[406356, 11701, 353, 7, 154, "Text"],
Cell[406712, 11710, 121, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[406858, 11716, 2356, 88, 38, "Input",
 CellOpen->False],
Cell[409217, 11806, 11186, 303, 636, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[420452, 12115, 119, 2, 72, "Subsection"],
Cell[420574, 12119, 754, 16, 253, "Text"],
Cell[CellGroupData[{
Cell[421353, 12139, 174, 3, 54, "Subsubsection"],
Cell[CellGroupData[{
Cell[421552, 12146, 3730, 99, 38, "Input",
 CellOpen->False],
Cell[425285, 12247, 4161, 104, 621, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[429507, 12358, 134, 2, 72, "Subsection"],
Cell[429644, 12362, 3211, 100, 541, "Text"],
Cell[432858, 12464, 91, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[432974, 12470, 74, 2, 57, "Input"],
Cell[CellGroupData[{
Cell[433073, 12476, 280, 4, 147, "Print",
 CellTags->"Info3426326367-7958013"],
Cell[433356, 12482, 322, 6, 146, "Print",
 CellTags->"Info3362457282-3716175"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[433727, 12494, 74, 2, 57, "Input"],
Cell[CellGroupData[{
Cell[433826, 12500, 276, 4, 147, "Print",
 CellTags->"Info3426326367-8704009"],
Cell[434105, 12506, 318, 6, 146, "Print",
 CellTags->"Info3362457286-9933190"]
}, Open  ]]
}, Open  ]],
Cell[434450, 12516, 365, 13, 125, "Text"],
Cell[434818, 12531, 94, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[434937, 12537, 2389, 94, 215, "Input"],
Cell[437329, 12633, 28807, 480, 488, "Output"]
}, Open  ]],
Cell[466151, 13116, 726, 23, 38, "Input",
 CellOpen->False],
Cell[466880, 13141, 104, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[467009, 13147, 2450, 98, 240, "Input"],
Cell[469462, 13247, 28452, 473, 488, "Output"]
}, Open  ]],
Cell[497929, 13723, 1053, 35, 253, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[499019, 13763, 125, 2, 72, "Subsection"],
Cell[499147, 13767, 2716, 99, 436, "Text"],
Cell[501866, 13868, 1784, 38, 584, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[503699, 13912, 93, 2, 139, "Section"],
Cell[503795, 13916, 710, 13, 286, "Text"],
Cell[CellGroupData[{
Cell[504530, 13933, 201, 7, 72, "Subsection"],
Cell[504734, 13942, 409, 7, 187, "Text"],
Cell[505146, 13951, 522, 9, 187, "Text"],
Cell[505671, 13962, 139, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[505835, 13970, 1438, 50, 38, "Input",
 CellOpen->False],
Cell[507276, 14022, 2595, 54, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[509908, 14081, 2594, 82, 38, "Input",
 CellOpen->False],
Cell[512505, 14165, 2492, 65, 275, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[515046, 14236, 189, 7, 72, "Subsection"],
Cell[515238, 14245, 2875, 93, 587, "Text"],
Cell[CellGroupData[{
Cell[518138, 14342, 113, 2, 54, "Subsubsection"],
Cell[518254, 14346, 146, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[518425, 14354, 1036, 29, 38, "Input",
 CellOpen->False],
Cell[519464, 14385, 1087, 28, 269, "Output"]
}, Open  ]],
Cell[520566, 14416, 339, 6, 154, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[520942, 14427, 113, 2, 54, "Subsubsection"],
Cell[521058, 14431, 2336, 65, 583, "Text"],
Cell[523397, 14498, 136, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[523558, 14506, 2570, 76, 38, "Input",
 Evaluatable->False,
 CellOpen->False],
Cell[526131, 14584, 1642, 53, 196, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[527810, 14642, 3669, 98, 245, "Input",
 Evaluatable->False],
Cell[531482, 14742, 138, 4, 57, "Output"]
}, Open  ]],
Cell[531635, 14749, 3387, 97, 245, "Input",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[535059, 14851, 143, 3, 54, "Subsubsection"],
Cell[535205, 14856, 3351, 110, 541, "Text"],
Cell[538559, 14968, 88, 1, 55, "Text"],
Cell[CellGroupData[{
Cell[538672, 14973, 1612, 38, 38, "Input",
 CellOpen->False],
Cell[540287, 15013, 2640, 64, 480, "Output"]
}, Open  ]],
Cell[542942, 15080, 118, 3, 55, "Text"],
Cell[CellGroupData[{
Cell[543085, 15087, 1685, 40, 38, "Input",
 CellOpen->False],
Cell[544773, 15129, 2457, 61, 412, "Output"]
}, Open  ]],
Cell[547245, 15193, 982, 27, 255, "Text"],
Cell[548230, 15222, 90, 1, 55, "Text"],
Cell[CellGroupData[{
Cell[548345, 15227, 2430, 66, 38, "Input",
 CellOpen->False],
Cell[550778, 15295, 4398, 96, 568, "Output"]
}, Open  ]],
Cell[555191, 15394, 242, 7, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555470, 15406, 153, 4, 54, "Subsubsection"],
Cell[555626, 15412, 1375, 35, 399, "Text"],
Cell[557004, 15449, 131, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[557160, 15457, 455, 12, 38, "Input",
 CellOpen->False],
Cell[557618, 15471, 490, 13, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[558145, 15489, 2033, 57, 38, "Input",
 CellOpen->False],
Cell[560181, 15548, 1595, 33, 257, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[561837, 15588, 130, 2, 72, "Subsection"],
Cell[561970, 15592, 1836, 42, 583, "Text"],
Cell[563809, 15636, 159, 5, 86, "Text"],
Cell[CellGroupData[{
Cell[563993, 15645, 593, 12, 38, "Input",
 CellOpen->False],
Cell[564589, 15659, 4638, 137, 789, "Output"]
}, Open  ]],
Cell[569242, 15799, 340, 6, 154, "Text"],
Cell[569585, 15807, 117, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[569727, 15813, 1362, 29, 38, "Input",
 CellOpen->False],
Cell[571092, 15844, 11417, 316, 1588, "Output"]
}, Open  ]],
Cell[582524, 16163, 164, 4, 88, "Text"],
Cell[582691, 16169, 106, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[582822, 16175, 1334, 30, 38, "Input",
 CellOpen->False],
Cell[584159, 16207, 12183, 371, 1761, "Output"]
}, Open  ]],
Cell[596357, 16581, 578, 11, 220, "Text"],
Cell[596938, 16594, 2286, 56, 715, "Text"],
Cell[599227, 16652, 204, 9, 56, "Text"],
Cell[CellGroupData[{
Cell[599456, 16665, 3809, 99, 38, "Input",
 CellOpen->False],
Cell[603268, 16766, 10750, 320, 1472, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[614067, 17092, 258, 10, 106, "Subsection"],
Cell[614328, 17104, 503, 9, 220, "Text"],
Cell[614834, 17115, 112, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[614971, 17121, 1558, 43, 38, "Input",
 CellOpen->False],
Cell[616532, 17166, 1645, 46, 364, "Output"]
}, Open  ]],
Cell[618192, 17215, 2031, 40, 715, "Text"],
Cell[CellGroupData[{
Cell[620248, 17259, 3637, 120, 38, "Input",
 CellOpen->False],
Cell[623888, 17381, 4414, 95, 602, "Output"]
}, Open  ]],
Cell[628317, 17479, 1193, 28, 352, "Text"],
Cell[629513, 17509, 188, 4, 88, "Text"],
Cell[629704, 17515, 532, 13, 187, "Text"],
Cell[630239, 17530, 179, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[630443, 17540, 8822, 316, 38, "Input",
 CellOpen->False],
Cell[639268, 17858, 14557, 282, 942, "Output"]
}, Open  ]],
Cell[653840, 18143, 480, 8, 187, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[654357, 18156, 114, 2, 72, "Subsection"],
Cell[654474, 18160, 1241, 25, 385, "Text"],
Cell[655718, 18187, 150, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[655893, 18197, 2762, 81, 38, "Input",
 CellOpen->False],
Cell[658658, 18280, 4440, 127, 698, "Output"]
}, Open  ]],
Cell[663113, 18410, 112, 4, 55, "Text"],
Cell[CellGroupData[{
Cell[663250, 18418, 692, 22, 38, "Input",
 CellOpen->False],
Cell[663945, 18442, 3703, 107, 277, "Output"]
}, Open  ]],
Cell[667663, 18552, 185, 4, 88, "Text"],
Cell[667851, 18558, 126, 4, 55, "Text"],
Cell[CellGroupData[{
Cell[668002, 18566, 258, 5, 92, "Input"],
Cell[668263, 18573, 2547, 78, 249, "Output"]
}, Open  ]],
Cell[670825, 18654, 954, 17, 286, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[671828, 18677, 103, 2, 139, "Section"],
Cell[671934, 18681, 218, 7, 88, "Text"],
Cell[CellGroupData[{
Cell[672177, 18692, 129, 2, 72, "Subsection"],
Cell[672309, 18696, 898, 14, 352, "Text"],
Cell[673210, 18712, 1255, 19, 286, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[674502, 18736, 112, 2, 72, "Subsection"],
Cell[674617, 18740, 170, 4, 88, "Text"],
Cell[674790, 18746, 369, 7, 154, "Text"],
Cell[675162, 18755, 163, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[675350, 18765, 408, 13, 56, "Input"],
Cell[675761, 18780, 485, 18, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[676283, 18803, 544, 15, 56, "Input"],
Cell[676830, 18820, 1002, 37, 92, "Output"]
}, Open  ]],
Cell[677847, 18860, 2350, 88, 254, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[680234, 18953, 149, 4, 72, "Subsection"],
Cell[680386, 18959, 152, 4, 88, "Text"],
Cell[680541, 18965, 77, 1, 55, "Text"],
Cell[680621, 18968, 1449, 48, 286, "Text"],
Cell[682073, 19018, 172, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[682270, 19028, 930, 27, 90, "Input"],
Cell[683203, 19057, 485, 18, 57, "Output"],
Cell[683691, 19077, 1002, 37, 92, "Output"]
}, Open  ]],
Cell[684708, 19117, 171, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[684904, 19127, 930, 27, 90, "Input"],
Cell[685837, 19156, 463, 17, 57, "Output"],
Cell[686303, 19175, 980, 36, 92, "Output"]
}, Open  ]],
Cell[687298, 19214, 680, 14, 286, "Text"],
Cell[687981, 19230, 169, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[688175, 19240, 1875, 53, 228, "Input"],
Cell[690053, 19295, 1637, 57, 126, "Output"],
Cell[691693, 19354, 1681, 59, 126, "Output"],
Cell[693377, 19415, 1681, 59, 126, "Output"]
}, Open  ]],
Cell[695073, 19477, 373, 7, 154, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[695483, 19489, 101, 2, 72, "Subsection"],
Cell[695587, 19493, 264, 5, 121, "Text"],
Cell[695854, 19500, 559, 14, 154, "Text"],
Cell[CellGroupData[{
Cell[696438, 19518, 1081, 31, 38, "Input",
 CellOpen->False],
Cell[697522, 19551, 4621, 148, 509, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[702182, 19704, 103, 2, 139, "Section"],
Cell[CellGroupData[{
Cell[702310, 19710, 86, 2, 75, "Section"],
Cell[702399, 19714, 426, 9, 154, "Text"],
Cell[CellGroupData[{
Cell[702850, 19727, 124, 2, 72, "Subsection"],
Cell[702977, 19731, 1687, 34, 583, "Text"],
Cell[704667, 19767, 156, 6, 55, "Text"],
Cell[704826, 19775, 55, 1, 58, "Input"],
Cell[CellGroupData[{
Cell[704906, 19780, 2830, 69, 663, "Input"],
Cell[707739, 19851, 5281, 163, 1084, "Output"]
}, Open  ]],
Cell[713035, 20017, 149, 6, 55, "Text"],
Cell[713187, 20025, 274, 7, 88, "Text"],
Cell[CellGroupData[{
Cell[713486, 20036, 740, 21, 38, "Input",
 CellOpen->False],
Cell[714229, 20059, 1052, 33, 223, "Output"]
}, Open  ]],
Cell[715296, 20095, 696, 17, 220, "Text"],
Cell[715995, 20114, 118, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[716138, 20120, 1776, 47, 38, "Input",
 CellOpen->False],
Cell[717917, 20169, 4792, 137, 1003, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[722758, 20312, 128, 2, 72, "Subsection"],
Cell[722889, 20316, 1098, 22, 385, "Text"],
Cell[723990, 20340, 148, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[724163, 20350, 249, 9, 38, "Input",
 CellOpen->False],
Cell[724415, 20361, 1605, 53, 244, "Output"]
}, Open  ]],
Cell[726035, 20417, 148, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[726208, 20427, 437, 13, 38, "Input",
 CellOpen->False],
Cell[726648, 20442, 2151, 72, 301, "Output"]
}, Open  ]],
Cell[728814, 20517, 148, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[728987, 20527, 467, 14, 38, "Input",
 CellOpen->False],
Cell[729457, 20543, 2078, 68, 301, "Output"]
}, Open  ]],
Cell[731550, 20614, 654, 10, 286, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[732241, 20629, 124, 2, 72, "Subsection"],
Cell[732368, 20633, 486, 8, 220, "Text"],
Cell[732857, 20643, 137, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[733019, 20653, 208, 6, 57, "Input"],
Cell[733230, 20661, 1969, 66, 336, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[735236, 20732, 689, 23, 108, "Input"],
Cell[735928, 20757, 1672, 54, 192, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[737637, 20816, 1643, 44, 38, "Input",
 CellOpen->False],
Cell[739283, 20862, 1319, 30, 281, "Output"],
Cell[740605, 20894, 651, 14, 161, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[741293, 20913, 1535, 45, 38, "Input",
 CellOpen->False],
Cell[742831, 20960, 848, 17, 189, "Output"]
}, Open  ]],
Cell[743694, 20980, 178, 6, 121, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[743909, 20991, 115, 2, 72, "Subsection"],
Cell[744027, 20995, 540, 8, 253, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[744616, 21009, 131, 2, 188, "Section"],
Cell[744750, 21013, 673, 12, 253, "Text"],
Cell[CellGroupData[{
Cell[745448, 21029, 103, 2, 72, "Subsection"],
Cell[745554, 21033, 662, 10, 286, "Text"],
Cell[746219, 21045, 2409, 67, 583, "Text"],
Cell[748631, 21114, 196, 7, 55, "Text"],
Cell[748830, 21123, 1826, 63, 268, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[750681, 21190, 1667, 51, 38, "Input",
 CellOpen->False],
Cell[752351, 21243, 1206, 36, 227, "Output"]
}, Open  ]],
Cell[753572, 21282, 1317, 39, 319, "Text"],
Cell[754892, 21323, 171, 6, 55, "Text"],
Cell[755066, 21331, 338, 8, 57, "Input"],
Cell[CellGroupData[{
Cell[755429, 21343, 7146, 269, 333, "Input"],
Cell[762578, 21614, 98, 2, 57, "Output"]
}, Open  ]],
Cell[762691, 21619, 1094, 37, 253, "Text"],
Cell[763788, 21658, 964, 16, 319, "Text"],
Cell[764755, 21676, 142, 6, 55, "Text"],
Cell[764900, 21684, 295, 9, 51, "Input"],
Cell[765198, 21695, 5782, 162, 871, "Input"],
Cell[770983, 21859, 170, 6, 55, "Text"],
Cell[771156, 21867, 1085, 31, 91, "Input"],
Cell[772244, 21900, 7752, 182, 484, "Input"],
Cell[779999, 22084, 619, 21, 124, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[780655, 22110, 155, 6, 72, "Subsection"],
Cell[780813, 22118, 1075, 21, 385, "Text"],
Cell[781891, 22141, 361, 14, 56, "Input"],
Cell[782255, 22157, 5350, 154, 489, "Input",
 Evaluatable->False],
Cell[787608, 22313, 9043, 212, 811, "Input"],
Cell[796654, 22527, 191, 4, 88, "Text"],
Cell[796848, 22533, 171, 6, 55, "Text"],
Cell[797022, 22541, 392, 13, 51, "Input"],
Cell[797417, 22556, 4226, 126, 462, "Input"],
Cell[801646, 22684, 5859, 133, 376, "Input"],
Cell[807508, 22819, 146, 6, 55, "Text"],
Cell[807657, 22827, 356, 11, 51, "Input"],
Cell[808016, 22840, 3980, 126, 405, "Input"],
Cell[811999, 22968, 5194, 127, 376, "Input"],
Cell[817196, 23097, 1280, 30, 418, "Text"],
Cell[818479, 23129, 938, 30, 913, "Text"],
Cell[819420, 23161, 381, 8, 154, "Text"],
Cell[CellGroupData[{
Cell[819826, 23173, 79, 1, 54, "Subsubsection"],
Cell[819908, 23176, 157, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[820090, 23184, 2796, 85, 38, "Input",
 CellOpen->False],
Cell[822889, 23271, 458, 8, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[823384, 23284, 2335, 73, 38, "Input",
 CellOpen->False],
Cell[825722, 23359, 290, 5, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[826049, 23369, 2318, 72, 38, "Input",
 CellOpen->False],
Cell[828370, 23443, 553, 9, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[828960, 23457, 2337, 73, 38, "Input",
 CellOpen->False],
Cell[831300, 23532, 354, 6, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[831691, 23543, 2333, 73, 38, "Input",
 CellOpen->False],
Cell[834027, 23618, 195, 4, 92, "Output"]
}, Open  ]],
Cell[834237, 23625, 49, 1, 55, "Text"],
Cell[834289, 23628, 458, 10, 220, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834784, 23643, 93, 1, 54, "Subsubsection"],
Cell[834880, 23646, 155, 4, 88, "Text"],
Cell[835038, 23652, 2973, 88, 38, "Input",
 CellOpen->False],
Cell[838014, 23742, 23, 0, 55, "Text"],
Cell[838040, 23744, 1407, 28, 228, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[839496, 23778, 129, 2, 72, "Subsection"],
Cell[839628, 23782, 1004, 15, 385, "Text"],
Cell[840635, 23799, 149, 6, 55, "Text"],
Cell[840787, 23807, 824, 23, 156, "Input"],
Cell[841614, 23832, 4696, 128, 326, "Input"],
Cell[846313, 23962, 758, 19, 253, "Text"],
Cell[847074, 23983, 164, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[847263, 23993, 224, 7, 57, "Input"],
Cell[847490, 24002, 1964, 67, 306, "Output"]
}, Open  ]],
Cell[849469, 24072, 1777, 57, 194, "Input"],
Cell[851249, 24131, 1214, 24, 418, "Text"],
Cell[852466, 24157, 186, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[852677, 24167, 712, 22, 142, "Input"],
Cell[853392, 24191, 4580, 158, 591, "Output"]
}, Open  ]],
Cell[857987, 24352, 6529, 207, 326, "Input",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[864553, 24564, 130, 2, 72, "Subsection"],
Cell[864686, 24568, 789, 20, 253, "Text"],
Cell[865478, 24590, 385, 16, 55, "Text"],
Cell[CellGroupData[{
Cell[865888, 24610, 1639, 45, 364, "Input"],
Cell[867530, 24657, 3581, 110, 799, "Output"]
}, Open  ]],
Cell[871126, 24770, 354, 8, 121, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[871517, 24783, 119, 2, 72, "Subsection"],
Cell[871639, 24787, 1034, 32, 257, "Text"],
Cell[CellGroupData[{
Cell[872698, 24823, 438, 17, 72, "Input"],
Cell[873139, 24842, 267, 11, 64, "Output"]
}, Open  ]],
Cell[873421, 24856, 232, 5, 121, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[873702, 24867, 114, 2, 139, "Section"],
Cell[873819, 24871, 8900, 303, 1119, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[882756, 25179, 91, 2, 139, "Section"],
Cell[882850, 25183, 555, 9, 220, "Text"],
Cell[883408, 25194, 1199, 27, 418, "Text"],
Cell[884610, 25223, 1483, 45, 378, "Text"],
Cell[886096, 25270, 963, 14, 385, "Text"],
Cell[887062, 25286, 186, 4, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[887285, 25295, 118, 2, 139, "Section"],
Cell[887406, 25299, 292, 8, 121, "Text"],
Cell[CellGroupData[{
Cell[887723, 25311, 110, 2, 72, "Subsection"],
Cell[887836, 25315, 605, 12, 253, "Text"],
Cell[CellGroupData[{
Cell[888466, 25331, 106, 3, 57, "Input"],
Cell[888575, 25336, 57, 1, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[888669, 25342, 4525, 94, 1282, "Input"],
Cell[893197, 25438, 3928, 72, 1758, "Output"]
}, Open  ]],
Cell[897140, 25513, 755, 20, 253, "Text"],
Cell[CellGroupData[{
Cell[897920, 25537, 4269, 112, 38, "Input",
 CellOpen->False],
Cell[902192, 25651, 2277, 49, 413, "Output"]
}, Open  ]],
Cell[904484, 25703, 119, 3, 55, "Text"],
Cell[CellGroupData[{
Cell[904628, 25710, 4317, 113, 38, "Input",
 CellOpen->False],
Cell[908948, 25825, 2321, 49, 413, "Output"]
}, Open  ]],
Cell[911284, 25877, 858, 31, 220, "Text"],
Cell[912145, 25910, 188, 6, 57, "Input"],
Cell[CellGroupData[{
Cell[912358, 25920, 1696, 39, 432, "Input"],
Cell[914057, 25961, 4408, 116, 874, "Output"]
}, Open  ]],
Cell[918480, 26080, 313, 6, 154, "Text"],
Cell[918796, 26088, 33, 0, 55, "Text"],
Cell[CellGroupData[{
Cell[918854, 26092, 2533, 83, 398, "Input"],
Cell[921390, 26177, 38, 0, 57, "Output"],
Cell[921431, 26179, 31, 0, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[921511, 26185, 149, 6, 72, "Subsection"],
Cell[921663, 26193, 691, 15, 286, "Text"],
Cell[922357, 26210, 120, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[922502, 26216, 1968, 60, 364, "Input"],
Cell[924473, 26278, 1486, 41, 360, "Output"]
}, Open  ]],
Cell[925974, 26322, 2188, 85, 418, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[928211, 26413, 150, 5, 139, "Section"],
Cell[928364, 26420, 574, 20, 155, "Text"],
Cell[CellGroupData[{
Cell[928963, 26444, 257, 7, 126, "Input"],
Cell[929223, 26453, 65, 1, 57, "Output"],
Cell[929291, 26456, 522, 15, 126, "Output"]
}, Open  ]],
Cell[929828, 26474, 313, 7, 121, "Text"],
Cell[CellGroupData[{
Cell[930166, 26485, 465, 15, 92, "Input"],
Cell[930634, 26502, 440, 8, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[931111, 26515, 645, 20, 126, "Input"],
Cell[931759, 26537, 750, 18, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[932546, 26560, 1066, 29, 194, "Input"],
Cell[933615, 26591, 489, 12, 81, "Output"],
Cell[934107, 26605, 440, 8, 92, "Output"]
}, Open  ]],
Cell[934562, 26616, 87, 1, 55, "Text"],
Cell[CellGroupData[{
Cell[934674, 26621, 847, 26, 262, "Input"],
Cell[935524, 26649, 64, 1, 57, "Output"],
Cell[935591, 26652, 484, 14, 126, "Output"],
Cell[936078, 26668, 440, 8, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[936555, 26681, 648, 21, 126, "Input"],
Cell[937206, 26704, 489, 12, 81, "Output"],
Cell[937698, 26718, 440, 8, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[938175, 26731, 1471, 46, 364, "Input"],
Cell[939649, 26779, 66, 1, 57, "Output"],
Cell[939718, 26782, 512, 15, 126, "Output"],
Cell[940233, 26799, 440, 8, 92, "Output"],
Cell[940676, 26809, 489, 12, 81, "Output"],
Cell[941168, 26823, 440, 8, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[941645, 26836, 1470, 46, 364, "Input"],
Cell[943118, 26884, 65, 1, 57, "Output"],
Cell[943186, 26887, 438, 13, 92, "Output"],
Cell[943627, 26902, 440, 8, 92, "Output"],
Cell[944070, 26912, 489, 12, 81, "Output"],
Cell[944562, 26926, 440, 8, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[945039, 26939, 1468, 46, 364, "Input"],
Cell[946510, 26987, 63, 1, 57, "Output"],
Cell[946576, 26990, 464, 14, 92, "Output"],
Cell[947043, 27006, 440, 8, 92, "Output"],
Cell[947486, 27016, 489, 12, 81, "Output"],
Cell[947978, 27030, 440, 8, 92, "Output"]
}, Open  ]],
Cell[948433, 27041, 58, 1, 55, "Text"],
Cell[CellGroupData[{
Cell[948516, 27046, 311, 10, 92, "Input"],
Cell[948830, 27058, 58, 0, 43, "Print"],
Cell[948891, 27060, 40, 0, 57, "Output"],
Cell[948934, 27062, 447, 14, 135, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[949430, 27082, 195, 8, 139, "Section"],
Cell[949628, 27092, 636, 19, 187, "Text"],
Cell[950267, 27113, 829, 29, 115, "Input",
 Evaluatable->False],
Cell[951099, 27144, 105, 3, 56, "Input"],
Cell[951207, 27149, 510, 15, 154, "Text"],
Cell[951720, 27166, 82, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[951827, 27172, 1395, 41, 38, "Input",
 CellOpen->False],
Cell[953225, 27215, 1419, 29, 330, "Output"]
}, Open  ]],
Cell[954659, 27247, 92, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[954776, 27253, 8605, 273, 38, "Input",
 CellOpen->False],
Cell[963384, 27528, 17758, 311, 780, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[981191, 27845, 120, 2, 139, "Section"],
Cell[981314, 27849, 239, 7, 88, "Text"],
Cell[CellGroupData[{
Cell[981578, 27860, 180, 6, 72, "Subsection"],
Cell[981761, 27868, 1505, 33, 454, "Text"],
Cell[983269, 27903, 92, 2, 54, "Text"],
Cell[983364, 27907, 2236, 71, 187, "Input"],
Cell[985603, 27980, 93, 1, 55, "Text"],
Cell[985699, 27983, 19840, 524, 431, "Output"],
Cell[1005542, 28509, 4971, 138, 123, "Input",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[1010550, 28652, 109, 2, 72, "Subsection"],
Cell[1010662, 28656, 81, 2, 56, "Input"],
Cell[1010746, 28660, 2346, 76, 485, "Text"],
Cell[CellGroupData[{
Cell[1013117, 28740, 85, 1, 54, "Subsubsection"],
Cell[CellGroupData[{
Cell[1013227, 28745, 525, 15, 126, "Input"],
Cell[1013755, 28762, 2418, 73, 355, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1016210, 28840, 160, 5, 57, "Input"],
Cell[CellGroupData[{
Cell[1016395, 28849, 471, 15, 48, "Print"],
Cell[1016869, 28866, 747, 24, 86, "Print"],
Cell[1017619, 28892, 707, 23, 86, "Print"],
Cell[1018329, 28917, 707, 23, 86, "Print"],
Cell[1019039, 28942, 66, 0, 43, "Print"]
}, Open  ]],
Cell[1019120, 28945, 35, 0, 57, "Output"]
}, Open  ]],
Cell[1019170, 28948, 117, 3, 55, "Text"],
Cell[CellGroupData[{
Cell[1019312, 28955, 1267, 40, 102, "Input"],
Cell[1020582, 28997, 28, 0, 57, "Output"]
}, Open  ]],
Cell[1020625, 29000, 517, 12, 187, "Text"],
Cell[1021145, 29014, 1708, 52, 217, "Input",
 Evaluatable->False],
Cell[1022856, 29068, 396, 12, 121, "Text"],
Cell[1023255, 29082, 5059, 152, 594, "Input",
 Evaluatable->False],
Cell[1028317, 29236, 268, 5, 121, "Text"],
Cell[1028588, 29243, 126, 3, 56, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1028763, 29252, 180, 5, 72, "Subsection"],
Cell[1028946, 29259, 443, 9, 154, "Text"],
Cell[1029392, 29270, 78, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1029495, 29276, 80, 1, 57, "Input"],
Cell[1029578, 29279, 1034, 31, 106, "Output"]
}, Open  ]],
Cell[1030627, 29313, 274, 10, 88, "Text"],
Cell[1030904, 29325, 165, 5, 86, "Input",
 Evaluatable->False],
Cell[1031072, 29332, 70, 1, 55, "Text"],
Cell[CellGroupData[{
Cell[1031167, 29337, 116, 4, 86, "Input"],
Cell[1031286, 29343, 2429, 60, 359, "Output"]
}, Open  ]],
Cell[1033730, 29406, 316, 7, 121, "Text"],
Cell[1034049, 29415, 239, 6, 115, "Input",
 Evaluatable->False],
Cell[1034291, 29423, 484, 12, 121, "Text"],
Cell[CellGroupData[{
Cell[1034800, 29439, 153, 4, 115, "Input"],
Cell[1034956, 29445, 1459, 45, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1036452, 29495, 150, 4, 86, "Input"],
Cell[1036605, 29501, 1782, 54, 174, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1038424, 29560, 150, 4, 86, "Input"],
Cell[1038577, 29566, 1828, 56, 174, "Output"]
}, Open  ]],
Cell[1040420, 29625, 84, 1, 55, "Text"],
Cell[CellGroupData[{
Cell[1040529, 29630, 154, 4, 86, "Input"],
Cell[1040686, 29636, 1426, 43, 174, "Output"]
}, Open  ]],
Cell[1042127, 29682, 187, 4, 86, "Input"],
Cell[1042317, 29688, 224, 5, 121, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1042578, 29698, 159, 6, 72, "Subsection"],
Cell[1042740, 29706, 598, 15, 187, "Text"],
Cell[1043341, 29723, 684, 14, 253, "Text"],
Cell[1044028, 29739, 1360, 38, 353, "Text"],
Cell[1045391, 29779, 689, 19, 220, "Text"],
Cell[1046083, 29800, 82, 1, 55, "Text"],
Cell[CellGroupData[{
Cell[1046190, 29805, 64, 1, 57, "Input"],
Cell[1046257, 29808, 861, 28, 138, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1047155, 29841, 96, 1, 57, "Input"],
Cell[1047254, 29844, 364, 9, 92, "Output"]
}, Open  ]],
Cell[1047633, 29856, 201, 6, 88, "Text"],
Cell[1047837, 29864, 105, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1047967, 29870, 56, 1, 57, "Input"],
Cell[1048026, 29873, 2375, 74, 391, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1050438, 29952, 74, 1, 57, "Input"],
Cell[1050515, 29955, 915, 31, 100, "Output"]
}, Open  ]],
Cell[1051445, 29989, 367, 7, 154, "Text"],
Cell[CellGroupData[{
Cell[1051837, 30000, 93, 2, 57, "Input"],
Cell[1051933, 30004, 522, 16, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1052492, 30025, 116, 3, 86, "Input"],
Cell[1052611, 30030, 1212, 38, 136, "Output"]
}, Open  ]],
Cell[1053838, 30071, 183, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[1054046, 30079, 103, 4, 86, "Input"],
Cell[1054152, 30085, 689, 20, 95, "Output"],
Cell[1054844, 30107, 290, 10, 59, "Output"]
}, Open  ]],
Cell[1055149, 30120, 544, 18, 89, "Text"],
Cell[CellGroupData[{
Cell[1055718, 30142, 103, 4, 86, "Input"],
Cell[1055824, 30148, 689, 20, 95, "Output"],
Cell[1056516, 30170, 290, 10, 59, "Output"]
}, Open  ]],
Cell[1056821, 30183, 259, 5, 121, "Text"],
Cell[CellGroupData[{
Cell[1057105, 30192, 93, 1, 54, "Subsubsection"],
Cell[CellGroupData[{
Cell[1057223, 30197, 145, 4, 86, "Input"],
Cell[1057371, 30203, 1664, 49, 176, "Output"]
}, Open  ]],
Cell[1059050, 30255, 177, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[1059252, 30265, 210, 5, 115, "Input"],
Cell[1059465, 30272, 449, 14, 100, "Output"]
}, Open  ]],
Cell[1059929, 30289, 137, 4, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1060103, 30298, 123, 2, 54, "Subsubsection"],
Cell[CellGroupData[{
Cell[1060251, 30304, 279, 6, 173, "Input"],
Cell[1060533, 30312, 4566, 123, 430, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1065136, 30440, 280, 6, 144, "Input"],
Cell[1065419, 30448, 4565, 123, 430, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1070021, 30576, 112, 3, 86, "Input"],
Cell[1070136, 30581, 634, 18, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1070807, 30604, 238, 6, 144, "Input"],
Cell[1071048, 30612, 6027, 156, 573, "Output"]
}, Open  ]],
Cell[1077090, 30771, 460, 12, 154, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1077587, 30788, 73, 1, 54, "Subsubsection"],
Cell[1077663, 30791, 543, 9, 220, "Text"],
Cell[CellGroupData[{
Cell[1078231, 30804, 83, 4, 86, "Input"],
Cell[1078317, 30810, 2423, 68, 390, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1080813, 30886, 121, 2, 139, "Section"],
Cell[1080937, 30890, 503, 17, 121, "Text"],
Cell[1081443, 30909, 4428, 155, 568, "Text"],
Cell[1085874, 31066, 1538, 49, 319, "Text"],
Cell[1087415, 31117, 117, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1087557, 31123, 2565, 76, 442, "Input"],
Cell[1090125, 31201, 308, 5, 160, "Output"]
}, Open  ]],
Cell[1090448, 31209, 2535, 83, 460, "Text"],
Cell[1092986, 31294, 137, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[1093148, 31302, 1768, 53, 212, "Input"],
Cell[1094919, 31357, 31820, 1603, 372, 23127, 1457, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1126754, 32963, 196, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[1126975, 32971, 1913, 57, 280, "Input"],
Cell[1128891, 33030, 40393, 2138, 372, 31794, 1994, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1169299, 35171, 110, 3, 55, "Text"],
Cell[CellGroupData[{
Cell[1169434, 35178, 2605, 78, 352, "Input"],
Cell[1172042, 35258, 44178, 2247, 372, 32430, 2051, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1216257, 37510, 2453, 73, 283, "Input"],
Cell[1218713, 37585, 46313, 2418, 372, 34939, 2228, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1265041, 40006, 1157, 39, 225, "Text"],
Cell[1266201, 40047, 156, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[1266382, 40055, 2620, 78, 352, "Input"],
Cell[1269005, 40135, 37557, 2121, 372, 32405, 2033, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1306599, 42261, 2636, 78, 352, "Input"],
Cell[1309238, 42341, 37231, 2122, 372, 32523, 2041, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1346484, 44466, 1186, 32, 296, "Text"],
Cell[1347673, 44500, 477, 20, 54, "Text"],
Cell[CellGroupData[{
Cell[1348175, 44524, 1728, 55, 38, "Input",
 CellOpen->False],
Cell[1349906, 44581, 13921, 577, 372, 7515, 468, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1363842, 45161, 1961, 67, 305, "Text"],
Cell[1365806, 45230, 254, 10, 54, "Text"],
Cell[CellGroupData[{
Cell[1366085, 45244, 2797, 87, 38, "Input",
 CellOpen->False],
Cell[1368885, 45333, 17635, 843, 372, 12126, 749, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1386535, 46179, 404, 16, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1386976, 46200, 109, 2, 139, "Section"],
Cell[1387088, 46204, 1155, 27, 287, "Text"],
Cell[CellGroupData[{
Cell[1388268, 46235, 104, 2, 72, "Subsection"],
Cell[1388375, 46239, 813, 15, 286, "Text"],
Cell[1389191, 46256, 122, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1389338, 46262, 287, 10, 56, "Input"],
Cell[1389628, 46274, 149, 5, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1389814, 46284, 370, 12, 56, "Input"],
Cell[1390187, 46298, 244, 8, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1390468, 46311, 370, 12, 56, "Input"],
Cell[1390841, 46325, 244, 8, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1391122, 46338, 371, 12, 56, "Input"],
Cell[1391496, 46352, 244, 8, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1391777, 46365, 553, 18, 90, "Input"],
Cell[1392333, 46385, 454, 13, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1392824, 46403, 895, 27, 123, "Input"],
Cell[1393722, 46432, 826, 22, 100, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1394597, 46460, 101, 2, 72, "Subsection"],
Cell[1394701, 46464, 743, 16, 286, "Text"],
Cell[1395447, 46482, 110, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1395582, 46488, 1410, 40, 255, "Input"],
Cell[1396995, 46530, 2329, 63, 364, "Output"]
}, Open  ]],
Cell[1399339, 46596, 416, 9, 154, "Text"],
Cell[1399758, 46607, 110, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1399893, 46613, 2563, 66, 453, "Input"],
Cell[1402459, 46681, 3496, 84, 493, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1405992, 46770, 264, 9, 54, "Subsubsection"],
Cell[1406259, 46781, 113, 2, 54, "Text"],
Cell[1406375, 46785, 221, 5, 121, "Text"],
Cell[CellGroupData[{
Cell[1406621, 46794, 923, 25, 189, "Input"],
Cell[1407547, 46821, 2782, 79, 361, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1410366, 46905, 2256, 64, 353, "Input"],
Cell[1412625, 46971, 118, 3, 57, "Output"]
}, Open  ]],
Cell[1412758, 46977, 116, 2, 54, "Text"],
Cell[1412877, 46981, 201, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[1413103, 46989, 807, 23, 156, "Input"],
Cell[1413913, 47014, 1672, 51, 214, "Output"]
}, Open  ]],
Cell[1415600, 47068, 115, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1415740, 47074, 795, 22, 156, "Input"],
Cell[1416538, 47098, 1717, 53, 214, "Output"]
}, Open  ]],
Cell[1418270, 47154, 339, 9, 88, "Text"],
Cell[1418612, 47165, 121, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1418758, 47171, 539, 15, 90, "Input"],
Cell[1419300, 47188, 897, 27, 138, "Output"]
}, Open  ]],
Cell[1420212, 47218, 134, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[1420371, 47226, 347, 10, 92, "Input"],
Cell[1420721, 47238, 1958, 59, 351, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1422716, 47302, 106, 3, 57, "Input"],
Cell[1422825, 47307, 1464, 37, 178, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1424326, 47349, 247, 7, 57, "Input"],
Cell[1424576, 47358, 1036, 28, 100, "Output"]
}, Open  ]],
Cell[1425627, 47389, 153, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[1425805, 47397, 810, 22, 104, "Input"],
Cell[1426618, 47421, 53, 1, 57, "Output"]
}, Open  ]],
Cell[1426686, 47425, 128, 4, 55, "Text"],
Cell[CellGroupData[{
Cell[1426839, 47433, 987, 26, 104, "Input"],
Cell[1427829, 47461, 53, 1, 57, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1427943, 47469, 96, 2, 72, "Subsection"],
Cell[1428042, 47473, 771, 15, 319, "Text"],
Cell[1428816, 47490, 106, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1428947, 47496, 9907, 245, 1293, "Input"],
Cell[1438857, 47743, 6434, 159, 1274, "Output"],
Cell[1445294, 47904, 4992, 125, 956, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1450335, 48035, 112, 2, 72, "Subsection"],
Cell[1450450, 48039, 794, 23, 253, "Text"],
Cell[1451247, 48064, 104, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1451376, 48070, 1272, 38, 160, "Input"],
Cell[1452651, 48110, 1353, 42, 135, "Output"],
Cell[1454007, 48154, 98, 3, 57, "Output"]
}, Open  ]],
Cell[1454120, 48160, 62, 1, 55, "Text"],
Cell[CellGroupData[{
Cell[1454207, 48165, 1099, 33, 194, "Input"],
Cell[1455309, 48200, 1185, 38, 136, "Output"],
Cell[1456497, 48240, 666, 18, 100, "Output"],
Cell[1457166, 48260, 343, 11, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1457546, 48276, 1099, 33, 194, "Input"],
Cell[1458648, 48311, 1185, 38, 136, "Output"],
Cell[1459836, 48351, 666, 18, 100, "Output"],
Cell[1460505, 48371, 343, 11, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1460885, 48387, 89, 2, 57, "Input"],
Cell[1460977, 48391, 1093, 36, 187, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1462119, 48433, 136, 2, 72, "Subsection"],
Cell[1462258, 48437, 288, 6, 121, "Text"],
Cell[1462549, 48445, 98, 2, 54, "Text"],
Cell[1462650, 48449, 403, 12, 92, "Input"],
Cell[1463056, 48463, 434, 13, 126, "Input"],
Cell[1463493, 48478, 435, 13, 126, "Input"],
Cell[1463931, 48493, 592, 15, 126, "Input"],
Cell[1464526, 48510, 101, 1, 55, "Text"],
Cell[1464630, 48513, 343, 10, 57, "Input"],
Cell[1464976, 48525, 345, 10, 57, "Input"],
Cell[CellGroupData[{
Cell[1465346, 48539, 484, 14, 126, "Input"],
Cell[1465833, 48555, 2167, 66, 194, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1468037, 48626, 484, 14, 126, "Input"],
Cell[1468524, 48642, 2695, 66, 228, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1471256, 48713, 589, 15, 126, "Input"],
Cell[1471848, 48730, 2056, 55, 200, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1473965, 48792, 124, 2, 139, "Section"],
Cell[1474092, 48796, 826, 15, 319, "Text"],
Cell[1474921, 48813, 110, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1475056, 48819, 2328, 63, 321, "Input"],
Cell[1477387, 48884, 1467, 39, 398, "Output"]
}, Open  ]],
Cell[1478869, 48926, 601, 10, 253, "Text"],
Cell[1479473, 48938, 139, 4, 54, "Text"],
Cell[CellGroupData[{
Cell[1479637, 48946, 1000, 27, 38, "Input",
 CellOpen->False],
Cell[1480640, 48975, 617, 16, 126, "Output"]
}, Open  ]],
Cell[1481272, 48994, 380, 11, 121, "Text"],
Cell[1481655, 49007, 87, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1481767, 49013, 1146, 31, 38, "Input",
 CellOpen->False],
Cell[1482916, 49046, 1514, 32, 364, "Output"]
}, Open  ]],
Cell[1484445, 49081, 505, 9, 220, "Text"],
Cell[1484953, 49092, 93, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[1485071, 49098, 1097, 32, 38, "Input",
 CellOpen->False],
Cell[1486171, 49132, 4741, 145, 620, "Output"]
}, Open  ]],
Cell[1490927, 49280, 137, 3, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1491101, 49288, 130, 2, 188, "Section"],
Cell[CellGroupData[{
Cell[1491256, 49294, 59, 1, 72, "Subsection"],
Cell[1491318, 49297, 623, 10, 253, "Text"],
Cell[CellGroupData[{
Cell[1491966, 49311, 735, 15, 228, "Input"],
Cell[1492704, 49328, 255, 6, 92, "Output"]
}, Open  ]],
Cell[1492974, 49337, 680, 13, 286, "Text"],
Cell[CellGroupData[{
Cell[1493679, 49354, 1623, 39, 432, "Input"],
Cell[1495305, 49395, 2130, 66, 330, "Output"]
}, Open  ]],
Cell[1497450, 49464, 568, 16, 154, "Text"],
Cell[CellGroupData[{
Cell[1498043, 49484, 89, 2, 57, "Input"],
Cell[1498135, 49488, 329, 11, 78, "Output"]
}, Open  ]],
Cell[1498479, 49502, 195, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[1498699, 49510, 175, 5, 57, "Input"],
Cell[1498877, 49517, 1976, 67, 354, "Output"]
}, Open  ]],
Cell[1500868, 49587, 169, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[1501062, 49595, 241, 7, 57, "Input"],
Cell[1501306, 49604, 644, 18, 126, "Output"]
}, Open  ]],
Cell[1501965, 49625, 143, 4, 55, "Text"],
Cell[CellGroupData[{
Cell[1502133, 49633, 1226, 33, 330, "Input"],
Cell[1503362, 49668, 163, 4, 57, "Output"],
Cell[1503528, 49674, 337, 12, 57, "Output"],
Cell[1503868, 49688, 257, 9, 57, "Output"],
Cell[1504128, 49699, 436, 15, 57, "Output"],
Cell[1504567, 49716, 110, 3, 57, "Output"],
Cell[1504680, 49721, 129, 4, 57, "Output"],
Cell[1504812, 49727, 132, 4, 57, "Output"],
Cell[1504947, 49733, 663, 24, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1505647, 49762, 241, 7, 57, "Input"],
Cell[1505891, 49771, 647, 18, 126, "Output"]
}, Open  ]],
Cell[1506553, 49792, 144, 3, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1506734, 49800, 56, 0, 73, "Subsection"],
Cell[1506793, 49802, 2645, 48, 948, "Text"],
Cell[CellGroupData[{
Cell[1509463, 49854, 81, 2, 82, "Input"],
Cell[1509547, 49858, 1424, 46, 268, "Output"]
}, Open  ]],
Cell[1510986, 49907, 494, 9, 187, "Text"],
Cell[1511483, 49918, 1959, 59, 511, "Text"],
Cell[1513445, 49979, 132, 3, 88, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1513626, 49988, 91, 2, 139, "Section"],
Cell[1513720, 49992, 166, 7, 43, "EndNote",
 CellTags->"MT2"],
Cell[1513889, 50001, 151, 5, 43, "EndNote",
 CellTags->"MT2"],
Cell[1514043, 50008, 157, 5, 43, "EndNote",
 CellTags->"MT2"],
Cell[1514203, 50015, 286, 7, 72, "EndNote",
 CellTags->"MT2"],
Cell[1514492, 50024, 186, 6, 43, "EndNote",
 CellTags->"CT"],
Cell[1514681, 50032, 204, 5, 72, "EndNote",
 CellTags->"FV"],
Cell[1514888, 50039, 138, 4, 43, "EndNote",
 CellTags->"MT2"],
Cell[1515029, 50045, 169, 5, 43, "EndNote",
 CellTags->"MT2"],
Cell[1515201, 50052, 267, 9, 72, "EndNote",
 CellTags->"MT2"],
Cell[1515471, 50063, 144, 4, 43, "EndNote",
 CellTags->"MT2"],
Cell[1515618, 50069, 281, 8, 43, "EndNote",
 CellTags->"MT2"],
Cell[1515902, 50079, 177, 6, 72, "EndNote",
 CellTags->"MT2"],
Cell[1516082, 50087, 138, 4, 43, "EndNote",
 CellTags->"MT2"],
Cell[1516223, 50093, 174, 5, 72, "EndNote",
 CellTags->"MT2"],
Cell[1516400, 50100, 158, 5, 43, "EndNote",
 CellTags->"MT2"],
Cell[1516561, 50107, 111, 2, 43, "EndNote",
 CellTags->"MT2"],
Cell[1516675, 50111, 123, 5, 72, "EndNote",
 CellTags->"MT2"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
