(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    288771,       7423]
NotebookOptionsPosition[    257977,       6721]
NotebookOutlinePosition[    276212,       7042]
CellTagsIndexPosition[    276169,       7039]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["GroupLoopTest.nb", "Title",
 PageWidth->WindowWidth],

Cell["Validation of GroupLoopHoop6.m. ", "Subtitle",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.428428167125*^9}],

Cell[TextData[{
 "R.H.Beresford. 11/10/6. From ",
 StyleBox["GroupLoopPackage.nb",
  FontSlant->"Italic"],
 " 2004-5\nMathematica6 version 22/8/8. Some unresolved M6 problems."
}], "Subsubtitle",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4262412317790394`*^9, 3.4262412364977894`*^9}, {
  3.428428268609375*^9, 3.42842827315625*^9}}],

Cell[CellGroupData[{

Cell["1. Tests & Data Validation.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["Summary. ",
  FontSlant->"Plain"],
 "A series of tests validate all the generation and prescription rules in the \
GroupLoopHoop database. Tables without generator rules or prescriptions are \
first identified and counted; every prescription and generator rule is then \
tested. Incorrect identification of the rules would be reported. Clifford and \
Cayley-Dickson algebras are tested. All signed tables are listed. All the \
generator & matrix generator rules are tested. No significant errors were \
found in the current version; if any are found in copies, they must arise \
from transcription errors. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " users should download, run (in your ExtraPackages file), save and close \
the GroupLoopHoop package, from ",
 ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://library.wolfram.com/infocenter/MathSource/4894/"], None}],
 " and then use:-"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4262412576384144`*^9, 3.4262412584040394`*^9}, {
  3.42851180253125*^9, 3.428511808890625*^9}},
 FontSlant->"Italic"],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"<<", "GroupLoopHoop6`"}]], "Input"],

Cell[CellGroupData[{

Cell["1.1 Validation of Prescription Rules.", "Subsection",
 PageWidth->WindowWidth],

Cell["\<\
\tTest 1 counts the loops in the database, finding only two that are not \
created as a protoloop; those without prescriptions are then counted and \
listed.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["Test 1. Report  Loops (< 64 elements) without Protoloops.", \
"Subsubsection",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"np", "=", "0"}], ";", 
  RowBox[{"nos", "=", "0"}], ";", 
  RowBox[{"noc", "=", "0"}], ";", 
  RowBox[{"lp", "=", 
   RowBox[{
    RowBox[{"Length", "[", "loop", "]"}], "-", "1"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"noc", "++"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"loop", "[", 
            RowBox[{"[", 
             RowBox[{"m", ",", "n", ",", "4"}], "]"}], "]"}], "===", 
           "\"\<ca[]\>\""}], "&&", 
          RowBox[{
           RowBox[{"loop", "[", 
            RowBox[{"[", 
             RowBox[{"m", ",", "n", ",", "5"}], "]"}], "]"}], "===", 
           RowBox[{"{", "}"}]}], "&&", 
          RowBox[{
           RowBox[{"loop", "[", 
            RowBox[{"[", 
             RowBox[{"m", ",", "n", ",", "7"}], "]"}], "]"}], "===", 
           RowBox[{"{", "}"}]}], "&&", 
          RowBox[{
           RowBox[{"loop", "[", 
            RowBox[{"[", 
             RowBox[{"m", ",", "n", ",", "8"}], "]"}], "]"}], "===", 
           RowBox[{"{", "}"}]}], "&&", 
          RowBox[{
           RowBox[{"loop", "[", 
            RowBox[{"[", 
             RowBox[{"m", ",", "n", ",", "9"}], "]"}], "]"}], "===", 
           RowBox[{"{", "}"}]}], "&&", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"loop", "[", 
             RowBox[{"[", 
              RowBox[{"m", ",", "n"}], "]"}], "]"}], "]"}], "<", "10"}]}], 
         ",", 
         RowBox[{
          RowBox[{"nos", "++"}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"m", "<", "64"}], ",", 
            RowBox[{
             RowBox[{"Print", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"gd", "[", 
                  RowBox[{"m", ",", "n"}], "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", 
                "\"\< has no protoloop\>\""}], "}"}], "]"}], ";", 
             RowBox[{"nos", "=", "0"}]}]}], "]"}]}], ",", 
         RowBox[{"np", "++"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "lp"}], "}"}]}], "]"}], ";", 
  RowBox[{"{", 
   RowBox[{
   "noc", ",", "\"\<loops \>\"", ",", "np", ",", "\"\< with protoloops\>\""}],
    "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Q20c\"\>", ",", "\<\" has no protoloop\"\>"}], "}"}]], "Print",\

 CellChangeTimes->{3.4256437651690097`*^9, 3.4256442354252048`*^9, 
  3.425665066740168*^9, 3.4256982670633183`*^9, 3.425699681537232*^9, 
  3.425702979484375*^9, 3.42570322609375*^9, 3.4262412809509144`*^9, 
  3.428428202*^9, 3.428428309140625*^9, 3.428428735625*^9, 3.4284287746875*^9,
   3.428429317890625*^9, 3.428429746875*^9, 3.428429901171875*^9, 
  3.428477095421875*^9, 3.428477259109375*^9, 3.42847744103125*^9, 
  3.42847906203125*^9, 3.42847948665625*^9, 3.428481564078125*^9, 
  3.428483364296875*^9, 3.4284834199375*^9, 3.428484257328125*^9, 
  3.428487143046875*^9, 3.42850147534375*^9, 3.428502680390625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A4C2r\"\>", ",", "\<\" has no protoloop\"\>"}], "}"}]], "Print",\

 CellChangeTimes->{3.4256437651690097`*^9, 3.4256442354252048`*^9, 
  3.425665066740168*^9, 3.4256982670633183`*^9, 3.425699681537232*^9, 
  3.425702979484375*^9, 3.42570322609375*^9, 3.4262412809509144`*^9, 
  3.428428202*^9, 3.428428309140625*^9, 3.428428735625*^9, 3.4284287746875*^9,
   3.428429317890625*^9, 3.428429746875*^9, 3.428429901171875*^9, 
  3.428477095421875*^9, 3.428477259109375*^9, 3.42847744103125*^9, 
  3.42847906203125*^9, 3.42847948665625*^9, 3.428481564078125*^9, 
  3.428483364296875*^9, 3.4284834199375*^9, 3.428484257328125*^9, 
  3.428487143046875*^9, 3.42850147534375*^9, 3.42850268040625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"PD16\"\>", ",", "\<\" has no protoloop\"\>"}], "}"}]], "Print",\

 CellChangeTimes->{3.4256437651690097`*^9, 3.4256442354252048`*^9, 
  3.425665066740168*^9, 3.4256982670633183`*^9, 3.425699681537232*^9, 
  3.425702979484375*^9, 3.42570322609375*^9, 3.4262412809509144`*^9, 
  3.428428202*^9, 3.428428309140625*^9, 3.428428735625*^9, 3.4284287746875*^9,
   3.428429317890625*^9, 3.428429746875*^9, 3.428429901171875*^9, 
  3.428477095421875*^9, 3.428477259109375*^9, 3.42847744103125*^9, 
  3.42847906203125*^9, 3.42847948665625*^9, 3.428481564078125*^9, 
  3.428483364296875*^9, 3.4284834199375*^9, 3.428484257328125*^9, 
  3.428487143046875*^9, 3.42850147534375*^9, 3.42850268040625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"D4Kr\"\>", ",", "\<\" has no protoloop\"\>"}], "}"}]], "Print",\

 CellChangeTimes->{3.4256437651690097`*^9, 3.4256442354252048`*^9, 
  3.425665066740168*^9, 3.4256982670633183`*^9, 3.425699681537232*^9, 
  3.425702979484375*^9, 3.42570322609375*^9, 3.4262412809509144`*^9, 
  3.428428202*^9, 3.428428309140625*^9, 3.428428735625*^9, 3.4284287746875*^9,
   3.428429317890625*^9, 3.428429746875*^9, 3.428429901171875*^9, 
  3.428477095421875*^9, 3.428477259109375*^9, 3.42847744103125*^9, 
  3.42847906203125*^9, 3.42847948665625*^9, 3.428481564078125*^9, 
  3.428483364296875*^9, 3.4284834199375*^9, 3.428484257328125*^9, 
  3.428487143046875*^9, 3.42850147534375*^9, 3.42850268040625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"g4828\"\>", ",", "\<\" has no protoloop\"\>"}], "}"}]], "Print",\

 CellChangeTimes->{3.4256437651690097`*^9, 3.4256442354252048`*^9, 
  3.425665066740168*^9, 3.4256982670633183`*^9, 3.425699681537232*^9, 
  3.425702979484375*^9, 3.42570322609375*^9, 3.4262412809509144`*^9, 
  3.428428202*^9, 3.428428309140625*^9, 3.428428735625*^9, 3.4284287746875*^9,
   3.428429317890625*^9, 3.428429746875*^9, 3.428429901171875*^9, 
  3.428477095421875*^9, 3.428477259109375*^9, 3.42847744103125*^9, 
  3.42847906203125*^9, 3.42847948665625*^9, 3.428481564078125*^9, 
  3.428483364296875*^9, 3.4284834199375*^9, 3.428484257328125*^9, 
  3.428487143046875*^9, 3.42850147534375*^9, 3.428502680421875*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "816", ",", "\<\"loops \"\>", ",", "672", ",", "\<\" with protoloops\"\>"}],
   "}"}]], "Output",
 CellChangeTimes->{3.425643765379312*^9, 3.42564423550532*^9, 
  3.4256650670005426`*^9, 3.425698267443866*^9, 3.4256996817275057`*^9, 
  3.425702979515625*^9, 3.425703226125*^9, 3.4262412809821644`*^9, 
  3.42842820203125*^9, 3.42842830915625*^9, 3.42842873565625*^9, 
  3.42842877471875*^9, 3.428429317921875*^9, 3.4284297469375*^9, 
  3.428429901265625*^9, 3.4284770955*^9, 3.428477259125*^9, 
  3.4284774410625*^9, 3.4284790620625*^9, 3.4284794866875*^9, 
  3.428481564109375*^9, 3.428483364328125*^9, 3.428483419953125*^9, 
  3.428484257359375*^9, 3.4284871430625*^9, 3.42850147540625*^9, 
  3.4285026804375*^9}]
}, Open  ]],

Cell[TextData[{
 "143 loops have no protoloops. ",
 StyleBox["dico",
  FontSlant->"Italic"],
 " was found for the others when they were created via GAP in external files. \
The first 4 had matrix protoloop prescriptions, but these do not work with \
Mathematica6."
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.428429915453125*^9, {3.428429965515625*^9, 3.4284300395625*^9}, 
   3.428501497546875*^9, {3.428511876453125*^9, 3.428511939765625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test 2. Unprescribed loops.", "Subsubsection",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"unp", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"noc", "=", "0"}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"loop", "[", 
        RowBox[{"[", "m", "]"}], "]"}], "\[NotEqual]", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"noc", "++"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"loop", "[", 
             RowBox[{"[", 
              RowBox[{"m", ",", "n", ",", "4"}], "]"}], "]"}], "===", 
            "\"\<ca[]\>\""}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"unp", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"m", ",", "n"}], "}"}], ",", 
               RowBox[{"loop", "[", 
                RowBox[{"[", 
                 RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}]}], "}"}]}], 
            "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"loop", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", "lp"}], "}"}]}], "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Length", "[", "unp", "]"}], ",", 
     "\"\< tables without prescriptions\>\""}], "}"}], "]"}], ";"}]], "Input",\

 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"236", ",", "\<\" tables without prescriptions\"\>"}], 
  "}"}]], "Print",
 CellChangeTimes->{
  3.425644235855824*^9, 3.42569828272584*^9, 3.425703226171875*^9, 
   3.4262412881384144`*^9, 3.42842820209375*^9, 3.428428336203125*^9, 
   3.42842874721875*^9, {3.428428781234375*^9, 3.428428786640625*^9}, 
   3.428429326484375*^9, 3.428429747*^9, 3.428430052109375*^9, 
   3.42847726909375*^9, 3.428477454390625*^9, 3.428479067375*^9, 
   3.428479649140625*^9, 3.428481576828125*^9, 3.428483364390625*^9, 
   3.4284834235625*^9, 3.42848426815625*^9, 3.428487153671875*^9, 
   3.42850147546875*^9, 3.428501546625*^9, 3.4285026805*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Print", "[", "\"\<Small Loops without prescriptions:-\>\"", "]"}], 
  ";", 
  RowBox[{"tbl", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"unp", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"unp", "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "24"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "24"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"tbl", "//", "tf"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"Small Loops without prescriptions:-\"\>"], "Print",
 CellChangeTimes->{3.4256442359860115`*^9, 3.4257032261875*^9, 
  3.4262412923102894`*^9, 3.428428202125*^9, 3.428428336265625*^9, 
  3.428428791796875*^9, 3.428429326515625*^9, 3.42842974703125*^9, 
  3.428430052140625*^9, 3.428477269125*^9, 3.4284774544375*^9, 
  3.428479067421875*^9, 3.4284796491875*^9, 3.428481580109375*^9, 
  3.42848336440625*^9, 3.428483423609375*^9, 3.428484268203125*^9, 
  3.42848715371875*^9, 3.4285014755*^9, 3.4285015525*^9, 3.428502680515625*^9}
  ],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "3"}], "}"}], ",", "\<\"Q20c\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"36", ",", "3"}], "}"}], ",", "\<\"g3603\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"12", ",", "3"}], "}"}], ",", "\<\"A4\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"36", ",", "9"}], "}"}], ",", "\<\"g3609\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"12", ",", "26"}], "}"}], ",", "\<\"A4C2r\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"39", ",", "1"}], "}"}], ",", "\<\"C39n\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"16", ",", "26"}], "}"}], ",", "\<\"PD16\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"40", ",", "3"}], "}"}], ",", "\<\"C40d\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"16", ",", "31"}], "}"}], ",", "\<\"D4Kr\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"40", ",", "12"}], "}"}], ",", "\<\"C40b\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"20", ",", "3"}], "}"}], ",", "\<\"g2003\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"42", ",", "5"}], "}"}], ",", "\<\"C42a\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"24", ",", "3"}], "}"}], ",", "\<\"SL23\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"48", ",", "3"}], "}"}], ",", "\<\"g4803\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"27", ",", "3"}], "}"}], ",", "\<\"P27\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"48", ",", "5"}], "}"}], ",", "\<\"g4805\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"27", ",", "4"}], "}"}], ",", "\<\"g2704\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"48", ",", "18"}], "}"}], ",", "\<\"g4818\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "2"}], "}"}], ",", "\<\"g3202\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"48", ",", "28"}], "}"}], ",", "\<\"g4828\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "6"}], "}"}], ",", "\<\"g3206\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"48", ",", "29"}], "}"}], ",", "\<\"g4829\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "7"}], "}"}], ",", "\<\"g3207\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"48", ",", "30"}], "}"}], ",", "\<\"g4830\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "8"}], "}"}], ",", "\<\"g3208\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"48", ",", "33"}], "}"}], ",", "\<\"g4833\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "11"}], "}"}], ",", "\<\"g3211\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"48", ",", "50"}], "}"}], ",", "\<\"g4850\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "15"}], "}"}], ",", "\<\"g3215\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"52", ",", "5"}], "}"}], ",", "\<\"C52a\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "17"}], "}"}], ",", "\<\"g3217\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"54", ",", "5"}], "}"}], ",", "\<\"D9C3a\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "30"}], "}"}], ",", "\<\"g3230\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"54", ",", "6"}], "}"}], ",", "\<\"g5406\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "31"}], "}"}], ",", "\<\"g3231\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"54", ",", "8"}], "}"}], ",", "\<\"P54\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "32"}], "}"}], ",", "\<\"Q8C4a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"54", ",", "11"}], "}"}], ",", "\<\"g2704C2\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "33"}], "}"}], ",", "\<\"g3233\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"54", ",", "14"}], "}"}], ",", "\<\"D27b\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "38"}], "}"}], ",", "\<\"g3238\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"55", ",", "2"}], "}"}], ",", "\<\"g5502\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "42"}], "}"}], ",", "\<\"g3242\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"56", ",", "11"}], "}"}], ",", "\<\"g5611\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "43"}], "}"}], ",", "\<\"g3243\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"57", ",", "1"}], "}"}], ",", "\<\"g5701\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"32", ",", "44"}], "}"}], ",", "\<\"g3244\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"60", ",", "5"}], "}"}], ",", "\<\"A5\"\>"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.4256442363765726`*^9, 3.42570322628125*^9, 
  3.4262412923884144`*^9, 3.42842820215625*^9, 3.42842833628125*^9, 
  3.428428791828125*^9, 3.42842932653125*^9, 3.428429747046875*^9, 
  3.42843005215625*^9, 3.42847726921875*^9, 3.428477454453125*^9, 
  3.4284790674375*^9, 3.428479649203125*^9, 3.428481580140625*^9, 
  3.428483364421875*^9, 3.428483423625*^9, 3.42848426821875*^9, 
  3.428487153734375*^9, 3.4285014755*^9, 3.428501552515625*^9, 
  3.42850268053125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Test 3. Correctness of first available prescriptions.",
 StyleBox[" SLOW.",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[TextData[{
 "\tmp",
 StyleBox[" uses the first available prescription to create a table. An error \
is reported if this does not have the correct ",
  FontSlant->"Plain"],
 "id",
 StyleBox[". set ",
  FontSlant->"Plain"],
 "pr=1",
 StyleBox[" to track progress. ",
  FontSlant->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.42848104384375*^9},
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "pr", "]"}], ";", 
  RowBox[{"pr", "=", "0"}], 
  RowBox[{"(*", " ", 
   RowBox[{"set", " ", "to", " ", "1", " ", "for", " ", "diagnostics"}], " ", 
   "*)"}], ";", 
  RowBox[{"presco", "=", "0"}], ";", 
  RowBox[{"tt", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";", 
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"pr", ">", "0"}], ",", 
          RowBox[{"Print", "[", 
           RowBox[{"{", 
            RowBox[{"m", ",", "n"}], "}"}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"unp", ",", 
             RowBox[{"{", 
              RowBox[{"m", ",", "n"}], "}"}]}], "]"}], "\[Equal]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{
           RowBox[{"id", "[", 
            RowBox[{"test", "=", 
             RowBox[{"mp", "[", 
              RowBox[{"{", 
               RowBox[{"m", ",", "n"}], "}"}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"mm", ",", "nn"}], "}"}], "\[Equal]", 
              RowBox[{"{", 
               RowBox[{"m", ",", "n"}], "}"}]}], ",", 
             RowBox[{
              RowBox[{"presco", "++"}], ";", 
              RowBox[{"mn", "=", 
               RowBox[{"{", 
                RowBox[{"mm", ",", "nn"}], "}"}]}]}], ",", 
             RowBox[{"Print", "[", 
              RowBox[{
               RowBox[{"gd", "[", "]"}], ",", "\"\< \>\"", ",", 
               RowBox[{"dico", "[", "test", "]"}], ",", "\"\< \>\"", ",", 
               RowBox[{"loop", "[", 
                RowBox[{"[", 
                 RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}]}], "]"}]}], 
            "]"}]}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"loop", "[", 
           RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "2", ",", 
       RowBox[{"lp", "-", "1"}]}], "}"}]}], "]"}], ";", "//", 
   "Timing"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "]"}], "-", "tt"}], ",", 
    "\"\<actual seconds\\n\>\"", ",", "presco", ",", 
    "\"\< correct prescriptions.\\nLast mm,nn=\>\"", ",", "mn"}], "}"}], 
  "]"}]}], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.428428851453125*^9, 3.42842929140625*^9, 
  3.428429364953125*^9, 3.4284300990625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"475.594`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.4285035566875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "484.5`10.136838774882758", ",", "\<\"actual seconds\\n\"\>", ",", "576", 
   ",", "\<\" correct prescriptions.\\nLast mm,nn=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"120", ",", "2"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.4285035566875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Test 3a. Matrix ",
 StyleBox["ma",
  FontSlant->"Italic"],
 " validation & listing.",
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4256983624504786`*^9, 3.4256984305183554`*^9}, 
   3.428499024484375*^9},
 FontWeight->"Bold"],

Cell[TextData[{
 "Group synthesis by ",
 StyleBox["ma, mg, ms",
  FontSlant->"Italic"],
 " often fails in Version 6 because many of u2, u3, & u4 unitary monomial \
matrices involve generalised signs. These worked in Version 4.2, but they \
have been removed from the current package."
}], "Text",
 CellChangeTimes->{{3.428499036953125*^9, 3.4284991481875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pr", "=", "1"}], 
  RowBox[{"(*", " ", "u2", "*)"}], ";", 
  RowBox[{"maco", "=", "0"}], ";", 
  RowBox[{"macn", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tst", "=", 
           RowBox[{
            RowBox[{"gd", "[", 
             RowBox[{"m", ",", "n"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "7"}], "]"}], "]"}]}], ")"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{
         RowBox[{"test", "=", 
          RowBox[{"mg", "[", 
           RowBox[{"tst", ",", "u2"}], "]"}]}], ";", 
         RowBox[{"mm", "=", "0"}], ";", 
         RowBox[{"nn", "=", "0"}], ";", 
         RowBox[{"id", "[", "test", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"mm", ",", "nn"}], "}"}], "\[Equal]", 
            RowBox[{"{", 
             RowBox[{"m", ",", "n"}], "}"}]}], ",", 
           RowBox[{"maco", "++"}], ",", 
           RowBox[{"(*", 
            RowBox[{"mn", "=", 
             RowBox[{"{", 
              RowBox[{"mm", ",", "nn"}], "}"}]}], "*)"}], 
           RowBox[{
            RowBox[{"macn", "++"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"pr", ">", "0"}], ",", 
              RowBox[{"Print", "[", 
               RowBox[{"{", 
                RowBox[{"m", ",", "n", ",", "tst", ",", 
                 RowBox[{
                  RowBox[{"gd", "[", 
                   RowBox[{"m", ",", "n"}], "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}]}], 
             "]"}]}]}], "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", 
      RowBox[{"lp", "-", "1"}]}], "}"}]}], "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
   "maco", ",", "\"\< correct \>\"", ",", "macn", ",", "\"\< wrong\>\""}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.425698538213213*^9, 3.4256985612162895`*^9}, 
   3.425698665516266*^9, {3.425698730099131*^9, 3.425698748245224*^9}, {
   3.4256989158562365`*^9, 3.4256989466104593`*^9}, {3.425699466477992*^9, 
   3.4256994810689726`*^9}, {3.425699764256176*^9, 3.425699770815608*^9}, {
   3.425699822459869*^9, 3.4256998339964576`*^9}, {3.425699926359269*^9, 
   3.4256999839620976`*^9}, 3.42570009583296*^9, {3.425700192542021*^9, 
   3.4257002213334208`*^9}, {3.425700292245387*^9, 3.425700305654669*^9}, {
   3.4257003808928556`*^9, 3.425700413730074*^9}, {3.4257004441738496`*^9, 
   3.4257004573027277`*^9}, 3.425700498832445*^9, {3.4257007144324627`*^9, 
   3.425700723665739*^9}, {3.4257008677128687`*^9, 3.4257008723795795`*^9}, {
   3.425700956450467*^9, 3.4257009879557695`*^9}, {3.425701069302741*^9, 
   3.425701091634853*^9}, {3.425703266984375*^9, 3.425703360078125*^9}, {
   3.425712476828125*^9, 3.42571249809375*^9}, 3.425712538109375*^9, {
   3.42571262721875*^9, 3.425712641875*^9}, 3.4257134273125*^9, 
   3.4257134875625*^9, 3.42571394359375*^9, {3.4257140566875*^9, 
   3.42571408465625*^9}, {3.425714440265625*^9, 3.425714465046875*^9}, 
   3.425714726671875*^9, {3.42571479396875*^9, 3.425714811109375*^9}, {
   3.42571485046875*^9, 3.425714851125*^9}, {3.428500102765625*^9, 
   3.428500135125*^9}, {3.428502748921875*^9, 3.4285027536875*^9}, 
   3.4285027928125*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "188", "\[InvisibleSpace]", "\<\" correct \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\" wrong\"\>"}],
  SequenceForm[188, " correct ", 0, " wrong"],
  Editable->False]], "Print",
 CellChangeTimes->{3.42850276084375*^9, 3.428502849109375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pr", "=", "1"}], 
  RowBox[{"(*", " ", "u3", "*)"}], ";", 
  RowBox[{"maco", "=", "0"}], ";", 
  RowBox[{"macn", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tst", "=", 
           RowBox[{
            RowBox[{"gd", "[", 
             RowBox[{"m", ",", "n"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "8"}], "]"}], "]"}]}], ")"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{
         RowBox[{"test", "=", 
          RowBox[{"mg", "[", 
           RowBox[{"tst", ",", "u3"}], "]"}]}], ";", 
         RowBox[{"mm", "=", "0"}], ";", 
         RowBox[{"nn", "=", "0"}], ";", 
         RowBox[{"id", "[", "test", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"mm", ",", "nn"}], "}"}], "\[Equal]", 
            RowBox[{"{", 
             RowBox[{"m", ",", "n"}], "}"}]}], ",", 
           RowBox[{"maco", "++"}], ",", 
           RowBox[{"(*", 
            RowBox[{"mn", "=", 
             RowBox[{"{", 
              RowBox[{"mm", ",", "nn"}], "}"}]}], "*)"}], 
           RowBox[{
            RowBox[{"macn", "++"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"pr", ">", "0"}], ",", 
              RowBox[{"Print", "[", 
               RowBox[{"{", 
                RowBox[{"m", ",", "n", ",", "tst", ",", 
                 RowBox[{
                  RowBox[{"gd", "[", 
                   RowBox[{"m", ",", "n"}], "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}]}], 
             "]"}]}]}], "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", 
      RowBox[{"lp", "-", "1"}]}], "}"}]}], "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
   "maco", ",", "\"\< correct \>\"", ",", "macn", ",", "\"\< wrong\>\""}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.425698538213213*^9, 3.4256985612162895`*^9}, 
   3.425698665516266*^9, {3.425698730099131*^9, 3.425698748245224*^9}, {
   3.4256989158562365`*^9, 3.4256989466104593`*^9}, {3.425699466477992*^9, 
   3.4256994810689726`*^9}, {3.425699764256176*^9, 3.425699770815608*^9}, {
   3.425699822459869*^9, 3.4256998339964576`*^9}, {3.425699926359269*^9, 
   3.4256999839620976`*^9}, 3.42570009583296*^9, {3.425700192542021*^9, 
   3.4257002213334208`*^9}, {3.425700292245387*^9, 3.425700305654669*^9}, {
   3.4257003808928556`*^9, 3.425700413730074*^9}, {3.4257004441738496`*^9, 
   3.4257004573027277`*^9}, 3.425700498832445*^9, {3.4257007144324627`*^9, 
   3.425700723665739*^9}, {3.4257008677128687`*^9, 3.4257008723795795`*^9}, {
   3.425700956450467*^9, 3.4257009879557695`*^9}, {3.425701069302741*^9, 
   3.425701091634853*^9}, {3.425703266984375*^9, 3.425703360078125*^9}, {
   3.425712476828125*^9, 3.42571249809375*^9}, 3.425712538109375*^9, {
   3.42571262721875*^9, 3.425712641875*^9}, 3.4257134273125*^9, 
   3.4257134875625*^9, 3.42571394359375*^9, {3.4257140566875*^9, 
   3.42571408465625*^9}, {3.425714440265625*^9, 3.425714465046875*^9}, 
   3.425714726671875*^9, {3.42571479396875*^9, 3.425714811109375*^9}, {
   3.42571485046875*^9, 3.425714851125*^9}, {3.428500102765625*^9, 
   3.428500135125*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "160", "\[InvisibleSpace]", "\<\" correct \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\" wrong\"\>"}],
  SequenceForm[160, " correct ", 0, " wrong"],
  Editable->False]], "Print",
 CellChangeTimes->{3.428502906515625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pr", "=", "1"}], 
  RowBox[{"(*", " ", "u4", "*)"}], ";", 
  RowBox[{"maco", "=", "0"}], ";", 
  RowBox[{"macn", "=", "0"}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tst", "=", 
           RowBox[{
            RowBox[{"gd", "[", 
             RowBox[{"m", ",", "n"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "9"}], "]"}], "]"}]}], ")"}], "\[NotEqual]", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{
         RowBox[{"test", "=", 
          RowBox[{"mg", "[", 
           RowBox[{"tst", ",", "u4"}], "]"}]}], ";", 
         RowBox[{"mm", "=", "0"}], ";", 
         RowBox[{"nn", "=", "0"}], ";", 
         RowBox[{"id", "[", "test", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"mm", ",", "nn"}], "}"}], "\[Equal]", 
            RowBox[{"{", 
             RowBox[{"m", ",", "n"}], "}"}]}], ",", 
           RowBox[{"maco", "++"}], ",", 
           RowBox[{"(*", 
            RowBox[{"mn", "=", 
             RowBox[{"{", 
              RowBox[{"mm", ",", "nn"}], "}"}]}], "*)"}], 
           RowBox[{
            RowBox[{"macn", "++"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"pr", ">", "0"}], ",", 
              RowBox[{"Print", "[", 
               RowBox[{"{", 
                RowBox[{"m", ",", "n", ",", "tst", ",", 
                 RowBox[{
                  RowBox[{"gd", "[", 
                   RowBox[{"m", ",", "n"}], "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}]}], 
             "]"}]}]}], "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"m", ",", "3", ",", 
      RowBox[{"lp", "-", "1"}]}], "}"}]}], "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
   "maco", ",", "\"\< correct \>\"", ",", "macn", ",", "\"\< wrong\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.425698538213213*^9, 3.4256985612162895`*^9}, 
   3.425698665516266*^9, {3.425698730099131*^9, 3.425698748245224*^9}, {
   3.4256989158562365`*^9, 3.4256989466104593`*^9}, {3.425699466477992*^9, 
   3.4256994810689726`*^9}, {3.425699764256176*^9, 3.425699770815608*^9}, {
   3.425699822459869*^9, 3.4256998339964576`*^9}, {3.425699926359269*^9, 
   3.4256999839620976`*^9}, 3.42570009583296*^9, {3.425700192542021*^9, 
   3.4257002213334208`*^9}, {3.425700292245387*^9, 3.425700305654669*^9}, {
   3.4257003808928556`*^9, 3.425700413730074*^9}, {3.4257004441738496`*^9, 
   3.4257004573027277`*^9}, 3.425700498832445*^9, {3.4257007144324627`*^9, 
   3.425700723665739*^9}, {3.4257008677128687`*^9, 3.4257008723795795`*^9}, {
   3.425700956450467*^9, 3.4257009879557695`*^9}, {3.425701069302741*^9, 
   3.425701091634853*^9}, {3.425703266984375*^9, 3.425703360078125*^9}, {
   3.425712476828125*^9, 3.42571249809375*^9}, 3.425712538109375*^9, {
   3.42571262721875*^9, 3.425712641875*^9}, 3.4257134273125*^9, 
   3.4257134875625*^9, 3.42571394359375*^9, 3.42571401765625*^9, {
   3.425714485203125*^9, 3.425714546984375*^9}, 3.425714821828125*^9, {
   3.42571495965625*^9, 3.425714960421875*^9}, 3.42571514315625*^9, {
   3.42850054403125*^9, 3.428500555703125*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "152", "\[InvisibleSpace]", "\<\" correct \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\" wrong\"\>"}],
  SequenceForm[152, " correct ", 0, " wrong"],
  Editable->False]], "Print",
 CellChangeTimes->{3.42850297403125*^9}]
}, Open  ]],

Cell["\<\
500 OK, 80 deleted because they fail in Mathematica6. All these were correct \
using Mathematica4.\
\>", "Text",
 CellChangeTimes->{{3.42571529765625*^9, 3.425715326265625*^9}, {
  3.425715381828125*^9, 3.425715423375*^9}, {3.425717807140625*^9, 
  3.425717814375*^9}, {3.428501340640625*^9, 3.428501370140625*^9}, {
  3.428503047140625*^9, 3.42850304940625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test 4. Cayley-Dickson validation & listing.", "Subsubsection",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cdcases", "=", "0"}], ";", 
  RowBox[{"cdd", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Take", "[", 
           RowBox[{
            RowBox[{"Characters", "[", 
             RowBox[{"loop", "[", 
              RowBox[{"[", 
               RowBox[{"m", ",", "n", ",", "4"}], "]"}], "]"}], "]"}], ",", 
            "2"}], "]"}], "==", 
          RowBox[{"{", 
           RowBox[{"\"\<c\>\"", ",", "\"\<d\>\""}], "}"}]}], ",", 
         RowBox[{
          RowBox[{"cdcases", "++"}], ";", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"cdd", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"loop", "[", 
               RowBox[{"[", 
                RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"loop", "[", 
               RowBox[{"[", 
                RowBox[{"m", ",", "n", ",", "4"}], "]"}], "]"}]}], "}"}]}], 
           "]"}]}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"idc", "[", "]"}], "\[NotEqual]", 
          RowBox[{"loop", "[", 
           RowBox[{"[", 
            RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}]}], ",", 
         RowBox[{"Print", "[", 
          RowBox[{"{", 
           RowBox[{"m", ",", "n"}], "}"}], "]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "33"}], "}"}]}], "]"}], ";", 
  RowBox[{"{", 
   RowBox[{"cdcases", ",", "\"\< have cd prescriptions\>\""}], 
   "}"}]}]], "Input",
 PageWidth->WindowWidth,
 FontFamily->"Courier New"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"42", ",", "\<\" have cd prescriptions\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.425646541451107*^9, 3.42570377590625*^9, 
  3.428510269484375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"cdd", ",", 
    RowBox[{"{", "}"}]}], "]"}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cdd", ",", 
    RowBox[{"{", "}"}]}], "]"}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cdd", ",", 
    RowBox[{"{", "}"}]}], "]"}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cdd", ",", 
    RowBox[{"{", "}"}]}], "]"}], ";", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"cdd", ",", 
    RowBox[{"{", "}"}]}], "]"}], ";", 
  RowBox[{"tbl", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"cdd", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"cdd", "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "15"}], "]"}], "]"}], ",", 
       RowBox[{"cdd", "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "30"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "15"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"tbl", "//", "tf"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"\<\"C4c\"\>", ",", "\<\"cd[{-1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C4C4c\"\>", ",", "\<\"cd[{2,1.,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C24r\"\>", ",", "\<\"cd[{-3,-1.,1}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"C3C2c\"\>", ",", "\<\"cd[{3.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"O4\"\>", ",", "\<\"cd[{1,1,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C24ra\"\>", ",", "\<\"cd[{3.,-1.,1}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"C3C2r\"\>", ",", "\<\"cd[{-3}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"O4a\"\>", ",", "\<\"cd[{-1,1.,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"Cm311\"\>", ",", "\<\"cd[{-3,-1.,-1.}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"Qr\"\>", ",", "\<\"cd[{-1,-1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"O4b\"\>", ",", "\<\"cd[{-1,-1.,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C24rb\"\>", ",", "\<\"cd[{3.,-1.,-1.}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"Kr\"\>", ",", "\<\"cd[{4.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"KKr\"\>", ",", "\<\"cd[{4.,1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C12n\"\>", ",", "\<\"cd[{-3,1.,-1}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"O2\"\>", ",", "\<\"cd[{-1,1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"Octr\"\>", ",", "\<\"cd[{-1,-1,-1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"Sed\"\>", ",", "\<\"cd[{-1,-1,-1,-1}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"Dav\"\>", ",", "\<\"cd[{-1,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C4C4r\"\>", ",", "\<\"cd[{-2,1,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"O8\"\>", ",", "\<\"cd[{1,1,1,-1.}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"C4C2r\"\>", ",", "\<\"cd[{-4}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"Octs\"\>", ",", "\<\"cd[{1,-1,-1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\\"C2\\\", \\\"5\\\"]\\)r\"\>", 
        ",", "\<\"cd[{4.,1,1}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"C3C4j\"\>", ",", "\<\"cd[{-2,1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"O4k\"\>", ",", "\<\"cd[{-2,1,1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C4KC2r\"\>", ",", "\<\"cd[{4.,1,-1.}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"C8c\"\>", ",", "\<\"cd[{-4.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C8n\"\>", ",", "\<\"cd[{2,-1.,-1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C8Kr\"\>", ",", "\<\"cd[{-4.,1,1}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"KC3c\"\>", ",", "\<\"cd[{3.,1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"Alt12n\"\>", ",", "\<\"cd[{-1,-1,{3}}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"O8a\"\>", ",", "\<\"cd[{4,1,-1.}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"C3Kr\"\>", ",", "\<\"cd[{-3,1}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C3Dav\"\>", ",", "\<\"cd[{3,-1.,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"O16\"\>", ",", "\<\"cd[{-1,1,1,1,1}]\"\>"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"C3C4c\"\>", ",", "\<\"cd[{3,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C3r8\"\>", ",", "\<\"cd[{3,-1.,1}]\"\>"}], "}"}], 
      RowBox[{"{", "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"Clm3r\"\>", ",", "\<\"cd[{-3,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C6Kc\"\>", ",", "\<\"cd[{3.,1,1}]\"\>"}], "}"}], 
      RowBox[{"{", "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"Cl3r\"\>", ",", "\<\"cd[{3.,-1.}]\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\<\"C6Kr\"\>", ",", "\<\"cd[{-3,1,1}]\"\>"}], "}"}], 
      RowBox[{"{", "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.4256465414911647`*^9, 3.425703775921875*^9, 
  3.428510269515625*^9}]
}, Open  ]],

Cell[TextData[{
 "\tFour of these (C8n, C12n, Alt12n, and Sed) are not conservative. \
Candidates for inclusion in the database should be checked by the following \
routine. ",
 "The first  case is neither conservative nor Moufang, though it has the same \
",
 StyleBox["dico",
  FontSlant->"Italic"],
 " as Q8C2M:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"id", "[", 
   RowBox[{"tst", "=", 
    RowBox[{"co", "[", 
     RowBox[{
      RowBox[{"cd", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}], ",", "C2"}], "]"}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"indexTableQ", "[", "tst", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"idc", "[", "tst", "]"}], ",", 
     RowBox[{"associativeQ", "[", "tst", "]"}], ",", 
     RowBox[{"alternativeQ", "[", "tst", "]"}], ",", 
     RowBox[{"MoufangQ", "[", "tst", "]"}], ",", 
     RowBox[{"dico", "[", "tst", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"id", "[", 
   RowBox[{"tst", "=", 
    RowBox[{"mp", "[", "\"\<Q8C2M\>\"", "]"}]}], "]"}], ";"}], "\n", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"indexTableQ", "[", "tst", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"idc", "[", "tst", "]"}], ",", 
     RowBox[{"associativeQ", "[", "tst", "]"}], ",", 
     RowBox[{"alternativeQ", "[", "tst", "]"}], ",", 
     RowBox[{"MoufangQ", "[", "tst", "]"}], ",", 
     RowBox[{"dico", "[", "tst", "]"}]}], "}"}]}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Not conservative.\"\>", ",", "False", ",", "False", ",", 
   "False", ",", 
   RowBox[{"{", 
    RowBox[{"20", ",", "12", ",", "31"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4256465444153695`*^9, 3.42570377665625*^9, {3.428510270234375*^9, 
   3.428510287859375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Q8C2M\"\>", ",", "False", ",", "True", ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{"20", ",", "12", ",", "31"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4256465444153695`*^9, 3.42570377665625*^9, {3.428510270234375*^9, 
   3.4285102895625*^9}}]
}, Open  ]],

Cell[TextData[{
 "Other Clifford-like algebras are created by the ",
 StyleBox["clf",
  FontSlant->"Italic"],
 " routine, but their protoloops are generated by other routines:-"
}], "Text",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.428510492625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test 5. Generalized Clifford Algebra validation & listing.", \
"Subsubsection",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"clcases", "=", "0"}], ";", 
  RowBox[{"cld", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Characters", "[", 
            RowBox[{"loop", "[", 
             RowBox[{"[", 
              RowBox[{"m", ",", "n", ",", "4"}], "]"}], "]"}], "]"}], ",", 
           "2"}], "]"}], "==", 
         RowBox[{"{", 
          RowBox[{"\"\<c\>\"", ",", "\"\<l\>\""}], "}"}]}], ",", 
        RowBox[{
         RowBox[{"clcases", "++"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"idc", "[", "]"}], "\[NotEqual]", 
            RowBox[{"loop", "[", 
             RowBox[{"[", 
              RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}]}], ",", 
           RowBox[{"Print", "[", 
            RowBox[{"{", 
             RowBox[{"m", ",", "n"}], "}"}], "]"}]}], "]"}], ";", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"cld", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"loop", "[", 
              RowBox[{"[", 
               RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"loop", "[", 
              RowBox[{"[", 
               RowBox[{"m", ",", "n", ",", "4"}], "]"}], "]"}]}], "}"}]}], 
          "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "33"}], "}"}]}], "]"}], ";", 
  RowBox[{"{", 
   RowBox[{"clcases", ",", "\"\< have clf prescriptions\>\""}], 
   "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4285103191875*^9, 3.428510385859375*^9}, 
   3.42851045353125*^9, {3.42851054584375*^9, 3.428510628234375*^9}, {
   3.42851065953125*^9, 3.428510678796875*^9}, 3.428510710265625*^9, {
   3.428510745640625*^9, 3.428510805265625*^9}, 3.42851085196875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"14", ",", "\<\" have clf prescriptions\"\>"}], "}"}]], "Output",
 CellChangeTimes->{
  3.42851059225*^9, 3.428510629640625*^9, {3.428510660859375*^9, 
   3.428510680359375*^9}, 3.428510719125*^9, 3.42851075553125*^9, 
   3.4285108065*^9, 3.428510853328125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Test 5a. Clifford Algebra Inverses & shape conservation.", \
"Subsubsection",
 CellChangeTimes->{
  3.4257180490625*^9, {3.425718167953125*^9, 3.425718217234375*^9}, {
   3.4262394501696644`*^9, 3.4262394596852894`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", "3", "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{
       "3", ",", "1", ",", "4", ",", "1", ",", "5", ",", "9", ",", "2", ",", 
        "6"}], "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", 
      RowBox[{"B", "=", 
       RowBox[{"{", 
        RowBox[{
        "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", 
         "8"}], "}"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636769859375*^9}, {3.425718376734375*^9, 
   3.425718389109375*^9}, 3.4285109904375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL3\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["123", "1825"], ",", 
     RowBox[{"-", 
      FractionBox["41", "1825"]}], ",", 
     FractionBox["778", "9125"], ",", 
     FractionBox["453", "9125"], ",", 
     RowBox[{"-", 
      FractionBox["179", "9125"]}], ",", 
     RowBox[{"-", 
      FractionBox["529", "9125"]}], ",", 
     FractionBox["12", "1825"], ",", 
     RowBox[{"-", 
      FractionBox["36", "1825"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "103"}], ",", 
     RowBox[{"-", "52"}], ",", "131", ",", "58", ",", 
     RowBox[{"-", "93"}], ",", 
     RowBox[{"-", "44"}], ",", "124", ",", "52"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", 
     "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"17", "+", 
      RowBox[{"94", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"17", "-", 
      RowBox[{"94", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.42563676203125*^9, 3.4256367713125*^9}, 
   3.42571822284375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636793625*^9}, {3.4257184019375*^9, 
   3.425718429171875*^9}, 3.42851099121875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL21\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["73", "875"], ",", 
     RowBox[{"-", 
      FractionBox["73", "2625"]}], ",", 
     FractionBox["722", "7875"], ",", 
     FractionBox["439", "7875"], ",", 
     RowBox[{"-", 
      FractionBox["61", "7875"]}], ",", 
     FractionBox["97", "7875"], ",", 
     RowBox[{"-", 
      FractionBox["52", "2625"]}], ",", 
     FractionBox["52", "875"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"121", ",", "36", ",", 
     RowBox[{"-", "107"}], ",", 
     RowBox[{"-", "60"}], ",", 
     RowBox[{"-", "93"}], ",", 
     RowBox[{"-", "44"}], ",", "124", ",", "52"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", 
     "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "125"}], ",", "63"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4256367949375*^9, 3.4257182229375*^9, 
  3.425718435859375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636769859375*^9}, {3.42563680509375*^9, 
   3.425636809859375*^9}, {3.425718447046875*^9, 3.425718455484375*^9}, 
   3.428510991953125*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL12\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["369", "13061"], ",", 
     RowBox[{"-", 
      FractionBox["123", "13061"]}], ",", 
     RowBox[{"-", 
      FractionBox["586", "13061"]}], ",", 
     RowBox[{"-", 
      FractionBox["405", "13061"]}], ",", 
     FractionBox["419", "13061"], ",", 
     FractionBox["961", "13061"], ",", 
     FractionBox["224", "13061"], ",", 
     RowBox[{"-", 
      FractionBox["672", "13061"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"29", ",", "54", ",", 
     RowBox[{"-", "107"}], ",", 
     RowBox[{"-", "60"}], ",", "15", ",", "62", ",", "124", ",", "52"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", 
     "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "65"}], "-", 
      RowBox[{"94", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "65"}], "+", 
      RowBox[{"94", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.425636811140625*^9, 3.425718222984375*^9, 
  3.425718458828125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", 
     RowBox[{"0", ",", "3"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636769859375*^9}, {3.425636825046875*^9, 
   3.425636826203125*^9}, {3.425718468421875*^9, 3.425718474953125*^9}, 
   3.428510992625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL03\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["15", "7031"]}], ",", 
     RowBox[{"-", 
      FractionBox["361", "21093"]}], ",", 
     FractionBox["154", "21093"], ",", 
     RowBox[{"-", 
      FractionBox["643", "21093"]}], ",", 
     RowBox[{"-", 
      FractionBox["959", "21093"]}], ",", 
     RowBox[{"-", 
      FractionBox["1181", "21093"]}], ",", 
     RowBox[{"-", 
      FractionBox["440", "21093"]}], ",", 
     FractionBox["252", "7031"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "49"}], ",", "54", ",", "131", ",", 
     RowBox[{"-", "60"}], ",", "13", ",", "62", ",", 
     RowBox[{"-", "104"}], ",", "52"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", 
     "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"79", ",", "267"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.425636827203125*^9, 3.425718223046875*^9, 
  3.4257184770625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", "4", "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{
       "3", ",", "1", ",", "4", ",", "1", ",", "5", ",", "9", ",", "2", ",", 
        "6", ",", "5", ",", "3", ",", "5", ",", "8", ",", "9", ",", "7", ",", 
        "9", ",", "3"}], "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", 
      RowBox[{"B", "=", 
       RowBox[{"{", 
        RowBox[{
        "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", 
         "8", ",", "2", ",", "8", ",", "4", ",", "5", ",", "9", ",", "0", ",",
          "4", ",", "5"}], "}"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636769859375*^9}, {3.425636825046875*^9, 
   3.425636826203125*^9}, {3.425718342171875*^9, 3.42571836121875*^9}, 
   3.428510993484375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL4\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["46", "9711"], ",", 
     FractionBox["4", "747"], ",", 
     FractionBox["13", "996"], ",", 
     FractionBox["76", "9711"], ",", 
     RowBox[{"-", 
      FractionBox["61", "19422"]}], ",", 
     RowBox[{"-", 
      FractionBox["181", "6474"]}], ",", 
     FractionBox["217", "9711"], ",", 
     RowBox[{"-", 
      FractionBox["1189", "38844"]}], ",", 
     FractionBox["59", "19422"], ",", 
     RowBox[{"-", 
      FractionBox["29", "9711"]}], ",", 
     FractionBox["7", "332"], ",", 
     RowBox[{"-", 
      FractionBox["326", "9711"]}], ",", 
     RowBox[{"-", 
      FractionBox["355", "19422"]}], ",", 
     FractionBox["9", "1079"], ",", 
     RowBox[{"-", 
      FractionBox["745", "19422"]}], ",", 
     RowBox[{"-", 
      FractionBox["1003", "38844"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "279"}], ",", 
     RowBox[{"-", "173"}], ",", "48", ",", "27", ",", "17", ",", "39", ",", 
     "149", ",", 
     RowBox[{"-", "26"}], ",", 
     RowBox[{"-", "107"}], ",", 
     RowBox[{"-", "37"}], ",", "86", ",", "107", ",", "73", ",", "27", ",", 
     "99", ",", 
     RowBox[{"-", "26"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", "8",
      ",", "2", ",", "8", ",", "4", ",", "5", ",", "9", ",", "0", ",", "4", 
     ",", "5"}], "}"}], ",", 
   RowBox[{"{", "77688", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.425718364015625*^9, 3.4262388453102894`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636769859375*^9}, {3.425636825046875*^9, 
   3.425636826203125*^9}, 3.425718342171875*^9, {3.425718488421875*^9, 
   3.425718500828125*^9}, {3.4262388279821644`*^9, 3.4262388296071644`*^9}, 
   3.428510994453125*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL13\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["451", "32194"], ",", 
     RowBox[{"-", 
      FractionBox["301", "32194"]}], ",", 
     RowBox[{"-", 
      FractionBox["617", "32194"]}], ",", 
     RowBox[{"-", 
      FractionBox["275", "32194"]}], ",", 
     FractionBox["481", "32194"], ",", 
     FractionBox["955", "32194"], ",", 
     FractionBox["474", "16097"], ",", 
     RowBox[{"-", 
      FractionBox["1297", "32194"]}], ",", 
     RowBox[{"-", 
      FractionBox["95", "32194"]}], ",", 
     FractionBox["653", "32194"], ",", 
     RowBox[{"-", 
      FractionBox["29", "16097"]}], ",", 
     FractionBox["31", "16097"], ",", 
     RowBox[{"-", 
      FractionBox["1103", "32194"]}], ",", 
     FractionBox["481", "32194"], ",", 
     FractionBox["1157", "32194"], ",", 
     FractionBox["388", "16097"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "77"}], ",", 
     RowBox[{"-", "65"}], ",", 
     RowBox[{"-", "328"}], ",", 
     RowBox[{"-", "229"}], ",", "67", ",", "27", ",", "99", ",", "130", ",", 
     "67", ",", "101", ",", "118", ",", "47", ",", "19", ",", "169", ",", 
     "99", ",", 
     RowBox[{"-", "26"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", "8",
      ",", "2", ",", "8", ",", "4", ",", "5", ",", "9", ",", "0", ",", "4", 
     ",", "5"}], "}"}], ",", 
   RowBox[{"{", "64388", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4262388309509144`*^9, 3.4262388527790394`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636769859375*^9}, {3.425636825046875*^9, 
   3.425636826203125*^9}, 3.425718342171875*^9, {3.425718488421875*^9, 
   3.425718500828125*^9}, {3.4262388613102894`*^9, 3.4262388627790394`*^9}, 
   3.428510995265625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL22\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["703", "30158"], ",", 
     RowBox[{"-", 
      FractionBox["625", "30158"]}], ",", 
     FractionBox["619", "30158"], ",", 
     FractionBox["457", "30158"], ",", 
     FractionBox["373", "30158"], ",", 
     FractionBox["775", "30158"], ",", 
     RowBox[{"-", 
      FractionBox["402", "15079"]}], ",", 
     FractionBox["1283", "30158"], ",", 
     FractionBox["229", "30158"], ",", 
     FractionBox["49", "1774"], ",", 
     RowBox[{"-", 
      FractionBox["77", "15079"]}], ",", 
     FractionBox["55", "15079"], ",", 
     RowBox[{"-", 
      FractionBox["1067", "30158"]}], ",", 
     FractionBox["373", "30158"], ",", 
     RowBox[{"-", 
      FractionBox["991", "30158"]}], ",", 
     RowBox[{"-", 
      FractionBox["320", "15079"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"93", ",", "97", ",", 
     RowBox[{"-", "328"}], ",", 
     RowBox[{"-", "229"}], ",", 
     RowBox[{"-", "203"}], ",", 
     RowBox[{"-", "127"}], ",", "99", ",", "130", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "97"}], ",", "118", ",", "47", ",", "73", ",", "27", ",", 
     "99", ",", 
     RowBox[{"-", "26"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", "8",
      ",", "2", ",", "8", ",", "4", ",", "5", ",", "9", ",", "0", ",", "4", 
     ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"-", "60316"}], "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4262388650759144`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636769859375*^9}, {3.425636825046875*^9, 
   3.425636826203125*^9}, 3.425718342171875*^9, {3.425718488421875*^9, 
   3.425718500828125*^9}, {3.4262388712009144`*^9, 3.4262388725915394`*^9}, 
   3.42851099609375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL31\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["431", "11090"]}], ",", 
     FractionBox["413", "11090"], ",", 
     RowBox[{"-", 
      FractionBox["271", "11090"]}], ",", 
     RowBox[{"-", 
      FractionBox["149", "11090"]}], ",", 
     FractionBox["57", "11090"], ",", 
     RowBox[{"-", 
      FractionBox["557", "11090"]}], ",", 
     FractionBox["404", "5545"], ",", 
     RowBox[{"-", 
      FractionBox["1009", "11090"]}], ",", 
     FractionBox["63", "11090"], ",", 
     RowBox[{"-", 
      FractionBox["481", "11090"]}], ",", 
     FractionBox["171", "5545"], ",", 
     RowBox[{"-", 
      FractionBox["169", "5545"]}], ",", 
     FractionBox["781", "11090"], ",", 
     RowBox[{"-", 
      FractionBox["499", "11090"]}], ",", 
     FractionBox["341", "11090"], ",", 
     FractionBox["114", "5545"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"73", ",", "69", ",", "214", ",", "89", ",", 
     RowBox[{"-", "203"}], ",", 
     RowBox[{"-", "127"}], ",", "99", ",", "130", ",", 
     RowBox[{"-", "107"}], ",", 
     RowBox[{"-", "37"}], ",", "86", ",", "107", ",", "73", ",", "27", ",", 
     "99", ",", 
     RowBox[{"-", "26"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", "8",
      ",", "2", ",", "8", ",", "4", ",", "5", ",", "9", ",", "0", ",", "4", 
     ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"-", "22180"}], "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4262388749821644`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"id", "[", 
    RowBox[{"clf", "[", 
     RowBox[{"0", ",", "4"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B"}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sA", " ", 
     RowBox[{"shape", "[", "B", "]"}]}], "-", 
    RowBox[{"shape", "[", "AB", "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.425636559828125*^9, 3.425636696765625*^9}, {
   3.425636730625*^9, 3.425636769859375*^9}, {3.425636825046875*^9, 
   3.425636826203125*^9}, 3.425718342171875*^9, {3.425718488421875*^9, 
   3.425718500828125*^9}, 3.42851099915625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CL04\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["239", "90918"], ",", 
     RowBox[{"-", 
      FractionBox["251", "90918"]}], ",", 
     RowBox[{"-", 
      FractionBox["185", "30306"]}], ",", 
     RowBox[{"-", 
      FractionBox["1225", "90918"]}], ",", 
     RowBox[{"-", 
      FractionBox["1751", "90918"]}], ",", 
     RowBox[{"-", 
      FractionBox["55", "10102"]}], ",", 
     RowBox[{"-", 
      FractionBox["770", "45459"]}], ",", 
     FractionBox["503", "90918"], ",", 
     RowBox[{"-", 
      FractionBox["1259", "90918"]}], ",", 
     RowBox[{"-", 
      FractionBox["697", "90918"]}], ",", 
     RowBox[{"-", 
      FractionBox["202", "15153"]}], ",", 
     FractionBox["581", "45459"], ",", 
     RowBox[{"-", 
      FractionBox["1339", "90918"]}], ",", 
     FractionBox["259", "10102"], ",", 
     FractionBox["1201", "90918"], ",", 
     FractionBox["713", "45459"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "93"}], ",", 
     RowBox[{"-", "65"}], ",", "138", ",", 
     RowBox[{"-", "229"}], ",", "127", ",", "27", ",", 
     RowBox[{"-", "137"}], ",", "130", ",", 
     RowBox[{"-", "145"}], ",", "101", ",", 
     RowBox[{"-", "10"}], ",", "47", ",", "27", ",", "169", ",", "9", ",", 
     RowBox[{"-", "26"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "7", ",", "1", ",", "8", ",", "2", ",", "8", ",", "1", ",", "8",
      ",", "2", ",", "8", ",", "4", ",", "5", ",", "9", ",", "0", ",", "4", 
     ",", "5"}], "}"}], ",", 
   RowBox[{"{", "181836", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.425718343546875*^9, 3.425718496921875*^9}]
}, Open  ]],

Cell["\<\
Shapes for larger Clifford algebras are not yet known, but they all have \
pairs of quartic factrs, each repeated 4 times. \
\>", "Text",
 CellChangeTimes->{{3.4262388924509144`*^9, 3.4262389264509144`*^9}, {
  3.4262392544977894`*^9, 3.4262393085915394`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"gmap", "[", 
    RowBox[{
     RowBox[{"cl", "[", "5", "]"}], ",", "pow2"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4262389460759144`*^9, 3.4262389722634144`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"652006216866072576085230444378204409", "-", 
     RowBox[{"3468053032956781722423279616", " ", "a"}], "+", 
     RowBox[{"6226906717107104150", " ", 
      SuperscriptBox["a", "2"]}], "-", 
     RowBox[{"4294967296", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"652006213398019550970293470893582585", "+", 
     RowBox[{"3468053017273092228840931328", " ", "a"}], "+", 
     RowBox[{"6226906704222202262", " ", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"4294967296", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"]}]], "Output",
 CellChangeTimes->{3.4262389752634144`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"gmap", "[", 
    RowBox[{
     RowBox[{"cl", "[", 
      RowBox[{"1", ",", "4"}], "]"}], ",", "pow2"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4262389460759144`*^9, 3.4262389917009144`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"850705919283050223959309206199168041", "-", 
     RowBox[{"3961408134014534346193518592", " ", "a"}], "+", 
     RowBox[{"6456643062581339750", " ", 
      SuperscriptBox["a", "2"]}], "-", 
     RowBox[{"4294967296", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"850705915321642098246092325662977065", "+", 
     RowBox[{"3961408117411899419173830656", " ", "a"}], "+", 
     RowBox[{"6456643049696437862", " ", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"4294967296", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"]}]], "Output",
 CellChangeTimes->{3.4262389944665394`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"gmap", "[", 
     RowBox[{
      RowBox[{"cl", "[", 
       RowBox[{"2", ",", "3"}], "]"}], ",", "pow2"}], "]"}], "]"}], ",", 
   RowBox[{"GaussianIntegers", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4262389460759144`*^9, 3.4262389722634144`*^9}, {
   3.4262390050759144`*^9, 3.4262390068571644`*^9}, 3.4262392393884144`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"662314295477605138378642714423392249", "-", 
       RowBox[{"1747680055461713328637739008", " ", "\[ImaginaryI]"}]}], 
      ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7866711303241351168", "+", 
        RowBox[{"3495360110923426655127994368", " ", "\[ImaginaryI]"}]}], 
       ")"}], " ", "a"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6239057414384626026", "-", 
        RowBox[{"6442450944", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox["a", "2"]}], "-", 
     RowBox[{"4294967296", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"662314295477605138378642714423392249", "+", 
       RowBox[{"1747680055461713328637739008", " ", "\[ImaginaryI]"}]}], 
      ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7866711303241351168", "-", 
        RowBox[{"3495360110923426655127994368", " ", "\[ImaginaryI]"}]}], 
       ")"}], " ", "a"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6239057414384626026", "+", 
        RowBox[{"6442450944", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"4294967296", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"]}]], "Output",
 CellChangeTimes->{3.4262390106071644`*^9, 3.4262392421071644`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"gmap", "[", 
    RowBox[{
     RowBox[{"cl", "[", 
      RowBox[{"3", ",", "2"}], "]"}], ",", "pow2"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4262389460759144`*^9, 3.4262389722634144`*^9}, {
  3.4262390239977894`*^9, 3.4262390253884144`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"652046013989091233300315881645353209", "-", 
     RowBox[{"3468158872765963518588502016", " ", "a"}], "+", 
     RowBox[{"6226953640340793750", " ", 
      SuperscriptBox["a", "2"]}], "-", 
     RowBox[{"4294967296", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"652046010520932368376293320730945785", "+", 
     RowBox[{"3468158857082081607535280128", " ", "a"}], "+", 
     RowBox[{"6226953627455891862", " ", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"4294967296", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"]}]], "Output",
 CellChangeTimes->{3.4262390273102894`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"gmap", "[", 
     RowBox[{
      RowBox[{"cl", "[", 
       RowBox[{"4", ",", "1"}], "]"}], ",", "pow2"}], "]"}], "]"}], ",", 
   RowBox[{"GaussianIntegers", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4262389460759144`*^9, 3.4262389722634144`*^9}, {
   3.4262390367321644`*^9, 3.4262390380915394`*^9}, 3.4262392269665394`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"652006215739274166024203892726049017", "-", 
       RowBox[{"1734026513364937503919833088", " ", "\[ImaginaryI]"}]}], 
      ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7841844748259147776", "+", 
        RowBox[{"3468053026729875005692182528", " ", "\[ImaginaryI]"}]}], 
       ")"}], " ", "a"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6226906711380612714", "-", 
        RowBox[{"6442450944", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox["a", "2"]}], "-", 
     RowBox[{"4294967296", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"652006215739274166024203892726049017", "+", 
       RowBox[{"1734026513364937503919833088", " ", "\[ImaginaryI]"}]}], 
      ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7841844748259147776", "-", 
        RowBox[{"3468053026729875005692182528", " ", "\[ImaginaryI]"}]}], 
       ")"}], " ", "a"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6226906711380612714", "+", 
        RowBox[{"6442450944", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"4294967296", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"]}]], "Output",
 CellChangeTimes->{3.4262390400290394`*^9, 3.4262392290134144`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"gmap", "[", 
     RowBox[{
      RowBox[{"cl", "[", 
       RowBox[{"0", ",", "5"}], "]"}], ",", "pow2"}], "]"}], "]"}], ",", 
   RowBox[{"GaussianIntegers", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4262389460759144`*^9, 3.4262389722634144`*^9}, {
   3.4262390539665394`*^9, 3.4262390545759144`*^9}, 3.4262392017946644`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2363071992506517103669647258495974969", "-", 
       RowBox[{"3301173438094347399015170048", " ", "\[ImaginaryI]"}]}], 
      ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"10760318044963094528", "+", 
        RowBox[{"6602346876188694795882856448", " ", "\[ImaginaryI]"}]}], 
       ")"}], " ", "a"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7685860699344835926", "-", 
        RowBox[{"6442450944", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox["a", "2"]}], "-", 
     RowBox[{"4294967296", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2363071992506517103669647258495974969", "+", 
       RowBox[{"3301173438094347399015170048", " ", "\[ImaginaryI]"}]}], 
      ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"10760318044963094528", "-", 
        RowBox[{"6602346876188694795882856448", " ", "\[ImaginaryI]"}]}], 
       ")"}], " ", "a"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7685860699344835926", "+", 
        RowBox[{"6442450944", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"4294967296", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["a", "3"]}], "+", 
     SuperscriptBox["a", "4"]}], ")"}], "4"]}]], "Output",
 CellChangeTimes->{3.4262390566071644`*^9, 3.4262392041696644`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test 6. Signed Table Generation.", "Subsubsection",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tscases", "=", "0"}], ";", 
  RowBox[{"tsd", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Characters", "[", 
            RowBox[{"loop", "[", 
             RowBox[{"[", 
              RowBox[{"m", ",", "n", ",", "4"}], "]"}], "]"}], "]"}], ",", 
           "2"}], "]"}], "==", 
         RowBox[{"{", 
          RowBox[{"\"\<t\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
        RowBox[{
         RowBox[{"tscases", "++"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"idc", "[", "]"}], "\[NotEqual]", 
            RowBox[{"loop", "[", 
             RowBox[{"[", 
              RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}]}], ",", 
           RowBox[{"Print", "[", 
            RowBox[{"{", 
             RowBox[{"m", ",", "n"}], "}"}], "]"}]}], "]"}], ";", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"tsd", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"loop", "[", 
              RowBox[{"[", 
               RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"loop", "[", 
              RowBox[{"[", 
               RowBox[{"m", ",", "n", ",", "4"}], "]"}], "]"}]}], "}"}]}], 
          "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "24"}], "}"}]}], "]"}], ";", 
  RowBox[{"{", 
   RowBox[{"tscases", ",", "\"\< have ts prescriptions\>\""}], 
   "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"37", ",", "\<\" have ts prescriptions\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.42416745971875*^9, 3.425627623125*^9, 
  3.425718223078125*^9, 3.428511330015625*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Validation of Relator Rules.", "Subsection",
 PageWidth->WindowWidth],

Cell["Test 7. Relator rules validation.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ung", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"totl", "=", "1"}], ";", 
  RowBox[{"relco", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"totl", "++"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"loop", "[", 
           RowBox[{"[", 
            RowBox[{"m", ",", "n", ",", "5"}], "]"}], "]"}], "===", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"ung", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"m", ",", "n"}], "}"}], ",", 
             RowBox[{"loop", "[", 
              RowBox[{"[", 
               RowBox[{"m", ",", "n", ",", "1"}], "]"}], "]"}]}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"relco", "++"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "2", ",", "lp"}], "}"}]}], "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
   "totl", ",", "\"\< loops, \>\"", ",", " ", "relco", ",", 
    "\"\< relators.\>\""}], "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
    RowBox[{"Length", "[", "ung", "]"}], " ", 
    "\"\< tables without generation rules.\>\""}], "]"}], ";"}], "\n", 
 RowBox[{"Print", "[", 
  RowBox[{
   RowBox[{"Length", "[", 
    RowBox[{"unpg", "=", 
     RowBox[{"Intersection", "[", 
      RowBox[{"unp", ",", "ung"}], "]"}]}], "]"}], " ", 
   "\"\< tables without prescription or generation rules.\>\""}], 
  "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "816", "\[InvisibleSpace]", "\<\" loops, \"\>", "\[InvisibleSpace]", "466", 
   "\[InvisibleSpace]", "\<\" relators.\"\>"}],
  SequenceForm[816, " loops, ", 466, " relators."],
  Editable->False]], "Print",
 CellChangeTimes->{3.4256642690932083`*^9, 3.428511365625*^9}],

Cell[BoxData[
 RowBox[{"349", " ", "\<\" tables without generation rules.\"\>"}]], "Print",
 CellChangeTimes->{3.4256642690932083`*^9, 3.428511365640625*^9}],

Cell[BoxData[
 RowBox[{"153", 
  " ", "\<\" tables without prescription or generation rules.\"\>"}]], "Print",\

 CellChangeTimes->{3.4256642690932083`*^9, 3.42851136565625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pr", "=", "0"}], ";", 
   RowBox[{"genco", "=", "0"}], ";", 
   RowBox[{"tt", "=", 
    RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], 
  RowBox[{"(*", 
   StyleBox["SLOW",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["*)",
    FontColor->GrayLevel[0.5]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"pr", "==", "1"}], ",", 
         RowBox[{"Print", "[", 
          RowBox[{"gd", "[", 
           RowBox[{"m", ",", "n"}], "]"}], "]"}]}], "]"}], ";", 
       RowBox[{"If", "[", "\[InvisibleSpace]", 
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"ung", ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", "n"}], "}"}]}], "]"}], "===", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"gi", "=", 
              RowBox[{"id", "[", 
               RowBox[{"mp", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"m", ",", "n"}], "}"}], ",", "1"}], "]"}], "]"}]}], 
             ")"}], "\[NotEqual]", 
            RowBox[{"(", 
             RowBox[{"gj", "=", 
              RowBox[{
               RowBox[{"gd", "[", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "n"}], "}"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ")"}]}], ",", 
           RowBox[{"Print", "[", 
            RowBox[{"{", 
             RowBox[{"gi", ",", "gj", ",", "m", ",", "n"}], "}"}], "]"}], ",",
            
           RowBox[{
            RowBox[{"genco", "++"}], ";", 
            RowBox[{"mn", "=", 
             RowBox[{"{", 
              RowBox[{"m", ",", "n"}], "}"}]}]}]}], "]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"loop", "[", 
          RowBox[{"[", "m", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "3", ",", 
      RowBox[{"lp", "-", "1"}]}], "}"}]}], "]"}], "//", 
  "Timing"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"genco", ",", "\"\< Loops tested\>\""}], 
  "}"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "]"}], "-", "tt"}], ",", 
    "\"\<actual seconds.\\nLast mm,nn=\>\"", ",", "mn"}], "}"}], 
  "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"454.609`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.4285118465625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"465", ",", "\<\" Loops tested\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.428511846578125*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "461.53125`10.115746105668485", 
   ",", "\<\"actual seconds.\\nLast mm,nn=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"104", ",", "1"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.42851184659375*^9}]
}, Open  ]],

Cell["Many 64-element group descriptions are incomplete.", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "1.4 ",
 StyleBox["hoopTest",
  FontSlant->"Italic"],
 " for Hoop Algebras."
}], "Subsection",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\t",
 StyleBox["hoopTest[loop_identifier]",
  FontSlant->"Italic"],
 " looks in the database for a ",
 StyleBox["shape",
  FontSlant->"Italic"],
 " for the loop, and attempts to create it if it is not there. It aborts if \
the conservation test fails. Division using  ",
 StyleBox["genInverse",
  FontSlant->"Italic"],
 " is tested. Then polar-vector transformations are tested. Polar algebras \
are tested for +ve powers and roots, and (if abelian) for a valid solution of \
a random real quadratic equation. Finally, negative powers are tested (as \
non-abelian loops fail this test it is only applied to abelian tables, and is \
repeated until a vec with the correct shape is found, for up to 10 times.) \
The output identifies the loop (if it is in the database) and reports which \
tests have been passed. Test 10 tests the loops with known shapes (and the \
first non-hoop with known shape, Q4n):-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Test 8. hoopTest for small Loops.",
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"hoopTest", "[", 
     RowBox[{"hoopList", "[", 
      RowBox[{"[", "ijk", "]"}], "]"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"ijk", ",", 
     RowBox[{
      RowBox[{"Length", "[", "hoopList", "]"}], "-", "3"}]}], "}"}]}], 
  "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData["\<\"Conservative C2, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers, hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409845446644`*^9}],

Cell[BoxData["\<\"Conservative C4c, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409845759144`*^9}],

Cell[BoxData["\<\"Conservative C3, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409845915394`*^9}],

Cell[BoxData["\<\"Conservative C3C2c, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409846384144`*^9}],

Cell[BoxData["\<\"Conservative C12c, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409847634144`*^9}],

Cell[BoxData["\<\"Conservative C3i, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409848415394`*^9}],

Cell[BoxData["\<\"Conservative C4C3c, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409849352894`*^9}],

Cell[BoxData["\<\"Conservative C3C3j, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409849821644`*^9}],

Cell[BoxData["\<\"Conservative C9j, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409849821644`*^9}],

Cell[BoxData["\<\"Conservative C9J, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409850134144`*^9}],

Cell[BoxData["\<\"Conservative C4, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers, hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409850915394`*^9}],

Cell[BoxData["\<\"Conservative K, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers, hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409851071644`*^9}],

Cell[BoxData["\<\"Conservative Qr, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409851384144`*^9}],

Cell[BoxData["\<\"Conservative P4, division, polar-vector, +ve Powers, \
hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409851696644`*^9}],

Cell[BoxData["\<\"Conservative C5, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409851852894`*^9}],

Cell[BoxData["\<\"Conservative Dav, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409852321644`*^9}],

Cell[BoxData["\<\"Conservative O2, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409852790394`*^9}],

Cell[BoxData["\<\"Conservative C8r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409853415394`*^9}],

Cell[BoxData["\<\"Conservative C3C4j, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409853727894`*^9}],

Cell[BoxData["\<\"Conservative CL2, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409853884144`*^9}],

Cell[BoxData["\<\"Conservative C4C2r, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers, hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409854665394`*^9}],

Cell[BoxData["\<\"Conservative P16c, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409854821644`*^9}],

Cell[BoxData["\<\"Conservative C8c, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409854977894`*^9}],

Cell[BoxData["\<\"Conservative C5, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409855290394`*^9}],

Cell[BoxData["\<\"Conservative C3C2, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers, hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409856071644`*^9}],

Cell[BoxData["\<\"Conservative D3, division, polar-vector, +ve Powers, -ve \
Powers, hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409856696644`*^9}],

Cell[BoxData["\<\"Conservative C3C4c, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409857634144`*^9}],

Cell[BoxData["\<\"Conservative Q12c, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409857946644`*^9}],

Cell[BoxData["\<\"Conservative Q12r, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409858415394`*^9}],

Cell[BoxData["\<\"Conservative Q12r, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409859040394`*^9}],

Cell[BoxData["\<\"Conservative g2401c, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409859509144`*^9}],

Cell[BoxData["\<\"Conservative D6r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409859821644`*^9}],

Cell[BoxData["\<\"Conservative D3C2c, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409860290394`*^9}],

Cell[BoxData["\<\"Conservative KC3c, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409860446644`*^9}],

Cell[BoxData["\<\"Conservative C3Kr, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409860759144`*^9}],

Cell[BoxData["\<\"Conservative Cl3r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409861696644`*^9}],

Cell[BoxData["\<\"Conservative Clm3r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409861852894`*^9}],

Cell[BoxData["\<\"Conservative C8, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409862321644`*^9}],

Cell[BoxData["\<\"Conservative KC2, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409867790394`*^9}],

Cell[BoxData["\<\"Conservative C4C2, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409873259144`*^9}],

Cell[BoxData["\<\"Conservative D4, division, polar-vector, +ve Powers, -ve \
Powers, hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409874352894`*^9}],

Cell[BoxData["\<\"Conservative Q8, division, polar-vector, +ve Powers, \
hyPolar test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409875759144`*^9}],

Cell[BoxData["\<\"Conservative Octr, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409877009144`*^9}],

Cell[BoxData["\<\"Conservative KiC4c, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409878571644`*^9}],

Cell[BoxData["\<\"Conservative O4, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409881384144`*^9}],

Cell[BoxData["\<\"Conservative O4a, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409882321644`*^9}],

Cell[BoxData["\<\"Conservative O4b, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409882634144`*^9}],

Cell[BoxData["\<\"Conservative C4C4c, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409884352894`*^9}],

Cell[BoxData["\<\"Conservative C4C4r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409885290394`*^9}],

Cell[BoxData["\<\"Conservative Q8C2r, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409886540394`*^9}],

Cell[BoxData["\<\"Conservative C2D4r, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409888102894`*^9}],

Cell[BoxData["\<\"Conservative P8, division, polar-vector test(s) \
passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409889821644`*^9}],

Cell[BoxData["\<\"Conservative CL3, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409890290394`*^9}],

Cell[BoxData["\<\"Conservative C4iC4c, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409891071644`*^9}],

Cell[BoxData["\<\"Conservative QC2r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409892477894`*^9}],

Cell[BoxData["\<\"Conservative KiC4r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409893102894`*^9}],

Cell[BoxData["\<\"Conservative CL21, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409894509144`*^9}],

Cell[BoxData["\<\"Conservative CL03, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409896227894`*^9}],

Cell[BoxData["\<\"Conservative Octs, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409897165394`*^9}],

Cell[BoxData["\<\"Conservative C3C3, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409908415394`*^9}],

Cell[BoxData["\<\"Conservative C9, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409990134144`*^9}],

Cell[BoxData["\<\"Conservative C6C3c, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409991540394`*^9}],

Cell[BoxData["\<\"Conservative C3C4, division, polar-vector, +ve Powers, \
quadratic eqn., -ve Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262409995290394`*^9}],

Cell[BoxData["\<\"Conservative C3K, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410003259144`*^9}],

Cell[BoxData["\<\"D8 Isomorph. Protoloop factors NOT conserved\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410003727894`*^9}],

Cell[BoxData["\<\"D8 No other test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410003727894`*^9}],

Cell[BoxData["\<\"Conservative Q12, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410005602894`*^9}],

Cell[BoxData["\<\"Conservative D3C2, division, polar-vector, +ve Powers \
test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410006852894`*^9}],

Cell[BoxData["\<\"Conservative A4, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410007790394`*^9}],

Cell[BoxData["\<\"Conservative C3Qr, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410009352894`*^9}],

Cell[BoxData["\<\"Conservative C3P4, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410009977894`*^9}],

Cell[BoxData["\<\"Conservative C6Kr, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410010915394`*^9}],

Cell[BoxData["\<\"Conservative C3KC2r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410012009144`*^9}],

Cell[BoxData["\<\"Conservative Q12C2c, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410013415394`*^9}],

Cell[BoxData["\<\"Conservative Q16, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410014977894`*^9}],

Cell[BoxData["\<\"Conservative D4C2, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410016540394`*^9}],

Cell[BoxData["\<\"Conservative C4C4, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410020290394`*^9}],

Cell[BoxData["\<\"Conservative Q8C2, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410022321644`*^9}],

Cell[BoxData["\<\"Conservative KK, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410038259144`*^9}],

Cell[BoxData["\<\"Conservative C4K, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410053102894`*^9}],

Cell[BoxData["\<\"Conservative KiC4, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410055446644`*^9}],

Cell[BoxData["\<\"Conservative C4iC4, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410056540394`*^9}],

Cell[BoxData["\<\"Conservative P16, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410058259144`*^9}],

Cell[BoxData["\<\"Conservative Oct, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410060290394`*^9}],

Cell[BoxData["\<\"Conservative Q8M2, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410062009144`*^9}],

Cell[BoxData["\<\"Conservative CL4, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410063727894`*^9}],

Cell[BoxData["\<\"Conservative CL13, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410065602894`*^9}],

Cell[BoxData["\<\"Conservative CL22, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410067321644`*^9}],

Cell[BoxData["\<\"Conservative CL31, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410069040394`*^9}],

Cell[BoxData["\<\"Conservative r31r, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410070915394`*^9}],

Cell[BoxData["\<\"Conservative CL04, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410072477894`*^9}],

Cell[BoxData["\<\"Conservative O8, division, polar-vector, +ve Powers, -ve \
Powers test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410088102894`*^9}],

Cell[BoxData["\<\"Conservative C3C4C2, division test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410095446644`*^9}],

Cell[BoxData["\<\"Q4n Isomorph. Protoloop factors NOT conserved\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410095602894`*^9}],

Cell[BoxData["\<\"Q4n No other test(s) passed\"\>"], "Print",
 CellChangeTimes->{3.4262395941540394`*^9, 3.4262402979977894`*^9, 
  3.4262408219821644`*^9, 3.4262410095602894`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5 Plex-conjugates.", "Subsection",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Test", " ", "9.", " ", "Plexes"}], " ", "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"mcount", "=", "0"}], ";", 
    RowBox[{"pl", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Do", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"plex", "=."}], ";", 
         RowBox[{"id", "[", 
          RowBox[{"mp", "[", 
           RowBox[{"m1", ",", "n1"}], "]"}], "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Head", "[", 
               RowBox[{"sh", "[", "gmn", "]"}], "]"}], "\[Equal]", "List"}], 
             ")"}], "&&", 
            RowBox[{"ListQ", "[", "plex", "]"}]}], ",", "\[IndentingNewLine]",
            
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"pl", ",", "gmn"}], "]"}], ";", 
            RowBox[{"mcount", "++"}], ";"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"n1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"loop", "[", 
            RowBox[{"[", "m1", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "2", ",", "16"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"{", 
     RowBox[{"mcount", ",", "\"\< plex-conjugates\>\"", ",", "pl"}], "}"}], 
    "]"}]}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"50", ",", "\<\" plex-conjugates\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C2\"\>", ",", "\<\"C4c\"\>", ",", "\<\"C3\"\>", 
     ",", "\<\"C3C2c\"\>", ",", "\<\"K\"\>", ",", "\<\"C4\"\>", 
     ",", "\<\"Qr\"\>", ",", "\<\"O2\"\>", ",", "\<\"Dav\"\>", 
     ",", "\<\"CL2\"\>", ",", "\<\"P4\"\>", ",", "\<\"C4C2r\"\>", 
     ",", "\<\"C3C4j\"\>", ",", "\<\"C8r\"\>", ",", "\<\"P16c\"\>", 
     ",", "\<\"C3C2\"\>", ",", "\<\"Q12c\"\>", ",", "\<\"Q12r\"\>", 
     ",", "\<\"KC3c\"\>", ",", "\<\"C3C4c\"\>", ",", "\<\"D3C2c\"\>", 
     ",", "\<\"Clm3r\"\>", ",", "\<\"g2401c\"\>", ",", "\<\"C8\"\>", 
     ",", "\<\"C4C2\"\>", ",", "\<\"Q8\"\>", ",", "\<\"KC2\"\>", 
     ",", "\<\"C4C4c\"\>", ",", "\<\"C4iC4c\"\>", ",", "\<\"QC2r\"\>", 
     ",", "\<\"Q8C2r\"\>", ",", "\<\"O4\"\>", ",", "\<\"O4a\"\>", 
     ",", "\<\"O4b\"\>", ",", "\<\"P8\"\>", ",", "\<\"C2D4r\"\>", 
     ",", "\<\"CL3\"\>", ",", "\<\"CL3\"\>", ",", "\<\"Octr\"\>", 
     ",", "\<\"KiC4r\"\>", ",", "\<\"CL21\"\>", ",", "\<\"CL03\"\>", 
     ",", "\<\"C4C4r\"\>", ",", "\<\"Octs\"\>", ",", "\<\"C3C3\"\>", 
     ",", "\<\"C3C4\"\>", ",", "\<\"C3K\"\>", ",", "\<\"C3KC2r\"\>", 
     ",", "\<\"C6Kr\"\>", ",", "\<\"r31r\"\>"}], "}"}]}], "}"}]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6 Remainders.", "Subsubsection",
 PageWidth->WindowWidth],

Cell["\<\
\tMultiplication (and division) using hoops with disparate zero sizes is not \
conservative unless the appropriate sizes of the multiplicands are \
\"ejected\" as remainders. The product is \"projected\" onto a sub-algebra \
with zeroed sizes. This is tested by the following procedure, which \
identifies the hoop, pads short vectors with zeroes, multiplies them, saves \
the result as R1, AB, R2, shows the results and their shapes, and confirms \
that AB/B+Rl=A & AB/A+Rr=B.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"muldiv", "[", 
    RowBox[{"Ao_", ",", "Bo_", ",", "H_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"sh", "[", "H", "]"}], "]"}]}], ",", 
       RowBox[{"z", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "32"}], "}"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"gmn", "=", "H"}], ";", 
      RowBox[{"glo", "=", 
       RowBox[{"mp", "[", "H", "]"}]}], ";", 
      RowBox[{"mm", "=", 
       RowBox[{"Length", "[", "glo", "]"}]}], ";", 
      RowBox[{"s", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<shape\>\"", ",", 
           RowBox[{"Range", "[", "s", "]"}]}], "}"}], "]"}], "]"}]}], ";", 
      RowBox[{"A", "=", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Append", "[", 
           RowBox[{"Ao", ",", "z"}], "]"}], "]"}], ",", "mm"}], "]"}]}], ";", 
      
      RowBox[{"B", "=", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Append", "[", 
           RowBox[{"Bo", ",", "z"}], "]"}], "]"}], ",", "mm"}], "]"}]}], ";", 
      
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<A  =\>\"", "}"}], ",", "A"}], "]"}], "]"}], 
          ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<B  =\>\"", "}"}], ",", "B"}], "]"}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<AB =\>\"", "}"}], ",", 
             RowBox[{"AB", "=", 
              RowBox[{"hoopTimes", "[", 
               RowBox[{"A", ",", "B"}], "]"}]}]}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<Rl =\>\"", "}"}], ",", 
             RowBox[{"R1", "=", "Rl"}]}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<Rr =\>\"", "}"}], ",", 
             RowBox[{"R2", "=", "Rr"}]}], "]"}], "]"}]}], "}"}], "//", "tf"}],
        "]"}], ";", "\n", 
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{"Chop", "[", 
         RowBox[{"{", 
          RowBox[{"s", ",", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Append", "[", 
             RowBox[{
              RowBox[{"{", "\"\<shA  =\>\"", "}"}], ",", 
              RowBox[{"shape", "[", "A", "]"}]}], "]"}], "]"}], ",", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Append", "[", 
             RowBox[{
              RowBox[{"{", "\"\<shB  =\>\"", "}"}], ",", 
              RowBox[{"shape", "[", "B", "]"}]}], "]"}], "]"}], ",", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Append", "[", 
             RowBox[{
              RowBox[{"{", "\"\<shAB =\>\"", "}"}], ",", 
              RowBox[{"shape", "[", "AB", "]"}]}], "]"}], "]"}], ",", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Append", "[", 
             RowBox[{
              RowBox[{"{", "\"\<shRl =\>\"", "}"}], ",", 
              RowBox[{"shape", "[", "Rl", "]"}]}], "]"}], "]"}], ",", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Append", "[", 
             RowBox[{
              RowBox[{"{", "\"\<shRr =\>\"", "}"}], ",", 
              RowBox[{"shape", "[", "Rr", "]"}]}], "]"}], "]"}]}], "}"}], 
         "]"}], "//", "tf"}], "]"}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"Chop", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<AB/B+Rl=A  \>\"", ",", 
          RowBox[{
           RowBox[{"hoopTimes", "[", 
            RowBox[{"AB", ",", 
             RowBox[{"hoopInverse", "[", "B", "]"}]}], "]"}], "+", "R1"}], 
          ",", "\"\<\\nAB/A+Rr=B  \>\"", ",", 
          RowBox[{
           RowBox[{"hoopTimes", "[", 
            RowBox[{
             RowBox[{"hoopInverse", "[", "A", "]"}], ",", "AB"}], "]"}], "+", 
           "R2"}]}], "}"}], "]"}], "]"}]}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth],

Cell["\<\
The remainders have been checked for all the members of hoopList. Examples, \
with some zero sizes, are:- \
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"muldiv", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "3.", ",", "4.", ",", "1.", ",", "0.", ",", "1.", ",", "1.", ",", "2.", 
      ",", 
      RowBox[{"-", "2."}], ",", "3.", ",", "4.", ",", 
      RowBox[{"-", "2."}], ",", "3.", ",", 
      RowBox[{"-", "1."}], ",", "0.", ",", "3.", ",", "2."}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2.", ",", "1.", ",", "2.", ",", 
      RowBox[{"-", "4."}], ",", "3.", ",", 
      RowBox[{"-", "4."}], ",", "3.", ",", "1.", ",", "0.", ",", "0.", ",", 
      RowBox[{"-", "3."}], ",", "2.", ",", "2.", ",", "4.", ",", "1.", ",", 
      RowBox[{"-", "2."}]}], "}"}], ",", "\[IndentingNewLine]", 
    "\"\<C3C4\>\""}], "]"}], ";"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"A  =\"\>", "3.`", "4.`", "1.`", "0.`", "1.`", "1.`", "2.`", 
       RowBox[{"-", "2.`"}], "3.`", "4.`", 
       RowBox[{"-", "2.`"}], "3.`"},
      {"\<\"B  =\"\>", "2.`", "1.`", "2.`", 
       RowBox[{"-", "4.`"}], "3.`", 
       RowBox[{"-", "4.`"}], "3.`", "1.`", "0.`", "0.`", 
       RowBox[{"-", "3.`"}], "2.`"},
      {"\<\"AB =\"\>", "24.`", "19.`", 
       RowBox[{"-", "18.`"}], 
       RowBox[{"-", "20.`"}], 
       RowBox[{"-", "9.`"}], "16.`", 
       RowBox[{"-", "1.`"}], "5.`", "28.`", "22.`", "4.`", 
       RowBox[{"-", "16.`"}]},
      {"\<\"Rl =\"\>", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
       "0"},
      {"\<\"Rr =\"\>", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
       "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{3.4256647078140574`*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"shape\"\>", "1", "2", "3", "4", "5", "6", "7"},
      {"\<\"shA  =\"\>", "18.`", "4.`", "34.`", "57.`", "7.`", 
       "141.69357503463522`", "34.306424965364805`"},
      {"\<\"shB  =\"\>", "3.`", "15.`", "17.`", "3.`", "39.`", 
       "75.57437415779592`", "186.42562584220408`"},
      {"\<\"shAB =\"\>", "54.`", "60.`", "578.`", "171.`", "273.`", 
       "10708.403255423254`", "6395.59674457675`"},
      {"\<\"shRl =\"\>", "0", "0", "0", "0", "0", "0", "0"},
      {"\<\"shRr =\"\>", "0", "0", "0", "0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{3.4256647079342303`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"AB/B+Rl=A  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "2.999999999999999`", ",", "4.`", ",", "0.9999999999999998`", ",", "0", 
     ",", "1.`", ",", "0.9999999999999994`", ",", "2.0000000000000004`", ",", 
     
     RowBox[{"-", "2.0000000000000004`"}], ",", "3.`", ",", "4.`", ",", 
     RowBox[{"-", "2.0000000000000004`"}], ",", "3.`"}], "}"}], 
   ",", "\<\"\\nAB/A+Rr=B  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1.9999999999999993`", ",", "0.9999999999999993`", ",", 
     "2.0000000000000013`", ",", 
     RowBox[{"-", "4.`"}], ",", "2.9999999999999982`", ",", 
     RowBox[{"-", "3.9999999999999987`"}], ",", "3.0000000000000004`", ",", 
     "1.0000000000000002`", ",", "0", ",", "0", ",", 
     RowBox[{"-", "3.`"}], ",", "2.`"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.4256647086152096`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"muldiv", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "3", ",", "4", ",", "1", ",", "0", ",", "1", ",", "1", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], "//", "N"}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "2", ",", 
       RowBox[{"-", "4"}], ",", "4", ",", "2", ",", 
       RowBox[{"-", "1"}], ",", "2"}], "}"}], "//", "N"}], ",", 
    "\[IndentingNewLine]", "\"\<CL03\>\""}], "]"}], ";"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"A  =\"\>", "3.`", "4.`", "1.`", "0.`", "1.`", "1.`", "2.`", 
       RowBox[{"-", "2.`"}]},
      {"\<\"B  =\"\>", "2.`", "1.`", "2.`", 
       RowBox[{"-", "4.`"}], "4.`", "2.`", 
       RowBox[{"-", "1.`"}], "2.`"},
      {"\<\"AB =\"\>", 
       RowBox[{"-", "8.`"}], 
       RowBox[{"-", "1.`"}], "13.`", 
       RowBox[{"-", "4.`"}], "4.`", "13.`", "1.`", 
       RowBox[{"-", "8.`"}]},
      {"\<\"Rl =\"\>", "2.5`", "3.`", "0", "0.5`", "0.5`", "0", "3.`", 
       RowBox[{"-", "2.5`"}]},
      {"\<\"Rr =\"\>", "0", "0", "0", "0", "0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{3.4256647092060595`*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"shape\"\>", "1", "2"},
      {"\<\"shA  =\"\>", "62.`", "10.`"},
      {"\<\"shB  =\"\>", "0", "100.`"},
      {"\<\"shAB =\"\>", "0", "1000.`"},
      {"\<\"shRl =\"\>", "62.`", "0"},
      {"\<\"shRr =\"\>", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{3.425664709346261*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"AB/B+Rl=A  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3.`", ",", "4.`", ",", "1.`", ",", "0", ",", "1.`", ",", "1.`", ",", 
     "1.9999999999999998`", ",", 
     RowBox[{"-", "2.`"}]}], "}"}], ",", "\<\"\\nAB/A+Rr=B  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1.9999999999999998`", ",", "0.9999999999999999`", ",", 
     "2.0000000000000004`", ",", 
     RowBox[{"-", "3.9999999999999996`"}], ",", "3.9999999999999996`", ",", 
     "2.0000000000000004`", ",", 
     RowBox[{"-", "0.9999999999999999`"}], ",", "1.9999999999999998`"}], 
    "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.425664710047269*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"muldiv", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "3", ",", "4", ",", "1", ",", "0", ",", "1", ",", "1", ",", "2", ",", 
       RowBox[{"-", "2"}], ",", "3", ",", "4", ",", 
       RowBox[{"-", "2"}], ",", "3", ",", 
       RowBox[{"-", "1"}], ",", "0", ",", "3", ",", "2"}], "}"}], "//", "N"}],
     ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "2", ",", 
       RowBox[{"-", "4"}], ",", "3", ",", 
       RowBox[{"-", "4"}], ",", "3", ",", "1", ",", "0", ",", "0", ",", 
       RowBox[{"-", "3"}], ",", "2", ",", "2", ",", "4", ",", "1", ",", 
       RowBox[{"-", "2"}]}], "}"}], "//", "N"}], ",", "\[IndentingNewLine]", 
    "\"\<D3\>\""}], "]"}], ";"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"A  =\"\>", "3.`", "4.`", "1.`", "0.`", "1.`", "1.`"},
      {"\<\"B  =\"\>", "2.`", "1.`", "2.`", 
       RowBox[{"-", "4.`"}], "3.`", 
       RowBox[{"-", "4.`"}]},
      {"\<\"AB =\"\>", "11.`", "6.`", 
       RowBox[{"-", "9.`"}], 
       RowBox[{"-", "1.`"}], 
       RowBox[{"-", "2.`"}], 
       RowBox[{"-", "5.`"}]},
      {"\<\"Rl =\"\>", "1.6666666666666667`", "1.6666666666666674`", 
       "1.6666666666666667`", "1.6666666666666667`", "1.6666666666666665`", 
       "1.6666666666666667`"},
      {"\<\"Rr =\"\>", "2.3333333333333335`", 
       RowBox[{"-", "2.333333333333333`"}], "2.3333333333333335`", 
       RowBox[{"-", "2.3333333333333335`"}], "2.3333333333333335`", 
       RowBox[{"-", "2.333333333333333`"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{3.4256647104879026`*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"shape\"\>", "1", "2", "3"},
      {"\<\"shA  =\"\>", "10.`", "0", 
       RowBox[{"-", "9.`"}]},
      {"\<\"shB  =\"\>", "0", "14.`", 
       RowBox[{"-", "24.`"}]},
      {"\<\"shAB =\"\>", "0", "0", "216.`"},
      {"\<\"shRl =\"\>", "10.`", "0", "0"},
      {"\<\"shRr =\"\>", "0", "14.`", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{3.425664710648133*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"AB/B+Rl=A  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3.`", ",", "4.`", ",", "1.`", ",", "0", ",", "0.9999999999999999`", ",", 
     "1.`"}], "}"}], ",", "\<\"\\nAB/A+Rr=B  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", "1.`", ",", "2.`", ",", 
     RowBox[{"-", "4.`"}], ",", "3.`", ",", 
     RowBox[{"-", "4.`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.425664710978608*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Octonion and Dozal conservation.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "Summary. ",
 StyleBox["Conservation is investigated for Octonion and Dozal algebras.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["2.1 Conservation of Octonion Compositions.", "Subsubsection",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["\thoopTimes[A,B,tst,1]",
  FontSlant->"Italic"],
 " uses a minimal multiplication routine, developed to test conservation of \
large tables that may not be in the databank. ",
 StyleBox["The table is conservative if one result is 0. ",
  FontColor->RGBColor[1, 0, 0]],
 "Repeat the test if both are zero, as this means that the product had a zero \
size."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"co", "[", 
    RowBox[{"Oct", ",", 
     RowBox[{"tst1", "=", "C2"}]}], "]"}]}], ";", 
  RowBox[{"id", "[", "tst", "]"}]}], "\n", 
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"RandomInteger", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "9"}], ",", "9"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "tst", "]"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"B", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"RandomInteger", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "9"}], ",", "9"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "tst", "]"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AB", "=", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"A", ",", "B", ",", "tst"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sA", "=", 
   RowBox[{"Det", "[", 
    RowBox[{"gmap", "[", 
     RowBox[{"tst", ",", "A"}], "]"}], "]"}]}], ";", 
  RowBox[{"sB", "=", 
   RowBox[{"Det", "[", 
    RowBox[{"gmap", "[", 
     RowBox[{"tst", ",", "B"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sAB", "=", 
   RowBox[{"Det", "[", 
    RowBox[{"gmap", "[", 
     RowBox[{"tst", ",", "AB"}], "]"}], "]"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Chop", "[", 
     FractionBox[
      RowBox[{
       RowBox[{"sA", " ", "sB"}], "+", "sAB"}], 
      RowBox[{"sA", "+", "sB"}]], "]"}], ",", 
    RowBox[{"Chop", "[", 
     FractionBox[
      RowBox[{
       RowBox[{"sA", " ", "sB"}], "-", "sAB"}], 
      RowBox[{"sA", "+", "sB"}]], "]"}]}], "}"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"OctC2\"\>"], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "13555974139832108784969870469068126082761495190296249725601786728389017600\
00", "/", "10869706413838515628261403524009"}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Direct compositions of Oct and the followng tables gave the following \
results:-
Conservative.\t\t\t\t\tNon-conservative.
C2,C3,C4,K,C5,C3C2,C8,C4C2,\tC5n,D3,C6n,D4,Q8,D5,Q12,A4,
KC2,C9,C3C3,C10,C11,C3C4,C3K,\tD3C2,Alt12n,KiC4,C4iC4,C8pC2,
C16,C4C4,C8C2,C4K,KK\t\tD8,Q8iC2,Q16,D4C2,Q8C2,P16,Oct
In this test, all abelain groups, and no non-abelian tables, give \
conservative octonions on direct composition with Oct.
Indirect compositions (where the result differed from the direct composition) \
gave no conservative tables, as in the following test:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"co", "[", 
    RowBox[{"Oct", ",", 
     RowBox[{"tst1", "=", 
      RowBox[{"mp", "[", 
       RowBox[{"6", ",", "1"}], "]"}]}]}], "]"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Length", "[", "tst", "]"}], ",", 
    RowBox[{"id", "[", "tst1", "]"}], ",", 
    RowBox[{"id", "[", "tst", "]"}], ",", 
    RowBox[{"dico", "[", "tst", "]"}], ",", 
    RowBox[{"alternativeQ", "[", "tst", "]"}], ",", 
    RowBox[{
     RowBox[{"A", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "9"}], ",", "19"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "tst", "]"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"B", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "9"}], ",", "9"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "tst", "]"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"AB", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "B", ",", "tst"}], "]"}]}], ";", 
     RowBox[{"sA", "=", 
      RowBox[{"Det", "[", 
       RowBox[{"gmap", "[", 
        RowBox[{"tst", ",", "A"}], "]"}], "]"}]}], ";", 
     RowBox[{"sB", "=", 
      RowBox[{"Det", "[", 
       RowBox[{"gmap", "[", 
        RowBox[{"tst", ",", "B"}], "]"}], "]"}]}], ";", 
     RowBox[{"sAB", "=", 
      RowBox[{"Det", "[", 
       RowBox[{"gmap", "[", 
        RowBox[{"tst", ",", "AB"}], "]"}], "]"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Chop", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"sA", " ", "sB"}], "-", "sAB"}], 
         RowBox[{"sA", "+", "sB"}]], "]"}], ",", 
       RowBox[{"Chop", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"sA", " ", "sB"}], "+", "sAB"}], 
         RowBox[{"sA", "+", "sB"}]], "]"}]}], "}"}]}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"96", ",", "\<\"D3\"\>", ",", "\<\"Unrecognised\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     SubscriptBox["2", "2"], ",", 
     SubscriptBox["14", "2"], ",", "56"}], "}"}], ",", "True", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "432316974560746646519762452662672989273063314100413442906686406577637241\
012403103105770467714615552894135375237575509801417314553428593278926093557457\
231964509811984240007231187284909131172799745146535129690411398374796732306721\
793516362275759039072088807450869760000000000", "/", 
      "24716474829671044267359840436714934065820254499657171390110969788899556\
961470133838294449455775393351546322638910908748075561"}], ",", 
     RowBox[{"-", 
      RowBox[{
      "43231700534012743490161494471065674265361203764588573492741634960135149\
645578799743011398304210452866068600857694076538242219014218492714453872097982\
995790524106111018360088529599912631178794599687022039392145165521249476705028\
5830123968726368135277669387086069760000000000", "/", 
       "2471647482967104426735984043671493406582025449965717139011096978889955\
6961470133838294449455775393351546322638910908748075561"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "2.2 Conservation of Dozal functions. ",
 StyleBox["Some Mathematica6 problems.",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.425664741692773*^9, 3.4256647507658195`*^9}}],

Cell["\<\
This section attempts to tabulate the conservation rules for Dozal, to help \
relate them to physics.
Test cases for A, polar forms (orbits) that are converted to vectors:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"testA", "=", 
   RowBox[{"{", 
    RowBox[{"(*", 
     RowBox[{
     "1", " ", "\[Alpha]\[Beta]\[Epsilon]\[Zeta]\[Lambda]\[Eta]\[Kappa]"}], 
     "*)"}], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "1.", ",", "1.", ",", ".34", ",", ".4", ",", ".51", ",", ".22", ",", 
       ".71", ",", ".3", ",", ".82", ",", "0.32", ",", ".9", ",", ".66"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"2", " ", "\[Alpha]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "0.", ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0", 
       ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"3", " ", "\[Beta]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", "1", ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0", 
       ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"4", " ", "\[Epsilon]", " ", "or", " ", "\[Gamma]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", "1", ",", ".1", ",", ".0", ",", ".0", ",", ".0", 
       ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"5", " ", "\[Zeta]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", "0.", ",", ".0", ",", "1", ",", ".1", ",", ".0", 
       ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"6", " ", "\[Lambda]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", "1", 
       ",", ".2", ",", ".0", ",", ".0", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"7", " ", "\[Eta]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", "0.", 
       ",", "0.", ",", "1", ",", ".3", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"8", " ", "\[Kappa]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0", 
       ",", ".0", ",", ".0", ",", "0.", ",", "1.", ",", ".4"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"9", " ", "\[Epsilon]\[Zeta]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", "1", ",", ".1", ",", "1.", ",", ".1", ",", ".0", 
       ",", ".0", ",", ".0", ",", ".0", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"10", " ", "\[Epsilon]\[Lambda]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", "1", ",", ".1", ",", ".0", ",", ".0", ",", "1.", 
       ",", ".1", ",", ".0", ",", ".0", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"11", " ", "\[Epsilon]\[Eta]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", "1", ",", ".1", ",", ".0", ",", ".0", ",", ".0", 
       ",", ".0", ",", "1.", ",", ".1", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"12", " ", "\[Epsilon]\[Kappa]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", "1", ",", ".1", ",", ".0", ",", ".0", ",", ".0", 
       ",", ".0", ",", ".0", ",", ".0", ",", "1.", ",", ".1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"13", " ", "\[Zeta]\[Eta]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", ".0", ",", ".0", ",", "1.", ",", ".2", ",", "0.", 
       ",", "0.", ",", "1.", ",", ".3", ",", ".0", ",", ".0"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"14", " ", "\[Zeta]\[Kappa]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", ".0", ",", ".0", ",", "1.", ",", ".2", ",", "0.", 
       ",", "0.", ",", "0.", ",", "0.", ",", "1.", ",", ".3"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"15", " ", "\[Lambda]\[Eta]\[Kappa]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", "0", ",", ".0", ",", ".0", ",", ".0", ",", "1.", 
       ",", ".1", ",", "1.", ",", ".3", ",", "1.0", ",", ".2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"16", " ", "\[Lambda]\[Eta]\[Kappa]"}], "="}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", "0", ",", ".0", ",", ".0", ",", ".0", ",", "1.", 
       ",", ".1", ",", "1.", ",", ".1", ",", "1.", ",", ".1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"17", " ", "\[Beta]\[Lambda]\[Eta]\[Kappa]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", "1.", ",", "0", ",", ".0", ",", ".0", ",", ".0", ",", "1.", 
       ",", ".1", ",", "1.", ",", ".1", ",", "1.", ",", ".1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"18", " ", "\[Eta]\[Kappa]"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", ".0", ",", ".0", ",", "0.", ",", ".0", ",", "0.", 
       ",", "0.", ",", "1.", ",", ".3", ",", "1.0", ",", ".7"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"19", " ", "\[Eta]\[Kappa]"}], "="}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", ".0", ",", ".0", ",", ".0", ",", "0.", ",", ".0", ",", "0.", 
       ",", "0.", ",", "1.", ",", ".3", ",", "1.", ",", ".3"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"20", " ", "\[Lambda]\[Eta]\[Kappa]r"}], "*)"}], 
     RowBox[{"{", 
      RowBox[{
      "0.", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1.", ",", 
       ".3", ",", ".1", ",", ".3", ",", "10.", ",", ".3"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell["\<\
\tSingle sizes, pairs and triples (omitting the linear sizes) and 4 sets of \
unit sizes are squared in turn, with different angles unless the name has a \
trailing \"=\". The last case has three sizes  .1, 1, 10; this is the \"Three \
Scales\" model.
\tOther cases can be added to investigate different hypotheses. Each loop is \
used in tern below;  the conserved functions are indicated by \"C\", \"K\", \
\"Q\", \"D\",  \"c\" , \"1\" if the function value is 1, \"0\" if it is zero, \
and those that are not conserved by \"n\". \
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", "\"\<C3C4\>\""}], ";", 
  RowBox[{"id", "[", "tst", "]"}], ";", 
  RowBox[{"dozalconserve", "=", 
   RowBox[{"{", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"tst", ",", "ds"}], "}"}], "]"}], "}"}]}], ";", 
  RowBox[{"colname", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cs", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"A", "=", 
      RowBox[{"testA", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"A", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{"toVector", "[", "A", "]"}], "]"}]}], ";", 
     RowBox[{"AA", "=", " ", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "A"}], "]"}]}], ";", 
     RowBox[{"res", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sa", "=", 
         RowBox[{"sh12", "[", "A", "]"}]}], ",", 
        RowBox[{"saa", "=", 
         RowBox[{"sh12", "[", "AA", "]"}]}], ",", 
        RowBox[{"sasa", "=", 
         RowBox[{"sa", " ", "sa"}]}], ",", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"saa", "-", "sasa"}], ",", 
          RowBox[{"10", "^", 
           RowBox[{"-", "8"}]}]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "sa", "]"}], "]"}]}], "}"}]}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"colname", ",", "tst"}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"cs", ",", 
       RowBox[{"Length", "[", "colname", "]"}]}], "]"}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"res", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"cs", ",", "0"}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{"4", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"res", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "1"}], 
               ",", "\"\<1\>\"", ",", "\"\<C\>\""}], "]"}]}], "]"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", "\"\<n\>\""}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "sa", "]"}]}], "}"}]}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"dozalconserve", ",", "cs"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "testA", "]"}]}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Rest", "[", "dozalconserve", "]"}], "]"}], "//", 
   "tf"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16", "17", "18", "19", "20"},
     {"\<\"1\"\>", "\<\"1\"\>", "0", "0", "\<\"C\"\>", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "0", "0", "\<\"C\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"C\"\>", "0", "0", "\<\"C\"\>"},
     {"\<\"1\"\>", "0", "\<\"1\"\>", "0", "0", "\<\"C\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", "0", "\<\"C\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", "0", "\<\"C\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", 
      "0"},
     {"\<\"C\"\>", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\
\<\"1\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>"},
     {"\<\"C\"\>", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>"},
     {"\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"C\"\>", "\<\"C\"\>", 
      "0", "0", "\<\"C\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"C\"\>"},
     {"\<\"C\"\>", "0", "0", "\<\"1\"\>", "0", "0", "\<\"C\"\>", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>"},
     {"\<\"1\"\>", "0", "0", "0", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "0", "0", "\<\"C\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"C\"\>", "0", "0", "\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", "0", "\<\"C\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", 
      "0"},
     {"\<\"C\"\>", "0", "0", "0", "\<\"1\"\>", "0", "0", 
      "0", "\<\"1\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", 
      "0", "0", "\<\"C\"\>"},
     {"\<\"C\"\>", "0", "0", "0", "0", "\<\"1\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"C\"\>", 
      "0", "\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "0", "0", "\<\"C\"\>", "\<\"C\"\>", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "0", "0", "\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"C\"\>"},
     {"\<\"C\"\>", "0", "0", "0", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", 
      "0", "0", "\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"n\"\>"},
     {"\<\"C\"\>", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\
\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "0", "0", 
      "0", "\<\"1\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", 
      "0", "0", "\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "\<\"1\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\
\<\"C\"\>", 
      "0", "\<\"C\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\
\<\"1\"\>", "\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "0", "\<\"C\"\>", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", 
      "0", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\
\<\"C\"\>"},
     {"\<\"C\"\>", "0", "0", "0", "0", "0", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "0", 
      "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", 
      "0", "0", "\<\"C\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", "\"\<Q12\>\""}], ";", 
  RowBox[{"id", "[", "tst", "]"}], ";", 
  RowBox[{"dozalconserve", "=", 
   RowBox[{"{", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"tst", ",", "ds"}], "}"}], "]"}], "}"}]}], ";", 
  RowBox[{"colname", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cs", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"A", "=", "\[IndentingNewLine]", 
      RowBox[{"testA", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ";", 
     RowBox[{"A", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{"toVector", "[", "A", "]"}], "]"}]}], ";", 
     RowBox[{"AA", "=", " ", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "A"}], "]"}]}], ";", 
     RowBox[{"res", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sa", "=", 
         RowBox[{"sh12", "[", "A", "]"}]}], ",", 
        RowBox[{"saa", "=", 
         RowBox[{"sh12", "[", "AA", "]"}]}], ",", 
        RowBox[{"sasa", "=", 
         RowBox[{"sa", " ", "sa"}]}], ",", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"saa", "-", "sasa"}], ",", 
          RowBox[{"10", "^", 
           RowBox[{"-", "8"}]}]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "sa", "]"}], "]"}]}], "}"}]}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"colname", ",", "tst"}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"cs", ",", 
       RowBox[{"Length", "[", "colname", "]"}]}], "]"}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"res", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"cs", ",", "0"}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{"4", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"res", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "1"}], 
               ",", "\"\<1\>\"", ",", "\"\<Q\>\""}], "]"}]}], "]"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", "\"\<n\>\""}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "sa", "]"}]}], "}"}]}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"dozalconserve", ",", "cs"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "testA", "]"}]}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Rest", "[", "dozalconserve", "]"}], "]"}], "//", 
   "tf"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16", "17", "18", "19", "20"},
     {"\<\"1\"\>", "\<\"1\"\>", "0", "0", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", 
      "0", "0", "\<\"Q\"\>"},
     {"\<\"1\"\>", "0", "\<\"1\"\>", "0", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"Q\"\>"},
     {"\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
     {"\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "0", "0", "\<\"Q\"\>", 
      "0", "\<\"Q\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"Q\"\>", "\<\"Q\"\>", 
      "0", "0", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"Q\"\>"},
     {"\<\"Q\"\>", "0", "0", "\<\"1\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
     {"\<\"1\"\>", "0", "0", "0", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", 
      "0", "0", "\<\"Q\"\>"},
     {"\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "0", "0", "\<\"Q\"\>", 
      "0", "\<\"Q\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"Q\"\>", 
      "0", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>"},
     {"\<\"Q\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"Q\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "0", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
      "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "0", "\<\"n\"\>", "0", 
      "0", "\<\"Q\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", "\"\<D3C2\>\""}], ";", 
  RowBox[{"id", "[", "tst", "]"}], ";", 
  RowBox[{"dozalconserve", "=", 
   RowBox[{"{", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"tst", ",", "ds"}], "}"}], "]"}], "}"}]}], ";", 
  RowBox[{"colname", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cs", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"A", "=", 
      RowBox[{"testA", "[", 
       RowBox[{"[", "jj", "]"}], "]"}]}], ";", 
     RowBox[{"A", "=", 
      RowBox[{"Chop", "[", 
       RowBox[{"toVector", "[", "A", "]"}], "]"}]}], ";", 
     RowBox[{"AA", "=", " ", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "A"}], "]"}]}], ";", 
     RowBox[{"res", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sa", "=", 
         RowBox[{"sh12", "[", "A", "]"}]}], ",", 
        RowBox[{"saa", "=", 
         RowBox[{"sh12", "[", "AA", "]"}]}], ",", 
        RowBox[{"sasa", "=", 
         RowBox[{"sa", " ", "sa"}]}], ",", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"saa", "-", "sasa"}], ",", 
          RowBox[{"10", "^", 
           RowBox[{"-", "8"}]}]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "sa", "]"}], "]"}]}], "}"}]}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"colname", ",", "tst"}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"cs", ",", 
       RowBox[{"Length", "[", "colname", "]"}]}], "]"}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"res", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"cs", ",", "0"}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{"4", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"res", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "1"}], 
               ",", "\"\<1\>\"", ",", "\"\<D\>\""}], "]"}]}], "]"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", "\"\<n\>\""}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "sa", "]"}]}], "}"}]}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"dozalconserve", ",", "cs"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"jj", ",", 
      RowBox[{"Length", "[", "testA", "]"}]}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Rest", "[", "dozalconserve", "]"}], "]"}], "//", 
   "tf"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16", "17", "18", "19", "20"},
     {"\<\"1\"\>", "\<\"1\"\>", "0", "0", "\<\"D\"\>", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", 
      "0", "0", "\<\"D\"\>"},
     {"\<\"1\"\>", "0", "\<\"1\"\>", "0", "\<\"D\"\>", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"D\"\>"},
     {"\<\"D\"\>", "0", "0", "\<\"1\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "0", "0", "\<\"D\"\>", 
      "0", "\<\"D\"\>"},
     {"\<\"D\"\>", "0", "0", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\
\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"D\"\>", "\<\"D\"\>", 
      "0", "0", "\<\"D\"\>", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"D\"\>"},
     {"\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
     {"\<\"1\"\>", "0", "0", "0", "\<\"D\"\>", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", 
      "0", "0", "\<\"D\"\>"},
     {"\<\"D\"\>", "0", "0", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\
\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "0", "0", "\<\"D\"\>", 
      "0", "\<\"D\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "0", "0", "\<\"n\"\>", 
      "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\
\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"D\"\>", 
      "0", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>"},
     {"\<\"D\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"D\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "0", "0", "\<\"D\"\>", 
      "0", "\<\"D\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "0", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "0", "\<\"D\"\>", "0", 
      "0", "\<\"D\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "0", "0", "\<\"n\"\>", 
      "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"n\"\>", "\
\<\"D\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "0", "0", "\<\"n\"\>", 
      "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "0", "0", "\<\"n\"\>", 
      "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\
\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "0", "0", "\<\"n\"\>", 
      "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "0", 
      "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", 
      "0", "0", "\<\"1\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "0", "\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "0", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>"},
     {"\<\"n\"\>", "0", "0", "0", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", "\"\<C3K\>\""}], ";", 
  RowBox[{"id", "[", "tst", "]"}], ";", 
  RowBox[{"dozalconserve", "=", 
   RowBox[{"{", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"tst", ",", "ds"}], "}"}], "]"}], "}"}]}], ";", 
  RowBox[{"colname", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cs", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"A", "=", 
      RowBox[{"1.1", " ", 
       RowBox[{"testA", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"eliminates", " ", "spurious", " ", 
       RowBox[{"1", "'"}], "s"}], "*)"}], 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"OMIT", " ", "toVector", " ", "A"}], "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"toVector", "[", "A", "]"}], "]"}]}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AA", "=", " ", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "A"}], "]"}]}], ";", 
     RowBox[{"res", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sa", "=", 
         RowBox[{"sh12", "[", "A", "]"}]}], ",", 
        RowBox[{"saa", "=", 
         RowBox[{"sh12", "[", "AA", "]"}]}], ",", 
        RowBox[{"sasa", "=", 
         RowBox[{"sa", " ", "sa"}]}], ",", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"saa", "-", "sasa"}], ",", 
          RowBox[{"10", "^", 
           RowBox[{"-", "8"}]}]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "sa", "]"}], "]"}]}], "}"}]}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"colname", ",", "tst"}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"cs", ",", 
       RowBox[{"Length", "[", "colname", "]"}]}], "]"}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"res", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"cs", ",", "0"}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{"4", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"res", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "1"}], 
               ",", "\"\<1\>\"", ",", "\"\<c\>\""}], "]"}]}], "]"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", "\"\<n\>\""}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "sa", "]"}]}], "}"}]}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"dozalconserve", ",", "cs"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "testA", "]"}]}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Rest", "[", "dozalconserve", "]"}], "]"}], "//", 
   "tf"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"stop\"\>"}], ":", 
  " ", "\<\"Further output of \\!\\(Power :: \\\"indet\\\"\\) will be \
suppressed during this calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\
\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16", "17", "18", "19", "20"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "0", "0", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\
\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\
\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "0", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\
\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\
\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
      "0", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
      "0", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
      "0", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
      "0", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\
\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
      "0", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", "\"\<A4\>\""}], ";", 
  RowBox[{"id", "[", "tst", "]"}], ";", 
  RowBox[{"dozalconserve", "=", 
   RowBox[{"{", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"tst", ",", "ds"}], "}"}], "]"}], "}"}]}], ";", 
  RowBox[{"colname", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cs", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"A", "=", 
      RowBox[{"1.1", " ", 
       RowBox[{"testA", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"eliminates", " ", "spurious", " ", 
       RowBox[{"1", "'"}], "s"}], "*)"}], 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"OMIT", " ", "toVector", " ", "A"}], "=", 
        RowBox[{"Chop", "[", 
         RowBox[{"toVector", "[", "A", "]"}], "]"}]}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AA", "=", " ", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "A"}], "]"}]}], ";", 
     RowBox[{"res", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sa", "=", 
         RowBox[{"sh12", "[", "A", "]"}]}], ",", 
        RowBox[{"saa", "=", 
         RowBox[{"sh12", "[", "AA", "]"}]}], ",", 
        RowBox[{"sasa", "=", 
         RowBox[{"sa", " ", "sa"}]}], ",", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"saa", "-", "sasa"}], ",", 
          RowBox[{"10", "^", 
           RowBox[{"-", "8"}]}]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "sa", "]"}], "]"}]}], "}"}]}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"colname", ",", "tst"}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"cs", ",", 
       RowBox[{"Length", "[", "colname", "]"}]}], "]"}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"res", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"cs", ",", "0"}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", 
              RowBox[{"4", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"res", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "1"}], 
               ",", "\"\<1\>\"", ",", "\"\<c\>\""}], "]"}]}], "]"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"cs", ",", "\"\<n\>\""}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "sa", "]"}]}], "}"}]}], "]"}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"dozalconserve", ",", "cs"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "testA", "]"}]}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Rest", "[", "dozalconserve", "]"}], "]"}], "//", 
   "tf"}]}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"Power", "::", "\<\"indet\"\>"}], ":", 
  " ", "\<\"Indeterminate expression \\!\\(0.`\\^0.`\\) encountered. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/indet\\\", \
ButtonNote -> \\\"Power::indet\\\"]\\)\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16", "17", "18", "19", "20"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\
\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
      "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\
\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
      "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\
\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
     {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe following procedure tests conservation of the ",
 StyleBox["sh12",
  FontSlant->"Italic"],
 " functions for multiplication of two vectors A & B. If the last parameter \
",
 StyleBox["n",
  FontSlant->"Italic"],
 " is negative, ",
 StyleBox["toVector[A]",
  FontSlant->"Italic"],
 " & ",
 StyleBox["toVector[B]",
  FontSlant->"Italic"],
 " are used. NB ",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[GreaterEqual]-",
 "4, as A4 lacks ",
 StyleBox["toVector",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "dozaltest", "]"}], ";", 
  RowBox[{
   RowBox[{"dozaltest", "[", 
    RowBox[{"A0_", ",", "B0_", ",", 
     RowBox[{"n_:", "5"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A", "=", "A0"}], ",", 
       RowBox[{"B", "=", "B0"}], ",", "alg", ",", 
       RowBox[{"tstname", "=", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "\"\<C\>\"", ",", "\"\<K\>\"", ",", "\"\<Q\>\"", ",", "\"\<D\>\"", 
            ",", "\"\<A\>\"", ",", "\"\<P\>\"", ",", "\"\<q\>\"", ",", 
            "\"\<k\>\"", ",", "\"\<c\>\""}], "}"}], ",", 
          RowBox[{"Abs", "[", "n", "]"}]}], "]"}]}], ",", 
       RowBox[{"tst", "=", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "\"\<C3C4\>\"", ",", "\"\<C3K\>\"", ",", "\"\<Q12\>\"", ",", 
            "\"\<D3C2\>\"", ",", "\"\<A4\>\"", ",", "\"\<C3P4\>\"", ",", 
            "\"\<C3Qr\>\"", ",", "\"\<C3KC2r\>\"", ",", "\"\<Q12C2c\>\""}], 
           "}"}], ",", 
          RowBox[{"Abs", "[", "n", "]"}]}], "]"}]}], ",", "dozalconserve", 
       ",", "sa", ",", "sb", ",", "sasb", ",", "sab", ",", "AB", ",", "cs"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"dozalconserve", "=", 
       RowBox[{"{", 
        RowBox[{"Range", "[", "39", "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"cs", "=", 
          RowBox[{"{", "}"}]}], ";", 
         RowBox[{"alg", "=", 
          RowBox[{"tst", "[", 
           RowBox[{"[", "ii", "]"}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"n", "<", "0"}], ",", 
           RowBox[{
            RowBox[{"A", "=", 
             RowBox[{"Chop", "[", 
              RowBox[{"toVector", "[", 
               RowBox[{"A", ",", "alg"}], "]"}], "]"}]}], ";", 
            RowBox[{"B", "=", 
             RowBox[{"Chop", "[", 
              RowBox[{"toVector", "[", 
               RowBox[{"B", ",", "alg"}], "]"}], "]"}]}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"AB", "=", " ", 
          RowBox[{"hoopTimes", "[", 
           RowBox[{"A", ",", "B", ",", "alg"}], "]"}]}], ";", 
         RowBox[{"sa", "=", 
          RowBox[{"sh12", "[", "A", "]"}]}], ";", 
         RowBox[{"sb", "=", 
          RowBox[{"sh12", "[", "B", "]"}]}], ";", 
         RowBox[{"sasb", "=", 
          RowBox[{"sa", " ", "sb"}]}], ";", 
         RowBox[{"sab", "=", 
          RowBox[{"sh12", "[", "AB", "]"}]}], ";", 
         RowBox[{"res", "=", 
          RowBox[{"Chop", "[", 
           RowBox[{"{", 
            RowBox[{"sa", ",", "sb", ",", "sab", ",", "sasb", ",", 
             RowBox[{"sab", "-", "sasb"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{"Length", "[", "sa", "]"}], "]"}]}], "}"}], "]"}]}], 
         ";", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"res", "[", 
               RowBox[{"[", 
                RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], ",",
              
             RowBox[{"AppendTo", "[", 
              RowBox[{"cs", ",", "0"}], "]"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"res", "[", 
                 RowBox[{"[", 
                  RowBox[{"5", ",", "i"}], "]"}], "]"}], "\[Equal]", "0"}], 
               ",", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"cs", ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"res", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "i"}], "]"}], "]"}], "\[Equal]", "1"}], 
                   ",", "\"\<1\>\"", ",", 
                   RowBox[{"tstname", "[", 
                    RowBox[{"[", "ii", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"cs", ",", "\"\<n\>\""}], "]"}]}], "]"}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "sa", "]"}]}], "}"}]}], "]"}], ";", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"dozalconserve", ",", "cs"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", 
          RowBox[{"Abs", "[", "n", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"Take", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", "dozalconserve", "]"}], ",", "21"}], 
           "]"}], "]"}], "//", "tf"}], ",", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", "dozalconserve", "]"}], ",", "21"}], 
           "]"}], "]"}], "//", "tf"}]}], "}"}]}]}], "]"}]}]}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dozaltest", "[", 
  RowBox[{
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{
     "1.", ",", "1.", ",", "1.", ",", "1", ",", "2.", ",", ".1", ",", 
      RowBox[{"1", "/", "2."}], ",", ".1", ",", "1.", ",", ".11", ",", "1.", 
      ",", ".12"}], "}"}]}], ",", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{"2.", ",", 
      RowBox[{"1", "/", "2."}], ",", "1.", ",", ".2", ",", "3.", ",", "0.3", 
      ",", 
      RowBox[{"1", "/", "3."}], ",", "0.1", ",", "1.", ",", "0.1", ",", "1.", 
      ",", "0.1"}], "}"}]}], ",", "9"}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
         "14", "15", "16", "17", "18", "19", "20", "21"},
        {"\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\
\"C\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
        {"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
        {"\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"n\"\>"},
        {"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
        {"\<\"A\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"A\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"A\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"P\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"q\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", 
         "33", "34", "35", "36", "37", "38", "39"},
        {"\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
        {"\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"P\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"q\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
        {"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\
\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tNote that C3KC2r & Q12C2c do not conserve any of these functions, whilst \
C3P4 & C3Qr only conserve 15 & 26, 16 & 27, which are not conserved by any \
other hoops.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"dozaltest", "[", 
  RowBox[{
   RowBox[{"testA", "[", 
    RowBox[{"[", "7", "]"}], "]"}], ",", 
   RowBox[{"testA", "[", 
    RowBox[{"[", "17", "]"}], "]"}], ",", 
   RowBox[{"-", "4"}]}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{"testA", "[", 
   RowBox[{"[", "11", "]"}], "]"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"gives", " ", "l22a"}], "=", 
    RowBox[{"l22b", "=", 
     RowBox[{"l4s", "\[Equal]", "0"}]}]}], "*)"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", "\"\<C3C4\>\""}], ";", 
  RowBox[{"id", "[", "tst", "]"}], ";", 
  RowBox[{"dozalconserve", "=", 
   RowBox[{"{", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"tst", ",", "ds"}], "}"}], "]"}], "}"}]}], ";", 
  RowBox[{"colname", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"A", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"toVector", "[", 
    RowBox[{"{", 
     RowBox[{
     "\[Alpha]", ",", "\[Beta]", ",", "\[Epsilon]", ",", "\[Sigma]", ",", 
      "\[Zeta]", 
      StyleBox[",",
       FontSize->9], "\[Tau]", ",", "\[Lambda]", ",", "\[Phi]", ",", "\[Eta]",
       ",", "\[Chi]", ",", "\[Kappa]", ",", "\[Psi]"}], "}"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"sh12", "[", 
   RowBox[{"[", "A", "]"}], "]"}], "]"}]}], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"sh12", "[", 
     RowBox[{"toVector", "[", 
      RowBox[{"{", 
       RowBox[{
       "\[Alpha]", ",", "\[Beta]", ",", "\[Epsilon]", ",", "\[Sigma]", ",", 
        "\[Zeta]", ",", "\[Tau]", ",", "\[Eta]", ",", "\[Phi]", ",", 
        "\[Lambda]", ",", "\[Phi]", ",", "\[Kappa]", ",", "\[Phi]"}], "}"}], 
      "]"}], "]"}], "/.", 
    RowBox[{
     SqrtBox["any_"], "\[Rule]", 
     RowBox[{"any", "/", "2"}]}]}], "]"}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe following table shows (for the first 25 functions) those functions \
that are sizes (irreducible determinant factors) as \"i\", those that are \
conserved combinations of sizes by \"c\", those that are conserved on orbit \
multiplication by \"o\", and those that are only conserved when some \
\"radii\" are zero or negative by \"n\". (Negative radii can occur in ",
 StyleBox["Q12 & D3C2",
  FontSlant->"Italic"],
 " because they have sizes with 3 positive and 3 negative squared terms.)  \
The names indicate the type of function:- o",
 StyleBox["n",
  FontSlant->"Italic"],
 " are linear functions, offsets in orbits. p",
 StyleBox["ab",
  FontSlant->"Italic"],
 "-s",
 StyleBox["ab",
  FontSlant->"Italic"],
 " have ",
 StyleBox["b",
  FontSlant->"Italic"],
 " terms each of order ",
 StyleBox["a",
  FontSlant->"Italic"],
 ". l3 is the cubic A4 size. l4",
 StyleBox["p",
  FontSlant->"Italic"],
 "-l4",
 StyleBox["s",
  FontSlant->"Italic"],
 " are quartic sizes. The last column gives the polar form for \
toVec[{\[Alpha], \[Beta], \[Gamma], \[Delta], \[Zeta]\[Zeta], \[Tau], \
\[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \[Chi], \[Kappa]\[Kappa], \[Psi]}, \
\"C3C4\"], with \[Zeta] replacing ",
 Cell[BoxData[
  FormBox[
   SqrtBox["\[Zeta]\[Zeta]"], TraditionalForm]]],
 " (etc). Note that \[Gamma], \[Delta] are retained here, instead of \
\[CurlyEpsilon], \[Sigma]; a second term gives the corresponding form for \
C3K, where it differs from that for C3C4. Third and fourth terms are for Q12 \
& D3C2. Long terms are simplified by making all angles equal to \[Tau]. \
(Functions 26 onward are not categorised wrt. the four groups.)\nI am \
attempting to correlate these relationships with the properties of \
fundamental particles."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "No. Name C3C4 Q12 C3K D3C2 A4 C3C4,C4K,Q12,D3C2\n1   o1   i    i   i   i    \
i  \[Alpha]\n2   o2   i    i   i   i       \[Beta]\n3   o3            i   i   \
    \[Gamma](Cos[\[Delta]]+Sin[\[Delta]]),\[Gamma],\n                         \
     \[Gamma](Cos[\[Delta]]+Sin[\[Delta]]),\[Gamma],\n4   o4            i   i \
      \[Gamma](Cos[\[Delta]]-Sin[\[Delta]]),\[Gamma],\n                       \
       \[Gamma](Cos[\[Delta]]-Sin[\[Delta]]),\[Delta],\n5   l22a i\n6   l22b \
i\n7   p22  o    o   o   o       (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Alpha]", "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Beta]", "2"], TraditionalForm]]],
 ")/2\n8   q22  i    i   o   o       ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "2"], TraditionalForm]]],
 ",(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Delta]", "2"], TraditionalForm]]],
 ")/2,",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "2"], TraditionalForm]]],
 ",(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Delta]", "2"], TraditionalForm]]],
 ")/2\n9   r22  c    c   c   c       \[Alpha] \[Beta]\n10  s22           c   \
c    i  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "\[Delta]"}], "]"}]}]]],
 ",\[Gamma] \[Delta],",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Gamma]", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "\[Delta]"}], "]"}]}]]],
 ",\[Gamma] \[Delta]\n11  p23  i    n   i   n       ",
 Cell[BoxData[
  SuperscriptBox["\[Zeta]", "2"]]],
 ",",
 Cell[BoxData[
  SuperscriptBox["\[Zeta]", "2"]]],
 ",",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], "+", 
   SuperscriptBox["\[Lambda]", "2"], "+", 
   RowBox[{"2", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Tau]", "-", "\[Phi]"}], "]"}]}]}]]],
 ",\n                                    ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], "+", 
   SuperscriptBox["\[Lambda]", "2"], "-", 
   RowBox[{"2", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Tau]", "-", "\[Phi]"}], "]"}]}]}]]],
 " \n12  q23  i    n   i   n       ",
 Cell[BoxData[
  SuperscriptBox["\[Lambda]", "2"]]],
 ",",
 Cell[BoxData[
  SuperscriptBox["\[Lambda]", "2"]]],
 ",",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], "+", 
   SuperscriptBox["\[Lambda]", "2"], "+", 
   RowBox[{"2", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Tau]", "-", "\[Phi]"}], "]"}]}]}]]],
 ",\n                                    ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], "+", 
   SuperscriptBox["\[Lambda]", "2"], "-", 
   RowBox[{"2", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Tau]", "-", "\[Phi]"}], "]"}]}]}]]],
 "\n13  r23  o    n   i   n       ",
 Cell[BoxData[
  SuperscriptBox["\[Eta]", "2"]]],
 ",",
 Cell[BoxData[
  SuperscriptBox["\[Eta]", "2"]]],
 ",",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Eta]", "2"], "+", 
    SuperscriptBox["\[Kappa]", "2"], "+", 
    RowBox[{"2", " ", "\[Eta]", " ", "\[Kappa]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Chi]", "-", "\[Psi]"}], "]"}]}]}], ","}]]],
 "\n                                    ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], "+", 
   SuperscriptBox["\[Kappa]", "2"], "-", 
   RowBox[{"2", " ", "\[Eta]", " ", "\[Kappa]", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Chi]", "-", "\[Psi]"}], "]"}]}]}]]],
 "\n14  s23  o    n   i   n       ",
 Cell[BoxData[
  SuperscriptBox["\[Kappa]", "2"]]],
 ",",
 Cell[BoxData[
  SuperscriptBox["\[Kappa]", "2"]]],
 ",",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], "+", 
   SuperscriptBox["\[Kappa]", "2"], "-", 
   RowBox[{"2", " ", "\[Eta]", " ", "\[Kappa]", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Chi]", "-", "\[Psi]"}], "]"}]}]}]]],
 ",\n                                    ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], "+", 
   SuperscriptBox["\[Kappa]", "2"], "+", 
   RowBox[{"2", " ", "\[Eta]", " ", "\[Kappa]", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Chi]", "-", "\[Psi]"}], "]"}]}]}]]],
 "\n15  q24  o    o   o   o      ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], "+", 
     SuperscriptBox["\[Beta]", "2"], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Gamma]", "2"]}]}], ")"}], "/", "4"}]]],
 ",",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], "+", 
     SuperscriptBox["\[Beta]", "2"], "+", 
     SuperscriptBox["\[Gamma]", "2"], "+", 
     SuperscriptBox["\[Delta]", "2"]}], ")"}], "/", "4"}]]],
 ",\n                             ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], "+", 
     SuperscriptBox["\[Beta]", "2"], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Gamma]", "2"]}]}], ")"}], "/", "4"}]]],
 ",",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], "+", 
     SuperscriptBox["\[Beta]", "2"], "+", 
     SuperscriptBox["\[Gamma]", "2"], "+", 
     SuperscriptBox["\[Delta]", "2"]}], ")"}], "/", "4"}]]],
 "\n16  s24           o   o\n           ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "\[Beta]"}], ")"}], "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Gamma]", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]"}], ")"}], " ", "\[Gamma]", " ", 
     RowBox[{"Cos", "[", "\[Delta]", "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Gamma]", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "\[Delta]"}], "]"}]}]}], ")"}]]],
 "/8,\n           ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["\[Alpha]", "2"]}], "-", 
    SuperscriptBox["\[Beta]", "2"], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "-", "\[Delta]"}], ")"}], "2"], "+", 
    RowBox[{"2", " ", "\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "+", "\[Delta]"}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{"\[Beta]", "+", "\[Gamma]", "+", "\[Delta]"}], ")"}]}]}], 
   ")"}]]],
 "/8,\n           ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "\[Beta]"}], ")"}], "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Gamma]", "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]"}], ")"}], " ", "\[Gamma]", " ", 
     RowBox[{"Cos", "[", "\[Delta]", "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Gamma]", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "\[Delta]"}], "]"}]}]}], ")"}]]],
 "/8,                  \n           ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["\[Alpha]", "2"]}], "-", 
    SuperscriptBox["\[Beta]", "2"], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "-", "\[Delta]"}], ")"}], "2"], "+", 
    RowBox[{"2", " ", "\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "+", "\[Delta]"}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{"\[Beta]", "+", "\[Gamma]", "+", "\[Delta]"}], ")"}]}]}], 
   ")"}]]],
 "/8\n17  p26       i       f   \[Zeta] \[Lambda] Cos[\[Tau]-\[Phi]],\[Zeta] \
\[Lambda] Cos[\[Tau]-\[Phi]],",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Zeta]", "2"], "-", 
    SuperscriptBox["\[Lambda]", "2"]}], ","}]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], "-", 
   SuperscriptBox["\[Lambda]", "2"]}]]],
 "\n18  q26  o    o   n   i   \[Eta] \[Kappa] Cos[\[Chi]-\[Psi]],\[Eta] \
\[Kappa] Cos[\[Chi]-\[Psi]],",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Eta]", "2"], "-", 
    SuperscriptBox["\[Kappa]", "2"]}], ","}]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], "-", 
   SuperscriptBox["\[Kappa]", "2"]}]]],
 "\n19  r26  o    n   o   o   ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Zeta]", "2"], "+", 
    SuperscriptBox["\[Lambda]", "2"]}], ")"}]]],
 "/2,",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Zeta]", "2"], "+", 
    SuperscriptBox["\[Lambda]", "2"]}], ")"}]]],
 "/2,",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Zeta]", "2"], "+", 
    SuperscriptBox["\[Lambda]", "2"]}], ","}]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], "+", 
   SuperscriptBox["\[Lambda]", "2"]}]]],
 "\n20  s26  o    i   o   o   ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Eta]", "2"], "+", 
    SuperscriptBox["\[Kappa]", "2"]}], ")"}]]],
 "/2,",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Eta]", "2"], "+", 
    SuperscriptBox["\[Kappa]", "2"]}], ")"}]]],
 "/2,",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], "+", 
   SuperscriptBox["\[Kappa]", "2"]}]]],
 ",",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], "+", 
   SuperscriptBox["\[Kappa]", "2"]}]]],
 "\n21  l3(\[Delta]->0)               i ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Beta]", " ", "\[Eta]", " ", "\[Kappa]"}], "+", " ", 
     RowBox[{"\[Lambda]\[Delta]", " ", "\[Eta]"}], "+", 
     RowBox[{"\[Lambda]\[Gamma]", " ", "\[Kappa]"}]}], ")"}], "/", "3"}]]],
 ",,\n",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Eta]", "2"], "-", 
       SuperscriptBox["\[Kappa]", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Gamma]", " ", "\[Eta]", " ", 
     RowBox[{"(", 
      RowBox[{"\[Zeta]", "-", "\[Lambda]"}], ")"}]}]}], ")"}]]],
 ",(\[Gamma](\[Eta]+\[Kappa])(\[Zeta]+\[Lambda])+(\[Eta]-\[Kappa])(\[Beta](\
\[Eta]+\[Kappa])+\[Delta](\[Zeta]+\[Lambda])))\n22  l4p  c    n   c   n       \
",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], " ", 
   SuperscriptBox["\[Lambda]", "2"]}]]],
 ",,",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "4"], "+", 
   SuperscriptBox["\[Lambda]", "4"], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["\[Zeta]", "2"], " ", 
    SuperscriptBox["\[Lambda]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "-", "\[Phi]"}], ")"}]}], "]"}]}]}]]],
 ",\n23  l4q  o    n   c   n       ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], " ", 
   SuperscriptBox["\[Kappa]", "2"]}]]],
 ",,",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "4"], "+", 
   SuperscriptBox["\[Kappa]", "4"], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}]]],
 ",\n24  l4r       n       n       ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Zeta]", "4"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[Zeta]", "2"], " ", 
       SuperscriptBox["\[Lambda]", "2"]}], "+", 
      SuperscriptBox["\[Lambda]", "4"], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[Zeta]", "2"], " ", 
       SuperscriptBox["\[Lambda]", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", "-", "\[Phi]"}], ")"}]}], "]"}]}]}], ")"}], "/", 
    "4"}],
   FontSize->9]]],
 "\n25  l4s  c    n   o   n ",
 Cell[BoxData[
  RowBox[{"             ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Eta]", "4"], "+", 
     SuperscriptBox["\[Kappa]", "4"], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Eta]", "2"], " ", 
      SuperscriptBox["\[Kappa]", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}], ")"}]}]]],
 "/4\n26  L4Q                 ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Zeta]", "2"], "+", 
     SuperscriptBox["\[Eta]", "2"], "+", 
     SuperscriptBox["\[Kappa]", "2"], "+", 
     SuperscriptBox["\[Lambda]", "2"]}], ")"}], "2"]]],
 "/16,",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Zeta]", "2"], "+", 
     SuperscriptBox["\[Eta]", "2"], "+", 
     SuperscriptBox["\[Kappa]", "2"], "+", 
     SuperscriptBox["\[Lambda]", "2"]}], ")"}], "2"]]],
 "/16,\n                        ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Zeta]", "2"], "+", 
     SuperscriptBox["\[Eta]", "2"], "+", 
     SuperscriptBox["\[Kappa]", "2"], "+", 
     SuperscriptBox["\[Lambda]", "2"]}], ")"}], "2"]]],
 "/4, (",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Zeta]", "2"], "+", 
     SuperscriptBox["\[Eta]", "2"], "+", 
     SuperscriptBox["\[Kappa]", "2"], "+", 
     SuperscriptBox["\[Lambda]", "2"]}], ")"}], "2"]]],
 "/4\n27  L4\[Sigma]  ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Zeta]", "2"], "+", 
     SuperscriptBox["\[Eta]", "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Kappa]", "-", "\[Lambda]"}], ")"}], "2"], "-", 
     RowBox[{"2", " ", "\[Eta]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Kappa]", "+", "\[Lambda]"}], ")"}]}], "-", 
     RowBox[{"2", " ", "\[Zeta]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Eta]", "+", "\[Kappa]", "+", "\[Lambda]"}], ")"}]}]}], 
    ")"}], "2"]]],
 "/64,,\n         ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Zeta]", " ", "\[Eta]"}], "+", 
      SuperscriptBox["\[Kappa]", "2"], "+", 
      SuperscriptBox["\[Lambda]", "2"]}], ")"}], "2"], "/", "4"}]]],
 ",\n28  L4a3  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[Zeta]", "2"]}], "+", 
     SuperscriptBox["\[Lambda]", "2"], "-", 
     RowBox[{
      SuperscriptBox["\[Lambda]", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "-", "\[Phi]"}], ")"}]}], "]"}]}]}], ")"}]}]]],
 "/2,,\n          ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "4"], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["\[Zeta]", "2"], " ", 
    SuperscriptBox["\[Lambda]", "2"]}], "+", 
   SuperscriptBox["\[Lambda]", "4"], "-", 
   RowBox[{"4", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Zeta]", "2"], "+", 
      SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Tau]", "-", "\[Phi]"}], "]"}]}]}]]],
 ",\n29  L4b3   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Lambda]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "2"]}], "+", 
     SuperscriptBox["\[Zeta]", "2"], "-", 
     RowBox[{
      SuperscriptBox["\[Zeta]", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "-", "\[Phi]"}], ")"}]}], "]"}]}]}], ")"}]}]]],
 "/2,,\n           ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "4"], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["\[Zeta]", "2"], " ", 
    SuperscriptBox["\[Lambda]", "2"]}], "+", 
   SuperscriptBox["\[Lambda]", "4"], "+", 
   RowBox[{"4", " ", "\[Zeta]", " ", "\[Lambda]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Zeta]", "2"], "+", 
      SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Tau]", "-", "\[Phi]"}], "]"}]}]}]]],
 ",\n30  L4c3   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[Eta]", "2"]}], "-", 
     SuperscriptBox["\[Kappa]", "2"], "+", 
     RowBox[{
      SuperscriptBox["\[Kappa]", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}], ")"}]}]]],
 "/2,\n           ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"], "-", 
      RowBox[{"4", " ", "\[Eta]", " ", "\[Kappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "-", "\[Psi]"}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}]]],
 ",\n           ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"], "+", 
      RowBox[{"4", " ", "\[Eta]", " ", "\[Kappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "-", "\[Psi]"}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}]]],
 "\n31  L4d3   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Kappa]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[Kappa]", "2"]}], "-", 
     SuperscriptBox["\[Eta]", "2"], "+", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}], ")"}]}]]],
 "/2,\n           ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"], "-", 
      RowBox[{"4", " ", "\[Eta]", " ", "\[Kappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "-", "\[Psi]"}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}]]],
 ",\n           ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Eta]", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"], "+", 
      RowBox[{"4", " ", "\[Eta]", " ", "\[Kappa]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Chi]", "-", "\[Psi]"}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}]]],
 "\n32  L4a6   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], " ", 
   SuperscriptBox["\[Lambda]", "2"]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "2"], " ", 
   SuperscriptBox["\[Lambda]", "2"]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Zeta]", "4"], "+", 
    SuperscriptBox["\[Lambda]", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Zeta]", "2"], " ", 
     SuperscriptBox["\[Lambda]", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "-", "\[Phi]"}], ")"}]}], "]"}]}]}], ","}]]],
 "\n33  L4b6   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], " ", 
   SuperscriptBox["\[Kappa]", "2"]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "2"], " ", 
   SuperscriptBox["\[Kappa]", "2"]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Eta]", "4"], "+", 
    SuperscriptBox["\[Kappa]", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Eta]", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}], ","}]]],
 "\n34  L4c6   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}], ","}]]],
 ",",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Eta]", "4"], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"]}], "+", 
   SuperscriptBox["\[Kappa]", "4"], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}]]],
 ",\n35  L4d6  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Zeta]", "4"], "+", 
     SuperscriptBox["\[Lambda]", "4"], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Zeta]", "2"], " ", 
      SuperscriptBox["\[Lambda]", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", "-", "\[Phi]"}], ")"}]}], "]"}]}]}], ")"}], "/", 
   "4"}]]],
 ",\n           ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Zeta]", "4"], "+", 
   SuperscriptBox["\[Lambda]", "4"], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["\[Zeta]", "2"], " ", 
    SuperscriptBox["\[Lambda]", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Tau]", "-", "\[Phi]"}], ")"}]}], "]"}]}]}]]],
 ",  \n36  L49  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Eta]", "4"], "+", 
    RowBox[{"12", " ", 
     SuperscriptBox["\[Eta]", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "+", 
    SuperscriptBox["\[Kappa]", "4"], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["\[Eta]", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Chi]", "-", "\[Psi]"}], ")"}]}], "]"}]}]}], ")"}]]],
 "/4,,\n         ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["\[Eta]", "4"]}], "-", 
   RowBox[{"8", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"]}], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["\[Kappa]", "4"]}]}]]],
 ",\n37  L49a ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Zeta]", "4"], "+", 
    RowBox[{"12", " ", 
     SuperscriptBox["\[Zeta]", "2"], " ", 
     SuperscriptBox["\[Lambda]", "2"]}], "+", 
    SuperscriptBox["\[Lambda]", "4"], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["\[Zeta]", "2"], " ", 
     SuperscriptBox["\[Lambda]", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "-", "\[Phi]"}], ")"}]}], "]"}]}]}], ")"}]]],
 "/4,,\n         ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["\[Zeta]", "4"]}], "-", 
   RowBox[{"8", " ", 
    SuperscriptBox["\[Zeta]", "2"], " ", 
    SuperscriptBox["\[Lambda]", "2"]}], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["\[Lambda]", "4"]}]}]]],
 ",\n38  L49b  long,,",
 Cell[BoxData[
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["\[Eta]", "4"]}], "-", 
   RowBox[{"8", " ", 
    SuperscriptBox["\[Eta]", "2"], " ", 
    SuperscriptBox["\[Lambda]", "2"]}], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["\[Lambda]", "4"]}]}]]],
 ",\n39  L49c  long,,",
 Cell[BoxData[
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["\[Zeta]", "4"]}], "-", 
   RowBox[{"8", " ", 
    SuperscriptBox["\[Zeta]", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"]}], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["\[Kappa]", "4"]}]}]]]
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Courier New",
 FontSize->10]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
WindowSize->{1011, 757},
WindowMargins->{{71, Automatic}, {Automatic, 31}},
DockedCells->FEPrivate`If[
  FEPrivate`SameQ[FEPrivate`$ProductIDName, "MathematicaPlayer"], {
   Cell[
    BoxData[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJy9XGdcVUfevkuzu0mMXcOq9GYHUaqxgImiia6xxI3JakzUmDVl35Rd3Y3G\n\
tWGMigKKgtJFKdIEBCnSpPeuYP0l77vv5/fDPu/MOTPnzrn3XMCy+wHuvXPm\n\
zL/MzPP8/zNzzsqtX+7Ytnvrl598tPV3y/du/XzHJx998btle/aSIvPf6HRm\n\
FjqdzvF3Ovod5Cv79zq6urp0FqjJL8CVgLdREBmFjrY2S6l4GBrrG3DXLxB9\n\
U1xR7uSGFl8v9P4hCPc/24Dqzetx9/JlnblUdwi6OjtRc/0aCnbvQuH8hSgZ\n\
Z4/E2R6ovHJFB1qnSaqoG8tEZv1wAFcn2yF2205Ul5RYSMVj0EmaaXhnI3rt\n\
5qDbdh5aV/ihY0sgHu58F/ffD0LzB2tRH3EOdanXUBUehvxdn6JooRfqZrqg\n\
2NkZ4RNm4Nrqd9DR1KQh1gr11dVIcJmP+OFTcXG2J0pOnkZDTp6ZdPk1dLS0\n\
oH3tGvR6eKJ99gLULnRH88aluPfFOjz+YRMebCLqrHwTrUH+aFm3BJXec1Ax\n\
1xWVs2chxtoBoVT8mnckyc2y5HHSx0SkEIPTx0xHzhgbJJPPDPuZuL37c5Sf\n\
OYvSTRvxyMMd9/180OTlhTabWWj0nod7P6zFo7+9i64vg9C+LQDNy+ehZceb\n\
uOM3D4X+bkhwc8EFa1tcdHDCzc//pDOWOxm1JcVIsnNF7LgZ5M8GuZNtkD7F\n\
FnG2dii2c8Ajl3l44OuDrmV+6Jm7EJ2uLujesxQPwjej99RGdHwVgPKtvijb\n\
5Im8dQuQ/OZ8hNo54tjEKQhxckFVYiKVRAeAbqgk0xz1WVloyMuTfkk6lYs6\n\
TUJnezsy1vweV155A4lenrjztw9R+Y8dKD28A1VHd6Dx+Kdo+mk3Gk/vQePP\n\
n6H+2A7Uh+xCU+xXaLzyNZqiv0bthT+h+swuVIXsRsWpz1B29FNk7lqL07Pc\n\
cPPb71B05Kgl6/TO9jZUXr6MsrBQZG3ciIx31+FufLykWYWs2XjpYwbukN5I\n\
cHFC9YWv0XLtOOpiT6I54RQepIfhXnoo7qWdQ09aKLozLqAn8zy6rv6MrpgT\n\
6CLXOnLC0ZYbjibyvS7pDOriT6E+6Wc0p55B7pcf44qdCzI/24NyokoF/YuM\n\
ROm5c7i+aTMSg1YjiYzjHNL7N4mKTQUFsucqRf2mo/BYMOICvdF49SDuRoai\n\
6kokHqXFoic9Gv9Tm4P/vZuDXwpS8aggE48L0/E0NRq/3IjF45QYPEyLQV9q\n\
HNqT49ARHYXW6EuoDif6XoxEB9ElzM0JP063RrCDA445u+D8HDKo3ecgztEN\n\
d2Z6oHiBD7K3f4z2+gZ5jFmi7Xoaqp28UPWKE2qDNtPfuilsEJSUlMgDg/yy\n\
ZbM+PT0dO3fuxKFDh9DU1BQnG/dbdgfFEH6HBTO4vaUNiWtWI2bFItTH/0i6\n\
/zz6rkbh18IUXPD2QUpgINrSI/HfjbfQV5COB7eS8bQkGU+yY9GXRJyTeAkP\n\
oyPQfekCus6fx/1LEWg5F4rG6Gh03UjFEY+ZODxrOoJdZyDM1RHZZOaXvumP\n\
Wl9/5Hr6ko77ihrcwgzurKpBtftyVL0xVzKaGE/mmKx+VVUVQkJCpF92zAjq\n\
hKSkJHzzzTeIiIhQGWyPouPByP7wQ+LV7bi5+zMUHDqM6tQbqLmZjcJPtiOf\n\
zO3Ut33QEH8ID1Iv4nFmNJ7WZCFpkS/KdVNxY6oTcvfuQHvBVTypysYjYvjD\n\
vDj0plwmxl9CLzG+mxjfdvE8miLPE8Q8i7b4WPRmpyF5mRcKAhehaeUStPkv\n\
Q4tPACr8/ZHu64fbB3/UdTAL2vNvS5bSv5afQydpGOvAyqKJT6mh9FesbOlw\n\
6YOgRHExqiMvoik8FDWXo1AWHYOiyMso3LUL9TNno+e1aeh+dTo6Rk1Du4Mj\n\
Hs52wWMbZ9x6yxfV8QfJ3LuIexlX0Hc3HXE+/qgYZoe60Y64pZuGRJc5uPXj\n\
t+gpT8XDoiT0pEaiKzECnVcvoi0uAjWXwlAWegZ3z51CdxLpgps3UP7OW2hd\n\
uxId5LN7QxDqli1BhvtC3NhMBnFtbSezqHbxasnw+s0f6/qznHYzHdfkU225\n\
M+orK1BEgOfmO2tw18EFZeOnI3aMNWImzUC+rT0yJ1ijdsQ03H/dBl0uzujw\n\
no97s2Yhd7U/yqL+RmZrODozL6O7PAXRZFAWjLRDyXgXlE5wQcloOySPJu35\n\
LUbJmYPouBmD1oTzaIy/QJDhPMounEXhz8G4cyqYTJJEtN1MQ+XH63Hvuy3o\n\
3bGGUN1S5Ph6I3PzFjrIdSNZn7dExip9Tka6NBfN6S9iKr3GJ6kZI386K+o/\n\
+UKBAvpJf5NyOUAwYzc3/nmfcDMtsxDL6Hep2IIhNx18FFeYIlKjpEyqY6Zv\n\
WLsRM9Y59BqzhgYq/CYr0RSlEulpQeMRSh1uIp/4VCuqnQQGdGpExrJYyBJN\n\
B47pXUGuD2StOYu3KJoS+Wo3kt+0nNXX6W8w7dMRStlgtDbjLEnqir6mVihi\n\
xqgUp39UKVpdNJTWGYxIq/575tn0N+dzlelOIdlSGJi0LV5f8KjOzJQTh2hM\n\
dF5GJzklMT1FmSukxkhMcia9l5IcLad/+/fvR15enplw+cSJE9i7d690mdED\n\
n0+CFOmPVqdlBGDlGEtShAij99N2SGWmjqWoDhVJRRNbaf0RkkoCL0t1uQ6U\n\
pmgZE85MGa5ShlMZa1c0jScC4iVelX6SW9lQG2MkloQCkqfpb24SvY/+ptcE\n\
taRrvB5xmeJxLZ8Rc82Yp5iWzEfGnclHERXHVFOaph4TO5N5kVus5UQmnTl+\n\
uCh+YCcOINFSIVruYzouzPsZO1Q7qs1vZGoaybirjdhaRsL3uzt3o89+Fvps\n\
HVBs44R8e0LYc2aidZoTup3d0L7AE91LfJHzfgAKL+xDfUIYCXIvobUoAeE+\n\
vrj2ig0yJjojfaIT+XNG9gRnXBs9A6Ek5bgctBJFIUdRGUeC3UuhKDp9AkUn\n\
jqAq9hwab6WiKTcNjfu24NefPsDDr9ag+i1/pHh5k1g9bBSzVkAJ6Y+yipkQ\n\
gIrXKERyLymxGrtGyFyBYVpOrzMvPS8/cfCj+ERjBRYa/hv4SUAwFfrzOjRC\n\
Ya1SOy0UyGQwyZFHdBjVnvHTwHoOp9GfGBXoDZb9bkxppr2qLxus3gozyR3J\n\
79fSm+hpzoolFVkwQiT1J2gAThq8xuZitMSpW4yWDMak6MPnJyUGPAop0d+c\n\
lMyEeykUyIxAAXm4BKcUTqgcjn0MUqQ26CepLzITxziOZQygWPY/VPpNVaTX\n\
6B9HbPpJRPCpK2goARa5hWk1QoJDqgkHf6oRxUB6D+cvpgqb7q+rVONt0za4\n\
JVwNfj+3lrdL6wkwLqs5wkg0tUxsll7jhCF6ifOY2DTlKz6gDdmCdYwZs0no\n\
FxVf8X7mfEXrMJYw6meZgOT2uJrkmqKmoWnG4+O3qvExGK8ayx4hypbqcJ2J\n\
O6Q26CcPb7QGGu0pOiKovuQ7pzE5i34VzbeL0BJ8GD1LFqDD0RVtnvNQu9wT\n\
rcsX4t6cBehd6I+M9QHIC/8rymLOoTwuDLW5cQj28kLwb61xdoIdcVDIeDvS\n\
FvmOc+NscWzkFPwwxQYRmzYi/9wJZAUfQd7pI6hICkfd7RTUF6Si9fAf8Hjf\n\
WnRt8MXtxZ64/hbJKe9W6ThviZClDrblFEG8RkGFk7/Idxw/yOdg0HQg3jJn\n\
GCGygNR0lyqEpg28KH2Zi6mTThsPaZmlUo/jqIKDTLARG6iLpXxwkLpyEYq7\n\
zejtMmiKjQ5AX5ZK2WB15srR5IMrpxQPUeksZn9UOd4sDVcEcSakDUBjz645\n\
7SCR+FVBlnALaU7fE+o+eflMRu/jaMDRkaIIL7MSqEikK4pEPHAm9bTEchE0\n\
OmcYrpSJqvAQkIKTGHOztsxNNm2lyVTKLVYS1DHHKMkccRZXghfpEyorIzsZ\n\
QvMWeSrBLzPG5hkepyfxMm9N8PRwkyZZKGTK8hnDftIzlpX0m5snSOuvawUn\n\
KdG96CV2j5ICiyKYK3SDMZan5Iq3CSPQj1fQlZZMUqCluBfoge7VnmjbGoC2\n\
zcvRt8IPmZsCkBX6FxRdOIHiiJ9x90YUDnoswBejJuH7sdb4dpy1Bb4ba60b\n\
je/HTcO3r07FnpHj8a29E85/+AHuXAtFRUo4akuuozbnGlqPbMWv/3gPbR8u\n\
R46fN64HBY1mdolrLeq5q8+SlETBfbl+aYQtY9J4VavM5Fx9Vi4hGMX7UQCN\n\
F+aSIQpHcN7knjCImY3JhKihRlBDeFMLNR9IU3lMqiCR8psW7D4ziQykq5Ze\n\
GiLkOINxMNFTL1ZNgv2Ie2YWGdDNlhL1Me41GqB80JI8TTvpelnEwRbamEpy\n\
GUUSXqZFHCLCs08tsRzfuFhxuYf85puRfF2LX35OviBKcSTkxCdcVtjJkBgM\n\
wJaCnaE0MS8zUnCYshZpkIZJ35l3Schvmik4/jIxWh3DPSkapqG8Vl8K7tFp\n\
+YdraGFwjW/g0PRoIEvpPdQCutkj19W9Jn2MRmfJHbRvXo0ev3l4sJPQw963\n\
cG/zYmSu8kM+ST+qI0+iJjUCDfmJOLxwEb7/7RQcnGBjhQPjZ5DbD0yYQb/h\n\
LyMnY/9rUxAVFIjCmJ/QWpmGBpJxdJzZjn+e3YJ7nyxH0VJvJK8gGUd19Ujm\n\
L3Hi8ZlLQnolumeIr7WNYGkIKvpaz0UOygIZm9hsc5jj00tZIBsiLn6pjKbQ\n\
IrSuX0mT9hIYSRLIUmlgsBtk6CETdGCUOkj52zNnFFb65SWTKhruvQ2KDJRu\n\
JGXCgqcyHQcrzqL/vhiM/uoFTc4cQmar1k8u42t9cs7B855/Fz0IS1dyDXZm\n\
gU9/cs2SLZzxxQwR/zhDUMagMTeJJ01rYCmBCA9TOXDzqIqCjrBwZqbRjOky\n\
SyPKIKIUsSLAPxNfDFEWv6ihfG2ONyGqw3daZGuGaiVIok8tmMOFfQum0TAj\n\
jXimwRegDEWbomMTJNJfjzPHafmNZyMWTFchQ9GT/RAjW3kipt+v042RPkah\n\
PS8XPR8EonfLInR84I/eA79Hzq41KA77K5riQtCaEYn2kiSEePng/KszED3J\n\
mVh3ZZIT4Y3L4+wRM8EeN+Z5IHvbJqT94yuSUpxFT1ky2ooz0Hl2G/73/Cb0\n\
bVuM5rWLkOnvixub3ue8oWz3kynJo3kyfXlAwGNt6RKP91Qh6b+HPcylrV6G\n\
7UTGS6CMYUb5gbibTL/rVbMUF7DkBt+YK6vx3GxhLtICUUyTQQadNxjr9WIU\n\
wYOogdrV4gIzllzS7mJ1dZojxLhxfacoWRXpHPqbRywk65MbG9rvkHphBhii\n\
h2BlUd2S7eCK01hcL6BTWgCL/vCeVqXJhjFqWijb3/R6v+nAfwTvuXge6spu\n\
EcJ1Y5C3MgI79l1yqpUJNBdXY14UzcXe688Hg8JuQzfLTQvrVjz0l89Qj0Tb\n\
yQPoWOeD1t0B6Pz7OuR88S7KzpPAJeoMWpIi0HnrKs57+yJ1tC1uTnSxoLvk\n\
JG/IHueEm2McUOQwGyXvrcb1b/YgNy4MrWWp6CxKRM+da+i4lYLOM9vwz6Or\n\
8fTL5bi/KxAVfp5I9fJGyYlgtNXVDWe2KGE/mTnKLBmqTDyeHYiTSx1TvWwo\n\
5/OBkged5lqtvQCUC3SlglF2eEm/DmJ0ak1mF1quXy95sSRA2NPhqae4Oq7y\n\
5aD3x/tX+MXwfugg29XCewtWj4b7z6f7MKOsjCaJYieS38r9Rgt+oj6ESp6b\n\
FHjwZ8YwgWf7DA04EvI9cRF0k9hBni62sECXmS0YHGgs8UjfeehKv/MFBlLP\n\
StBITRvDFGoQtJK+85Ukqrc2aA2eL/Sc8FzrSZZMYeo8qhbb0TWtwTDReCMn\n\
qc80mYuO1vGHUwxX6ETHGjLJcy4u9dff/Tlt8ItMQzUXmXjeR7IECzXJtCQl\n\
ot1vPmrXLULVzmXI/Gw1qqP+jtZLZ9ARcwFdOQmI9vZD8XBbVI51MUP5WGfd\n\
WJSPcUL5aAfUTnVF3YplKNj3Oa6dOILrR4+iMTMeHXnX0Z6VgJ7CNHTfJkD9\n\
zSo8/moper9+G73v+aNz+QIUeXgg2X0hUtf9Hm01NaQHZD/yPWMOBIxWzNhB\n\
T4GM+luTeqk7Ewbr3nxumdyREDdlhTb4coSCl0bsww3itnM2YkDWD5g++2aE\n\
ppLyZoR4RF852SqsuAv+V1RiuY5KzYGwvD/VX3BvYoh201asA8WN6S4Wy/Dz\n\
XMRQbgyvQg21YlPGoEWpnkAmXCtOJLwfhN0KBUYUnjIcmDz66JdvLFk6YbDi\n\
QwFQta/NMgSlF8Ukg2908iVqccFJBFFODXSJur/lcmO6GWqSbpgsLaYScZ6q\n\
qy/T3rwgTYnbuOyWZ0tOrBSj+R/LJURlmN8U0uEnjwz9xX1LTz5xGBL8zvyl\n\
pk0mzuS+Cesrbswgtr3VPW9llF7247rB74APM7kDLuxvqZMbW7RejUPzGg9U\n\
rfVA4TYfpG0PQP2VA7gXE477KdHou5WMBC9/VFnZom6MM2pfc0bNKEc0jnVC\n\
+yJvlP/pj8i5eAolaQmoTUnArdNn0Jgehwfl6biffx0PirPIZxZq3vVF45rZ\n\
qF+zCK1LPdH5thda3d1RMmse0twXIHnVapT89BPJeGrZRNMvT7GQn89SM4YC\n\
bBLL85wxALmF+1hElpd82Iqu77DnKIStD6mq/gizSbqzUJbjpHPMVGMZ7Lgx\n\
wmEAMS+ScxjhAQnDbV+92paqdIc9W2EcXXMmMs1OVoa6qr08XMw1Ffzm+vB+\n\
E5iXmygSFpcgrwUx9fUMMrD6/TKUiSNY8ilxZZGG8wyTZTJDNVobkyelyNPq\n\
BFWddatNsTRiP5njZcOMD9QN1y+nCeu6PJgRqE9qnh/MozJpffEww+DW0V7n\n\
iy3KfgZlH+EcqHSdswoP94WzptJ1DkrKXoeFIophm7gmpU4GtNMmftbLkMeE\n\
c78s6ZssSeePagpJoSoq56dleZKhRWz9nYxVs5t+b0BDLtGLMreVqj3uIVKH\n\
wYQcT5g+ZDxcpWM/PWJlQG9CPqUcyDWkN+ODvlNVB31NuXOggTEYV76cQ8Ym\n\
YxMzkfzs0fTdf6FixUJUvk+I7CMv3PjjcjTG/oju2Ag8TIrGo4I0xC7yR9kw\n\
W2lqVb7qgEa3+aj5aAOyju5DXkwk2gtvoqsgk2Rb13En6hKqoy/iaWkKHhVd\n\
wy+VWei7Tchvy2K0LHZEzVw71Ds5onnOTNTYz0KZ/UxUuM5CgcscZM5dgIx3\n\
1qE05Bxd9lMGk1aUy7cZzKQg1kIFwArFWSjIwB6X4YDEIdsIB0UapFyrf6xm\n\
hIQu9EaKSsJmvP75PZaJ6NMAS+UZDQEZjaNrPZRWKdvChmUiL1uKDYiJH0cR\n\
Ht/LB5eM0zS2BCk4REzAmM68lvwcSJeQgUhPzdL7RqmQXdxCo2YZEI0R6Rmb\n\
bqXqGAHd9S4TtNanjZRvyJ28mHeU6iFPSy1dlRBHkktkNQpP3giizEUHKcBs\n\
goWFA2RCyqZpgt7xPP2iShmuFdCDYxyphAdBVQ9+GoxgC5UnhUNvg6O9Ecpy\n\
EH/Ckcfb4sN77KSTsuokPhfK6VJ5JkZPeaw5biVP5+jCkWnKs1QoqkufrilY\n\
ZyiZPdghydS9KsElP+hGxXHI5Uwn7onzOgYPLyqhl/EDsfpnLeU1UipzqMKk\n\
4uOMRk6x4qht+OQnT2cMs0Qt9w8xIDjOlfSYmNbhbrlsqKnnMLnWsiFDFEO0\n\
RBvyp5bjXtJjn4YbazyZY8/LyCcNSAhZV4eyNxej1MMVhW8tQFaQJ5I3LENz\n\
zI/ouRiOBwnReJCXivOLfJE8bBqK7WajfN1KZO/7AukhJ1EaFYmq6MuoSYhF\n\
S1Yy2nJSUHM1FnejIvAgNwGPcuLwtPgG+vIz0LDBB/eXu6LehSSGdjaod7BF\n\
82RbVEyyQamrGyrtZ6PKbhaq7d1QOs8DBe9tQNXFS2i5U6ocJNa/jEAZzLyM\n\
zmA+i9UrUcNVuY3yHLjwbAXLw4x2Ylh7bIfDUrXQx7hNJ0I+b1tBVxm29QG+\n\
0r78XLv4dgAKbfR+ylAGZepzsMpSXtBmZUrx/SblgUQDoxnki+8q4UZLSlnp\n\
UVlwsJyGSRCrXg+UPS899s9xk76RQdZWvjxKlaqILxSgsqmRbOFOLFPWJfrR\n\
VyFGy37oQ25ntHJqRHkxDWmTZ4r9yOgvczM8WalECEScyJkDmSAchzRMqeVw\n\
QnayidceqNJYZViSOs9AXpM0ykZqlBlSD4UyrXr8oRARPV/pp55YprWUOEpg\n\
Qo7SypMsajFap4yHadSboFHPUoREGzR8/SXq7VyQP8cNqY6uuOLoiMQgXzRJ\n\
kBiGThLCNyXF44z7QiTOd0f2lzuQevxHlMVeQsO1GNy9chEl4aG4FXIGBaHn\n\
UBUfhcrYSOSFnEZT3AV0JFzAg5vX0JtzA+UrfdC1wh21bs4onjsXOb5+KPhw\n\
K/I/+QS1sXGoS0gwI//iafCWEIeGK1GoiyF9fSvPcL1BOUEvQZVhSESnxEhD\n\
cNNPZ+MyW7GyuN/KW+azQIl8DWLm4Qb6GQR9amkOpi5M0WhFayWErXxomsLf\n\
y/OyZgP3PCVo/oTsqP/wbBCeif43zQb5FPs0NPz9B9yd7YYMG2fETLFH9BRb\n\
RFhPR0ygN2ou/4Dms6dQeuY0Ss+F4HLQKqTu/wqlVyPQU3gNDxty8KgxG/cq\n\
MqQtxYbkaJRGnEXWiWCkBx9D5vGjKDx1gpD8WbQnx6Iz+waKlvqh3HsBchcv\n\
RvE/DqNGwBpOIHris1A9QE++Kymd/hjBwANf5DZbZQ4ZbYzJ3hEFslBDUfBZ\n\
B/uAW2S0/jiN8c5eFaBPgdlpieedA+qDD+rDt2NNzgvTj/fT8alE7ebiNpJ8\n\
AMmMajKUGcYb6RIWxl5VammNZZPTg5/N4kG4OF+NJojUvNYs7WdavMKnRckd\n\
1Gz8AKWT7XBhvDWiRlsj6XVrXJxqjeOTpiLUyx0VFw8g79BhFJ84jrLTJ1AR\n\
eRbNuYnoupOMrspUdNO/0mvoKExAc2o0WjJi0JEZibroEOTTHfkfDiCN3F94\n\
7jQZiTfRW1mOHB935HrMR9GhQ7rRTE1jeLZQ4qp+AgxhWqjHobK/IPMHS7kJ\n\
M3bpl4ipTO5gowNOGjOD0oUUEPGp298old59ReYkXf0xWXmcJjXoY259aDaA\n\
NBObs+biiRDTk8BcqMyWMZUzUuKwf62fwf7GMzGAuZJS0oxV68VT459tTI/i\n\
3Utf25qahtwDB5FCAp9cW1dcc/NAQsAKxHstQca6DYheHoATTi649MpUZP/5\n\
MzQmE5i/W44nLXV42tmEJ/da8eRhF3552oOnT3rwS18rnt5rwqP2Rjxqq8fj\n\
DvLXXI0HtZXouVuBltIy3G9twf/961+4G3wcqU6OSPX2RsWlS076jjNejJKP\n\
g+kHKe+nN031tpt8QZ4jYqDyu2cZHzaCF/nbotw0emCqRj2rQd47QaOeqqeG\n\
oKO5GfE+/ri+4i0Uf/8d6pKT0VxdRd+lyuBuMhrKypCwJABXRk/EERsbJHz8\n\
ARpOHkbDmWA0Rp5B+/UIdKZfQXtqJNpToqQXZ7ZdD0PrpZNoDP0JjeeOounM\n\
ETSePk6+n0B18FFU0deLbf8Y52bYI9baBlc9F6Ei4qLuXxquqhdVJgDQ0YFK\n\
gsqdbS3ME5NRmZmNrAM/4vzqVdhnPQln585AwxIP1G5Ygo796/H44Ab8emkn\n\
fo3fi18jtuOXxI/x5ML76Nu2EJ1B89H6tita/BzQ4D8bjW/OQelcV2SSaD2e\n\
qBZubY/wqfTVti4oOXlSpSI/lsBUlB0+EVFrVuPg5InI8ZyJJq+FaN+6Ck8O\n\
bcWjr9bi0Q8b8OSv6/Fr8Cb8+vN6PNm/Cvd3+aNniTP6Ns1Hd+As1Pi5o2nh\n\
bNR7zcGdma7Id3BBPAmbTr9hh8iJ1kjfuEl+j2ujLHc8c0NLYxNO+vri9NiJ\n\
qJ/ngdZ3AtC7YzUe7X4XT/+yDj3bA/FgbxAefuiPp38OwMPvV6FrTyBal7ig\n\
eb4tOjwI+vl5osp1Nmrf9Ea5+zyUOrqg2G0mkmc4Iub16UhYtkIaHZL8BrX8\n\
0sREhFlPQ661A5rm+aJv3Sr0blmBe+8Hou2PK1AX6IvG1f5oD3THw93L8ODL\n\
lehY44023zlodLVDtb0NKny8Ubr/b6iOikL+F18gY81a3CI+vOPiipRJ9gh+\n\
dSpu7tuvIf81lF2OQuIMG1QtWoCuZUtx390HTUErUbxlE25/81+4c/wYcrZs\n\
Rr6fNxoCFuH+uoXofs8X7QtmoWmWI8odnVEVdo6vfrXV1aI8LAx5dP7MIvA1\n\
wQah8xfRlxDL4utF8UMQt349MkhX9Xj7oG91AFo/24P65CTpJcb8rEhrZSVu\n\
/P495BCTmgM9cW+VLzrmzkKbvT1uvb0C9dnZyrkQOjlLyAhLXuiDmOmOyP7+\n\
Lyq54xgaNNzKkyZxrfN84soVaE9PQ2dTkyWLkqjI9I0bUTh7DprnupOU1A31\n\
r0yTUkOiGj8kVUOmftZH2xDn6UVazJcE1YmCLJCz53NkzpqHSp/laLqZO5TJ\n\
r8vIkN6uVjV/NmocnFE+wwnlISHD2F3UjOxPd+Hm13+WJi8trpUb5u/tll7d\n\
/PZbyF+8FLW3bg1nDig+egy5JDFutnFAddC70glBHsXVEn7pbGuTfklN1ohN\n\
mqP01ClkBAag/k4Zu8eCdFwuUhb5osHaEWXvvS/d1i3f9joPQAh1pW7YiKqU\n\
FOXFpbQs65NPUUJorGj7DvE2Lq2zpUWBex6pVF9PRtrcBfRdvDrxHg79tF+S\n\
V7yN1PXrVddt2fXMP27D9VVr9BbKzet0v/l/ed5zfg=="], ImageSize -> {516, 41}, 
      ImageMargins -> {{0, 0}, {0, 0}}, ImageRegion -> {{0, 1}, {0, 1}}]], 
    "DockedCell", Background -> GrayLevel[0.866682], 
    CellFrame -> {{0, 0}, {0, 4}}, CellFrameColor -> 
    RGBColor[0.690074, 0.12871, 0.194598], CellMargins -> {{0, 0}, {-3, 0}}, 
    CellFrameMargins -> 0], 
   Cell[
    BoxData[
     GridBox[{{
        Cell[
         GraphicsData[
         "CompressedBitmap", 
          "eJzVV0tIVFEYvs4dx9FkFtZCAh+LyhLMDDNNXJio+UILKqOVqOHbUtEEH5BR\n\
ahmC2MuQHhNFJpJIUFRChK4qNwWuWrSsdfjI/s5/zn/unHvnTpoMRBfunfP4\n\
H9/3/+f850xJRVtNdWNFW21lRXx+S8XZmtrK1vi85hY2pIdomjbP3th4DdvA\n\
mvSZh56eHja5/k8W/9HB6/XC7Owsvto5/hVjbJZLbDWLo+hSezS+TBy/Yux/\n\
E9f5NxJWZmoAHxzHZ/l+AW+vvD5v7gs5B3ac2NLchg7OYXvt+2f4uTgl9bis\n\
FgGrC3f4lDSDbXzWvr71M625TBbx/fXjG6rIaRWwAkAnVoq24CjAhv+RIP1q\n\
DlKTiFHTwb9ibKk3Bo0LN+y7fCsT6CG5UAOfZIjyWzaTG5d/bibKEYLw5BRd\n\
a/wiueTq3CAHh68pS/07DdKYKUbKgYMsSxhmjIl0im1uws6L05QlnmuBCR34\n\
SZuzYjcmGLsDYjcx13mX4GsCf7iBX8UuVQkNk2Wj6IzlkVzRmBJsxsCIwUxN\n\
RJC2FaHAFWEQ2kicXAYhjAs3ycAzdaeMxXAyX6vMMsafqXgC7RHeRjMoz+NF\n\
Y5vKlp1cqB1ZDLHE6+Z4/ZajL0e6ylqpAhaImH2qKWJvBydFGBSjINikSG58\n\
dE96tPEjjDG5uHABYt5k6aMFt5EcybXM65BdlQzzi49EzbyJZSCgelSo9hTt\n\
4Qp1p9W9bo2Cb2tR6ZSrNHiJQQhqEG33TpSMr6gdbJHZ1j1S5cUDNwIWaEZa\n\
nl6sv15+jLpCtZHL+GqGQ6lkan4kCUIhuEYHBB2Isx1w7kqteCy7NrtJdRPs\n\
3aSr4aIdkWCAlgTQu1wfvLpTVmyzphBSzhm+fLk+ydodV4H8oCwdEbhee2NY\n\
miU2tfxLvwYuSjO2KVS6Uu4s8Im+x49+IAoWug5+ZfCYFp9SP6w5DMqBFeq/\n\
6VgdUWs/lQy6+viOS/mYyoZLVB1WWWRBpEucTrcHyzVQnA2hKg15mTQOFlzx\n\
SsHhQXKSN3nx5BH27QKlZDtNu0m5TkpuFqAmVUnGvwYK16Yrn+j/5Y3vn/01\n\
iCfx8YIi6G9q4r3tmzNxLy8fBmtrTSY2+OcqjsQvtrfDo+wcGCsp1R6qU064\n\
0tAAk4eywJuTC30dHV7z7EBjIzxOTYfpjCwYqK/3kL2e7m7D1YjQiOE/Lj41\n\
erIchhjiuwl74d3+DBg/eiySNK8yg7dPnYberi5tVGjGkuaD3HzwVp+BqT1J\n\
8CElDV4UF8JwVWUEaV5jmpOHc2Gkqkq7rmqGwQSj9jEtHV4lJ8JcUip8Kj0C\n\
02VlcKGzk50YgslQfT08O5AJT7Ky0TlZ2EbGL7e2wmBTs+TAvm641NcHLwtL\n\
YDFqBzzdvQvepxyEL8VFsFBUDDfr6sIUw2/2ZcDzuEQYO37ihjCshfwGPGMf\nPw=="], 
         Evaluatable -> False, ImageSize -> {199, 30}, 
         ImageMargins -> {{0, 0}, {0, 0}}, ImageRegion -> {{0, 1}, {0, 1}}], 
        ButtonBox[
         Cell[
          GraphicsData[
          "CompressedBitmap", 
           "eJylVb1uAjEMDuSAUqTr1J234A3aqQ9xQpVgqFpRZkZWNkZWRkZmRkZmVkZ2\n\
xtSfY0e+9MrSSLkY27E//4W3aj55/6jm03E1fJ1VX5Pp+Hv48jkjlm8550a0\n\
y6EDHYiUzygsFgsS1o42Hw9hs9mE6/UasHCu12tI+KTVYbUy7Ha7pIZ1uVys\n\
GtPL5ZJpmLzdbrgTvXgrol+0XBHO5zOr4irtyO7zTWHx3u/3CRTo1Wol4FMM\n\
WBBB5Xg8MlDQsE6rYLUnjkFVIdputwm7qCYvigLmCCi5AvSSZapnbUFPY89l\n\
hN4zhE44HA4J3el0EtMcjHusAUHG8gTX4ikZIwxqpmwM1gwcqh7xC8k//CtU\n\
YrcFIthaXS1Z7IJuKiMyqcBI3pIIvHUtcRU5rDYLe4zKZgvVkLS4qJObw3eA\n\
+qeIkQG9Z20obm0/U2lpP5/CB09jRxW18mhPyoO7F9xzY87zNrTIgF56ovEO\n\
PGri8BsoRSeyB7U2w7ZtbNsOg1JIYCioBixtczewwZ+BWW9IEcrVES8NerUu\n\
gGcZqMju/womz5vtPnWNHOqMUkf+v0AohmIDDT19T/I7pBc90Rd3ZBycrY5W\n\
AEOn49JUHW+qowMKm6STXgVvX4GUTfsqEB1no8uXbTZBk3EdJ9RLbsgY9FJj\n\
6kaXyMMRvelzjWRpIInt01MRX+KGPxo5XOsHSMiAwg=="], Evaluatable -> False, 
          ImageSize -> {55, 14}, ImageMargins -> {{0, 0}, {0, 0}}, 
          ImageRegion -> {{0, 1}, {0, 1}}], ButtonData -> {
           URL["http://store.wolfram.com/view/app/playerpro/"], None}, 
         ButtonNote -> "http://store.wolfram.com/view/app/playerpro/"], 
        Cell[
         GraphicsData[
         "CompressedBitmap", 
          "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwMAExnwIDiP0fyIQS\n\
jP9bWloY/8+ZPZuBgfF/V2cn4//VK1cOFnZ7ezvj/+XLlgFdyggAJaVbgQ==\n"], Evaluatable -> 
         False, ImageSize -> {2, 14}, ImageMargins -> {{0, 0}, {0, 0}}, 
         ImageRegion -> {{0, 1}, {0, 1}}], 
        ButtonBox[
         Cell[
          GraphicsData[
          "CompressedBitmap", 
           "eJyVVj1vIjEQ9bIBRKKjyClFOn5NUvEjUBQpKU6JctSUtHSUtJSU1JSU1LSU\n\
9JTOPHued0x2SWJpWXvGOx/Pb8YMR+OX53+j8evTaPD4MXp/eX36P3h4+xBR\n\
WTjnhvL0Bw5zL1P9GfrJZCLK7NUKr9LP53OPgVWQlVi5O386nbC0G/x0Og3z\n\
xWKRybHGgN7KMYcdjPV67TrBzZXfbreeQ+aMBQOfYMWty+UybZV5S5XH4zGJ\n\
xTK9xeB7/nA4BBEfbFHLYT6bzVyRA8EcEhDuPllnvjZXmiJOVs78VqtVJocN\n\
yJgUwrgKvnrBFrISWXhgd7PZhO8Uc9dVUBQM2onhdlOocKHm6V5SgoFekFlk\n\
4AJuMd/tdn6/33+PTJlYUMn6GQtgktFbBJAVdOKG8lJNGnIlULCVx3seLfd2\n\
lBLWjdFH8+2MuwSlc6YDcMpfAQHGm0GIVCsDaJplxMVdJ5D5EWuCbz03Zg4T\n\
yErC0My7aRuzIWUS/PJLgKtDaEShpZlCDVcEsYq6zlysVDJczqxAZV1ixt+s\n\
Zs5xYG2wPCmHZzACMuiwjqSNfqDT2pAcILu5BFAWQwVqvwmcVMsYOAzwwcTX\n\
UpgotgAhXFJAgCoQ+29L5zYLzCZCOZIHORko25/dI+B0GsqGn3wtm95FTBRH\n\
V9ak09Zf08vYD6V2gLoTNrDrEV3Lip8wxXRXASvylMcANlBmbqrY6kgTUAlG\n\
2FYtNGcBpK7zHSQSmCMnTNCNPZaUZgMEpNpj1YJekikdFkidTNLUkm2nAmBj\n\
QfcutYNgv82ClxIquO4ilghrG1vF0z/Z5U40eDEiFl72X2PN7cWLzNX+M3HF\nJ/Rd8Mk="], 
          Evaluatable -> False, ImageSize -> {77, 14}, 
          ImageMargins -> {{0, 0}, {0, 0}}, ImageRegion -> {{0, 1}, {0, 1}}], 
         ButtonData -> {
           URL[
           "http://www.wolfram.com/solutions/interactivedeployment/\
licensingterms.html"], None}, ButtonNote -> 
         "http://www.wolfram.com/solutions/interactivedeployment/\
licensingterms.html"]}}, ColumnsEqual -> False, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}]], 
    "DockedCell", Background -> GrayLevel[0.494118], 
    CellFrame -> {{0, 0}, {4, 0}}, CellFrameColor -> 
    RGBColor[0.690074, 0.12871, 0.194598], CellMargins -> 0, 
    CellFrameMargins -> {{0, 0}, {0, -1}}, 
    ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
         NotebookLocate[#2]}]& ), Appearance -> None, ButtonFrame -> None, 
      Evaluator -> None, Method -> "Queued"}]}, {}],
PrintingCopies->1,
PrintingPageRange->{1, 2},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], 
   Cell[
    TextData["11/10/6"]], 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, Visible -> False, 
  FrontEndVersion -> "6.0 for Microsoft Windows (32-bit) (May 21, 2008)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 58, 1, 123, "Title"],
Cell[651, 26, 116, 2, 74, "Subtitle"],
Cell[770, 30, 338, 8, 72, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1133, 42, 103, 2, 105, "Section"],
Cell[1239, 46, 1178, 24, 188, "Text"],
Cell[2420, 72, 52, 1, 43, "Input"],
Cell[2475, 75, 59, 1, 43, "Input"],
Cell[CellGroupData[{
Cell[2559, 80, 84, 1, 54, "Subsection"],
Cell[2646, 83, 206, 5, 66, "Text"],
Cell[CellGroupData[{
Cell[2877, 92, 130, 3, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[3032, 99, 2604, 76, 260, "Input"],
Cell[CellGroupData[{
Cell[5661, 179, 734, 12, 32, "Print"],
Cell[6398, 193, 734, 12, 32, "Print"],
Cell[7135, 207, 733, 12, 32, "Print"],
Cell[7871, 221, 733, 12, 32, "Print"],
Cell[8607, 235, 735, 12, 32, "Print"]
}, Open  ]],
Cell[9357, 250, 757, 14, 42, "Output"]
}, Open  ]],
Cell[10129, 267, 462, 11, 66, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10628, 283, 98, 2, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[10751, 289, 1532, 48, 152, "Input"],
Cell[12286, 339, 671, 12, 32, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12994, 356, 537, 17, 98, "Input"],
Cell[13534, 375, 551, 8, 32, "Print"],
Cell[14088, 385, 7519, 238, 566, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21656, 629, 192, 6, 42, "Subsubsection"],
Cell[21851, 637, 391, 14, 66, "Text"],
Cell[CellGroupData[{
Cell[22267, 655, 2761, 77, 233, "Input"],
Cell[25031, 734, 123, 3, 42, "Output"],
Cell[25157, 739, 293, 7, 83, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25499, 752, 313, 11, 42, "Subsubsection"],
Cell[25815, 765, 360, 8, 66, "Text"],
Cell[CellGroupData[{
Cell[26200, 777, 3796, 87, 206, "Input"],
Cell[29999, 866, 306, 7, 32, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30342, 878, 3728, 86, 206, "Input"],
Cell[34073, 966, 285, 7, 32, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34395, 978, 3646, 84, 179, "Input"],
Cell[38044, 1064, 284, 7, 32, "Print"]
}, Open  ]],
Cell[38343, 1074, 373, 7, 41, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38753, 1086, 115, 2, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[38893, 1092, 1883, 56, 152, "Input"],
Cell[40779, 1150, 191, 4, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41007, 1159, 1010, 33, 125, "Input"],
Cell[42020, 1194, 4646, 119, 376, "Output"]
}, Open  ]],
Cell[46681, 1316, 353, 10, 90, "Text"],
Cell[CellGroupData[{
Cell[47059, 1330, 1273, 37, 179, "Input"],
Cell[48335, 1369, 323, 8, 42, "Output"],
Cell[48661, 1379, 303, 7, 42, "Output"]
}, Open  ]],
Cell[48979, 1389, 253, 7, 41, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49269, 1401, 131, 3, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[49425, 1408, 2110, 58, 179, "Input"],
Cell[51538, 1468, 300, 6, 42, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51887, 1480, 227, 4, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[52139, 1488, 1205, 31, 152, "Input"],
Cell[53347, 1521, 1193, 36, 125, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54577, 1562, 883, 22, 125, "Input"],
Cell[55463, 1586, 1054, 32, 125, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56554, 1623, 961, 23, 152, "Input"],
Cell[57518, 1648, 1212, 37, 125, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58767, 1690, 959, 23, 152, "Input"],
Cell[59729, 1715, 1093, 33, 125, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60859, 1753, 1435, 34, 152, "Input"],
Cell[62297, 1789, 1617, 46, 170, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63951, 1840, 1015, 24, 125, "Input"],
Cell[64969, 1866, 1603, 44, 170, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66609, 1915, 1015, 24, 125, "Input"],
Cell[67627, 1941, 1608, 45, 170, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69272, 1991, 1014, 24, 125, "Input"],
Cell[70289, 2017, 1608, 45, 170, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71934, 2067, 960, 23, 125, "Input"],
Cell[72897, 2092, 1699, 47, 170, "Output"]
}, Open  ]],
Cell[74611, 2142, 270, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[74906, 2151, 254, 7, 43, "Input"],
Cell[75163, 2160, 800, 20, 138, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76000, 2185, 281, 8, 43, "Input"],
Cell[76284, 2195, 800, 20, 138, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77121, 2220, 432, 10, 43, "Input"],
Cell[77556, 2232, 1576, 42, 215, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79169, 2279, 334, 9, 43, "Input"],
Cell[79506, 2290, 800, 20, 138, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80343, 2315, 432, 10, 43, "Input"],
Cell[80778, 2327, 1576, 42, 215, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82391, 2374, 432, 10, 43, "Input"],
Cell[82826, 2386, 1580, 42, 240, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[84455, 2434, 103, 2, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[84583, 2440, 1833, 54, 179, "Input"],
Cell[86419, 2496, 210, 4, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[86690, 2507, 79, 1, 54, "Subsection"],
Cell[86772, 2510, 95, 2, 41, "Text"],
Cell[CellGroupData[{
Cell[86892, 2516, 1773, 54, 233, "Input"],
Cell[CellGroupData[{
Cell[88690, 2574, 316, 7, 32, "Print"],
Cell[89009, 2583, 157, 2, 32, "Print"],
Cell[89169, 2587, 177, 4, 32, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[89395, 2597, 2621, 79, 233, "Input"],
Cell[92019, 2678, 123, 3, 42, "Output"],
Cell[92145, 2683, 137, 3, 42, "Output"],
Cell[92285, 2688, 244, 7, 58, "Print"]
}, Open  ]],
Cell[92544, 2698, 91, 1, 41, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92672, 2704, 136, 6, 54, "Subsection"],
Cell[92811, 2712, 959, 20, 188, "Text"],
Cell[93773, 2734, 158, 6, 41, "Text"],
Cell[CellGroupData[{
Cell[93956, 2744, 364, 12, 43, "Input"],
Cell[CellGroupData[{
Cell[94345, 2760, 258, 3, 58, "Print"],
Cell[94606, 2765, 250, 3, 58, "Print"],
Cell[94859, 2770, 249, 3, 58, "Print"],
Cell[95111, 2775, 252, 3, 58, "Print"],
Cell[95366, 2780, 235, 3, 58, "Print"],
Cell[95604, 2785, 234, 3, 58, "Print"],
Cell[95841, 2790, 224, 3, 32, "Print"],
Cell[96068, 2795, 196, 2, 32, "Print"],
Cell[96267, 2799, 194, 2, 32, "Print"],
Cell[96464, 2803, 194, 2, 32, "Print"],
Cell[96661, 2807, 258, 3, 58, "Print"],
Cell[96922, 2812, 257, 3, 58, "Print"],
Cell[97182, 2817, 233, 3, 58, "Print"],
Cell[97418, 2822, 230, 3, 32, "Print"],
Cell[97651, 2827, 193, 2, 32, "Print"],
Cell[97847, 2831, 250, 3, 58, "Print"],
Cell[98100, 2836, 249, 3, 58, "Print"],
Cell[98352, 2841, 194, 2, 32, "Print"],
Cell[98549, 2845, 252, 3, 58, "Print"],
Cell[98804, 2850, 234, 3, 58, "Print"],
Cell[99041, 2855, 261, 3, 58, "Print"],
Cell[99305, 2860, 223, 3, 32, "Print"],
Cell[99531, 2865, 194, 2, 32, "Print"],
Cell[99728, 2869, 193, 2, 32, "Print"],
Cell[99924, 2873, 260, 3, 58, "Print"],
Cell[100187, 2878, 242, 3, 58, "Print"],
Cell[100432, 2883, 252, 3, 58, "Print"],
Cell[100687, 2888, 235, 3, 58, "Print"],
Cell[100925, 2893, 235, 3, 58, "Print"],
Cell[101163, 2898, 235, 3, 58, "Print"],
Cell[101401, 2903, 197, 2, 32, "Print"],
Cell[101601, 2907, 194, 2, 32, "Print"],
Cell[101798, 2911, 196, 2, 32, "Print"],
Cell[101997, 2915, 195, 2, 32, "Print"],
Cell[102195, 2919, 195, 2, 32, "Print"],
Cell[102393, 2923, 195, 2, 32, "Print"],
Cell[102591, 2927, 196, 2, 32, "Print"],
Cell[102790, 2931, 193, 2, 32, "Print"],
Cell[102986, 2935, 234, 3, 58, "Print"],
Cell[103223, 2940, 235, 3, 58, "Print"],
Cell[103461, 2945, 242, 3, 58, "Print"],
Cell[103706, 2950, 230, 3, 32, "Print"],
Cell[103939, 2955, 235, 3, 58, "Print"],
Cell[104177, 2960, 236, 3, 58, "Print"],
Cell[104416, 2965, 249, 3, 58, "Print"],
Cell[104668, 2970, 194, 2, 32, "Print"],
Cell[104865, 2974, 194, 2, 32, "Print"],
Cell[105062, 2978, 252, 3, 58, "Print"],
Cell[105317, 2983, 196, 2, 32, "Print"],
Cell[105516, 2987, 224, 3, 32, "Print"],
Cell[105743, 2992, 224, 3, 32, "Print"],
Cell[105970, 2997, 209, 3, 32, "Print"],
Cell[106182, 3002, 194, 2, 32, "Print"],
Cell[106379, 3006, 197, 2, 32, "Print"],
Cell[106579, 3010, 195, 2, 32, "Print"],
Cell[106777, 3014, 196, 2, 32, "Print"],
Cell[106976, 3018, 223, 3, 32, "Print"],
Cell[107202, 3023, 223, 3, 32, "Print"],
Cell[107428, 3028, 223, 3, 32, "Print"],
Cell[107654, 3033, 235, 3, 58, "Print"],
Cell[107892, 3038, 193, 2, 32, "Print"],
Cell[108088, 3042, 196, 2, 32, "Print"],
Cell[108287, 3046, 251, 3, 58, "Print"],
Cell[108541, 3051, 234, 3, 58, "Print"],
Cell[108778, 3056, 197, 2, 32, "Print"],
Cell[108978, 3060, 179, 2, 32, "Print"],
Cell[109160, 3064, 222, 3, 32, "Print"],
Cell[109385, 3069, 223, 3, 32, "Print"],
Cell[109611, 3074, 193, 2, 32, "Print"],
Cell[109807, 3078, 195, 2, 32, "Print"],
Cell[110005, 3082, 195, 2, 32, "Print"],
Cell[110203, 3086, 195, 2, 32, "Print"],
Cell[110401, 3090, 197, 2, 32, "Print"],
Cell[110601, 3094, 197, 2, 32, "Print"],
Cell[110801, 3098, 194, 2, 32, "Print"],
Cell[110998, 3102, 195, 2, 32, "Print"],
Cell[111196, 3106, 195, 2, 32, "Print"],
Cell[111394, 3110, 195, 2, 32, "Print"],
Cell[111592, 3114, 233, 3, 58, "Print"],
Cell[111828, 3119, 234, 3, 58, "Print"],
Cell[112065, 3124, 195, 2, 32, "Print"],
Cell[112263, 3128, 196, 2, 32, "Print"],
Cell[112462, 3132, 194, 2, 32, "Print"],
Cell[112659, 3136, 194, 2, 32, "Print"],
Cell[112856, 3140, 195, 2, 32, "Print"],
Cell[113054, 3144, 194, 2, 32, "Print"],
Cell[113251, 3148, 195, 2, 32, "Print"],
Cell[113449, 3152, 195, 2, 32, "Print"],
Cell[113647, 3156, 195, 2, 32, "Print"],
Cell[113845, 3160, 195, 2, 32, "Print"],
Cell[114043, 3164, 195, 2, 32, "Print"],
Cell[114241, 3168, 233, 3, 58, "Print"],
Cell[114477, 3173, 197, 2, 32, "Print"],
Cell[114677, 3177, 198, 2, 32, "Print"],
Cell[114878, 3181, 180, 2, 32, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[115119, 3190, 67, 1, 54, "Subsection"],
Cell[CellGroupData[{
Cell[115211, 3195, 1599, 47, 206, "Input"],
Cell[116813, 3244, 1265, 20, 133, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118115, 3269, 65, 1, 42, "Subsubsection"],
Cell[118183, 3272, 526, 9, 139, "Text"],
Cell[118712, 3283, 4538, 122, 449, "Input"],
Cell[123253, 3407, 155, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[123433, 3415, 756, 18, 98, "Input"],
Cell[CellGroupData[{
Cell[124214, 3437, 1369, 35, 105, "Print"],
Cell[125586, 3474, 1161, 27, 123, "Print"],
Cell[126750, 3503, 865, 19, 58, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[127664, 3528, 529, 15, 71, "Input"],
Cell[CellGroupData[{
Cell[128218, 3547, 1193, 31, 105, "Print"],
Cell[129414, 3580, 854, 24, 123, "Print"],
Cell[130271, 3606, 661, 16, 58, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[130981, 3628, 784, 20, 98, "Input"],
Cell[CellGroupData[{
Cell[131790, 3652, 1367, 34, 105, "Print"],
Cell[133160, 3688, 933, 26, 123, "Print"],
Cell[134096, 3716, 442, 11, 58, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[134623, 3736, 111, 2, 105, "Section"],
Cell[134737, 3740, 164, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[134926, 3749, 92, 1, 42, "Subsubsection"],
Cell[135021, 3752, 419, 10, 90, "Text"],
Cell[CellGroupData[{
Cell[135465, 3766, 1733, 58, 230, "Input"],
Cell[137201, 3826, 40, 0, 42, "Output"],
Cell[137244, 3828, 209, 5, 68, "Output"]
}, Open  ]],
Cell[137468, 3836, 603, 12, 213, "Text"],
Cell[CellGroupData[{
Cell[138096, 3852, 2109, 63, 214, "Input"],
Cell[140208, 3917, 1228, 24, 393, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[141485, 3947, 244, 6, 42, "Subsubsection"],
Cell[141732, 3955, 221, 5, 66, "Text"],
Cell[141956, 3962, 6098, 150, 419, "Input"],
Cell[148057, 4114, 581, 10, 164, "Text"],
Cell[CellGroupData[{
Cell[148663, 4128, 3045, 86, 287, "Input"],
Cell[151711, 4216, 9529, 172, 899, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161277, 4393, 3044, 86, 287, "Input"],
Cell[164324, 4481, 9577, 172, 899, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[173938, 4658, 3024, 86, 260, "Input"],
Cell[176965, 4746, 9502, 169, 899, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186504, 4920, 3295, 94, 314, "Input"],
Cell[189802, 5016, 399, 7, 32, "Message"],
Cell[190204, 5025, 11181, 172, 899, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201422, 5202, 3294, 94, 314, "Input"],
Cell[204719, 5298, 359, 6, 35, "Message"],
Cell[205081, 5306, 11181, 172, 899, "Output"]
}, Open  ]],
Cell[216277, 5481, 546, 23, 66, "Text"],
Cell[216826, 5506, 5122, 134, 476, "Input"],
Cell[CellGroupData[{
Cell[221973, 5644, 607, 16, 71, "Input"],
Cell[222583, 5662, 6361, 112, 434, "Output"]
}, Open  ]],
Cell[228959, 5777, 215, 5, 66, "Text"],
Cell[229177, 5784, 256, 8, 43, "Input"],
Cell[229436, 5794, 275, 9, 43, "Input"],
Cell[229714, 5805, 967, 28, 125, "Input"],
Cell[230684, 5835, 557, 15, 98, "Input"],
Cell[231244, 5852, 1801, 45, 265, "Text"],
Cell[233048, 5899, 24889, 817, 1568, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature #wTY9wCcOe@RtC1yw3Ha4WKo *)
