(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    563529,      17416]
NotebookOptionsPosition[    543992,      16815]
NotebookOutlinePosition[    545759,      16872]
CellTagsIndexPosition[    545495,      16863]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Hoop Algebra Demonstration.", "Title",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
Conservative Division Algebras - Data, Procedures, Demonstrations, Physics. \
\>", "Subtitle",
 PageWidth->WindowWidth],

Cell["\<\
R.H.Beresford. 2004-5, revised 8/10/2006. Mathematica6 22/8/8.\
\>", "Subsubtitle",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell["\<\
\".. we must be willing to question basic, seemingly self-evident, elements \
of reality.\" (Brian Greene, The Fabric of the Cosmos\" 2004, p426.)\
\>", "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Summary.",
 FontFamily->"Arial",
 FontSize->16]], "Section"],

Cell["\<\
Symmetry-conserving partial-fraction-division \"Hoop Algebras\" multiply, \
divide, add and split vectors with generalized signs. GroupLoopHoop6.m \
develops them, and this notebook demonstrates them. Geometric (Clifford) \
algebras are such an important sub-set of hoops that they are covered by the \
CliffordG.m package. Real and Complex algebra are degenerate, \
single-symmetry, Hoops. Hoops employ many new or neglected mathematical \
concepts to re-define physical mathematics.\
\>", "Text"],

Cell[TextData[{
 "The key concepts of \"Primal Maths\" (the background to Hoop algebras) \
are:-\n1) Unsigned Natural numbers \[DoubleStruckCapitalN], {0,1,2,...} arise \
from labelling the empty set \"",
 StyleBox["0",
  FontWeight->"Bold"],
 "\", the set containing the empty set \"",
 StyleBox["1",
  FontWeight->"Bold"],
 "\", etc. Natural numbers (shown as ",
 StyleBox["bold",
  FontWeight->"Bold"],
 " letters",
 StyleBox[")",
  FontWeight->"Bold"],
 " have trichotomous order ",
 StyleBox["i<j ",
  FontWeight->"Bold"],
 "or ",
 StyleBox["i=j",
  FontWeight->"Bold"],
 " or",
 StyleBox[" i>j",
  FontWeight->"Bold"],
 "; addition, ",
 StyleBox["i+j=s",
  FontWeight->"Bold"],
 " (sum); multiplication ",
 StyleBox["i*j=t",
  FontWeight->"Bold"],
 " (times); powers ",
 StyleBox["i^j=p",
  FontWeight->"Bold"],
 " (power); factors ",
 StyleBox["j | k",
  FontWeight->"Bold"],
 " if ",
 StyleBox["i*j=k",
  FontWeight->"Bold"],
 " for some ",
 StyleBox["i",
  FontWeight->"Bold"],
 ", division with remainders ",
 StyleBox["k/j=i+r",
  FontWeight->"Bold"],
 " where ",
 StyleBox["r<j",
  FontWeight->"Bold"],
 "; every natural number has a unique set of prime divisors. Subtraction is \
undefined, but the symmetric difference ",
 StyleBox["m",
  FontWeight->"Bold"],
 " is defined by Min[",
 StyleBox["i,j",
  FontWeight->"Bold"],
 "] + ",
 StyleBox["m",
  FontWeight->"Bold"],
 " = Max[",
 StyleBox["i,j",
  FontWeight->"Bold"],
 "].\n2) Unsigned Rational numbers ",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalQ]", 
   RowBox[{"0", "+"}]]]],
 " are equivalence relations on ordered pairs of Natural numbers, q ~ {",
 StyleBox["i,j",
  FontWeight->"Bold"],
 "} ~ {",
 StyleBox["k,l",
  FontWeight->"Bold"],
 "} iff ",
 StyleBox["i*l ",
  FontWeight->"Bold"],
 "=",
 StyleBox[" j*k",
  FontWeight->"Bold"],
 ". Rational infinity is \[Infinity] ~ {",
 StyleBox["i,0",
  FontWeight->"Bold"],
 "}, rational zero is 0 ~ {",
 StyleBox["0,i",
  FontWeight->"Bold"],
 "}, both with ",
 StyleBox["i",
  FontWeight->"Bold"],
 ">",
 StyleBox["0",
  FontWeight->"Bold"],
 ". {",
 StyleBox["0,0",
  FontWeight->"Bold"],
 "} is undefined. (These differ from Landau's ",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalQ]", "+"]]],
 " because he did not include ",
 StyleBox["0",
  FontWeight->"Bold"],
 " as a Natural number.)\n3) \"Primal Numbers\". Any continuity axiom can be \
used to extend ",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalQ]", 
   RowBox[{"0", "+"}]]]],
 " to \"Primal Numbers\" (the half line). The (often implicit) introduction \
of negative numbers (integers, signed rationals, reals, complex) as \
equivalence relations on a pair or quad of unsigned natural, rational or \
primal numbers is postponed until it can be generalised in 6.\n4) To avoid \
the ambiguity caused by the several conflicting meanings of ",
 StyleBox["vector",
  FontSlant->"Italic"],
 ", the term \"vec\" is introduced for indexed sets of (signed or unsigned) \
coefficients and/or operators. Hamilton introduced vector as the imaginary \
part of a quaternion or octonion. In geometric algebra, a vector is a ",
 StyleBox["direction",
  FontSlant->"Italic"],
 ", a distinguished element of a vec. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", a vec is a list without sublists, and passes the VectorQ test.\n5) \
Algebraic Loops (Q,e,*,/,\\) are Cayley Index Tables that define \
multiplication tables for \"unsigned vecs\". They are quasigroups with an \
identity element e, and both left and right division. Negation, subtraction, \
and signs are not necessarily defined for them.\n6) \"Generalised Signs\". If \
a loop has ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry, it can be ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-folded to a smaller table that multiplies \"",
 StyleBox["r",
  FontSlant->"Italic"],
 "-signed vecs\". This equivalences each set of ",
 StyleBox["r",
  FontSlant->"Italic"],
 " unsigned numbers to a single ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-signed number. Signs provide the second operation (generalised addition / \
subtraction) that converts a loop into an algebra. ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2 gives Real algebra with signs {+, -; ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", "-", ")"}], "2"]]],
 "=+1}; the C4 and K groups give Complex {+, \[ImaginaryI], -, \
-\[ImaginaryI]; ",
 Cell[BoxData[
  SuperscriptBox["\[ImaginaryI]", "4"]]],
 "=+1} and Study (hyperbolic) algebras \
{+,-,\[DoubleStruckK],-\[DoubleStruckK]; ",
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckK]", "2"]]],
 "=+1}; ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=3 gives \"Terplex\" {+, \[DoubleStruckCapitalJ], \[DoubleStruckCapitalJ]\
\[DoubleStruckCapitalJ] ; ",
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckCapitalJ]", "3"]]],
 "=+1}, a complete algebra with divisors of zero. Non-abelian Clifford \
algebras have ",
 Cell[BoxData[
  SuperscriptBox["2", "n"]]],
 " elements, with ",
 StyleBox["n",
  FontSlant->"Italic"],
 " generators that are distinct square roots or fourth roots of +1.\n7) If \
the table has the Moufang division property ",
 StyleBox["zx.yz=(z.xy)z",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 ", every vec has a multiplicative inverse. Groups are the associative subset \
of Moufang Loops, with x(yz)=(xy)z.\n8) All groups, and a few (mainly \
octonionic) non-associative loops, have the determinant conservation property \
Det[A] Det[B] = \[PlusMinus] Det[AB], where Det is calculated for the table \
mapped with the conjugate of the vec. Frobenius showed that all associative \
tables (groups) have this property. The \[PlusMinus] arises from a symmetric \
difference interpretation of the unsigned nature of loops. The factors of the \
symbolic determinant are \"conserved sizes\" (real Eigenvectors, symmetries) \
that define metrics for multiplication. Symmetry conservation leads to forces \
and particles by Noether's laws. \n9) \"Hoops\". I define a hoop as a finite \
Moufang Loop with the Frobenius property. Every vec has a multiplicative \
hoopInverse. As this can be found by Cramer's method, the determinant is a \
denominator for the inverse.\n10) Most hoops have several sizes (determinant \
factors). Consequently, inverses split into partial-fractions having sizes as \
denominators. If some (but not all) sizes become zero, the determinant is \
zero but some partial fractions remain finite. Retaining only the finite \
terms \"projects\" the result onto a constrained sub-algebra of reduced \
symmetry.\n11) To maintain symmetry conservation, both multiplication A*B and \
division A",
 StyleBox["inverse",
  FontSlant->"Italic"],
 "*B create \"remainders\" that carry any sizes of A and B that are lost in \
the result. This corresponds to particle interaction and decay. Different \
algebras conserve overlapping sets of symmetries, just as different forces \
conserve overlapping sets of particle properties.\n12) Every Abelian algebra \
corresponds to sets of polar or hyperbolic planes. These provide polar and/or \
hyperbolic dual formulations that lead to powers and roots. Constraining \
vectors to unit or zero sizes gives \"continuous orbit\" sub-algebras, \
generalised circles with centres displaced from the origin. These are \
described by multi-phase sinusoids.\n13) Non-Abelian algebras have repeated \
sizes (Eigenvalues with different signs) that may introduce uncertainty. They \
split into commutative (Jordan, dot, inner) and non-commutative (Lie, wedge, \
outer) products AB=A.B+A\[And]B.\n14) Clifford algebras are an important \
sub-set of non-Abelian hoop algebras. They are generated from orthogonal \
anti-symmetric \"monovectors\" ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 ", with ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 "=\[PlusMinus]1, ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 ".",
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 "=0, ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 "=-",
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 ". Bivectors ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 ", trivectors ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 Cell[BoxData[
  SubscriptBox["e", "k"]]],
 ", etc., can be interpreted as directed areas, volumes, etc. in Geometric \
Algebra; they unify 2D, 3D, spacetime, non-commutative, projective and \
conformal geometries. They are developed in a different package, ",
 StyleBox["CliffordG.m",
  FontSlant->"Italic"],
 ".\n15) The ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " package implements these concepts. It contains a database of over 800 \
loops (including all groups with up to 73 elements and all non-Abelian \
Moufang Loops with up to 32 elements), together with their sizes where known. \
Because of computational limitations, very few sizes have been found for \
tables with over 16 elements. Procedures are supplied to generate, identify, \
and test these loops, and to perform algebraic operations on those with known \
sizes."
}], "Text"],

Cell[TextData[{
 "A shorter and simpler account of Hoop Algebras (using a much smaller \
package) is available at ",
 ButtonBox["http://library.wolfram.com/infocenter/MathSource/6198/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://library.wolfram.com/infocenter/MathSource/6198/"], None}],
 ". This notebook goes into much greater detail.\n",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " users can save (in ",
 StyleBox["addons/ExtraPackages",
  FontSlant->"Italic"],
 ") & initialize the ",
 StyleBox["GrouploopHoop6.nb",
  FontSlant->"Italic"],
 " from ",
 ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://library.wolfram.com/infocenter/MathSource/4894/"], None}],
 ". to set up the package and investigate the demonstrations.\n",
 StyleBox["HoopDemo",
  FontSlant->"Italic"],
 " is a simplified version of ",
 StyleBox["GroupLoopDemo",
  FontSlant->"Italic"],
 ", omitting material on the creation, identification, and manipulation of \
Groups & Loops. If you have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and wish to test the examples with different data, save and run ",
 StyleBox["GroupLoopHoop.nb ",
  FontSlant->"Italic"],
 "in ",
 StyleBox["ExtraPackages",
  FontSlant->"Italic"],
 ".\nPlease send any comments to me at ",
 StyleBox["rhberesford@btinternet.com",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["Illustrated Introduction.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Arial",
 FontSize->16],

Cell[TextData[{
 "\"What I tell you three times is True.\" (",
 StyleBox["Lewis Carroll.)",
  FontSlant->"Plain"]
}], "Text",
 FontSlant->"Italic"],

Cell[TextData[{
 "\tHoops are \"symmetry-conserving partial-fraction-division vector algebras\
\" that unify many physically significant algebras (including \
\[DoubleStruckCapitalR], \[DoubleStruckCapitalC], Clifford (Geometric), \
Davenport, Dirac-\[Gamma], graded, \[DoubleStruckCapitalH], Lie, \
noncommutative, non-associative, \[DoubleStruckCapitalO], Pauli-\[Sigma], and \
Wedge etc., algebras). Hoops act on \"vecs\" - generalized vectors - indexed \
lists of operators or coefficients {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], ","}], TraditionalForm]]],
 "...",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "m"], TraditionalForm]]],
 "}, equivalent to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Sum]", "i"], 
    RowBox[{
     SubscriptBox["a", "i"], 
     SubscriptBox["d", "i"], " ", "where", " ", 
     SubscriptBox["d", "i"]}]}], TraditionalForm]]],
 " is a sign, dimension or \"basis vector\" - using a Cayley index \
multiplication table G:",
 StyleBox["i j\[RightArrow] k",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["i, j & k",
  FontSlant->"Italic"],
 " are indices though ",
 StyleBox["k",
  FontSlant->"Italic"],
 " may be signed (see Figure 1). "
}], "Text"],

Cell[TextData[{
 "\tGeneralized procedures multiply, divide and (in some Abelian cases) \
provide cartesian/polar interconversions that lead to powers and roots. Hoops \
have the Moufang division property, ensuring that vecs have multiplicative \
inverses. Consequently, division employs the same procedure, ",
 StyleBox["hoopTimes",
  FontSlant->"Italic"],
 ", as multiplication; AB=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Sum]", "k"], 
    RowBox[{
     SubscriptBox["a", "i"], 
     SubscriptBox["b", "j"], 
     SubscriptBox["d", "k"]}]}], TraditionalForm]]],
 ". Warning - this multiplication MUST NOT be confused with matrix \
multiplication (transformations of coordinates for a single vector); it \
represents interactions between two vectors to give a product vector and two \
(possibly null) remainder vectors.\n\tThe defining feature of a hoop is \
\"Frobenius conservation\", Det[AB]=\[PlusMinus]Det[A] Det[B]; each algebra \
has conserved \"sizes\" or symmetries (related to eigenvalues) that may (by \
Noether's theorem) define particles and forces. These sizes are the factors \
of the determinant of the multiplication table mapped with the vecs \
(conjugate vectors if the field is not \[DoubleStruckCapitalR]). The sizes \
are denominators of the partial-fraction formulation of the inverse. Hoops \
comprise all groups, a few non-associative Moufang Loops (including octonions \
and split-octonions), and the \"signed tables\" obtained by \"folding\" \
conservative unsigned tables. Hoops combine the \"conservative\" property \
with the Moufang division property, so they describe conservative \
partial-fraction vector-division algebras. Most tables lack both of these \
properties. Generalised signs are created when Hoops are \"folded\" from \
larger tables."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 1.",
  FontWeight->"Bold"],
 " Two-fold and three-fold ",
 StyleBox["Folding ",
  FontWeight->"Bold"],
 "of Moufang Loops, the\nresulting signed algebras, and their conserved \
shapes.."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "  C4C2 group    Quaternion group     C9 Group\n\n",
 Cell[BoxData[
  TagBox[
   FormBox[
    RowBox[{GridBox[{
       {
        StyleBox["1",
         FontWeight->"Bold"], 
        StyleBox["2",
         FontWeight->"Bold"], 
        StyleBox["3",
         FontWeight->"Bold"], 
        StyleBox["4",
         FontWeight->"Bold"], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["2",
         FontWeight->"Bold"], 
        StyleBox["3",
         FontWeight->"Bold"], 
        StyleBox["4",
         FontWeight->"Bold"], 
        StyleBox["1",
         FontWeight->"Bold"], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["3",
         FontWeight->"Bold"], 
        StyleBox["4",
         FontWeight->"Bold"], 
        StyleBox["1",
         FontWeight->"Bold"], 
        StyleBox["2",
         FontWeight->"Bold"], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["4",
         FontWeight->"Bold"], 
        StyleBox["1",
         FontWeight->"Bold"], 
        StyleBox["2",
         FontWeight->"Bold"], 
        StyleBox["3",
         FontWeight->"Bold"], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["8",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["5",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["6",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["7",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]"}],
    TraditionalForm],
   TraditionalForm,
   Editable->True]],
  PageWidth->PaperWidth,
  Evaluatable->False,
  FontSize->9],
 ", ",
 Cell[BoxData[
  RowBox[{
   TagBox[
    FormBox[
     RowBox[{"\[NoBreak]", GridBox[{
        {
         StyleBox["1",
          FontWeight->"Bold"], 
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["3",
          FontWeight->"Bold"], 
         StyleBox["4",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"], 
         StyleBox["8",
          FontWeight->"Bold"], 
         StyleBox["3",
          FontWeight->"Bold"], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["3",
          FontWeight->"Bold"], 
         StyleBox["4",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"], 
         StyleBox["6",
          FontWeight->"Bold"], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["4",
          FontWeight->"Bold"], 
         StyleBox["7",
          FontWeight->"Bold"], 
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["5",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["5",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["5",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]},
        {
         StyleBox["8",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["3",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["6",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["1",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["4",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["7",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["2",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}], 
         StyleBox["5",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"CompatibilityType"->0,
          "Masked"->False,
          "Outline"->False,
          "RotationAngle"->0,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Underline"->False}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak] "}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ","}]],
  PageWidth->PaperWidth,
  Evaluatable->False,
  FontSize->9],
 " ",
 Cell[BoxData[
  RowBox[{GridBox[{
     {
      StyleBox["1",
       FontWeight->"Bold"], 
      StyleBox["2",
       FontWeight->"Bold"], 
      StyleBox["3",
       FontWeight->"Bold"], 
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["2",
       FontWeight->"Bold"], 
      StyleBox["3",
       FontWeight->"Bold"], 
      StyleBox["4",
       FontWeight->"Bold"], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["3",
       FontWeight->"Bold"], 
      StyleBox["4",
       FontWeight->"Bold"], 
      StyleBox["5",
       FontWeight->"Bold"], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]},
     {
      StyleBox["9",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["1",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["2",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["3",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["4",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["5",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["6",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["7",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], 
      StyleBox["8",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], 
   TagBox[
    FormBox["\[NoBreak]",
     TraditionalForm],
    TraditionalForm,
    Editable->True], " "}]]],
 "\n\nC4 & Complex    Quaternion     C9J     Symbolic\n  algebra        \
algebra      algebra   C9J  \n",
 Cell[BoxData[{
  RowBox[{
   TagBox[
    FormBox[
     RowBox[{"\[NoBreak]", GridBox[{
        {
         StyleBox["1",
          FontWeight->"Bold"], 
         StyleBox["\[ImaginaryI]",
          FontWeight->"Bold"], 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "\[ImaginaryI]"}]},
        {
         StyleBox["\[ImaginaryI]",
          FontWeight->"Bold"], 
         StyleBox[
          RowBox[{"-", "1"}],
          FontWeight->"Bold"], 
         RowBox[{"-", "\[ImaginaryI]"}], "1"},
        {
         RowBox[{"-", "1"}], 
         RowBox[{"-", "\[ImaginaryI]"}], "1", "\[ImaginaryI]"},
        {
         RowBox[{"-", "\[ImaginaryI]"}], "1", "\[ImaginaryI]", 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", " ", 
   TagBox[
    FormBox[
     RowBox[{"\[NoBreak]", GridBox[{
        {"1", 
         StyleBox["i",
          FontSlant->"Plain"], 
         StyleBox["j",
          FontSlant->"Plain"], "ij"},
        {
         StyleBox["i",
          FontSlant->"Plain"], 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "ij"}], 
         StyleBox["j",
          FontSlant->"Plain"]},
        {
         StyleBox["j",
          FontSlant->"Plain"], "ij", 
         RowBox[{"-", "1"}], 
         RowBox[{"-", 
          StyleBox["i",
           FontSlant->"Plain"]}]},
        {"ij", 
         RowBox[{"-", 
          StyleBox["j",
           FontSlant->"Plain"]}], 
         StyleBox["i",
          FontSlant->"Plain"], 
         RowBox[{"-", "1"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "     ", 
   RowBox[{
    TagBox[
     FormBox[
      RowBox[{"\[NoBreak]", 
       RowBox[{GridBox[{
          {"1", "2", "3"},
          {"2", 
           RowBox[{"3", " "}], "\[DoubleStruckCapitalJ]1"},
          {"3", "\[DoubleStruckCapitalJ]1", "\[DoubleStruckCapitalJ]2"}
         }], ",", "\[NoBreak]"}]}],
      TraditionalForm],
     TraditionalForm,
     Editable->True], GridBox[{
      {"a", "b", "c"},
      {"b", "c", 
       RowBox[{"\[DoubleStruckCapitalJ]a", " "}]},
      {"c", "\[DoubleStruckCapitalJ]a", "\[DoubleStruckCapitalJ]b"}
     }]}]}], "\[IndentingNewLine]", 
  RowBox[{"   "}]}], "Input",
  PageWidth->PaperWidth,
  FontSize->9,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]
}], "Text",
 PageWidth->WindowWidth,
 FontFamily->"Courier New",
 FontSize->9],

Cell[TextData[{
 "\tNew concepts, transcending the limitations of \"real algebras without \
divisors of zero\", are introduced. The most important of these are unsigned \
continuous \"primal numbers\", \"generalized signs\", \"folding\", conserved \
\"sizes\" (symmetries), conservative multiplication-division with \
\"remainders\", degenerate \"monosized\" algebras, \"polar-duals\" with \
\"offsets\", \"plex-conjugates\", and \"unital hoop algebras\" with \
continuous \"orbits\" that provide analogies with deBroglie waves and Planck \
areas. Real numbers are \"folded\" (equivalenced) from pairs of \"primal\" \
(unsigned continuous, half-line) numbers via an equivalence relationship ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["r",
     FontSlant->"Plain"], "i"], TraditionalForm]]],
 " ~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "j"], TraditionalForm]]],
 "} ~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "j"], TraditionalForm]]],
 "} iff ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "j"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "j"], TraditionalForm]]],
 "; reals do not exist in some algebras. Other types of number are folded \
from larger sets of primal numbers by the introduction of generalized signs.\n\
\tHoop multiplication tables are, or are \"folded\" from, algebraic loops. An \
unsigned ",
 StyleBox["m\[Times]m",
  FontSlant->"Italic"],
 " loop with ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry can be folded to an ",
 StyleBox["(m/r)\[Times](m/r) ",
  FontSlant->"Italic"],
 "table whose elements are \"",
 StyleBox["r-signed",
  FontSlant->"Italic"],
 "\". The tables inherit the Moufang division properties, including \
zx.yz=(z.xy)z. This ensures that there are multiplicative inverses for each \
group element and for each vector, so division (multiplication by a \
multiplicative inverse) is always possible. Any group G can be composed with \
e.g. C2 or C4 to give GC2 or GC4. As these are associative Moufang loops that \
can be folded back to G, all groups define hoop algebras over the real and \
complex fields. Only a few of the many non-associative Moufang loops [4] are \
conservative (i.e. hoops). (Those with up to 32 elements are in the database \
as D4M, Oct, OctC2, P4M, KiC4M, C8pC2M, C4iC4M.)"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tFig.1 (above) shows three small Moufang loops (the C4C2, quaternion, and \
C9 groups) as index tables; the boldface top left squares define the folded \
versions. These, because of a loop symmetry, occur with or without offsets in \
the other squares of the same size. The folded tables are interpreted as \
algebraic multiplication tables with signed products. The minus sign is a \
square root of +1, the sign \[DoubleStruckCapitalJ] is a cube root of +1, and \
\[ImaginaryI], i, j are fourth roots of +1. The first and folded second \
tables define the complex and quaternion algebras; the third is a new algebra \
\"C9J\" developed to demonstrate ternary symmetry and \"3-folding\". \n\tThe \
last table is the symbolic form of the C9J table; {a,b,c} has been mapped \
onto the signed elements. This mapping allows the evaluation of the table \
determinant, Det. (Hoops are defined as having the Frobenius property, \
conservation of conjugate factors of the determinant Det[AB].) The conserved \
factors (omitting the voluminous C9 case) are shown, together with th \
eigenvalues for the C4 case. In all but the C9J case (where the determinant \
is -",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "3"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b", "3"], TraditionalForm]]],
 "\[DoubleStruckCapitalJ]+3",
 StyleBox["abc",
  FontSlant->"Italic"],
 "\[DoubleStruckCapitalJ]-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "3"], TraditionalForm]]],
 ") conjugation has had no effect as the determinants are real."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 1a.",
  FontWeight->"Bold"],
 " Hoop shapes (lists of sizes) & C4 Eigenvalues."
}], "Text"],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"<<", "GroupLoopHoop6`"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"shape", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h"}], "}"}], ",", "\"\<C4C2\>\""}], "]"}], TraditionalForm]], "Input",
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
    "h"}], ",", 
   RowBox[{
   "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
    "h"}], ",", 
   RowBox[{
   "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
    "h"}], ",", 
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
    "h"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "c", "-", "e", "+", "g"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "d", "-", "f", "+", "h"}], ")"}], "2"]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "c", "+", "e", "-", "g"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "d", "+", "f", "-", "h"}], ")"}], "2"]}]}], 
  "}"}]], "Output",
 FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"shape", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", "\"\<C4\>\""}],
     "]"}], " "}], TraditionalForm]], "Input",
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "d"}], ")"}], "2"]}]}], "}"}]], "Output",
 FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"shape", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
       "h"}], "}"}], ",", "\"\<Q8\>\""}], "]"}], " "}], 
  TraditionalForm]], "Input",
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
    "h"}], ",", 
   RowBox[{
   "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
    "h"}], ",", 
   RowBox[{
   "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
    "h"}], ",", 
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
    "h"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"d", "-", "h"}], ")"}], "2"]}]}], "}"}]], "Output",
 FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"shape", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", "\"\<Qr\>\""}],
     "]"}], " "}], TraditionalForm]], "Input",
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["a", "2"], "+", 
   SuperscriptBox["b", "2"], "+", 
   SuperscriptBox["c", "2"], "+", 
   SuperscriptBox["d", "2"]}], "}"}]], "Output",
 FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"shape", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "\"\<C9J\>\""}], "]"}], 
   " "}], TraditionalForm]], "Input",
 FontSize->9],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["a", "3"], "+", 
   RowBox[{
    SuperscriptBox["b", "3"], " ", "\[DoubleStruckCapitalJ]"}], "-", 
   RowBox[{
   "3", " ", "a", " ", "b", " ", "c", " ", "\[DoubleStruckCapitalJ]"}], "+", 
   RowBox[{
    SuperscriptBox["c", "3"], " ", 
    SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigenvalues", "[", 
  RowBox[{"gmap", "[", 
   RowBox[{"C4", ",", "alph"}], "]"}], "]"}]], "Input",
 FontSize->10],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
   RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ",", 
   RowBox[{"-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"2", " ", "b", " ", "d"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "c"}], "+", 
     SuperscriptBox["c", "2"], "-", 
     RowBox[{"2", " ", "b", " ", "d"}], "+", 
     SuperscriptBox["d", "2"]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Protoloops, Symbolic shapes & sizes.\n",
  FontWeight->"Bold"],
 "\tLoops can be expressed as Cayley tables in many isomorphic ways. The \
Hoops database provides a preferred isomorph or \"protoloop\" for each table. \
The basic properties are unchanged if an isomorph is used - the elements are \
merely re-labelled in isomorphs. However, different isomorphs can fold to \
different hoops (see Figures 2 and 24). Protoloops of hoops of a given size \
are usually based on generators of decreasing order for the hoop with most \
generators. Thus 12 element hoops are based on C3C2C2, with C3C4, D3C2, Q12 \
and A4 all having some sizes in common \n\tFig. 2 folds a different C4C2 \
isomorph to the Davenport algebra, by ",
 StyleBox["5",
  FontWeight->"Bold"],
 "\[RightArrow]-1, ",
 StyleBox["6",
  FontWeight->"Bold"],
 "\[RightArrow]-2, ",
 StyleBox["7",
  FontWeight->"Bold"],
 "\[RightArrow]-3. The symbolic table ({a,b,c,d} mapped onto {1,2,3,4}),  is \
also shown. The determinant of this table factorises into ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    StyleBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        StyleBox["(",
         FontSlant->"Plain"], 
        RowBox[{
         StyleBox["b",
          FontSlant->"Italic"], 
         StyleBox["+",
          FontSlant->"Plain"], 
         StyleBox["c",
          FontSlant->"Italic"]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "d"}], ")"}], "2"]}],
     FontSlant->"Plain"], 
    StyleBox[" ",
     FontSlant->"Plain"], 
    StyleBox[")",
     FontSlant->"Plain"]}], TraditionalForm]]],
 " \[PlusMinus] ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    StyleBox[
     RowBox[{"(", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         StyleBox["(",
          FontSlant->"Plain"], 
         StyleBox[
          RowBox[{"b", "-", "c"}],
          FontSlant->"Italic"], 
         StyleBox[")",
          FontSlant->"Plain"]}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "d"}], ")"}], "2"]}], ")"}],
     FontSlant->"Plain"]}], TraditionalForm]], "Text"],
 ", and these two factors are conserved on multiplication. Their square roots \
are the eigenvalues."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 2. ",
  FontWeight->"Bold"],
 "Davenport algebra is folded from a C4C2 Isomorph."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[{
 RowBox[{"C4C2", " ", "Isomorph", "                ", "Davenport", " ", 
  "Algebra"}], "\[IndentingNewLine]", GridBox[{
   {GridBox[{
      {"1", "2", "3", "4", 
       StyleBox["5",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["6",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["7",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["8",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {"2", "5", "4", "7", 
       StyleBox["6",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["1",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["8",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["3",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {"3", "4", "5", "6", 
       StyleBox["7",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["8",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["1",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["2",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {"4", "7", "6", "1", 
       StyleBox["8",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["3",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["2",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["5",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {
       StyleBox["5",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["6",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["7",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["8",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["1",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["2",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["3",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["4",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {
       StyleBox["6",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["1",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["8",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["3",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["2",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["5",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["4",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["7",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {
       StyleBox["7",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["8",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["1",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["2",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["3",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["4",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["5",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["6",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {
       StyleBox["8",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["3",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["2",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["5",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["4",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["7",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["6",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox["1",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], 
    RowBox[{GridBox[{
       {
        StyleBox[
         RowBox[{"     ", "1"}],
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["2",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["3",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["2",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox[
         RowBox[{"-", "1"}],
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox[
         RowBox[{"-", "3"}],
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["3",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["4",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox[
         RowBox[{"-", "1"}],
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox[
         RowBox[{"-", "2"}],
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]},
       {
        StyleBox["4",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox[
         RowBox[{"-", "3"}],
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox[
         RowBox[{"-", "2"}],
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}], 
        StyleBox["1",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "     "}], GridBox[{
      {
       StyleBox["a",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox[
        RowBox[{"   ", "b"}],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       RowBox[{"  ", 
        StyleBox["c",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]}], 
       RowBox[{"  ", 
        StyleBox["d",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]}]},
      {
       StyleBox["b",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       RowBox[{"  ", 
        StyleBox["d",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]}], 
       StyleBox[
        RowBox[{"-", "c"}],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {
       StyleBox["c",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       RowBox[{"  ", 
        StyleBox["d",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]}], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox[
        RowBox[{"-", "b"}],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}]},
      {
       StyleBox["d",
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox[
        RowBox[{"-", "c"}],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       StyleBox[
        RowBox[{"-", "b"}],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"CompatibilityType"->0,
        "Masked"->False,
        "Outline"->False,
        "RotationAngle"->0,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Underline"->False}], 
       RowBox[{"  ", 
        StyleBox["a",
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontTracking->"Plain",
         FontVariations->{"CompatibilityType"->0,
         "Masked"->False,
         "Outline"->False,
         "RotationAngle"->0,
         "Shadow"->False,
         "StrikeThrough"->False,
         "Underline"->False}]}]}
     }]}
  }]}], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Dava", "=", 
   RowBox[{"gmap", "[", 
    RowBox[{
     RowBox[{"mp", "[", "\"\<Dav\>\"", "]"}], ",", "alph"}], "]"}]}], ";", 
  RowBox[{"Dava", "//", "tf"}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"a", "b", "c", "d"},
     {"b", 
      RowBox[{"-", "a"}], "d", 
      RowBox[{"-", "c"}]},
     {"c", "d", 
      RowBox[{"-", "a"}], 
      RowBox[{"-", "b"}]},
     {"d", 
      RowBox[{"-", "c"}], 
      RowBox[{"-", "b"}], "a"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigenvalues", "[", "Dava", "]"}]], "Input",
 FontSize->10],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "d"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "+", 
     RowBox[{"2", " ", "b", " ", "c"}], "+", 
     SuperscriptBox["c", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d"}], "+", 
     SuperscriptBox["d", "2"]}]], ",", 
   RowBox[{"-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "d"}], "+", 
      SuperscriptBox["d", "2"]}]]}], ",", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     RowBox[{"2", " ", "b", " ", "c"}], "+", 
     SuperscriptBox["c", "2"], "+", 
     RowBox[{"2", " ", "a", " ", "d"}], "+", 
     SuperscriptBox["d", "2"]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tMost hoop determinants have more than one factor. I call the determinant \
factors \"sizes\" and the list of symbolic sizes the \"shape\" for the hoop. \
Sizes are conserved properties or symmetries for the algebra, size[AB]=\
\[PlusMinus]size[A] size[B]. This means that each size is a metric, with the \
triangle inequality being exact. Hoops are so-named because they conserve \
their shape and come between groups and loops. They also \"bind together\" a \
number of concepts - just as cooper's hoops bind staves to create a barrel. \
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Loop Properties - Moufang, Alternative, Frobenius, Associative, \
Abelian.\n",
  FontWeight->"Bold"],
 "\t Multiplication tables for unsigned sets are \"Algebraic loops\". If they \
have the Moufang division property \"For all x,y,z, zx.yz=(z.xy)z\" (and some \
equivalent properties), they are Moufang loops. All groups (associative loops \
with x(yz)=(xy)z ) and the Octonions (which are only \"alternative\", \
x(xy)=(xx).y ) are conservative Moufang loops. Neither the alternative \
property nor the Moufang property ensures the \"Frobenius\" (conservative) \
property that defines a hoop. Most loops are not hoops, though some (e.g C6n) \
conserve some, but not all, their factors.\n\tLoops are defined without \
introducing negation, so they multiply sets of essentially unsigned elements \
(numbers or operators). Unsigned continuous \"Primal\" numbers (the \
half-line) can be defined from set theory, via Natural numbers, unsigned \
rational numbers, and an axiom of continuity. Other numbers can then be \
defined via equivalence relations that \"fold\" a set of ",
 StyleBox["r",
  FontSlant->"Italic"],
 " primal numbers to a single ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-signed number. ",
 StyleBox["m\[Times]m",
  FontSlant->"Italic"],
 " Moufang loops with ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry can be folded to (",
 StyleBox["m/r)\[Times]",
  FontSlant->"Italic"],
 "(",
 StyleBox["m/r) ",
  FontSlant->"Italic"],
 "Hoop tables. At the same time the sets of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " unsigned elements are folded to vecs with ",
 StyleBox["m/r ",
  FontSlant->"Italic"],
 "\"",
 StyleBox["r",
  FontSlant->"Italic"],
 "-signed\" elements. Signs introduce the second operation that converts a \
loop into an algebra. The standard cases are ",
 StyleBox["r ",
  FontSlant->"Italic"],
 "= 2 and 4, creating numbers in real or complex fields and the signs \"+\", \
\"",
 StyleBox["\[DoubleStruckI]",
  FontSlant->"Italic"],
 "\", \"-\", and \"-",
 StyleBox["\[DoubleStruckI]",
  FontSlant->"Italic"],
 "\".\n\tMost mathematical texts wrongly assume that negative numbers are \
fundamental, with the unstated axioms \"Minus 1 exists\" and \"Minus 1 is \
unique\". Only a few define them as equivalence relations on pairs of \
unsigned numbers; even fewer include the axioms. The effect is that much of \
mathematics has been restricted to \"fields\" where \"ordinary negation\" and \
\"subtraction\" are conflated, the only \"signs\" are \"+\", \
\"\[ImaginaryI]\", \"-\", & \"-\[ImaginaryI]\", and other possibilities are \
excluded. Hoops transcend this artificial limitation."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tHoop vector multiplicative inverses can be found via Cramer's rule (solving \
for Ai*A={1,0,...}), and so they have the conjugate determinant as a \
denominator. In most hoops (excluding degenerate monosized \
\[DoubleStruckCapitalR], \[DoubleStruckCapitalC], \[DoubleStruckCapitalH], \
\[DoubleStruckCapitalO], Pauli-\[Sigma], C9j, C9J, some Clifford algebras, \
etc.) the determinant has more than one distinct factor, and the inverse \
splits into partial-fractions with each distinct real factor providing a \
partial-fraction denominator (repeated factors occur in non-abelian hoops, \
but only provide one size.)\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Division, Remainders.\n",
  FontWeight->"Bold"],
 "\t Vecs give a zero determinant if any sizes are zero, even though some \
sizes are still finite. Such \"zero-vectors\" (with one or more size \
evaluating to zero) can still have conservative hoop multiplication and \
division. Division projects the results onto sub-algebras (constrained to \
have these sizes zero) and is defined so that it ejects left & right \
\"remainders\"; A/B=C+Rl+Rr, with C*B+Rl=A & A/C+Rr=B. The remainders Rl & Rr \
have the sizes of A or B that would be infinite in 1/B & 1/A respectively; \
i.e. 0\[LessSlantEqual]size[Rl]<size[1/B], just as integer division has \
I/J=K+R, 0\[LessEqual]R<J. Conservation is maintained by the creation of \
remainders wherever a size would otherwise be lost by becoming zero or \
infinity. Division-by-zero is eliminated by \"projection\" into sub-algebras. \
In effect, the zeroes and infinities are factored out of the result.\n\t\
Multiplication behaves in the same way (multiplication and division are the \
same operation, using inverse vectors). In Fig. 3, multiplying A={2,1,-1,2} \
by B={1,3,5,2} in the Davenport algebra gives AB={8,-1,1,8} and a right \
remainder {-.5,4,4,.5} because the shape of A is {0,20}. The shape of B is \
{65,13}, so the shapes of AB and Rr are {0,13} and {65,0}.\n\t (Most figures \
are the output from a set of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " input instructions, which are usually hidden in a \"closed cell\" because \
they are probably meaningless to non-users of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". If desired, the instructions can be inspected by clicking on the tiny \
cell bracket, then on ",
 StyleBox["Cell,",
  FontSlant->"Italic"],
 " ",
 StyleBox["Cell Properties ",
  FontSlant->"Italic"],
 "and ",
 StyleBox["Cell Open.",
  FontSlant->"Italic"],
 ")"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 3.",
  FontWeight->"Bold"],
 " Remainders in Dav multiplication and division."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{"\"\<A= \>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", 
      RowBox[{"-", "1"}], ",", "2"}], "}"}]}], ",", "\"\<B= \>\"", ",", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3", ",", "5", ",", "2"}], "}"}]}], ",", 
   "\"\<\\nUsing Davenport Algebra, AB=\>\"", ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B", ",", "\"\<Dav\>\""}], "]"}]}], ",", 
   "\"\<\\nRl is\>\"", ",", "Rl", ",", "\"\< with shape[Rl]=\>\"", ",", 
   RowBox[{"shape", "[", "Rl", "]"}], ",", "\"\<\\nRr is\>\"", ",", 
   RowBox[{"rr", "=", "Rr"}], ",", "\"\< with shape[Rr]=\>\"", ",", 
   RowBox[{"shape", "[", "Rr", "]"}], ",", "\"\<\\nAinverse=\>\"", ",", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   "\"\<\\nAinverse.AB = \>\"", ",", 
   RowBox[{"B0", "=", 
    RowBox[{"hoopTimes", "[", " ", 
     RowBox[{"Ai", ",", "AB"}], "]"}]}], ",", 
   "\"\<which only recovers B when Rr is added to give \>\"", ",", 
   RowBox[{"B0", "+", "rr"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A", "=."}], ";", 
  RowBox[{"AB", "=."}], ";", 
  RowBox[{"B0", "=."}], ";", 
  RowBox[{"rr", "=."}]}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A= \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", "\<\"B= \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5", ",", "2"}], "}"}], 
   ",", "\<\"\\nUsing Davenport Algebra, AB=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "8"}], "}"}], ",", "\<\"\\nRl is\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", "\<\" with shape[Rl]=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", "\<\"\\nRr is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", "4", ",", "4", ",", 
     FractionBox["1", "2"]}], "}"}], ",", "\<\" with shape[Rr]=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"65", ",", "0"}], "}"}], ",", "\<\"\\nAinverse=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "10"], ",", 
     RowBox[{"-", 
      FractionBox["1", "20"]}], ",", 
     FractionBox["1", "20"], ",", 
     FractionBox["1", "10"]}], "}"}], ",", "\<\"\\nAinverse.AB = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "2"], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     FractionBox["3", "2"]}], "}"}], 
   ",", "\<\"which only recovers B when Rr is added to give \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5", ",", "2"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tGeneralized signs ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "j"], TraditionalForm]]],
 " (with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "r"], TraditionalForm]]],
 " = 1) are introduced as distinct ",
 StyleBox["j",
  FontSlant->"Italic"],
 "'th powers of ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'th roots of unity. They include, when ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = 4, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "0"], TraditionalForm]]],
 "=\"+\", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "1"], TraditionalForm]]],
 "=\"\[ImaginaryI]\", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "2"], TraditionalForm]]],
 "=\"-\", & ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "3"], TraditionalForm]]],
 "=\"-\[ImaginaryI]\". Projecting roots of unity onto the complex plane as \
\"cyclotomic numbers\" is a distortion and restriction of their properties. \
In many hoops, \"Minus 1\" is not unique; the standard proof that it is \
unique is based on the usually unstated axiom (assumption) that integers are \
equivalence relations on ",
 StyleBox["pairs",
  FontSlant->"Italic"],
 " rather than ",
 StyleBox["indexed sets",
  FontSlant->"Italic"],
 " of natural numbers. \"Study numbers\" have ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["k", "2"], TraditionalForm]]],
 "=1,  ",
 StyleBox["k",
  FontSlant->"Italic"],
 "\[NotEqual]-1. \"Minus 1\" need not exist; ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=3 gives \"Terplex algebra\", with signs \"+\", \
\"\[DoubleStruckCapitalJ]\", \"",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], TraditionalForm]]],
 "\", where \[DoubleStruckCapitalJ]\[DoubleStruckCapitalJ]\
\[DoubleStruckCapitalJ]=1, and there is no entity that squares to 1. (The \
standard proof that all 3-element algebras are equivalent to complex algebra \
is only valid for fields with a single -1.)\n\tComplex functions are special \
cases of functions involving generalized signs. In particular, ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[ExponentialE]", "r", 
    RowBox[{
     SuperscriptBox["\[DoubleStruckS]", "j"], " ", "x"}]], 
   TraditionalForm]]],
 "defines multiphase symmetric sinusoids that fold to the asymmetric ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], TraditionalForm]]],
 "= Cos[x] +\[ImaginaryI] Sin[x] when ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Polar Duals, Orbits,\n ",
  FontWeight->"Bold"],
 "\tMany hoops have quadratic sizes that can be expressed as sums or \
differences of squares. These lead to polar-dual forms (generalizations of \
the polar description of the complex plane) that involve multiphase sinusoids \
with angles; the quadratic sizes are squared radii. Because angles add on \
abelian multiplication, polar-duals provide abelian hoops with roots, powers, \
logarithms, and continuous multi-phase sinusoidal \"orbits\" that are are \
related to the discrete orbits of loops. Whilst complex-conjugate \
factor-pairs are not conserved, their real products are conserved sizes that \
define the squared radii of orbits."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 4.",
  FontWeight->"Bold"],
 " The polar form of \"Terplex\" C3 is given by \"",
 StyleBox["toPol[{a,b,c}]",
  FontSlant->"Italic"],
 "\". The Orbit has an offset ",
 StyleBox["d",
  FontSlant->"Italic"],
 "=",
 StyleBox["a+b+c",
  FontSlant->"Italic"],
 ", a squared radius ",
 StyleBox["r2",
  FontSlant->"Italic"],
 ", and an angle \[Sigma]. The function \"",
 StyleBox["toVec[{d,r2,\[Sigma]}]",
  FontSlant->"Italic"],
 "\" recovers the Cartesian form."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{"\"\<The Terplex Polar form of {a,b,c} is\>\"", ",", 
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "\"\<C3\>\""}], "]"}], 
   ",", "\"\<\\nThe general toVec[{d,r2,\[Sigma]},C3] expression is\>\"", ",",
    
   RowBox[{"toVec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", "r2", ",", "\[Sigma]"}], "}"}], ",", "\"\<C3\>\""}], 
    "]"}], ",", "\"\<\\nThe Polar form of {1.,2.,5.} is\>\"", ",", 
   RowBox[{"p3", "=", 
    RowBox[{"toPol", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.", ",", "2.", ",", "5."}], "}"}], ",", "\"\<C3\>\""}], 
     "]"}]}], ",", "\[IndentingNewLine]", "\"\<\\ntoVec recovers  \>\"", ",", 
   
   RowBox[{"toVec", "[", 
    RowBox[{"p3", ",", "\"\<C3\>\""}], "]"}]}], 
  "}"}], "\[IndentingNewLine]", 
 RowBox[{"p3", "=."}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"The Terplex Polar form of {a,b,c} is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"]}], ")"}]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ",", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["3"]}], " ", 
        RowBox[{"(", 
         RowBox[{"b", "-", "c"}], ")"}]}]}], "]"}]}], "}"}], 
   ",", "\<\"\\nThe general toVec[{d,r2,\[Sigma]},C3] expression is\"\>", ",",
    
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"2", " ", 
         SqrtBox["r2"], " ", 
         RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "-", 
        RowBox[{"2", " ", 
         SqrtBox["r2"], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "6"], "+", "\[Sigma]"}], "]"}]}]}], ")"}]}], 
     ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "-", 
        RowBox[{"2", " ", 
         SqrtBox["r2"], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "6"], "-", "\[Sigma]"}], "]"}]}]}], ")"}]}]}],
     "}"}], ",", "\<\"\\nThe Polar form of {1.,2.,5.} is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"8.`", ",", "13.`", ",", "2.3369589764886807`"}], "}"}], 
   ",", "\<\"\\ntoVec recovers  \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "1.9999999999999993`", ",", "5.`"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tSome unitary algebras, i.e. where the determinant is constrained to be 1 \
(apart from any zero sizes), have 3, 4, 6, & 12-phase de-Broglie-wave-like \
orbits, stable Planck-area-like sizes, and reciprocal-radius pairs. \
12-element hoops provide \"half-spin\" quantum operators related to 6-element \
\"unit-spin\" operators; there are fewer 6-element \"supersymmetric\" \
elements because they result from a fold that frees them from the Pauli \
exclusion principle. Note that, whilst algebras are usually taken to have \
vector elements that are \"coefficients\", elements can also be operators.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Hoops & Physics.",
  FontWeight->"Bold"],
 "\n\tSizes are symmetries that may (via Noether's theorem) account for \
forces and particles. They may determine the different families and the \
limited number of fundamental particles. They may also lead to the \"law of \
large numbers\" and three size regimes, R = the radius of universe, \[Rho] = \
a Planck-size , and r = \[Rho]/R = the radius of \"pseudopoint\" particles. \
Hoops may provide a new basis for symmetry in mathematical physics, based on \
finite hoops rather than infinite groups.\n\tClifford (Geometric) algebras \
are a subset of non-commutative hoops, but deserve special treatment, \
provided in the CliffordG.m package. They generalise geometry and analysis to \
any number of dimensions; \[ImaginaryI] is replaced by a non-commutative \
operator in many formulae."
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["GroupLoopHoop6.m ",
  FontSlant->"Italic"],
 "is a package that includes data on over 90 hoop algebras (including some \
isomorphs). Most of these have under 16 elements. Large symbolic determinant \
factors are difficult to find, so most larger hoops still have un-defined \
division. The package provides the generalized procedures ",
 StyleBox["hoopTimes, hoopInverse, hoopPower",
  FontSlant->"Italic"],
 ". In addition to the hoops, it provides a database of all groups with up to \
73 elements, and some other tables, and includes procedures to generate, \
manipulate, and identify isomorphs of these tables. ",
 StyleBox["GroupLoopTest.nb",
  FontSlant->"Italic"],
 " validates the package.\n\t",
 StyleBox["HoopGlossary.nb",
  FontSlant->"Italic"],
 " gives brief explanations of the relevant concepts. ",
 StyleBox["GroupLoopDemo.nb",
  FontSlant->"Italic"],
 " demonstrates the database and procedures. This notebook, ",
 StyleBox["HoopDemo.nb",
  FontSlant->"Italic"],
 ", is a shortened version concerned only with hoops. ",
 StyleBox["MathSource",
  FontSlant->"Italic"],
 " /6198 gives a simplified account of hoops, with a database restricted to \
hoops. ",
 StyleBox["CliffordG.m",
  FontSlant->"Italic"],
 " (in preparation) will develop the distinctive features of Clifford \
(Geometric) algebras."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hoop Tutorial.", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Arial",
 FontSize->16,
 FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell["1. \"Hoops\", Hoop Names.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["Conservative division algebras (Hoops) are created by \"folding\" \
Moufang loops (groups and a few alternative loops such as octonions) by the \
introduction of generalized signs. Hoops multiply and divide vectors whilst \
conserving \"sizes\" (factors of the symbolic inverse table determinant). A \
database provides named tables and sizes for over 90 hoops, together with \
much more material on small loops and groups.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tHoops are \"conservative division algebras\" that unify most algebras \
(including the Cayley-Dickson algebras {\[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], \[DoubleStruckCapitalO]}, \
Clifford (geometric), Davenport, Dirac-\[Gamma], Lie, non-commutative, \
non-associative, Pauli-\[Sigma], Terplex & Wedge algebras, etc) by employing \
generalized procedures for multiplication, division, and (where appropriate) \
conversion to and from the polar-dual forms that provide powers and roots. \
They act on generalized vectors - indexed lists of coefficients {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], ","}], TraditionalForm]]],
 "...",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "m"], TraditionalForm]]],
 "}, equivalent to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Sum]", "i"], 
    RowBox[{
     SubscriptBox["a", "i"], 
     SubscriptBox["d", "i"], " ", "where", " ", 
     SubscriptBox["d", "i"]}]}], TraditionalForm]]],
 " is a sign, direction, or dimension.\n\tHoops are division algebras because \
their multiplication tables have the Moufang division property, \
zx.yz=(z.xy)z. This ensures that each element in the table, and each vector, \
has a multiplicative inverse. Vector-division is multiplication by the \
inverse vector.\n\tHoops are conservative algebras because (by definition) \
they have the Frobenius determinant conservation property, Det[AB] = \
\[PlusMinus]Det[A]Det[B] where Det is evaluated from the multiplication table \
mapped with the conjugate vector. The factors of the determinant are \
conserved properties, or \"sizes\", and the list of distinct factors is the \
\"shape\" for a vector in a specified algebra.\n\tHoops are algebras because \
they have another operation (apart from multiplication/division).This is \
addition with generalized negation and \"generalized signs\". This operation \
is obtained by an equivalence relationship on sets of coefficients,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["h",
     FontSlant->"Plain"], "i"], TraditionalForm]]],
 "~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "r"}]}]], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"2", 
      RowBox[{"m", "/", "r"}]}]}]], TraditionalForm]]],
 ",..} ~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "r"}]}]], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"2", 
      RowBox[{"m", "/", "r"}]}]}]], TraditionalForm]]],
 "...}. The commonest case is ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2, giving half as many real coefficients, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["r",
     FontSlant->"Plain"], "i"], TraditionalForm]]],
 "~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 " ,",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "} ~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "} iff ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 ". Equivalencing an ",
 StyleBox["m\[Cross]m",
  FontSlant->"Italic"],
 " table with ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry \"folds\" it to an ",
 StyleBox["(m/r)\[Cross](m/r)",
  FontSlant->"Italic"],
 " table. This may be a smaller unsigned Moufang loop (e.g. one C4C2 isomorph \
folds to C4) but in many cases it is a signed table in which some products \
are signed; e.g. C4 2-folds to C4c (complex algebra) with elements {1,\
\[ImaginaryI]} and the signed product \[ImaginaryI].\[ImaginaryI] is -1; the \
C4C2 isomorph in Fig.2 2-folds to the signed Davenport multiplication table."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe database in ",
 StyleBox["GroupLoopHoop.m",
  FontSlant->"Italic"],
 " includes multiplication tables and properties for over 90 loops with known \
determinant factors, each with a string as a name. The names without the \
quotation marks identify Cayley tables, providing the \"preferred isomorph\" \
for hoop multiplication tables. The procedures ",
 StyleBox["hoopTimes ",
  FontSlant->"Italic"],
 "and ",
 StyleBox["hoopShape",
  FontSlant->"Italic"],
 " select a \"target algebra\" for further operations. The names, in order of \
increasing vector size, (apart from 4 non-conservative loops, moved to the \
end) are:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox["hoopList", TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C2\"\>", ",", "\<\"C4c\"\>", ",", "\<\"C3\"\>", 
   ",", "\<\"C3C2c\"\>", ",", "\<\"C12c\"\>", ",", "\<\"C3i\"\>", 
   ",", "\<\"C4C3c\"\>", ",", "\<\"C3C3j\"\>", ",", "\<\"C9j\"\>", 
   ",", "\<\"C9J\"\>", ",", "\<\"C4\"\>", ",", "\<\"K\"\>", ",", "\<\"Qr\"\>",
    ",", "\<\"P4\"\>", ",", "\<\"Dav\"\>", ",", "\<\"O2\"\>", 
   ",", "\<\"C8r\"\>", ",", "\<\"C3C4j\"\>", ",", "\<\"CL2\"\>", 
   ",", "\<\"C4C2r\"\>", ",", "\<\"P16c\"\>", ",", "\<\"C8c\"\>", 
   ",", "\<\"C5\"\>", ",", "\<\"C3C2\"\>", ",", "\<\"D3\"\>", 
   ",", "\<\"C3C4c\"\>", ",", "\<\"Q12c\"\>", ",", "\<\"Q12r\"\>", 
   ",", "\<\"Q12r\"\>", ",", "\<\"g2401c\"\>", ",", "\<\"D6r\"\>", 
   ",", "\<\"D3C2c\"\>", ",", "\<\"KC3c\"\>", ",", "\<\"C3Kr\"\>", 
   ",", "\<\"Cl3r\"\>", ",", "\<\"Clm3r\"\>", ",", "\<\"C8\"\>", 
   ",", "\<\"KC2\"\>", ",", "\<\"C4C2\"\>", ",", "\<\"D4\"\>", 
   ",", "\<\"Q8\"\>", ",", "\<\"Octr\"\>", ",", "\<\"KiC4c\"\>", 
   ",", "\<\"O4\"\>", ",", "\<\"O4a\"\>", ",", "\<\"O4b\"\>", 
   ",", "\<\"C4C4c\"\>", ",", "\<\"C4C4r\"\>", ",", "\<\"Q8C2r\"\>", 
   ",", "\<\"C2D4r\"\>", ",", "\<\"P8\"\>", ",", "\<\"CL3\"\>", 
   ",", "\<\"C4iC4c\"\>", ",", "\<\"QC2r\"\>", ",", "\<\"KiC4r\"\>", 
   ",", "\<\"CL21\"\>", ",", "\<\"CL03\"\>", ",", "\<\"Octi\"\>", 
   ",", "\<\"C3C3\"\>", ",", "\<\"C9\"\>", ",", "\<\"C6C3c\"\>", 
   ",", "\<\"C3C4\"\>", ",", "\<\"C3K\"\>", ",", "\<\"Q12\"\>", 
   ",", "\<\"D3C2\"\>", ",", "\<\"A4\"\>", ",", "\<\"C3Qr\"\>", 
   ",", "\<\"C3P4\"\>", ",", "\<\"C6Kr\"\>", ",", "\<\"C3KC2r\"\>", 
   ",", "\<\"Q12C2c\"\>", ",", "\<\"D8\"\>", ",", "\<\"Q16\"\>", 
   ",", "\<\"D4C2\"\>", ",", "\<\"C4C4\"\>", ",", "\<\"Q8C2\"\>", 
   ",", "\<\"KK\"\>", ",", "\<\"C4K\"\>", ",", "\<\"KiC4\"\>", 
   ",", "\<\"C4iC4\"\>", ",", "\<\"P16\"\>", ",", "\<\"Oct\"\>", 
   ",", "\<\"Q8M2\"\>", ",", "\<\"CL4\"\>", ",", "\<\"CL13\"\>", 
   ",", "\<\"CL22\"\>", ",", "\<\"CL31\"\>", ",", "\<\"r31r\"\>", 
   ",", "\<\"CL04\"\>", ",", "\<\"O8\"\>", ",", "\<\"C3C4C2\"\>", 
   ",", "\<\"CL31C2\"\>", ",", "\<\"CL4C2\"\>", ",", "\<\"Q4n\"\>", 
   ",", "\<\"C6n\"\>", ",", "\<\"Q8n\"\>", ",", "\<\"D3Mn\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe names are based on the names of loops used in ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 ". Thus C2, C3, etc. are cyclic groups, D3, D4, etc. are dihedral groups, \
Q8, Q12 are quaternionic groups (Q12 is called T in Mathworld ",
 StyleBox["Groups",
  FontSlant->"Italic"],
 ",",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["Dic", "3"]}], TraditionalForm]]],
 " in Wikipedia). C3C2 is the direct composition of C3 with C2; C4iC4 is the \
indirect composition of C4 with C4; K=C2C2 is the Klein 4-group. P4, P8, P16 \
have Pauli-\[Sigma] matrices as generators. CLpq is Clifford(p,q). Names \
ending in r, J, or i are signed tables that compose with C2, C3, or C4 to \
Moufang loops. Oct is the 16-element Octonion loop, which folds to the \
8-element octonion hoop Octr. O4, O4a, O4b are hoops with polar",
 StyleBox["-duals",
  FontSlant->"Plain"],
 " having four {angle, radius} pairs. Dav is the Davenport (hypercomplex) \
algebra. An M indicates a non-associative Moufang loop, obtained by doubling \
a non-abelian group, so Q8M2 is the non-associative but conservative Moufang \
loop obtained from Q8. The last four loops, with names ending in n, are not \
conservative; they are included as non-hoop counter-examples with known \
determinant factors that do not define inverses."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["\tAll these hoops have been tested, using a routine in ",
  FontSlant->"Plain"],
 "GroupLoopTest.nb",
 StyleBox[". This shows them to be conservative division algebras by tests \
with random real vectors. Polar-duals, positive powers, roots, and quadratic \
equation solution have also been tested successfully wherever duals are \
known.",
  FontSlant->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell["\<\
\tConservative Moufang loops are a small subset of quasi-groups and \
semi-groups. Most tables have neither the Moufang nor the Frobenius property, \
so they lack inverses and conserved sizes.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Multiplication, Conserved \"sizes\".", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["hoopTimes ",
  FontSlant->"Italic"],
 "and ",
 StyleBox["hoopShape select an algebra & hoopTimes defines multiplication in \
it. Conservation of determinant factors is demonstrated for C3 algebra.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tThe ",
 StyleBox["GroupLoopHoop6.m ",
  FontSlant->"Italic"],
 "database contains a multiplication table and a \"shape\" for each hoop \
algebra. A \"target hoop\" is selected by a ",
 StyleBox["hoopShape[name]",
  FontSlant->"Italic"],
 " instruction (or by specifying the loop in a multiplication operation)",
 StyleBox[".",
  FontSlant->"Italic"],
 " ",
 StyleBox["hoopTimes",
  FontSlant->"Italic"],
 " uses the selected multiplication table to multiply two vectors. The result \
is a vector ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "k"], TraditionalForm]]],
 " = \[CapitalSigma]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "j"], TraditionalForm]]],
 " where ",
 StyleBox["i\[Cross] j = k",
  FontSlant->"Italic"],
 " in the table. Do not confuse hoop multiplication (which creates a vector \
and remainders from two vectors) with matrix multiplication (which transforms \
a single vector to new coordinates) or the Dot product, which creates a \
scalar from two vectors."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 6.",
  FontWeight->"Bold"],
 " Multiplication. The C3 algebra is selected by ",
 StyleBox["hoopShape[\"C3\"];",
  FontSlant->"Italic"],
 " and two 3-element vectors are set up and multiplied:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Figure", " ", "6."}], "*)"}], 
  RowBox[{
   RowBox[{"hoopShape", "[", "\"\<C3\>\"", "]"}], ";", 
   RowBox[{"{", 
    RowBox[{"\"\<If A=\>\"", ",", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{"3.", ",", "1.", ",", "4."}], "}"}]}], ",", "\"\<& B=\>\"", 
     ",", 
     RowBox[{"B", "=", 
      RowBox[{"{", 
       RowBox[{"1.", ",", "2.", ",", 
        RowBox[{"-", "4."}]}], "}"}]}], ",", "\"\<AB in C3 algebra =\>\"", 
     ",", 
     RowBox[{"AB", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "B"}], "]"}]}], ",", 
     "\"\<\\nThis is not the Dot product, which is\>\"", " ", ",", 
     RowBox[{"A", ".", "B"}], ",", 
     "\"\<\\nbut a vector. The general product {a,b,c}\[Times]{d,e,f} is \
\>\"", ",", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", "e", ",", "f"}], "}"}]}], "]"}]}], 
    "}"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"If A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3.`", ",", "1.`", ",", "4.`"}], "}"}], ",", "\<\"& B=\"\>", ",", 
   
   RowBox[{"{", 
    RowBox[{"1.`", ",", "2.`", ",", 
     RowBox[{"-", "4.`"}]}], "}"}], ",", "\<\"AB in C3 algebra =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"7.`", ",", 
     RowBox[{"-", "9.`"}], ",", 
     RowBox[{"-", "6.`"}]}], "}"}], 
   ",", "\<\"\\nThis is not the Dot product, which is\"\>", ",", 
   RowBox[{"-", "11.`"}], 
   ",", "\<\"\\nbut a vector. The general product {a,b,c}\[Times]{d,e,f} is \
\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", "d"}], "+", 
      RowBox[{"c", " ", "e"}], "+", 
      RowBox[{"b", " ", "f"}]}], ",", 
     RowBox[{
      RowBox[{"b", " ", "d"}], "+", 
      RowBox[{"a", " ", "e"}], "+", 
      RowBox[{"c", " ", "f"}]}], ",", 
     RowBox[{
      RowBox[{"c", " ", "d"}], "+", 
      RowBox[{"b", " ", "e"}], "+", 
      RowBox[{"a", " ", "f"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThree variables, the hoop name ",
 StyleBox["gmn,",
  FontSlant->"Italic"],
 " the multiplication table ",
 StyleBox["glo,",
  FontSlant->"Italic"],
 " and the length ",
 StyleBox["mm",
  FontSlant->"Italic"],
 ", are automatically set when an algebra is selected by ",
 StyleBox["hoopShape",
  FontSlant->"Italic"],
 ". \n\tThe multiplication index-table can be shown in \"TraditionalForm\" by \
appending ",
 StyleBox["//tf ",
  FontSlant->"Italic"],
 ", the symbolic form by ",
 StyleBox["gmap[glo,{a,b,..}]//tf",
  FontSlant->"Italic"],
 ", (which puts ",
 StyleBox["a,b...",
  FontSlant->"Italic"],
 " in place of ",
 StyleBox["1,2..",
  FontSlant->"Italic"],
 ", etc.) and the shape is given by ",
 StyleBox["sh[gmn]",
  FontSlant->"Italic"],
 "\n",
 StyleBox["Figure 7. ",
  FontWeight->"Bold"],
 "C3 Index table, Symbolic table, and Polar form."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Figure", " ", "7."}], "*)"}], 
  RowBox[{"{", 
   RowBox[{"gmn", ",", "\"\<Index Table\>\"", ",", 
    RowBox[{"glo", "//", "tf"}], ",", "\"\<Symbolic Form\>\"", ",", 
    RowBox[{
     RowBox[{"gmap", "[", 
      RowBox[{"glo", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", "tf"}], ",", 
    "\"\<\\nhas shape=\>\"", ",", 
    RowBox[{"shape", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "\"\<C3\>\""}], "]"}]}],
    "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C3\"\>", ",", "\<\"Index Table\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3"},
        {"2", "3", "1"},
        {"3", "1", "2"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"Symbolic Form\"\>", ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"a", "b", "c"},
        {"b", "c", "a"},
        {"c", "a", "b"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"\\nhas shape=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 8.",
  FontWeight->"Bold"],
 " Size Conservation in Multiplication. The shapes of A, B, and AB (from Fig. \
6.) are shown; conservation is demonstrated in the last line by subtracting \
to give {0,0}:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<\>\"", ",", "sh1", ",", "sh2"}], "}"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "shA", " ", "}"}], ",", 
       RowBox[{"sA", "=", 
        RowBox[{"shape", "[", "A", "]"}]}]}], "]"}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "shB", " ", "}"}], ",", 
       RowBox[{"sB", "=", 
        RowBox[{"shape", "[", "B", "]"}]}]}], "]"}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "shAB", "}"}], ",", 
       RowBox[{"sAB", "=", 
        RowBox[{"shape", "[", "AB", "]"}]}]}], "]"}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"shA", "*", "shB"}], "-", "shAB"}], "}"}], ",", 
       RowBox[{
        RowBox[{"sA", "*", "sB"}], "-", "sAB"}]}], "]"}], "]"}]}], "}"}], "//",
   "tf"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"\"\>", "sh1", "sh2"},
     {"shA", "8.`", "7.`"},
     {"shB", 
      RowBox[{"-", "1.`"}], "31.`"},
     {"shAB", 
      RowBox[{"-", "8.`"}], "217.`"},
     {
      RowBox[{
       RowBox[{"shA", " ", "shB"}], "-", "shAB"}], "0.`", "0.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Multiplicative inverses, Division.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary.",
 StyleBox[" Division is multiplication by a multiplicative inverse that can \
be found by Cramer's method and so has the determinant as denominator.  ",
  FontSlant->"Italic"],
 StyleBox["hoopIn",
  FontSlant->"Italic"],
 StyleBox["verse creates the left inverse Ainv. This is demonstrated for \
abelian C3 and non-abelian D3, where Ainv.AB recovers B and AB.Binv recovers \
A (because B is the left inverse of Binv), provided that A & B have the same \
zero-sizes.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["\t",
  FontSlant->"Italic"],
 StyleBox["hoopIn",
  FontSlant->"Italic"],
 StyleBox["verse[A]",
  FontSlant->"Italic"],
 " gives the multiplicative left inverse Ainv (which is also a right inverse \
for abelian hoops). The inverses have been found by Cramer's method, solving \
Ainv.A= I, where I is the hoop unit vector, {1,0....0}. (Again, do not \
confuse this with matrix inversion, where I is the unit diagonal matrix.) \
Cramer's method makes the table determinant the denominator for every element \
of the inverse.\n",
 StyleBox["Figure 9. ",
  FontWeight->"Bold"],
 "C3 Division using ",
 StyleBox["hoopIn",
  FontSlant->"Italic"],
 StyleBox["verse",
  FontSlant->"Italic"],
 ". Ainv.AB recovers B:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Example", " ", "2", "a"}], "*)"}], 
  RowBox[{"{", 
   RowBox[{"\"\<Ainv\>\"", ",", 
    RowBox[{"Ainv", "=", 
     RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", "\"\<\\nDeterminant \>\"",
     ",", 
    RowBox[{"Det", "[", 
     RowBox[{"gmap", "[", 
      RowBox[{"C3", ",", "A"}], "]"}], "]"}], ",", "\"\<\\nShape Ainv\>\"", 
    ",", 
    RowBox[{"shape", "[", "Ainv", "]"}], ",", "\"\<\\nAinv.AB recovers B\>\"",
     ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ainv", ",", "AB"}], "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Ainv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0.08928571428571427`", ",", "0.23214285714285712`", ",", 
     RowBox[{"-", "0.1964285714285714`"}]}], "}"}], 
   ",", "\<\"\\nDeterminant \"\>", ",", 
   RowBox[{"-", "56.`"}], ",", "\<\"\\nShape Ainv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0.125`", ",", "0.14285714285714282`"}], "}"}], 
   ",", "\<\"\\nAinv.AB recovers B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0.9999999999999997`", ",", "1.9999999999999996`", ",", 
     RowBox[{"-", "3.999999999999999`"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tNon-abelian (non-commutative) algebra determinants have repeated roots, \
as shown by the third line of Figure 10., where {a,b,c,d,e,f} is mapped onto \
the index table of D3 (the smallest non-abelian group, aka S3), and the \
determinant is factorised. (The repeated factor \"fragments\" into (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "-", "c"}], ")"}], "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"c", "-", "e"}], ")"}], "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"e", "-", "a"}], ")"}], "2"], TraditionalForm]]],
 ")/2-(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"b", "-", "d"}], ")"}], "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"d", "-", "f"}], ")"}], "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"f", "-", "b"}], ")"}], "2"], TraditionalForm]]],
 ")/2 ). The D3 products AB and BA differ. Inverses are \"left inverses\", so \
both Ainv.AB & BA.Ainv recover B, but AB.Ainv gives rubbish.\n\n",
 StyleBox["Figure 10.",
  FontWeight->"Bold"],
 " Noncommutative Multiplication & Division using D3 and CL22."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Example", " ", "2", "b"}], "*)"}], 
  RowBox[{
   RowBox[{"hoopShape", "[", "\"\<D3\>\"", "]"}], ";", 
   RowBox[{"{", 
    RowBox[{"\"\<A=\>\"", ",", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5"}], 
       "}"}]}], ",", "\"\<B=\>\"", ",", 
     RowBox[{"B", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4"}], 
       "}"}]}], ",", "\"\<\\nD3 Determinant \>\"", ",", 
     RowBox[{"Factor", "[", 
      RowBox[{"Det", "[", 
       RowBox[{"gmap", "[", 
        RowBox[{"D3", ",", 
         RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
          "}"}]}], "]"}], "]"}], "]"}], ",", "\"\<\\nAB in D3 algebra =\>\"", 
     ",", 
     RowBox[{"AB", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "B"}], "]"}]}], ",", "\"\<\\nBA in D3 algebra =\>\"",
      ",", 
     RowBox[{"BA", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"B", ",", "A"}], "]"}]}], ",", "\"\<\\nAinv\>\"", ",", 
     RowBox[{"Ainv", "=", 
      RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
     "\"\<\\nShapes of A & Ainv\>\"", ",", 
     RowBox[{"shape", "[", "A", "]"}], ",", 
     RowBox[{"shape", "[", "Ainv", "]"}], ",", 
     "\"\<\\nAinv.AB recovers B\>\"", ",", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"Ainv", ",", "AB"}], "]"}], ",", 
     "\"\<\\nBA.Ainv recovers B\>\"", ",", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"BA", ",", "Ainv"}], "]"}], ",", 
     "\"\<\\nAB.Ainv is rubbish\>\"", ",", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"AB", ",", "Ainv"}], "]"}], ",", "\"\<\\nBinv\>\"", ",", 
     RowBox[{"Binv", "=", 
      RowBox[{"hoopInverse", "[", "B", "]"}]}], ",", 
     "\"\<\\nShapes of B & Binv\>\"", ",", 
     RowBox[{"shape", "[", "B", "]"}], ",", 
     RowBox[{"shape", "[", "Binv", "]"}], ",", 
     "\"\<\\nAB.Binv recovers A\>\"", ",", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"AB", ",", "Binv"}], "]"}], ",", 
     "\"\<\\nBinv.BA recovers A\>\"", ",", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"Binv", ",", "BA"}], "]"}]}], "}"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5"}], "}"}], 
   ",", "\<\"B=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4"}], "}"}], 
   ",", "\<\"\\nD3 Determinant \"\>", ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], 
      ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ")"}], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"a", " ", "c"}], "+", 
       SuperscriptBox["c", "2"], "+", 
       RowBox[{"b", " ", "d"}], "-", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"a", " ", "e"}], "-", 
       RowBox[{"c", " ", "e"}], "+", 
       SuperscriptBox["e", "2"], "+", 
       RowBox[{"b", " ", "f"}], "+", 
       RowBox[{"d", " ", "f"}], "-", 
       SuperscriptBox["f", "2"]}], ")"}], "2"]}], 
   ",", "\<\"\\nAB in D3 algebra =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"49", ",", "58", ",", "48", ",", "51", ",", "40", ",", "48"}], 
    "}"}], ",", "\<\"\\nBA in D3 algebra =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"49", ",", "54", ",", "46", ",", "55", ",", "42", ",", "48"}], 
    "}"}], ",", "\<\"\\nAinv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["83", "315"], ",", 
     RowBox[{"-", 
      FractionBox["191", "630"]}], ",", 
     RowBox[{"-", 
      FractionBox["149", "630"]}], ",", 
     RowBox[{"-", 
      FractionBox["43", "315"]}], ",", 
     FractionBox["61", "630"], ",", 
     FractionBox["229", "630"]}], "}"}], ",", "\<\"\\nShapes of A & Ainv\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"21", ",", "5", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "21"], ",", 
     FractionBox["1", "5"], ",", 
     RowBox[{"-", 
      FractionBox["1", "6"]}]}], "}"}], ",", "\<\"\\nAinv.AB recovers B\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4"}], "}"}], 
   ",", "\<\"\\nBA.Ainv recovers B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4"}], "}"}], 
   ",", "\<\"\\nAB.Ainv is rubbish\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5", ",", "4", ",", "1", ",", "0", ",", "3"}], "}"}], 
   ",", "\<\"\\nBinv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["39", "56"]}], ",", 
     FractionBox["59", "56"], ",", 
     FractionBox["73", "56"], ",", 
     FractionBox["3", "56"], ",", 
     RowBox[{"-", 
      FractionBox["39", "56"]}], ",", 
     RowBox[{"-", 
      FractionBox["53", "56"]}]}], "}"}], 
   ",", "\<\"\\nShapes of B & Binv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"14", ",", 
     RowBox[{"-", "4"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "14"], ",", 
     RowBox[{"-", 
      FractionBox["1", "4"]}], ",", "1"}], "}"}], 
   ",", "\<\"\\nAB.Binv recovers A\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5"}], "}"}], 
   ",", "\<\"\\nBinv.BA recovers A\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<A=\>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{
     "3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "0", ",", 
      "7", ",", "1", ",", "0", ",", "4", ",", "2", ",", "3", ",", "0", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "4"}]}], "}"}]}], ",", "\"\<B=\>\"", ",", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{
     "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", 
      "0", ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", 
      "0", ",", "4"}], "}"}]}], ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B", ",", "\"\<CL22\>\""}], "]"}]}], ",", 
   "\"\<\\nAinv\>\"", ",", 
   RowBox[{"Ainv", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   "\"\<\\nShapes of A & Ainv\>\"", ",", 
   RowBox[{"shape", "[", "A", "]"}], ",", 
   RowBox[{"shape", "[", "Ainv", "]"}], ",", "\"\<\\nAinv.AB recovers B\>\"", 
   ",", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"Ainv", ",", "AB"}], "]"}], ",", 
   RowBox[{"sA", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], ",", 
   RowBox[{"sB", "=", 
    RowBox[{"shape", "[", "B", "]"}]}], ",", 
   RowBox[{"sAB", "=", 
    RowBox[{"shape", "[", "AB", "]"}]}], ",", 
   RowBox[{
    RowBox[{"sA", " ", "sB"}], " ", "-", "sAB"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "0", ",", "7",
      ",", "1", ",", "0", ",", "4", ",", "2", ",", "3", ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", "\<\"B=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", "0",
      ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", "0", 
     ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14"}], ",", "50", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "5"}], ",", "6", ",", 
     RowBox[{"-", "4"}], ",", "35", ",", "39", ",", "18", ",", 
     RowBox[{"-", "23"}], ",", "19", ",", 
     RowBox[{"-", "83"}], ",", "27", ",", 
     RowBox[{"-", "48"}], ",", "37", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", "\<\"\\nAinv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["201", "2297"]}], ",", 
     RowBox[{"-", 
      FractionBox["61", "2297"]}], ",", 
     RowBox[{"-", 
      FractionBox["284", "2297"]}], ",", 
     RowBox[{"-", 
      FractionBox["414", "2297"]}], ",", 
     RowBox[{"-", 
      FractionBox["266", "2297"]}], ",", 
     RowBox[{"-", 
      FractionBox["473", "2297"]}], ",", 
     RowBox[{"-", 
      FractionBox["128", "2297"]}], ",", 
     FractionBox["413", "2297"], ",", 
     RowBox[{"-", 
      FractionBox["125", "2297"]}], ",", 
     RowBox[{"-", 
      FractionBox["160", "2297"]}], ",", 
     FractionBox["400", "2297"], ",", 
     FractionBox["90", "2297"], ",", 
     FractionBox["441", "2297"], ",", 
     RowBox[{"-", 
      FractionBox["40", "2297"]}], ",", 
     FractionBox["117", "2297"], ",", 
     RowBox[{"-", 
      FractionBox["112", "2297"]}]}], "}"}], 
   ",", "\<\"\\nShapes of A & Ainv\"\>", ",", 
   RowBox[{"{", "2297", "}"}], ",", 
   RowBox[{"{", 
    FractionBox["1", "2297"], "}"}], ",", "\<\"\\nAinv.AB recovers B\"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", "0",
      ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", "0", 
     ",", "4"}], "}"}], ",", 
   RowBox[{"{", "2297", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"-", "5436"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"-", "12486492"}], "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<A=\>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{
     "3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "0", ",", 
      "7", ",", "1", ",", "0", ",", "4", ",", "2", ",", "3", ",", "0", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "4"}]}], "}"}]}], ",", "\"\<B=\>\"", ",", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{
     "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", 
      "0", ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", 
      "0", ",", "4"}], "}"}]}], ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B", ",", "\"\<CL13\>\""}], "]"}]}], ",", 
   "\"\<\\nAinv\>\"", ",", 
   RowBox[{"Ainv", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   "\"\<\\nShapes of A & Ainv\>\"", ",", 
   RowBox[{"shape", "[", "A", "]"}], ",", 
   RowBox[{"shape", "[", "Ainv", "]"}], ",", "\"\<\\nDivision\!\(\*
StyleBox[\".\",
FontWeight->\"Plain\"]\)\\nAinv.AB recovers B\>\"", ",", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"Ainv", ",", "AB"}], "]"}], ",", 
   "\"\<\\n\\nShape Conservation\!\(\*
StyleBox[\".\",
FontWeight->\"Plain\"]\)\\nshape[A] shape[B] - shape[AB] = \>\"", ",", 
   RowBox[{
    RowBox[{"sA", "=", 
     RowBox[{"shape", "[", "A", "]"}]}], ";", 
    RowBox[{"sB", "=", 
     RowBox[{"shape", "[", "B", "]"}]}], ";", 
    RowBox[{"sAB", "=", 
     RowBox[{"shape", "[", "AB", "]"}]}], ";", 
    RowBox[{
     RowBox[{"sA", " ", "sB"}], " ", "-", "sAB"}]}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "0", ",", "7",
      ",", "1", ",", "0", ",", "4", ",", "2", ",", "3", ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", "\<\"B=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", "0",
      ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", "0", 
     ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18"}], ",", 
     RowBox[{"-", "12"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "5"}], ",", "14", ",", 
     RowBox[{"-", "18"}], ",", "35", ",", "39", ",", 
     RowBox[{"-", "48"}], ",", "25", ",", "19", ",", 
     RowBox[{"-", "83"}], ",", 
     RowBox[{"-", "19"}], ",", "36", ",", "37", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", "\<\"\\nAinv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["375", "17209"], ",", 
     FractionBox["99", "17209"], ",", 
     RowBox[{"-", 
      FractionBox["636", "17209"]}], ",", 
     RowBox[{"-", 
      FractionBox["422", "17209"]}], ",", 
     RowBox[{"-", 
      FractionBox["82", "17209"]}], ",", 
     FractionBox["215", "17209"], ",", 
     FractionBox["208", "17209"], ",", 
     RowBox[{"-", 
      FractionBox["819", "17209"]}], ",", 
     RowBox[{"-", 
      FractionBox["93", "17209"]}], ",", 
     RowBox[{"-", 
      FractionBox["32", "17209"]}], ",", 
     RowBox[{"-", 
      FractionBox["456", "17209"]}], ",", 
     RowBox[{"-", 
      FractionBox["70", "17209"]}], ",", 
     RowBox[{"-", 
      FractionBox["647", "17209"]}], ",", 
     FractionBox["136", "17209"], ",", 
     FractionBox["533", "17209"], ",", 
     FractionBox["880", "17209"]}], "}"}], 
   ",", "\<\"\\nShapes of A & Ainv\"\>", ",", 
   RowBox[{"{", "17209", "}"}], ",", 
   RowBox[{"{", 
    FractionBox["1", "17209"], "}"}], 
   ",", "\<\"\\nDivision\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontWeight->\\\"\
Plain\\\"]\\)\\nAinv.AB recovers B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", "0",
      ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", "0", 
     ",", "4"}], "}"}], 
   ",", "\<\"\\n\\nShape \
Conservation\\!\\(\\*\\nStyleBox[\\\".\\\",\\nFontWeight->\\\"Plain\\\"]\\)\\\
nshape[A] shape[B] - shape[AB] = \"\>", ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe database contains a few hoops that are non-associative, with \
Octonions being best known. \"Octr\" is the 8-element octonion algebra, and \
\"Oct\" is its parent 16-element unsigned table, the third nonassociative \
Moufang loop with 16 elements. \"Q8M2\" is the second, and is parent to \
another 8-element signed table \"Octs\" (split-octonions in Wikipedia); both \
have a size consisting of four positive and four negated squares, giving the \
signature (4,4). Left and right multiplication of two 16-element vectors is \
demonstrated for \"Q8M2\" in Figure 10a:-\n\n",
 StyleBox["Figure 10a",
  FontWeight->"Bold"],
 ". Noncommutative Nonassociative Multiplication & Division Q8M2."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<A=\>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{
     "3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "0", ",", 
      "7", ",", "1", ",", "0", ",", "4", ",", "2", ",", "3", ",", "0", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "4"}]}], "}"}]}], ",", "\"\<B=\>\"", ",", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{
     "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", 
      "0", ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", 
      "0", ",", "4"}], "}"}]}], ",", 
   "\"\<\\nQ8M2 Determinant Factors\\n \>\"", ",", 
   RowBox[{"hoopShape", "[", "\"\<Q8M2\>\"", "]"}], ",", 
   "\"\<\\nAB in Q8M2 algebra =\>\"", ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B"}], "]"}]}], ",", "\"\<\\nBA in Q8M2 algebra =\>\"",
    ",", 
   RowBox[{"BA", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"B", ",", "A"}], "]"}]}], ",", "\"\<\\nAinv\>\"", ",", 
   RowBox[{"Ainv", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", 
   "\"\<\\nShapes of A & Ainv\>\"", ",", 
   RowBox[{"shape", "[", "A", "]"}], ",", 
   RowBox[{"shape", "[", "Ainv", "]"}], ",", "\"\<\\nAinv.AB recovers B\>\"", 
   ",", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"Ainv", ",", "AB"}], "]"}], ",", "\"\<\\nBA.Ainv recovers B\>\"", 
   ",", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"BA", ",", "Ainv"}], "]"}], ",", "\"\<\\nAB.Ainv is rubbish\>\"", 
   ",", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"AB", ",", "Ainv"}], "]"}], ",", "\"\<\\nBinv\>\"", ",", 
   RowBox[{"Binv", "=", 
    RowBox[{"hoopInverse", "[", "B", "]"}]}], ",", 
   "\"\<\\nShapes of B & Binv\>\"", ",", 
   RowBox[{"shape", "[", "B", "]"}], ",", 
   RowBox[{"shape", "[", "Binv", "]"}], ",", "\"\<\\nAB.Binv recovers A\>\"", 
   ",", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"AB", ",", "Binv"}], "]"}], ",", "\"\<\\nBinv.BA recovers A\>\"", 
   ",", 
   RowBox[{"hoopTimes", "[", 
    RowBox[{"Binv", ",", "BA"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "0", ",", "7",
      ",", "1", ",", "0", ",", "4", ",", "2", ",", "3", ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", "\<\"B=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", "0",
      ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", "0", 
     ",", "4"}], "}"}], ",", "\<\"\\nQ8M2 Determinant Factors\\n \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"i", "-", "m"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"j", "-", "n"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", "o"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"l", "-", "p"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nAB in Q8M2 algebra =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "103", ",", "128", ",", "56", ",", "53", ",", "63", ",", "46", ",", "119",
      ",", "89", ",", "102", ",", "124", ",", "43", ",", "99", ",", "105", 
     ",", "75", ",", "149", ",", "98"}], "}"}], 
   ",", "\<\"\\nBA in Q8M2 algebra =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "103", ",", "60", ",", "123", ",", "90", ",", "63", ",", "114", ",", "52",
      ",", "52", ",", "124", ",", "60", ",", "124", ",", "98", ",", "83", ",",
      "139", ",", "68", ",", "99"}], "}"}], ",", "\<\"\\nAinv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["121636", "79695"]}], ",", 
     FractionBox["154249", "79695"], ",", 
     RowBox[{"-", 
      FractionBox["22292", "11385"]}], ",", 
     FractionBox["29228", "11385"], ",", 
     FractionBox["117449", "79695"], ",", 
     RowBox[{"-", 
      FractionBox["164531", "79695"]}], ",", 
     FractionBox["23248", "11385"], ",", 
     RowBox[{"-", 
      FractionBox["27697", "11385"]}], ",", 
     FractionBox["86929", "79695"], ",", 
     FractionBox["4589", "79695"], ",", 
     RowBox[{"-", 
      FractionBox["29182", "11385"]}], ",", 
     RowBox[{"-", 
      FractionBox["35162", "11385"]}], ",", 
     RowBox[{"-", 
      FractionBox["72461", "79695"]}], ",", 
     FractionBox["4589", "79695"], ",", 
     FractionBox["27743", "11385"], ",", 
     FractionBox["33148", "11385"]}], "}"}], 
   ",", "\<\"\\nShapes of A & Ainv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"23", ",", "5", ",", "7", ",", "9", ",", "7", ",", 
     RowBox[{"-", "11"}], ",", 
     RowBox[{"-", "1"}], ",", "33", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "23"], ",", 
     FractionBox["1", "5"], ",", 
     FractionBox["1", "7"], ",", 
     FractionBox["1", "9"], ",", 
     FractionBox["1", "7"], ",", 
     RowBox[{"-", 
      FractionBox["1", "11"]}], ",", 
     RowBox[{"-", "1"}], ",", 
     FractionBox["1", "33"], ",", "1"}], "}"}], 
   ",", "\<\"\\nAinv.AB recovers B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", "0",
      ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", "0", 
     ",", "4"}], "}"}], ",", "\<\"\\nBA.Ainv recovers B\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "5", ",", "0",
      ",", "2", ",", "6", ",", "5", ",", "0", ",", "7", ",", "1", ",", "0", 
     ",", "4"}], "}"}], ",", "\<\"\\nAB.Ainv is rubbish\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "82"}], ",", "34", ",", "308", ",", "3", ",", "88", ",", 
     RowBox[{"-", "28"}], ",", 
     RowBox[{"-", "305"}], ",", "96", ",", 
     RowBox[{"-", "146"}], ",", "118", ",", 
     RowBox[{"-", "239"}], ",", 
     RowBox[{"-", "87"}], ",", "153", ",", 
     RowBox[{"-", "113"}], ",", "243"}], "}"}], ",", "\<\"\\nBinv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1471", "40832"]}], ",", 
     FractionBox["1571", "122496"], ",", 
     RowBox[{"-", 
      FractionBox["3731", "122496"]}], ",", 
     FractionBox["1109", "122496"], ",", 
     RowBox[{"-", 
      FractionBox["2879", "40832"]}], ",", 
     FractionBox["5795", "122496"], ",", 
     FractionBox["4717", "122496"], ",", 
     RowBox[{"-", 
      FractionBox["5227", "122496"]}], ",", 
     FractionBox["1169", "40832"], ",", 
     FractionBox["3859", "122496"], ",", 
     FractionBox["10877", "122496"], ",", 
     RowBox[{"-", 
      FractionBox["11387", "122496"]}], ",", 
     FractionBox["4689", "40832"], ",", 
     RowBox[{"-", 
      FractionBox["6701", "122496"]}], ",", 
     FractionBox["317", "122496"], ",", 
     RowBox[{"-", 
      FractionBox["2939", "122496"]}]}], "}"}], 
   ",", "\<\"\\nShapes of B & Binv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "8", ",", "4", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "6"}], ",", "44", ",", 
     RowBox[{"-", "58"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "6"]}], ",", 
     FractionBox["1", "8"], ",", 
     FractionBox["1", "4"], ",", 
     RowBox[{"-", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "4"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"-", 
      FractionBox["1", "6"]}], ",", 
     FractionBox["1", "44"], ",", 
     RowBox[{"-", 
      FractionBox["1", "58"]}]}], "}"}], ",", "\<\"\\nAB.Binv recovers A\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
    "3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "0", ",", "7",
      ",", "1", ",", "0", ",", "4", ",", "2", ",", "3", ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", "\<\"\\nBinv.BA recovers A\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "0", ",", "7",
      ",", "1", ",", "0", ",", "4", ",", "2", ",", "3", ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Recovery fails unless A & B have the same zero-sizes; disparate zeroes are \
handled in the next sections.\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. \"Zero sizes\" & \"Remainders\".", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["Vectors B with zero-sizes are given an inverse Binv with the same \
zeroes, so these sizes are lost in the dividend. hoopTimes is defined so that \
A/B (= Binv*A) is \"projected\" onto a sub-algebra, whilst conservation is \
maintained by \"ejecting\" remainders. The analogy with integer division, A/B \
= C, C*B+R=A with R<B, is that the ejected remainder contains those sizes of \
A that are less than the (infinite) sizes omitted from Binv. There is another \
analogy, with q-deformed and h-deformed algebras, whichgive different \
algebras when q",
  FontSlant->"Italic"],
 "\[RightArrow]",
 StyleBox["1 or h",
  FontSlant->"Italic"],
 "\[RightArrow]0."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tMost hoop determinants have more than one factor, so most inverses split \
into partial fractions with the factors (sizes) as denominators. (A \
mathematical quirk makes repeated factors give a single partial fraction, \
weighted by the multiplicity, rather than the general partial fractions.)\n\t\
",
 StyleBox["hoopIn",
  FontSlant->"Italic"],
 StyleBox["verse",
  FontSlant->"Italic"],
 " creates the required partial fractions, but omits any in which the \
denominator is effectively zero (to within an arbitrary ",
 StyleBox["hmin",
  FontSlant->"Italic"],
 "). Consequently, Ainv has the same zeroes as A and dividends have the same \
zeroed sizes. The dividends are \"projected\" onto a sub-algebra in which \
these sizes are constrained to be zero. By analogy with natural number \
division, where A/B = C with remainder R (with 0\[LessSlantEqual]R<B) such \
that C*B+R=A, there is a dividend C and a remainder R, into which any \
unconserved sizes are \"ejected\". This is implemented by ",
 StyleBox["hoopTi",
  FontSlant->"Italic"],
 StyleBox["mes[A,Binv]",
  FontSlant->"Italic"],
 "; it is demonstrated here and discussed in the next section.\n\t\n",
 StyleBox["Figure 11.",
  FontWeight->"Bold"],
 "  B is altered to have a zero D3 size. Dividing A by B splits A into the \
dividend A0, with the same size zero, and the (left) remainder Rl, with the \
other sizes zero:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Example", " ", "3"}], "*)"}], 
  RowBox[{
   RowBox[{"hoopShape", "[", "\"\<D3\>\"", "]"}], ";", 
   RowBox[{"{", 
    RowBox[{"\"\<A=\>\"", ",", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5"}], 
       "}"}]}], ",", "\"\<B=\>\"", ",", 
     RowBox[{"B", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "1", ",", "3", ",", "7", ",", "4"}], 
       "}"}]}], ",", "\"\<\\nAB in D3 algebra =\>\"", ",", 
     RowBox[{"AB", "=", 
      RowBox[{"hoopTimes", "[", 
       RowBox[{"A", ",", "B"}], "]"}]}], ",", "\"\<\\nBinv\>\"", ",", 
     RowBox[{"Binv", "=", 
      RowBox[{"hoopInverse", "[", "B", "]"}]}], ",", 
     "\"\<\\nwith remainders Rl, Rr\>\"", ",", 
     RowBox[{"R1", "=", "Rl"}], ",", "Rr", ",", "\"\<\\nShapes A,B    \>\"", 
     ",", 
     RowBox[{"shape", "[", "A", "]"}], ",", 
     RowBox[{"shape", "[", "B", "]"}], ",", "\"\<\\nShapes Rl,Binv\>\"", ",", 
     
     RowBox[{"shape", "[", "Rl", "]"}], ",", 
     RowBox[{"shape", "[", "Binv", "]"}], ",", "\"\<\\nAB/B+Rl=A\>\"", ",", 
     RowBox[{
      RowBox[{"hoopTimes", "[", 
       RowBox[{"AB", ",", "Binv"}], "]"}], "+", "R1"}]}], "}"}]}]}]], "Input",\

 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5"}], "}"}], 
   ",", "\<\"B=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1", ",", "3", ",", "7", ",", "4"}], "}"}], 
   ",", "\<\"\\nAB in D3 algebra =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"65", ",", "78", ",", "72", ",", "55", ",", "52", ",", "56"}], 
    "}"}], ",", "\<\"\\nBinv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["61", "1188"]}], ",", 
     FractionBox["47", "1188"], ",", 
     FractionBox["155", "1188"], ",", 
     FractionBox["1", "108"], ",", 
     RowBox[{"-", 
      FractionBox["61", "1188"]}], ",", 
     RowBox[{"-", 
      FractionBox["25", "1188"]}]}], "}"}], 
   ",", "\<\"\\nwith remainders Rl, Rr\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["5", "6"], ",", 
     RowBox[{"-", 
      FractionBox["5", "6"]}], ",", 
     FractionBox["5", "6"], ",", 
     RowBox[{"-", 
      FractionBox["5", "6"]}], ",", 
     FractionBox["5", "6"], ",", 
     RowBox[{"-", 
      FractionBox["5", "6"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", "\<\"\\nShapes A,B    \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"21", ",", "5", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "0", ",", "33"}], "}"}], 
   ",", "\<\"\\nShapes Rl,Binv\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "5", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "18"], ",", "0", ",", 
     FractionBox["1", "33"]}], "}"}], ",", "\<\"\\nAB/B+Rl=A\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Conservative Hoops and Remainders.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["Multiplication by a vector Z with zero-sizes gives a product with \
the same zeroes, losing any corresponding sizes in the other multiplicand, so \
that ZB/Z does not recover B. The product ZB has been \"projected\" onto a \
sub-algebra, just as in division. Conservation is maintained by \"ejecting\" \
left and right remainders so that ZB/B+Rl = Z & ZB/Z + Rr = B. Abelian, \
non-abelian, and monosized algebra remainders are demonstrated.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tDivision needs remainders to maintain conservation. As division is \
multiplication by an inverse, using ",
 StyleBox["hoopTi",
  FontSlant->"Italic"],
 StyleBox["mes",
  FontSlant->"Italic"],
 ", remainders must also be involved in multiplication. If different sizes of \
A & B are zero, these sizes will be zero in the product AB. To maintain \
conservation, the \"missing sizes\" have to be \"ejected\" as remainders when \
AB is \"projected\" onto a sub-algebra. Rl is the remainder for the left \
multiplicand A, and Rr for the right multiplicand B. They ensure that \
AB/B+Rl=A and AB/A+Rr=B. The procedure ",
 StyleBox["hoopTi",
  FontSlant->"Italic"],
 StyleBox["mes",
  FontSlant->"Italic"],
 " creates the product and both remainders, which are {0,0..} if different \
zeroes are not involved.\n\tA general function ",
 StyleBox["muldiv",
  FontSlant->"Italic"],
 " is set up to demonstrate remainders. (The details are irrelevant to \
non-users of Mathematica):-"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"muldiv", "[", 
    RowBox[{"Ao_", ",", "Bo_", ",", "H_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"sh", "[", "H", "]"}], "]"}]}], ",", 
       RowBox[{"z", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "32"}], "}"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"gmn", "=", "H"}], ";", 
      RowBox[{"glo", "=", 
       RowBox[{"ToExpression", "[", "H", "]"}]}], ";", 
      RowBox[{"mm", "=", 
       RowBox[{"Length", "[", "glo", "]"}]}], ";", 
      RowBox[{"s", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<shape no.\>\"", ",", 
           RowBox[{"Range", "[", "s", "]"}]}], "}"}], "]"}], "]"}]}], ";", 
      RowBox[{"A", "=", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Append", "[", 
           RowBox[{"Ao", ",", "z"}], "]"}], "]"}], ",", "mm"}], "]"}]}], ";", 
      
      RowBox[{"B", "=", 
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"Append", "[", 
           RowBox[{"Bo", ",", "z"}], "]"}], "]"}], ",", "mm"}], "]"}]}], ";", 
      
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<A  =\>\"", "}"}], ",", "A"}], "]"}], "]"}], 
          ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<B  =\>\"", "}"}], ",", "B"}], "]"}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<AB =\>\"", "}"}], ",", 
             RowBox[{"AB", "=", 
              RowBox[{"hoopTimes", "[", 
               RowBox[{"A", ",", "B"}], "]"}]}]}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<Rl =\>\"", "}"}], ",", 
             RowBox[{"R1", "=", "Rl"}]}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<Rr =\>\"", "}"}], ",", 
             RowBox[{"R2", "=", "Rr"}]}], "]"}], "]"}]}], "}"}], "//", "tf"}],
        "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s", ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<shA  =\>\"", "}"}], ",", 
             RowBox[{"shape", "[", "A", "]"}]}], "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<shB  =\>\"", "}"}], ",", 
             RowBox[{"shape", "[", "B", "]"}]}], "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<shAB =\>\"", "}"}], ",", 
             RowBox[{"shape", "[", "AB", "]"}]}], "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<shRl =\>\"", "}"}], ",", 
             RowBox[{"shape", "[", "Rl", "]"}]}], "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"{", "\"\<shRr =\>\"", "}"}], ",", 
             RowBox[{"shape", "[", "Rr", "]"}]}], "]"}], "]"}]}], "}"}], "//",
         "tf"}], "]"}], ";", 
      RowBox[{"{", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<AB/B+Rl=A  \>\"", ",", 
         RowBox[{
          RowBox[{"hoopTimes", "[", 
           RowBox[{"AB", ",", 
            RowBox[{"hoopInverse", "[", "B", "]"}]}], "]"}], "+", "R1"}], 
         ",", "\"\<\\nAB/A+Rr=B  \>\"", ",", 
         RowBox[{
          RowBox[{"hoopTimes", "[", 
           RowBox[{
            RowBox[{"hoopInverse", "[", "A", "]"}], ",", "AB"}], "]"}], "+", 
          "R2"}]}], "]"}], "}"}], ";"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[TextData[{
 StyleBox["Figure 12.",
  FontWeight->"Bold"],
 " The C3C2 algebra is used. A is chosen to have the first size zero, B to \
have the second and fourth zero, so AB has only the third size non-zero. Rl & \
Rr have the shapes that are missing from AB:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Figure", " ", "12"}], "*)"}], 
  RowBox[{
   RowBox[{"muldiv", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "3", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1", ",", "3", ",", "1", ",", "1"}], "}"}], 
     ",", "\"\<C3C2\>\""}], "]"}], ";"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"A  =\"\>", "2", "1", 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "2"}], "3", 
       RowBox[{"-", "2"}]},
      {"\<\"B  =\"\>", "3", "1", "1", "3", "1", "1"},
      {"\<\"AB =\"\>", "0", "8", 
       RowBox[{"-", "8"}], "0", "8", 
       RowBox[{"-", "8"}]},
      {"\<\"Rl =\"\>", "2", 
       RowBox[{"-", "1"}], "0", 
       RowBox[{"-", "2"}], "1", "0"},
      {"\<\"Rr =\"\>", 
       FractionBox["5", "3"], 
       FractionBox["5", "3"], 
       FractionBox["5", "3"], 
       FractionBox["5", "3"], 
       FractionBox["5", "3"], 
       FractionBox["5", "3"]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print"],

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"shape no.\"\>", "1", "2", "3", "4"},
      {"\<\"shA  =\"\>", "0", "2", "48", "28"},
      {"\<\"shB  =\"\>", "10", "0", "16", "0"},
      {"\<\"shAB =\"\>", "0", "0", "768", "0"},
      {"\<\"shRl =\"\>", "0", "2", "0", "28"},
      {"\<\"shRr =\"\>", "10", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"AB/B+Rl=A  \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}], ",", "3", ",", 
     RowBox[{"-", "2"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"\\nAB/A+Rr=B  \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "1", ",", "3", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm[
  "AB/B+Rl=A  ", {2, 1, -2, -2, 3, -2}, "\nAB/A+Rr=B  ", {3, 1, 1, 3, 1, 1}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 13.",
  FontWeight->"Bold"],
 " Non-abelian D3 is used; two of the sizes of B are zero and Rl contains the \
sizes ejected from A:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Figure", " ", "13."}], "*)"}], 
  RowBox[{
   RowBox[{"muldiv", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", 
       RowBox[{"-", "2"}], ",", "2", ",", "3", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1", ",", "3", ",", "1", ",", "1"}], "}"}], 
     ",", "\"\<D3\>\""}], "]"}], ";"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"A  =\"\>", "2", "1", 
       RowBox[{"-", "2"}], "2", "3", 
       RowBox[{"-", "2"}]},
      {"\<\"B  =\"\>", "3", "1", "1", "3", "1", "1"},
      {"\<\"AB =\"\>", "12", "12", 
       RowBox[{"-", "4"}], "12", "12", 
       RowBox[{"-", "4"}]},
      {"\<\"Rl =\"\>", 
       FractionBox["4", "3"], 
       FractionBox["1", "3"], 
       RowBox[{"-", 
        FractionBox["8", "3"]}], 
       FractionBox["4", "3"], 
       FractionBox["7", "3"], 
       RowBox[{"-", 
        FractionBox["8", "3"]}]},
      {"\<\"Rr =\"\>", "0", "0", "0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print"],

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"shape no.\"\>", "1", "2", "3"},
      {"\<\"shA  =\"\>", "4", "2", "8"},
      {"\<\"shB  =\"\>", "10", "0", "0"},
      {"\<\"shAB =\"\>", "40", "0", "0"},
      {"\<\"shRl =\"\>", "0", "2", "8"},
      {"\<\"shRr =\"\>", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"AB/B+Rl=A  \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "3", ",", 
     RowBox[{"-", "2"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"\\nAB/A+Rr=B  \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "1", ",", "3", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm[
  "AB/B+Rl=A  ", {2, 1, -2, 2, 3, -2}, "\nAB/A+Rr=B  ", {3, 1, 1, 3, 1, 1}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 14.",
  FontWeight->"Bold"],
 " P4 is a non-abelian group with one size; the Pauli-\[Sigma] matrices \
provide a representation. It gives a complex product from real vectors. As \
the size is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]]],
 ", real vectors can have a size of zero (the \"light-cone\" of relativity.) \
A is chosen to have size 0, so the remainder for B is all of B:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Figure", " ", "14."}], "*)"}], 
  RowBox[{
   RowBox[{"muldiv", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "4", ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "4", ",", "3"}], "}"}], ",", "\"\<P4\>\""}],
     "]"}], ";"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"A  =\"\>", "5", "4", "0", "3"},
      {"\<\"B  =\"\>", "2", "1", "4", "3"},
      {"\<\"AB =\"\>", "23", 
       RowBox[{"13", "+", 
        RowBox[{"12", " ", "\[ImaginaryI]"}]}], 
       RowBox[{"20", "+", 
        RowBox[{"9", " ", "\[ImaginaryI]"}]}], 
       RowBox[{"21", "-", 
        RowBox[{"16", " ", "\[ImaginaryI]"}]}]},
      {"\<\"Rl =\"\>", "0", "0", "0", "0"},
      {"\<\"Rr =\"\>", "2", "1", "4", "3"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print"],

Cell[BoxData[
 TagBox[
  FormBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"\<\"shape no.\"\>", "1"},
      {"\<\"shA  =\"\>", "0"},
      {"\<\"shB  =\"\>", 
       RowBox[{"-", "22"}]},
      {"\<\"shAB =\"\>", "0"},
      {"\<\"shRl =\"\>", "0"},
      {"\<\"shRr =\"\>", 
       RowBox[{"-", "22"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"AB/B+Rl=A  \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"5", ",", "4", ",", "0", ",", "3"}], "}"}], 
   "\[InvisibleSpace]", "\<\"\\nAB/A+Rr=B  \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "4", ",", "3"}], "}"}]}],
  SequenceForm["AB/B+Rl=A  ", {5, 4, 0, 3}, "\nAB/A+Rr=B  ", {2, 1, 4, 3}],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell["\<\
\tThe projection of an algebra onto a sub=algebra (with fewer symmetries) \
corresponds to the qualitative change in a \"q-deformed\" algebra when the \
parameter \"q\" becomes 1, and in the equivalent \"h-deformed\" algebras when \
h (which is q-1) becomes zero.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Polar and Hyperbolic Duals.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["Abelian hoops have quadratic sizes that can be written as sums or \
differences of squared terms. In many cases, their cartesian forms can be \
converted to polar-duals or hyperbolic-duals in which each quadratic size is \
a squared radius (or \"ulna\" in the hyperbolic case) associated with an \
angle that can be calculated by an ArcTan (or ArcTanh) function. These duals \
generalise the complex plane; angles add on abelian multiplication.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tAbelian hoops have Polar, as well as Cartesian, forms because they have \
quadratic sizes that \"fragment\" into sums of squares. The polar form (here \
called ",
 StyleBox["pA",
  FontSlant->"Italic"],
 ") is given by ",
 StyleBox["toPolar[A]",
  FontSlant->"Italic"],
 ", and the cartesian form is recovered by ",
 StyleBox["toVector[pA]",
  FontSlant->"Italic"],
 ". The polar forms have squared radii and angles, and often involve linear \
\"offsets\" such as ",
 StyleBox["a+b+c, a+b+c+d, a-b+c-d",
  FontSlant->"Italic"],
 " that are conserved on addition as well as on multiplication The forms for \
the radii and angles are exemplified by those of C3 & C4:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 15.",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "Typical Polar-duals."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toPolar", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "\"\<C3\>\""}], 
  "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c"}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "-", "c"}], ")"}]}]}], "]"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toPolar", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", "\"\<C4\>\""}], 
  "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "d"}], ")"}], "2"]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"a", "-", "c"}], ",", 
     RowBox[{"b", "-", "d"}]}], "]"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tIn Figure 16, the C4 algebra is used to multiply arbitrary real A & B; the \
polar form pA=toPolar[A] is found; toVector[pA] is shown to recover A. The \
two linear offsets, the squared radii and the angles are tabulated for A, B, \
and AB. The zeroes in the last two lines show that sizes multiply and angles \
add:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 16.",
  FontWeight->"Bold"],
 " Interconversion between C4 vector & polar"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hoopShape", "[", "\"\<C4\>\"", "]"}], ";", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<A =\>\"", "}"}], ",", 
         RowBox[{"A", "=", 
          RowBox[{"{", 
           RowBox[{"2.", ",", "0.5", ",", "1.", ",", "0.1"}], "}"}]}]}], 
        "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<B =\>\"", "}"}], ",", 
         RowBox[{"B", "=", 
          RowBox[{"{", 
           RowBox[{"3.", ",", ".7", ",", "2.5", ",", ".5"}], "}"}]}]}], "]"}],
        "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<AB=\>\"", "}"}], ",", 
         RowBox[{"AB", "=", 
          RowBox[{"hoopTimes", "[", 
           RowBox[{"A", ",", "B"}], "]"}]}]}], "]"}], "]"}]}], "}"}], "//", 
    "tf"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Chop", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", " ", ",", "\"\<\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[SuperscriptBox[\")\", \"2\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[SuperscriptBox[\")\", \"2\"],
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"angle\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"or\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",
FontSlant->\"Italic\"]\)\>\""}], "}"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<pA=\>\"", "}"}], ",", 
        RowBox[{"pA", "=", 
         RowBox[{"toPolar", "[", "A", "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<toVector[pA]\>\"", "}"}], ",", 
        RowBox[{"toVector", "[", "pA", "]"}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<pB=\>\"", "}"}], ",", 
        RowBox[{"pB", "=", 
         RowBox[{"toPolar", "[", "B", "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<pAB=\>\"", "}"}], ",", 
        RowBox[{"pAB", "=", 
         RowBox[{"toPolar", "[", "AB", "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<pA pB-pAB\>\"", "}"}], ",", 
        RowBox[{
         RowBox[{"pA", " ", "pB"}], "-", "pAB"}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<pA+pB-pAB\>\"", "}"}], ",", 
        RowBox[{"pA", "+", "pB", "-", "pAB"}]}], "]"}], "]"}]}], "}"}], "]"}],
   "//", "tf"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"A =\"\>", "2.`", "0.5`", "1.`", "0.1`"},
     {"\<\"B =\"\>", "3.`", "0.7`", "2.5`", "0.5`"},
     {"\<\"AB=\"\>", "8.82`", "3.65`", "8.4`", "3.25`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\"+\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\
\"b\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"+\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"c\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"+\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\
\"b\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"+\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"c\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\
\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"c\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\")\\\", \
\\\"2\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"+\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"b\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\
SuperscriptBox[\\\")\\\", \\\"2\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"\\!\\(\\*\\nStyleBox[\\\"angle\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\
\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"or\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\"\>"},
     {"\<\"pA=\"\>", "3.6`", "2.4`", "1.1600000000000001`", 
      "0.3805063771123649`"},
     {"\<\"toVector[pA]\"\>", "2.`", "0.5000000000000001`", 
      "0.9999999999999999`", "0.09999999999999998`"},
     {"\<\"pB=\"\>", "6.7`", "4.3`", "0.29`", "0.3805063771123648`"},
     {"\<\"pAB=\"\>", "24.12`", "10.32`", "0.33639999999999987`", 
      "0.7610127542247297`"},
     {"\<\"pA pB-pAB\"\>", "0", "0", "0", 
      RowBox[{"-", "0.6162276512015525`"}]},
     {"\<\"pA+pB-pAB\"\>", 
      RowBox[{"-", "13.820000000000002`"}], 
      RowBox[{"-", "3.6200000000000006`"}], "1.1136000000000004`", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tSome algebras, with sizes expressible as linear terms equivalent to \
differences of squares, have hyperbolic dual formulations with hyperbolic \
angles and squared \"ulnae\" (named by analogy with radii). Thus the ",
 StyleBox["(a+b+c+d)",
  FontSlant->"Italic"],
 " and ",
 StyleBox["(a-b+c-d)",
  FontSlant->"Italic"],
 " sizes of the C4 algebra lead to conservation of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "+", "c"}], ")"}], "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"b", "+", "d"}], ")"}], "2"], TraditionalForm]]],
 " and a hyperbolic angle ",
 StyleBox["ArcTanh[a+c, b+d]",
  FontSlant->"Italic"],
 ". This has to be written in the logarithmic form for full generality, and \
the infinite case has to be allowed for in the calculation.\n\tExample 17 \
shows the hyperbolic form of Example 16. (It has to use \"local variables\" \
b$, x$ and y$ to handle special cases.) The polar components are unchanged, \
and the two linear sizes are replaced by an {ulna, hyperbolic angle} pair. \
The hyperbolic angles add on multiplication."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 17.",
  FontWeight->"Bold"],
 " Interconversion between vector & \"hypolar\". Hyperbolic angle addition. "
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\"\<tohyPolar[{a,b,c,d},C4] =\>\"", ",", 
    RowBox[{"tohyPolar", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
      "\"\<C4\>\""}], "]"}]}], "}"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Chop", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", " ", ",", "\"\<\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[SuperscriptBox[\")\", \"2\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[SuperscriptBox[\")\", \"2\"],
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"hyperangle\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"c\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[SuperscriptBox[\")\", \"2\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"+\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"b\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"-\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"d\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[SuperscriptBox[\")\", \"2\"],
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"angle\",
FontSlant->\"Italic\"]\)\>\""}], "}"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<hA=\>\"", "}"}], ",", 
        RowBox[{"hA", "=", 
         RowBox[{"tohyPolar", "[", "A", "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<Reverts to A\>\"", "}"}], ",", 
        RowBox[{"tohyVector", "[", "hA", "]"}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<hB=\>\"", "}"}], ",", 
        RowBox[{"hB", "=", 
         RowBox[{"tohyPolar", "[", "B", "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<hAB=\>\"", "}"}], ",", 
        RowBox[{"hAB", "=", 
         RowBox[{"tohyPolar", "[", "AB", "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<hA hB-hAB\>\"", "}"}], ",", 
        RowBox[{
         RowBox[{"hA", " ", "hB"}], "-", "hAB"}]}], "]"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "\"\<hA+hB-hAB\>\"", "}"}], ",", 
        RowBox[{"hA", "+", "hB", "-", "hAB"}]}], "]"}], "]"}]}], "}"}], "]"}],
   "//", "tf"}]}], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"tohyPolar[{a,b,c,d},C4] =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "d"}], ")"}], "2"]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", "+", "c"}], "\[Equal]", 
         RowBox[{"b", "+", "d"}]}], "||", 
        RowBox[{
         RowBox[{"a", "+", "c"}], "\[Equal]", 
         RowBox[{
          RowBox[{"-", "b"}], "-", "d"}]}]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x$381", "\[NotEqual]", "0"}], ",", 
         FractionBox[
          RowBox[{"\[Infinity]", " ", 
           RowBox[{"Sign", "[", "y$381", "]"}]}], 
          RowBox[{"Sign", "[", "x$381", "]"}]], ",", "0", ",", "0"}], "]"}], 
       ",", 
       RowBox[{
        RowBox[{"b$381", "=", 
         RowBox[{"Log", "[", 
          RowBox[{"N", "[", 
           FractionBox[
            RowBox[{"x$381", "+", "y$381"}], 
            SqrtBox[
             RowBox[{
              SuperscriptBox["x$381", "2"], "-", 
              SuperscriptBox["y$381", "2"]}]]], "]"}], "]"}]}], ";", 
        RowBox[{"Chop", "[", 
         RowBox[{
          RowBox[{"Re", "[", "b$381", "]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Chop", "[", 
            RowBox[{"Im", "[", "b$381", "]"}], "]"}]}]}], "]"}]}]}], "]"}], 
     ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "d"}], ")"}], "2"]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"a", "-", "c"}], ",", 
       RowBox[{"b", "-", "d"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\
\"+\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"c\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\")\\\", \
\\\"2\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"-\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"b\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\"+\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\
SuperscriptBox[\\\")\\\", \\\"2\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\
\<\"\\!\\(\\*\\nStyleBox[\\\"hyperangle\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\
\>", "\<\"\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\\
(\\*\\nStyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"\
c\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\"\
)\\\", \\\"2\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"+\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"(\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"b\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"-\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[\\\"d\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[SuperscriptBox[\\\")\\\", \
\\\"2\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"angle\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>"}\
,
     {"\<\"hA=\"\>", "8.64`", "0.20273255405408228`", "1.1600000000000001`", 
      "0.3805063771123649`"},
     {"\<\"Reverts to A\"\>", "2.0000000000000004`", "0.5000000000000002`", 
      "1.`", "0.10000000000000012`"},
     {"\<\"hB=\"\>", "28.81`", "0.22174625184870195`", "0.29`", 
      "0.3805063771123648`"},
     {"\<\"hAB=\"\>", "248.91839999999996`", "0.4244788059027839`", 
      "0.33639999999999987`", "0.7610127542247297`"},
     {"\<\"hA hB-hAB\"\>", "0", 
      RowBox[{"-", "0.3795236219135768`"}], "0", 
      RowBox[{"-", "0.6162276512015525`"}]},
     {"\<\"hA+hB-hAB\"\>", 
      RowBox[{"-", "211.46839999999997`"}], "0", "1.1136000000000004`", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\tMany non-abelian hoops have \"pseudo-polar-duals\" that revert correctly to \
the cartesian form, but do not have additive angles. This is because they \
have repeated determinant factors, and the pseudo-polar-duals are created by \
splitting a repeated quadratic into two sections that are not conserved \
independently. Figure 18 shows this for D3, the smallest non-abelian loop. \
The third size contains six squared fragments, 3 positive and 3 negative. \
These are used to create two {squared radius, angle} pairs that allow \
reversion but give neither conserved radii nor additive angles. Clifford \
algebras (and some other non-Abelian hoops) have vector rotation, pre- and \
post-multiplication by half-angles. Non-abelian multiplication may introduce \
uncertainty into the polar angles.\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 18.",
  FontWeight->"Bold"],
 " D3 has polar reversion without {radius,angle} conservation."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Figure", " ", "17."}], "*)"}], 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<Shape of D3 is\>\"", ",", 
     RowBox[{"hoopShape", "[", "\"\<D3\>\"", "]"}], ",", 
     "\"\<\\n\\ntoPolar D3 is\>\"", ",", "\[IndentingNewLine]", 
     RowBox[{"toPolar", "[", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}],
       "]"}]}], "}"}], "\[IndentingNewLine]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<A=\>\"", "}"}], ",", 
          RowBox[{"A", "=", 
           RowBox[{"{", 
            RowBox[{
            "3.", ",", "2.", ",", ".1", ",", "2.", ",", "1.", ",", ".4"}], 
            "}"}]}]}], "]"}], "]"}], ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<B=\>\"", "}"}], ",", 
          RowBox[{"B", "=", 
           RowBox[{"{", 
            RowBox[{"1.", ",", "3.", ",", 
             RowBox[{"-", ".1"}], ",", ".2", ",", 
             RowBox[{"-", "1."}], ",", "1."}], "}"}]}]}], "]"}], "]"}], ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<AB=\>\"", "}"}], ",", 
          RowBox[{"AB", "=", 
           RowBox[{"hoopTimes", "[", 
            RowBox[{"A", ",", "B"}], "]"}]}]}], "]"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<pA\>\"", "}"}], ",", 
          RowBox[{"pA", "=", 
           RowBox[{"toPolar", "[", "A", "]"}]}]}], "]"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<Revert pA\>\"", "}"}], ",", 
          RowBox[{"toVector", "[", "pA", "]"}]}], "]"}], "]"}], ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<pB\>\"", "}"}], ",", 
          RowBox[{"pB", "=", 
           RowBox[{"toPolar", "[", "B", "]"}]}]}], "]"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<Revert pB\>\"", "}"}], ",", 
          RowBox[{"toVector", "[", "pB", "]"}]}], "]"}], "]"}], ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<pAB\>\"", "}"}], ",", 
          RowBox[{"pAB", "=", 
           RowBox[{"toPolar", "[", "AB", "]"}]}]}], "]"}], "]"}], ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<pA+pB-pAB\>\"", "}"}], ",", 
          RowBox[{"pA", "+", "pB", "-", "pAB"}]}], "]"}], "]"}], ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<pA*pB-pAB\>\"", "}"}], ",", 
          RowBox[{"Chop", "[", 
           RowBox[{
            RowBox[{"pA", "*", "pB"}], "-", "pAB"}], "]"}]}], "]"}], "]"}], 
       ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"{", "\"\<pA+pB+pAB\>\"", "}"}], ",", 
          RowBox[{"Chop", "[", 
           RowBox[{"pA", "+", "pB", "+", "pAB"}], "]"}]}], "]"}], "]"}]}], 
      "}"}], "//", "tf"}], ")"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Shape of D3 is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
     RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "c"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "e"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d", "-", "f"}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "b"}], "+", "f"}], ")"}], "2"]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\n\\ntoPolar D3 is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
     RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "e"}], ")"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "d"}], ")"}], "2"]}], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "f"}], ")"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "b"}], "+", "f"}], ")"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "c", "-", "e"}], ",", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "c"}], "+", "e"}], ")"}]}]}], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"c", "-", "e"}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "e"}], ")"}], "2"]}], ")"}]}], ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "b"}], "-", "d", "-", "f"}], ",", 
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "d"}], "+", "f"}], ")"}]}]}], "]"}]}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"A=\"\>", "3.`", "2.`", "0.1`", "2.`", "1.`", "0.4`"},
     {"\<\"B=\"\>", "1.`", "3.`", 
      RowBox[{"-", "0.1`"}], "0.2`", 
      RowBox[{"-", "1.`"}], "1.`"},
     {"\<\"AB=\"\>", "9.600000000000001`", "10.7`", "6.88`", "1.86`", 
      "1.5900000000000003`", "4.22`"},
     {"\<\"pA\"\>", "8.5`", 
      RowBox[{"-", "0.2999999999999998`"}], "4.05`", "0.30800734320987755`", 
      "6.61`", 
      RowBox[{"-", "1.0471975511965976`"}]},
     {"\<\"Revert pA\"\>", "3.`", "2.`", "0.10000000000000009`", "2.`", 
      "1.0000000000000002`", "0.3999999999999999`"},
     {"\<\"pB\"\>", "4.1`", 
      RowBox[{"-", "4.300000000000001`"}], 
      RowBox[{"-", "3.23`"}], 
      RowBox[{"-", "0.4659277707138729`"}], "3.0100000000000002`", 
      "0.2810349015028136`"},
     {"\<\"Revert pB\"\>", "0.9999999999999998`", "3.`", 
      RowBox[{"-", "0.09999999999999994`"}], "0.20000000000000018`", 
      RowBox[{"-", "1.`"}], "1.0000000000000004`"},
     {"\<\"pAB\"\>", "34.85`", "1.2900000000000027`", 
      RowBox[{"-", "13.081499999999984`"}], 
      RowBox[{"-", "0.7067647371985015`"}], "49.77130000000001`", 
      "0.2607429503865873`"},
     {"\<\"pA+pB-pAB\"\>", 
      RowBox[{"-", "22.25`"}], 
      RowBox[{"-", "5.890000000000003`"}], "13.901499999999984`", 
      "0.5488443096945061`", 
      RowBox[{"-", "40.15130000000001`"}], 
      RowBox[{"-", "1.0269056000803714`"}]},
     {"\<\"pA*pB-pAB\"\>", "0", "0", "0", "0.5632555624132205`", 
      RowBox[{"-", "29.875200000000007`"}], 
      RowBox[{"-", "0.5550420110411107`"}]},
     {"\<\"pA+pB+pAB\"\>", "47.45`", 
      RowBox[{"-", "3.309999999999998`"}], 
      RowBox[{"-", "12.261499999999984`"}], 
      RowBox[{"-", "0.8646851647024969`"}], "59.39130000000001`", 
      RowBox[{"-", "0.5054196993071967`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 19.",
  FontWeight->"Bold"],
 " Clifford(2) Algebra has pseudo-polar reversion but angles do not add.\n\t\t\
(See CliffordGA.m for Clifford Rotations.)"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Figure", " ", "19."}], "*)"}], 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<Clifford(2) Shape is \>\"", ",", 
     RowBox[{"hoopShape", "[", "\"\<CL2\>\"", "]"}]}], "}"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<A=\>\"", "}"}], ",", 
         RowBox[{"A", "=", 
          RowBox[{"{", 
           RowBox[{"3.", ",", "2.", ",", ".1", ",", ".3"}], "}"}]}]}], "]"}], 
       "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<B=\>\"", "}"}], ",", 
         RowBox[{"B", "=", 
          RowBox[{"{", 
           RowBox[{"1.", ",", "3.", ",", 
            RowBox[{"-", ".1"}], ",", ".7"}], "}"}]}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<AB=\>\"", "}"}], ",", 
         RowBox[{"AB", "=", 
          RowBox[{"hoopTimes", "[", 
           RowBox[{"A", ",", "B"}], "]"}]}]}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<pA\>\"", "}"}], ",", 
         RowBox[{"pA", "=", 
          RowBox[{"toPolar", "[", "A", "]"}]}]}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<Revert pA\>\"", "}"}], ",", 
         RowBox[{"Chop", "[", 
          RowBox[{"toVector", "[", "pA", "]"}], "]"}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<pB\>\"", "}"}], ",", 
         RowBox[{"pB", "=", 
          RowBox[{"toPolar", "[", "B", "]"}]}]}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<Revert pB\>\"", "}"}], ",", 
         RowBox[{"Chop", "[", 
          RowBox[{"toVector", "[", "pB", "]"}], "]"}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<pAB\>\"", "}"}], ",", 
         RowBox[{"pAB", "=", 
          RowBox[{"toPolar", "[", "AB", "]"}]}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<pA+pB-pAB\>\"", "}"}], ",", 
         RowBox[{"pA", "+", "pB", "-", "pAB"}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<pA+pB+pAB\>\"", "}"}], ",", 
         RowBox[{"Chop", "[", 
          RowBox[{"pA", "+", "pB", "+", "pAB"}], "]"}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<BA=\>\"", "}"}], ",", 
         RowBox[{"BA", "=", 
          RowBox[{"hoopTimes", "[", 
           RowBox[{"B", ",", "A"}], "]"}]}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<pBA\>\"", "}"}], ",", 
         RowBox[{"pBA", "=", 
          RowBox[{"toPolar", "[", "BA", "]"}]}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<pA+pB-pBA\>\"", "}"}], ",", 
         RowBox[{"pA", "+", "pB", "-", "pBA"}]}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"{", "\"\<pA+pB+pBA\>\"", "}"}], ",", 
         RowBox[{"Chop", "[", 
          RowBox[{"pA", "+", "pB", "+", "pBA"}], "]"}]}], "]"}], "]"}]}], 
     "}"}], "//", "tf"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Clifford(2) Shape is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox["d", "2"]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"A=\"\>", "3.`", "2.`", "0.1`", "0.3`"},
     {"\<\"B=\"\>", "1.`", "3.`", 
      RowBox[{"-", "0.1`"}], "0.7`"},
     {"\<\"AB=\"\>", "9.22`", "11.1`", "0.30000000000000004`", 
      "1.8999999999999997`"},
     {"\<\"pA\"\>", "4.92`", "0.033320995878247196`", "4.09`", 
      "0.14888994760949725`"},
     {"\<\"Revert pA\"\>", "3.`", "2.`", "0.09999999999999998`", 
      "0.30000000000000004`"},
     {"\<\"pB\"\>", 
      RowBox[{"-", "8.48`"}], 
      RowBox[{"-", "0.09966865249116204`"}], "9.49`", 
      "0.22923193327699531`"},
     {"\<\"Revert pB\"\>", "0.9999999999999999`", "3.`", 
      RowBox[{"-", "0.1`"}], "0.7`"},
     {"\<\"pAB\"\>", 
      RowBox[{"-", "41.72159999999998`"}], "0.03252648539175909`", "126.82`", 
      "0.16952821145792177`"},
     {"\<\"pA+pB-pAB\"\>", "38.16159999999998`", 
      RowBox[{"-", "0.09887414200467395`"}], 
      RowBox[{"-", "113.24`"}], "0.2085936694285708`"},
     {"\<\"pA+pB+pAB\"\>", 
      RowBox[{"-", "45.28159999999998`"}], 
      RowBox[{"-", "0.03382117122115575`"}], "140.4`", 
      "0.5476500923444143`"},
     {"\<\"BA=\"\>", "9.22`", "10.9`", 
      RowBox[{"-", "0.7000000000000001`"}], "2.8999999999999995`"},
     {"\<\"pBA\"\>", 
      RowBox[{"-", "41.721599999999995`"}], 
      RowBox[{"-", "0.07577653658853419`"}], "127.22`", 
      "0.26003128958213206`"},
     {"\<\"pA+pB-pBA\"\>", "38.16159999999999`", "0.009428879975619343`", 
      RowBox[{"-", "113.64`"}], "0.1180905913043605`"},
     {"\<\"pA+pB+pBA\"\>", 
      RowBox[{"-", "45.2816`"}], 
      RowBox[{"-", "0.14212419320144903`"}], "140.8`", "0.6381531704686246`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
\tSection 12 returns to duals, showing that they create \"orbits\".\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. Powers, Roots, Quadratic equations.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["Multiplication of polar-duals multiplies sizes and (if abelian) \
adds angles. This generalizes to powers and roots, in which the sizes are \
raised to the exponent and angles are multiplied by the exponent. Quadratic \
equations can be solved via square roots. If angles exceed 2\[Pi] the results \
are rotated vectors with the correct sizes.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["\tAbelian Hoops with polar-duals or hyperbolic-duals have powers \
and roots. (The others may have higher analogues using",
  FontSlant->"Plain"],
 StyleBox[" pseudo",
  FontSlant->"Plain"],
 "-",
 StyleBox["polar-duals, but I have not found them.)  ",
  FontSlant->"Plain"],
 "hoopPower[A,p]",
 StyleBox[" raises A to the power ",
  FontSlant->"Plain"],
 "p",
 StyleBox[", giving the square root if no power is specified. A dual of the \
algebra must be known, because powers involve the multiplication of the \
angle(s) by the exponent. If the result exceeds 2\[Pi], recovering a root \
will give a rotated value with the same sizes.\n",
  FontSlant->"Plain"],
 StyleBox["Figure 20.",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 StyleBox[" Squaring the C3 square root recovers the original. :-",
  FontSlant->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hoopShape", "[", "\"\<C3\>\"", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{"\"\<A=\>\"", ",", 
    RowBox[{"A", "=", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "4."}], "}"}]}], ",", 
    "\"\<\\nIn C3, \!\(\*SqrtBox[\(A\)]\) =\>\"", ",", 
    RowBox[{"RootA", "=", 
     RowBox[{"hoopPower", "[", "A", "]"}]}], ",", 
    "\"\<\\n(\!\(\*SqrtBox[\(A\)]\)\!\(\*SuperscriptBox[\()\), \(2\)]\) \
=\>\"", ",", 
    RowBox[{"hoopPower", "[", 
     RowBox[{"RootA", ",", "2"}], "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "4.`"}], "}"}], 
   ",", "\<\"\\nIn C3, \\!\\(\\*SqrtBox[\\(A\\)]\\) =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.7789046383311686`", ",", 
     RowBox[{"-", "0.07325649775906365`"}], ",", "1.1227789841740856`"}], 
    "}"}], ",", "\<\"\\n(\\!\\(\\*SqrtBox[\\(A\\)]\\)\\!\\(\\*SuperscriptBox[\
\\()\\), \\(2\\)]\\) =\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3.000000000000001`", ",", "1.0000000000000009`", ",", 
     "4.000000000000001`"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 21.",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 StyleBox[" ",
  FontSlant->"Plain"],
 " Powers give rotated roots for vectors with high angles."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Example", " ", "7", 
    RowBox[{"b", "."}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"hoopShape", "[", "\"\<C4\>\"", "]"}], ";", 
   RowBox[{"{", 
    RowBox[{"\"\<A=\>\"", ",", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{"1.6", ",", "1", ",", "1.4", ",", "0"}], "}"}]}], ",", 
     "\"\<\\nIn C4, shape[\!\(\*
StyleBox[\"A\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",
FontSlant->\"Italic\"]\) is \>\"", ",", 
     RowBox[{"shape", "[", "A", "]"}], ",", "\"\<\\n     and polar A is\>\"", 
     ",", " ", 
     RowBox[{"toPolar", "[", "A", "]"}], ",", 
     "\"\<\\n     with angle             1.3734 \[UpArrow]\\n\!\(\*
StyleBox[SuperscriptBox[\"A\", \"2\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)is \>\"", ",", 
     RowBox[{"SquareA", "=", 
      RowBox[{"hoopPower", "[", 
       RowBox[{"A", ",", "2"}], "]"}]}], ",", "\"\<\\nwith Polar-dual\>\"", 
     ",", 
     RowBox[{"toPolar", "[", "SquareA", "]"}], ",", 
     "\"\<\\nwith squared sizes & doubled angle \[UpArrow].\\nThe square root \
recovers \!\(\*
StyleBox[\"A\",
FontSlant->\"Italic\"]\)\>\"", ",", 
     RowBox[{"hoopPower", "[", "SquareA", "]"}], ",", "\"\<\\n\!\(\*
StyleBox[SuperscriptBox[\"A\", \"3\"],
FontSlant->\"Italic\"]\) takes the angle beyond 2\[Pi] \\n\!\(\*
StyleBox[SuperscriptBox[\"A\", \"3\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)is \>\"", ",", 
     RowBox[{"CubeA", "=", 
      RowBox[{"hoopPower", "[", 
       RowBox[{"A", ",", "3"}], "]"}]}], ",", "\"\<\\nWith Polar-dual\>\"", 
     ",", 
     RowBox[{"toPolar", "[", "CubeA", "]"}], ",", 
     "\"\<\\nNow the cube root of \!\(\*
StyleBox[SuperscriptBox[\"A\", \"3\"],
FontSlant->\"Italic\"]\)\>\"", ",", 
     RowBox[{"A3", "=", 
      RowBox[{"hoopPower", "[", 
       RowBox[{"CubeA", ",", 
        RowBox[{"1", "/", "3"}]}], "]"}]}], ",", 
     "\"\<has the same sizes but a rotated angle\>\"", ",", 
     RowBox[{"Chop", "[", 
      RowBox[{"toPolar", "[", "A3", "]"}], "]"}]}], "}"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.6`", ",", "1", ",", "1.4`", ",", "0"}], "}"}], 
   ",", "\<\"\\nIn C4, \
shape[\\!\\(\\*\\nStyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", "2.`", ",", "1.04`"}], "}"}], 
   ",", "\<\"\\n     and polar A is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", "2.`", ",", "1.04`", ",", "1.3734007669450157`"}], 
    "}"}], ",", "\<\"\\n     with angle             1.3734 \
\[UpArrow]\\n\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\"A\\\", \
\\\"2\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4.52`", ",", "3.2`", ",", "5.48`", ",", "2.8`"}], "}"}], 
   ",", "\<\"\\nwith Polar-dual\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "16.`", ",", "4.`", ",", "1.081600000000002`", ",", 
     "2.746801533890032`"}], "}"}], 
   ",", "\<\"\\nwith squared sizes & doubled angle \[UpArrow].\\nThe square \
root recovers \\!\\(\\*\\nStyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1.6`", ",", "1.0000000000000002`", ",", "1.4`", ",", "0"}], 
    "}"}], ",", "\<\"\\n\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\"A\\\", \
\\\"3\\\"],\\nFontSlant->\\\"Italic\\\"]\\) takes the angle beyond 2\[Pi] \\n\
\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\"A\\\", \
\\\"3\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)is \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"17.704`", ",", "13.56`", ",", "18.296`", ",", "14.44`"}], "}"}], 
   ",", "\<\"\\nWith Polar-dual\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"64.`", ",", "8.`", ",", "1.1248639999999968`", ",", 
     RowBox[{"-", "2.1629830063445383`"}]}], "}"}], 
   ",", "\<\"\\nNow the cube root of \
\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\"A\\\", \
\\\"3\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "1.883012701892219`", ",", "0.16339745962155627`", ",", 
     "1.1169872981077806`", ",", "0.8366025403784434`"}], "}"}], 
   ",", "\<\"has the same sizes but a rotated angle\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3.999999999999999`", ",", "2.`", ",", "1.0399999999999987`", ",", 
     RowBox[{"-", "0.7209943354481794`"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tQPower calculates powers in the quaternion algebra (28/1/05), and handles \
complex (biquaternion) elements. It multiplies the angle ",
 StyleBox["t",
  FontSlant->"Italic"],
 " by the power ",
 StyleBox["n",
  FontSlant->"Italic"],
 ". It may lead to better ",
 StyleBox["topolar & toVector",
  FontSlant->"Italic"],
 " formulations for quaternion & other non-abelian hoops; the current \
formulations do not have angle addition. Clifford algebras (and, perhaps, \
some other non-commutative hoops) perform rotations via pre- and post- \
multiplication by a half-angle \"rotor\"."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 22.",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 " QPower works with biquaternions (quaternions over the complex field)."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<A =       \>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{".6", "-", 
       RowBox[{".1", "\[ImaginaryI]"}]}], ",", ".5", ",", ".3", ",", 
      RowBox[{
       RowBox[{"-", ".2"}], "\[ImaginaryI]"}]}], "}"}]}], ",", 
   "\"\<\\nrootA = \>\"", ",", 
   RowBox[{"rA", "=", 
    RowBox[{"QPower", "[", 
     RowBox[{"A", ",", 
      RowBox[{"1", "/", "2"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   "\"\<\\n(rootA\!\(\*SuperscriptBox[\()\), \(2\)]\) = \>\"", ",", 
   RowBox[{"Chop", "[", 
    RowBox[{"QPower", "[", 
     RowBox[{"rA", ",", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   "\"\<\\n\!\(\*SuperscriptBox[\(A\), \(2\)]\)     =   \>\"", ",", 
   RowBox[{"AA", "=", 
    RowBox[{"Chop", "[", 
     RowBox[{"QPower", "[", 
      RowBox[{"A", ",", "2"}], "]"}], "]"}]}], ",", 
   "\"\<\\n\!\(\*SqrtBox[SuperscriptBox[\(A\), \(2\)]]\)   =   \>\"", ",", 
   RowBox[{"Chop", "[", 
    RowBox[{"QPower", "[", 
     RowBox[{"AA", ",", 
      RowBox[{"1", "/", "2"}]}], "]"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A =       \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.6`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ",", "0.5`", ",", "0.3`", ",",
      
     RowBox[{
      RowBox[{"-", "0.2`"}], " ", "\[ImaginaryI]"}]}], "}"}], 
   ",", "\<\"\\nrootA = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.8411243957355754`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.05174871201067143`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.2961004243225318`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.018217062377681108`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.17766025459351908`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.010930237426608666`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.0072868249510724455`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.11844016972901276`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", "\<\"\\n(rootA\\!\\(\\*SuperscriptBox[\\()\\), \\(2\\)]\\) = \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.6000000000000001`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.09999999999999999`", " ", "\[ImaginaryI]"}]}], ",", 
     "0.5000000000000001`", ",", "0.3000000000000001`", ",", 
     RowBox[{
      RowBox[{"-", "0.20000000000000018`"}], " ", "\[ImaginaryI]"}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*SuperscriptBox[\\(A\\), \\(2\\)]\\)     =   \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.05000000000000004`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.11999999999999997`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.6`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.36`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.06`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.040000000000000015`"}], "-", 
      RowBox[{"0.24000000000000005`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
    "\<\"\\n\\!\\(\\*SqrtBox[SuperscriptBox[\\(A\\), \\(2\\)]]\\)   =   \"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.6000000000000001`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ",", "0.5000000000000001`", 
     ",", "0.30000000000000004`", ",", 
     RowBox[{
      RowBox[{"-", "0.2000000000000001`"}], " ", "\[ImaginaryI]"}]}], "}"}]}],
   "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tQuadratics can be solved in algebras that have powers. ",
 StyleBox["Figure",
  FontSlant->"Plain"],
 " 23 sets up three random C4 vectors A, B, C. Then ",
 StyleBox["genQuadratic",
  FontSlant->"Italic"],
 " is used to solve A ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "2"], TraditionalForm]]],
 "+B ",
 StyleBox["X ",
  FontSlant->"Italic"],
 "== C. Substituting the two results into A ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "2"], TraditionalForm]]],
 "+B ",
 StyleBox["X",
  FontSlant->"Italic"],
 " shows that they are both solutions. Calculating C from  A ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Xo", "2"], TraditionalForm]]],
 "+B Xo = C and solving for X often does not give Xo as one of the solutions \
because negative sizes and large angles can result in many different \
solutions. The next example uses random coefficients in the range [0.,1.] for \
A, B, & C. Two solutions are found, and validated by recovering C."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 23.",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 " Solving a random quadratic equation in C4,  K, O2,  & C4C2r"
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
Often fails to find the expected answer, due to multiplicity of solutions \
with the same sizes.\
\>", "Text",
 FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "\"\<C4\>\"", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{"\"\<A=\>\"", ",", 
    RowBox[{"A", "=", 
     RowBox[{"{", 
      RowBox[{"12", ",", "8", ",", "9", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], ",", "\"\<\\n B=\>\"", ",", 
    RowBox[{"B", "=", 
     RowBox[{"{", 
      RowBox[{"7", ",", "9", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
    "\"\<\\n C=\>\"", ",", 
    RowBox[{"Cc", "=", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "4", ",", "1."}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    "\"\<\\nC4 Solutions for x if A \!\(\*SuperscriptBox[\(x\), \(2\)]\)+B \
x=C:-\\n\>\"", ",", 
    RowBox[{"result", "=", 
     RowBox[{"genQuadratic", "[", 
      RowBox[{"A", ",", "B", ",", "Cc"}], "]"}]}], ",", 
    "\"\<A \!\(\*SuperscriptBox[\(x\), \(2\)]\)+B x recovers C in both \
cases:-\\n\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"result", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"B", "+", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"result", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"result", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"B", "+", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"result", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "8", ",", "9", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", "\<\"\\n B=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "9", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", "\<\"\\n C=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "6", ",", "4", ",", "1.`"}], "}"}], 
   ",", "\<\"\\nC4 Solutions for x if A \\!\\(\\*SuperscriptBox[\\(x\\), \\(2\
\\)]\\)+B x=C:-\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.3506822341683291`", ",", "0.12666742374608164`", ",", 
       "0.03294838678788307`", ",", 
       RowBox[{"-", "0.01029804470229384`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.093539377025472`"}], ",", 
       RowBox[{"-", "0.1361912332698912`"}], ",", "0.4241944703549741`", ",", 
       
       RowBox[{"-", "0.26589243148818237`"}]}], "}"}]}], "}"}], 
   ",", "\<\"A \\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)+B x recovers C in \
both cases:-\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "4.`", ",", "5.999999999999999`", ",", "4.`", ",", 
     "1.0000000000000016`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "4.`", ",", "6.`", ",", "4.000000000000001`", ",", 
     "1.0000000000000018`"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "\"\<K\>\"", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{
   "\"\<K Solutions for x if A \!\(\*SuperscriptBox[\(x\), \(2\)]\)+B \
x=C:-\\n\>\"", ",", 
    RowBox[{"result", "=", 
     RowBox[{"genQuadratic", "[", 
      RowBox[{"A", ",", "B", ",", "Cc"}], "]"}]}], ",", 
    "\"\<A \!\(\*SuperscriptBox[\(x\), \(2\)]\)+B x recovers C in both \
cases:-\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"result", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"B", "+", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"result", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"result", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"B", "+", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"result", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"K Solutions for x if A \\!\\(\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)+B x=C:-\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06915083668919719`"}], ",", "0.4497978669250322`", ",",
        "0.4527814576454093`", ",", 
       RowBox[{"-", "0.3334284878812444`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5737063061679457`"}], ",", 
       RowBox[{"-", "0.7593216764488417`"}], ",", 
       RowBox[{"-", "0.09563860050255213`"}], ",", "0.3572380116907682`"}], 
      "}"}]}], "}"}], 
   ",", "\<\"A \\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)+B x recovers C in \
both cases:-\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "3.9999999999999987`", ",", "5.9999999999999964`", ",", 
     "3.9999999999999973`", ",", "1.0000000000000009`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "4.000000000000002`", ",", "5.999999999999998`", ",", 
     "3.9999999999999987`", ",", "1.0000000000000013`"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "\"\<O2\>\"", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{
   "\"\<O2 Solutions for x if A \!\(\*SuperscriptBox[\(x\), \(2\)]\)+B \
x=C:-\\n\>\"", ",", 
    RowBox[{"result", "=", 
     RowBox[{"genQuadratic", "[", 
      RowBox[{"A", ",", "B", ",", "Cc"}], "]"}]}], ",", 
    "\"\<A \!\(\*SuperscriptBox[\(x\), \(2\)]\)+B x recovers C in both \
cases:-\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"result", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"B", "+", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"result", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"result", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"B", "+", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"result", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"O2 Solutions for x if A \\!\\(\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)+B x=C:-\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.4015855484243147`", ",", "0.0946579063267217`", ",", 
       "0.08385170104386858`", ",", 
       RowBox[{"-", "0.04230756212165385`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.2301569769957434`"}], ",", 
       RowBox[{"-", "0.07561028727910268`"}], ",", "0.2875768703847029`", ",",
        
       RowBox[{"-", "0.2053114854973937`"}]}], "}"}]}], "}"}], 
   ",", "\<\"A \\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)+B x recovers C in \
both cases:-\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "4.000000000000001`", ",", "6.000000000000002`", ",", 
     "4.000000000000001`", ",", "1.000000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "4.000000000000001`", ",", "6.000000000000002`", ",", 
     "4.000000000000003`", ",", "1.000000000000002`"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"id", "[", "\"\<C4C2r\>\"", "]"}], ";", 
  RowBox[{"{", 
   RowBox[{
   "\"\<C4C2r Solutions for x if A \!\(\*SuperscriptBox[\(x\), \(2\)]\)+B \
x=C:-\\n\>\"", ",", 
    RowBox[{"result", "=", 
     RowBox[{"genQuadratic", "[", 
      RowBox[{"A", ",", "B", ",", "Cc"}], "]"}]}], ",", 
    "\"\<A \!\(\*SuperscriptBox[\(x\), \(2\)]\)+B x recovers C in both \
cases:-\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"result", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"B", "+", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"result", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Chop", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{
       RowBox[{"result", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"B", "+", 
        RowBox[{"hoopTimes", "[", 
         RowBox[{"A", ",", 
          RowBox[{"result", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C4C2r Solutions for x if A \\!\\(\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)+B x=C:-\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.4896860240123267`", ",", "0.07282445416966857`", ",", 
       "0.017137988320277568`", ",", "0.15623065269524933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.2359503918284185`"}], ",", 
       RowBox[{"-", "0.10931870704323163`"}], ",", "0.5124597128291476`", ",",
        "0.19060842776452064`"}], "}"}]}], "}"}], 
   ",", "\<\"A \\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)+B x recovers C in \
both cases:-\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
    "4.0000000000000036`", ",", "6.000000000000002`", ",", 
     "3.9999999999999964`", ",", "1.0000000000000018`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "4.000000000000001`", ",", "5.999999999999995`", ",", 
     "3.9999999999999933`", ",", "1.000000000000004`"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. Many Moufang Loops \"Collapse\"  to Hoops.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary.",
 StyleBox[" Hoops are obtained from Moufang loops. These act on sets of \
unsigned coefficients; Algebras operate on signed vectors, usually sets of \
real or complex numbers. Real numbers are obtained from pairs of unsigned \
numbers via a \"folding\" equivalence relationship, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["r",
     FontSlant->"Italic"], "i"], TraditionalForm]]],
 StyleBox["~ {",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[",",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox["}; this halves the number of coefficients, and halves the number \
of elements in Moufang loops with 2-fold symmetry - it \"folds\" the loop to \
an algebra. The results may be either smaller Moufang loops, or signed \
multiplication tables such as those for Complex & Quaternion algebras. Most \
of the non-associative Moufang loops [4] are not conservative; only a few \
describe hoops (all associative loops are related to groups and so describe \
hoops).",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tHoops are obtained from conservative Moufang Loops (i.e. all groups and a \
few non-associative cases), inheriting vector multiplication and division \
from them. The definition of Moufang loops does not involve signs, so they \
multiply (and divide) sets of unsigned coefficients, but they are not \
algebras because they lack a second operation. They only become algebras if \
generalized signs are introduced, as equivalence relations on sets of \
coefficients,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["h",
     FontSlant->"Plain"], "i"], TraditionalForm]]],
 "~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "r"}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"2", 
      RowBox[{"m", "/", "r"}]}]}]], TraditionalForm]]],
 ", ..} ~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "r"}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"2", 
      RowBox[{"m", "/", "r"}]}]}]], TraditionalForm]]],
 ", ...}. The general case is discussed in Section 9, but the commonest \
cases, ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2 or 4, are developed here. ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2 gives half the number of real coefficients, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["r",
      FontSlant->"Plain"], "i"], " "}], TraditionalForm]]],
 "~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "} ~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "} iff ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["a", "i"]}], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 ". The ",
 StyleBox["m\[Times]m",
  FontSlant->"Italic"],
 " table \"folds\" to an ",
 StyleBox["(m/r\[Times]m/r)",
  FontSlant->"Italic"],
 " table, which may a smaller (unsigned) Moufang loop or a signed table in \
which some products are signed. Thus C4 is a hoop over the real field because \
it can be regarded as the folded version of C4C2; the highlights in the \
illustration of C4C2 (figure 24) give the C4 table. C4 is also a loop that \
fold to complex algebra, \[DoubleStruckCapitalC]. This is shown by mapping \
{1,\[ImaginaryI],-1,-\[ImaginaryI]} onto the C4 table, and highlighting the \
complex multiplication table that results from folding. This matches the \
signed C4c table, which is complex multiplication.\n\n",
 StyleBox["Figure 24.",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 " Collapsing Moufang Tables to Hoops."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[GridBox[{
   {"C4C2", "1", "2", "3", "4", 
    StyleBox["5",
     FontWeight->"Plain"], 
    StyleBox["6",
     FontWeight->"Plain"], 
    StyleBox["7",
     FontWeight->"Plain"], 
    StyleBox["8",
     FontWeight->"Plain"]},
   {" ", "2", "3", "4", "1", 
    StyleBox["6",
     FontWeight->"Plain"], 
    StyleBox["7",
     FontWeight->"Plain"], 
    StyleBox["8",
     FontWeight->"Plain"], 
    StyleBox["5",
     FontWeight->"Plain"]},
   {" ", "3", "4", "1", "2", 
    StyleBox["7",
     FontWeight->"Plain"], 
    StyleBox["8",
     FontWeight->"Plain"], 
    StyleBox["5",
     FontWeight->"Plain"], 
    StyleBox["6",
     FontWeight->"Plain"]},
   {" ", "4", "1", "2", "3", 
    StyleBox["8",
     FontWeight->"Plain"], 
    StyleBox["5",
     FontWeight->"Plain"], 
    StyleBox["6",
     FontWeight->"Plain"], 
    StyleBox["7",
     FontWeight->"Plain"]},
   {" ", 
    StyleBox["5",
     FontWeight->"Plain"], 
    StyleBox["6",
     FontWeight->"Plain"], 
    StyleBox["7",
     FontWeight->"Plain"], 
    StyleBox["8",
     FontWeight->"Plain"], 
    StyleBox["1",
     FontWeight->"Plain"], 
    StyleBox["2",
     FontWeight->"Plain"], 
    StyleBox["3",
     FontWeight->"Plain"], 
    StyleBox["4",
     FontWeight->"Plain"]},
   {" ", 
    StyleBox["6",
     FontWeight->"Plain"], 
    StyleBox["7",
     FontWeight->"Plain"], 
    StyleBox["8",
     FontWeight->"Plain"], 
    StyleBox["5",
     FontWeight->"Plain"], 
    StyleBox["2",
     FontWeight->"Plain"], 
    StyleBox["3",
     FontWeight->"Plain"], 
    StyleBox["4",
     FontWeight->"Plain"], 
    StyleBox["1",
     FontWeight->"Plain"]},
   {" ", 
    StyleBox["7",
     FontWeight->"Plain"], 
    StyleBox["8",
     FontWeight->"Plain"], 
    StyleBox["5",
     FontWeight->"Plain"], 
    StyleBox["6",
     FontWeight->"Plain"], 
    StyleBox["3",
     FontWeight->"Plain"], 
    StyleBox["4",
     FontWeight->"Plain"], 
    StyleBox["1",
     FontWeight->"Plain"], 
    StyleBox["2",
     FontWeight->"Plain"]},
   {" ", 
    StyleBox["8",
     FontWeight->"Plain"], 
    StyleBox["5",
     FontWeight->"Plain"], 
    StyleBox["6",
     FontWeight->"Plain"], 
    StyleBox["7",
     FontWeight->"Plain"], 
    StyleBox["4",
     FontWeight->"Plain"], 
    StyleBox["1",
     FontWeight->"Plain"], 
    StyleBox["2",
     FontWeight->"Plain"], 
    StyleBox["3",
     FontWeight->"Plain"]}
  }]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[GridBox[{
   {"C4", "1", "\[ImaginaryI]", 
    StyleBox[
     RowBox[{"-", "1"}],
     FontWeight->"Plain"], 
    StyleBox[
     RowBox[{"-", "\[ImaginaryI]"}],
     FontWeight->"Plain"], " ", "C4c", "1", "2", " ", 
    "\[DoubleStruckCapitalC]", "1", "\[ImaginaryI]"},
   {" ", "\[ImaginaryI]", 
    RowBox[{"-", "1"}], 
    StyleBox[
     RowBox[{"-", "\[ImaginaryI]"}],
     FontWeight->"Plain"], 
    StyleBox["1",
     FontWeight->"Plain"], " ", " ", "2", 
    RowBox[{"-", "1"}], " ", " ", "\[ImaginaryI]", 
    RowBox[{"-", "1"}]},
   {" ", 
    StyleBox[
     RowBox[{"-", "1"}],
     FontWeight->"Plain"], 
    StyleBox[
     RowBox[{"-", "\[ImaginaryI]"}],
     FontWeight->"Plain"], 
    StyleBox["1",
     FontWeight->"Plain"], 
    StyleBox["\[ImaginaryI]",
     FontWeight->"Plain"], " ", " ", " ", "  ", " ", " ", " ", " "},
   {" ", 
    StyleBox[
     RowBox[{"-", "\[ImaginaryI]"}],
     FontWeight->"Plain"], 
    StyleBox["1",
     FontWeight->"Plain"], 
    StyleBox["\[ImaginaryI]",
     FontWeight->"Plain"], 
    StyleBox[
     RowBox[{"-", "1"}],
     FontWeight->"Plain"], " ", " ", " ", " ", " ", " ", " ", " "}
  }]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\"A =\"\>", "2.`", "0.5`", "1.`", "0.1`"},
     {"\<\"B =\"\>", "3.`", "0.7`", "2.5`", "0.5`"},
     {"\<\"AB=\"\>", "8.82`", "3.65`", "8.4`", "3.25`"}
    }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "The C4 multiplication of {2., 0.5, 1., 0.1} and {3., .7, 2.5, .5} (in Fig. \
16) gave {8.82, 3.65, 8.4, 3.25}. These vectors fold to complex numbers \
(2-1)+(.5-.1)\[ImaginaryI] and (3-2.5)+(.7-.5)\[ImaginaryI], with product \
(8.82-8.4)+(3.65-3.25)\[ImaginaryI]; i.e. (1+.4\[ImaginaryI])(.5+.2\
\[ImaginaryI]) = .42+.4\[ImaginaryI]. \nThis is confirmed in ",
 StyleBox["Figure 25:-",
  FontWeight->"Bold",
  FontSlant->"Plain"]
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    StyleBox["Figure",
     FontSlant->"Plain"], 
    StyleBox[" ",
     FontSlant->"Plain"], 
    StyleBox["25.",
     FontSlant->"Plain"], " ", "C4", " ", "example", " ", "folds", " ", "to", 
    " ", "C4c"}], "*)"}], 
  RowBox[{"{", 
   RowBox[{
   "\"\< {(2-1),(.5-.1)}*{(3-2.5),(.7-.5)}\\n~.42+.4\[ImaginaryI]\>\"", ",", 
    "\"\<\\nC4c product folds to (1+.4\[ImaginaryI])(.5+.2\[ImaginaryI]) & \
gives\>\"", ",", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "-", "1"}], ")"}], ",", 
        RowBox[{"(", 
         RowBox[{".5", "-", ".1"}], ")"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "-", "2.5"}], ")"}], ",", 
        RowBox[{"(", 
         RowBox[{".7", "-", ".5"}], ")"}]}], "}"}], ",", "\"\<C4c\>\""}], 
     "]"}]}], "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\" {(2-1),(.5-.1)}*{(3-2.5),(.7-.5)}\\n~.42+.4\[ImaginaryI]\"\>",
    ",", "\<\"\\nC4c product folds to (1+.4\[ImaginaryI])(.5+.2\[ImaginaryI]) \
& gives\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0.42000000000000004`", ",", "0.39999999999999997`"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 "The properties of complex algebra result from the Moufang & Frobenius \
properties of C4. The rules for quaternion and octonion algebras arise \
similarly, from the Q8 and Oct tables. As their determinant factors are \
(repeated) sums of the squares of their elements, they are \"real algebras \
without divisors of zero\".\n\tAfter finding several conservative tables \
related to Octonions, I conjectured that all non-associative Moufang Loops \
might be conservative. This was comprehensively disproved by the examples in \
[4]; on testing the 88 with up to 36 elements, only 7 were hoops. Figure 24a \
shows these, together with the non-hoop 12 & 20 element cases, and 4 larger \
non-associative hoops composed from Oct."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 24a.",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 " A few nonassociative Moufang Tables are conservative."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"conservativeQ", "[", 
    RowBox[{"mp", "[", "\"\<D3Mn\>\"", "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"mp", "[", "\"\<Q8M2\>\"", "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", "Oct", "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"mp", "[", "\"\<D5Mn\>\"", "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"mp", "[", "\"\<P16M\>\"", "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"mp", "[", "\"\<OctC2\>\"", "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"mp", "[", "\"\<C8pC2M\>\"", "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"mp", "[", "\"\<KiC4M\>\"", "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", "C4iC4M", "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"co", "[", 
     RowBox[{"Oct", ",", "C3"}], "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"co", "[", 
     RowBox[{"Oct", ",", "C4"}], "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"co", "[", 
     RowBox[{"Oct", ",", "K"}], "]"}], "]"}], ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"co", "[", 
     RowBox[{"Oct", ",", "C5"}], "]"}], "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "False", ",", "True", ",", "True", ",", "False", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tOct and Q8M2 are the two 16 element non-associative Moufang loops. They \
each have 8 linear and one quadratic size, and fold to the signed tables for \
the \"Octr\" Octonion and the \"Octs\" (\"Split-Octonion\" in Wikipedia) \
algebras. Q8M2 operations were demonstrated in Figure 10a. Figure 24b gives \
the shapes of these algebras\n\t",
 "Octs",
 " is an algebra with divisors of zero and signature {4,4} as it conserves \
{",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b", "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", "2"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["g", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", "2"], TraditionalForm]]],
 "}. Oct and Q8M2 have one quadratic and 8 linear sizes and the linear sizes \
produce divisors of zero."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 24b.",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 " Conservative nonassociative Octonion and \"Split-octonion\" Algebras."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<Q8M2 shape\>\"", ",", 
   RowBox[{"sh", "[", "\"\<Q8M2\>\"", "]"}], ",", "\"\<\\nOct shape\>\"", ",",
    
   RowBox[{"sh", "[", "\"\<Oct\>\"", "]"}], ",", "\"\<\\nOcts shape\>\"", ",",
    
   RowBox[{"sh", "[", "\"\<Octs\>\"", "]"}], ",", "\"\<\\nOctr shape\>\"", 
   ",", 
   RowBox[{"sh", "[", "\"\<Octr\>\"", "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Q8M2 shape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "-", "i", "-", "j", "-", "k", "-", "l", "-", "m", "-", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h", "-", "i", "+", "j", "+", "k", "-", "l", "-", "m", "+", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "-", "i", "+", "j", "-", "k", "+", "l", "-", "m", "+", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h", "-", "i", "-", "j", "+", "k", "+", "l", "-", "m", "-", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "h"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"i", "-", "m"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"j", "-", "n"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", "o"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"l", "-", "p"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nOct shape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
      "h", "+", "i", "+", "j", "+", "k", "+", "l", "+", "m", "+", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "+", "e", "-", "f", "-", "g", "+", 
      "h", "+", "i", "-", "j", "-", "k", "+", "l", "+", "m", "-", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f", "+", "g", "-", 
      "h", "+", "i", "-", "j", "+", "k", "-", "l", "+", "m", "-", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "+", "e", "+", "f", "-", "g", "-", 
      "h", "+", "i", "+", "j", "-", "k", "-", "l", "+", "m", "+", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "+", "c", "-", "d", "-", "e", "+", "f", "-", "g", "+", 
      "h", "+", "i", "-", "j", "+", "k", "-", "l", "-", "m", "+", "n", "-", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "-", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
      "h", "+", "i", "+", "j", "-", "k", "-", "l", "-", "m", "-", "n", "+", 
      "o", "+", "p"}], ",", 
     RowBox[{
     "a", "+", "b", "+", "c", "+", "d", "-", "e", "-", "f", "-", "g", "-", 
      "h", "+", "i", "+", "j", "+", "k", "+", "l", "-", "m", "-", "n", "-", 
      "o", "-", "p"}], ",", 
     RowBox[{
     "a", "-", "b", "-", "c", "+", "d", "-", "e", "+", "f", "+", "g", "-", 
      "h", "+", "i", "-", "j", "-", "k", "+", "l", "-", "m", "+", "n", "+", 
      "o", "-", "p"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "i"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "j"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"e", "-", "m"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"f", "-", "n"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"g", "-", "o"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"h", "-", "p"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nOcts shape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox["d", "2"], "+", 
     SuperscriptBox["e", "2"], "-", 
     SuperscriptBox["f", "2"], "+", 
     SuperscriptBox["g", "2"], "-", 
     SuperscriptBox["h", "2"]}], "}"}], ",", "\<\"\\nOctr shape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "+", 
     SuperscriptBox["e", "2"], "+", 
     SuperscriptBox["f", "2"], "+", 
     SuperscriptBox["g", "2"], "+", 
     SuperscriptBox["h", "2"]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tOf the 88 non-associative Moufang loops with up to 36 elements in [4], only \
M1602 (Q8M2), M1603 (Oct), M3202 (Q8C2M), M3216 (OctC2), M3221 (P16M), M3235 \
(C8pC2M), M3254 (KiC4M), and M3265 (C4iC4M) are conservative. They are all \
hoops, becase their compositions with C2, C3, C4, K, etc. are conservative. \
Figure 24c gives some examples. I have not found (folded) signed tables for \
P16M, C8pC2M, KiC4M or C4iC4M; these are related to the corresponding groups \
(without M) via a \"Moufang modification\". Unlike D3Mn, their diagonals do \
not preclude a folded version.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Figure 24c.",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 " Composition of conservative non-associative Moufang Loops."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"conservativeQ", "[", 
    RowBox[{"co", "[", 
     RowBox[{
      RowBox[{"mp", "[", "\"\<P16M\>\"", "]"}], ",", "C2"}], "]"}], "]"}], 
   ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"co", "[", 
     RowBox[{
      RowBox[{"mp", "[", "\"\<C8pC2M\>\"", "]"}], ",", "C3"}], "]"}], "]"}], 
   ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"co", "[", 
     RowBox[{
      RowBox[{"mp", "[", "\"\<KiC4M\>\"", "]"}], ",", "K"}], "]"}], "]"}], 
   ",", 
   RowBox[{"conservativeQ", "[", 
    RowBox[{"co", "[", 
     RowBox[{
      RowBox[{"mp", "[", "\"\<C4iC4M\>\"", "]"}], ",", "C4"}], "]"}], "]"}]}],
   "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
9. \"Generalized signs\" fold unsigned numbers and Moufang loops.\
\>", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary.",
 StyleBox[" The signs {1, \[ImaginaryI], -1, -\[ImaginaryI]} or {",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ImaginaryI]", 
    RowBox[{" ", "0"}]], TraditionalForm]]],
 StyleBox[", ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ImaginaryI]", 
    RowBox[{" ", "1"}]], TraditionalForm]]],
 StyleBox[", ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ImaginaryI]", 
    RowBox[{" ", "2"}]], TraditionalForm]]],
 StyleBox[", ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ImaginaryI]", 
    RowBox[{" ", "3"}]], TraditionalForm]]],
 StyleBox["} are the r=4 (complex) case of generalised signs ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "j"], TraditionalForm]]],
 " ",
 StyleBox["where ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "r"], TraditionalForm]]],
 StyleBox["=+1 & 0\[LessEqual]j<r. Other algebras use other r values, e.g. \
r=3 gives Terplex algebra. m\[Times]m Moufang loops operate on sets of m \
unsigned coefficients, but if they have r-fold symmetry they can be folded to \
(m/r)\[Cross](m/r) hoop tables that  multiply vectors with m/r \"r-signed\" \
coefficients. These tables inherit the Moufang and Frobenius properties, but \
some sizes are destroyed by folding.",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\tSection 8 demonstrated the folding of Moufang loops with 2-fold symmetry \
to introduce the traditional \"-\" sign. Many hoops in the database involve \
\"generalized signs\", (\"-\", \[DoubleStruckCapitalJ], \[ImaginaryI]), that \
are primitive roots of unity - e.g. ",
 Cell[BoxData[
  SuperscriptBox["\<\"-\"\>", "2"]], "Output"],
 "=+1, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], TraditionalForm]]],
 "=+1, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ImaginaryI]", "4"], TraditionalForm]]],
 "=+1. (They should not be confused with the cyclotomic numbers, which are \
points in the complex plane). The package defines \[DoubleStruckCapitalJ] and \
some other signs (e.g. ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckK]", "2"], TraditionalForm]]],
 "=1, \[DoubleStruckK] distinct from \"-\") as extensions to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". (Only \[ImaginaryI] & \[DoubleStruckCapitalJ] are used in this notebook, \
but the generalization is explained for completeness). These numbers resemble \
\[ImaginaryI] but are not real, not (apart from \[ImaginaryI]) complex, not \
positive, not negative; they are their own sign and have an absolute value \
(magnitude) of 1. The general case \[DoubleStruckS] is set up as the ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'th root of unity, with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "r"], TraditionalForm]]],
 "=1. A ",
 StyleBox["minSign",
  FontSlant->"Italic"],
 " function is provided to reduce the powers of any signs in an expression to \
the minimum range ",
 StyleBox["0\[LessEqual]j<r",
  FontSlant->"Italic"],
 ". \n\tEach signed table has been obtained from a larger Moufang table that \
(because negation is not required in the definition of Moufang loops) \
consists of unsigned indices. Moufang coefficients may be operators, but if \
they are numbers they are therefore fundamentally \"unsigned\", i.e. natural \
numbers, unsigned rational numbers, or unsigned (non-negative) continuous \
numbers (for which I propose the name Primal numbers.) Signed numbers are \
equivalence relations on sets of unsigned numbers. Thus, Real coefficients \
are equivalence relations on pairs of primal numbers, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "i"], TraditionalForm]]],
 "~{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "}~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "}, -",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "i"], TraditionalForm]]],
 "~{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "}, 0~{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "} with the relationship ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ". Complex coefficients are equivalence relations on quads of real numbers, \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "i"], TraditionalForm]]],
 "~{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "4"}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"3", 
      RowBox[{"m", "/", "4"}]}]}]], TraditionalForm]]],
 "}, -",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "i"], TraditionalForm]]],
 "~{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"3", 
      RowBox[{"m", "/", "4"}]}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "4"}]}]], TraditionalForm]]],
 "} with the relationships ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "4"}]}]], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"3", 
      RowBox[{"m", "/", "4"}]}]}]], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"3", 
      RowBox[{"m", "/", "4"}]}]}]], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "4"}]}]], TraditionalForm]]],
 ". Terplex coefficients, with signs {1,\[DoubleStruckCapitalJ], ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], TraditionalForm]]],
 "} are equivalence relations on triples of primal numbers, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "i"], " "}], TraditionalForm]]],
 "~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "3"}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"2", 
      RowBox[{"m", "/", "3"}]}]}]], TraditionalForm]]],
 "}, \[DoubleStruckCapitalJ]",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "i"], " "}], TraditionalForm]]],
 "~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "3"}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"2", 
      RowBox[{"m", "/", "3"}]}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "}, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalJ]", "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "i"], " "}], TraditionalForm]]],
 "~ {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "3"}]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"2", 
      RowBox[{"m", "/", "3"}]}]}]], TraditionalForm]]],
 "} with the relationship ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "3"}]}]], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "3"}]}]], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "i"], "=", 
    RowBox[{
     FormBox[
      SubscriptBox["a", 
       RowBox[{"i", "+", 
        RowBox[{"2", 
         RowBox[{"m", "/", "2"}]}]}]],
      TraditionalForm], "+", 
     FormBox[
      SubscriptBox["b", "i"],
      TraditionalForm]}]}], TraditionalForm]]],
 ". I call the equivalencing of 2, 3, 4 or more primal coefficients to a \
single real, terplex, complex or hypercomplex (etc) number \"folding\". \n\t\
Signed tables are produced by folding Moufang Loops that have suitable \
symmetry. A Moufang table of size ",
 StyleBox["m\[Times]m ",
  FontSlant->"Italic"],
 "can be folded to a signed table of size ",
 StyleBox["(m/r)\[Times](m/r)",
  FontSlant->"Italic"],
 " if it has ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry. The unsigned tables consist of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "2"], TraditionalForm]]],
 " blocks (of size ",
 StyleBox["(m/r)\[Times](m/r)",
  FontSlant->"Italic"],
 ") that are repeated with offsets. Twofold folding gives the top left ",
 StyleBox["(m/2)\[Cross](m/2)",
  FontSlant->"Italic"],
 " table; indices greater than r become negated smaller indices. Threefold \
folding gives a ",
 StyleBox["(m/3)\[Cross](m/3)",
  FontSlant->"Italic"],
 " table that may involve \[DoubleStruckCapitalJ]."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 26.",
  FontWeight->"Bold"],
 " Collapsing the unsigned C6, Quaternion (Q8) and C9 tables to signed Hoop \
tables."
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     RowBox[{"C6", "=", 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"1", "2", "3", " ", 
          StyleBox["4",
           FontWeight->"Plain"], 
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"]},
         {"2", "3", "4", " ", 
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"]},
         {"3", "4", "5", " ", 
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"], 
          StyleBox["2",
           FontWeight->"Plain"]},
         {" ", " ", " ", " ", 
          StyleBox[" ",
           FontWeight->"Plain"], 
          StyleBox[" ",
           FontWeight->"Plain"], 
          StyleBox[" ",
           FontWeight->"Plain"]},
         {
          StyleBox["4",
           FontWeight->"Plain"], 
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"], " ", "1", "2", "3"},
         {
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"], " ", "2", "3", "4"},
         {
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"], 
          StyleBox["2",
           FontWeight->"Plain"], " ", "3", "4", "5"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
       ")"}]}], "\[IndentingNewLine]"}], 
    RowBox[{
     RowBox[{"C3C2c", "=", 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"1", "2", "3"},
         {"2", "3", 
          RowBox[{"-", "1"}]},
         {"3", 
          RowBox[{"-", "1"}], 
          RowBox[{"-", "2"}]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
       ")"}]}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"4", " ", "&"}], " ", "5", "  ", "become"}], " ", "-", "1"}],
        " ", "&"}], " ", "-", "2"}]}]},
   {
    RowBox[{"Q8", "=", 
     RowBox[{"(", GridBox[{
        {"1", "2", "3", "4", " ", 
         StyleBox["5",
          FontWeight->"Plain"], 
         StyleBox["6",
          FontWeight->"Plain"], 
         StyleBox["7",
          FontWeight->"Plain"], 
         StyleBox["8",
          FontWeight->"Plain"]},
        {"2", "5", "8", "3", " ", 
         StyleBox["6",
          FontWeight->"Plain"], 
         StyleBox["1",
          FontWeight->"Plain"], 
         StyleBox["4",
          FontWeight->"Plain"], 
         StyleBox["7",
          FontWeight->"Plain"]},
        {"3", "4", "5", "6", " ", 
         StyleBox["7",
          FontWeight->"Plain"], 
         StyleBox["8",
          FontWeight->"Plain"], 
         StyleBox["1",
          FontWeight->"Plain"], 
         StyleBox["2",
          FontWeight->"Plain"]},
        {"4", "7", "2", "5", " ", 
         StyleBox["8",
          FontWeight->"Plain"], 
         StyleBox["3",
          FontWeight->"Plain"], 
         StyleBox["6",
          FontWeight->"Plain"], 
         StyleBox["1",
          FontWeight->"Plain"]},
        {
         StyleBox[" ",
          FontSlant->"Italic"], 
         StyleBox[" ",
          FontSlant->"Italic"], 
         StyleBox[" ",
          FontSlant->"Italic"], 
         StyleBox[" ",
          FontSlant->"Italic"], " ", 
         StyleBox[" ",
          FontWeight->"Bold"], 
         StyleBox[" ",
          FontWeight->"Bold"], 
         StyleBox[" ",
          FontWeight->"Bold"], 
         StyleBox[" ",
          FontWeight->"Bold"]},
        {
         StyleBox["5",
          FontWeight->"Plain"], 
         StyleBox["6",
          FontWeight->"Plain"], 
         StyleBox["7",
          FontWeight->"Plain"], 
         StyleBox["8",
          FontWeight->"Plain"], " ", 
         StyleBox["1",
          FontWeight->"Bold"], 
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["3",
          FontWeight->"Bold"], 
         StyleBox["4",
          FontWeight->"Bold"]},
        {
         StyleBox["6",
          FontWeight->"Plain"], 
         StyleBox["1",
          FontWeight->"Plain"], 
         StyleBox["4",
          FontWeight->"Plain"], 
         StyleBox["7",
          FontWeight->"Plain"], " ", 
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"], 
         StyleBox["8",
          FontWeight->"Bold"], 
         StyleBox["3",
          FontWeight->"Bold"]},
        {
         StyleBox["7",
          FontWeight->"Plain"], 
         StyleBox["8",
          FontWeight->"Plain"], 
         StyleBox["1",
          FontWeight->"Plain"], 
         StyleBox["2",
          FontWeight->"Plain"], " ", 
         StyleBox["3",
          FontWeight->"Bold"], 
         StyleBox["4",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"], 
         StyleBox["6",
          FontWeight->"Bold"]},
        {
         StyleBox["8",
          FontWeight->"Plain"], 
         StyleBox["3",
          FontWeight->"Plain"], 
         StyleBox["6",
          FontWeight->"Plain"], 
         StyleBox["1",
          FontWeight->"Plain"], " ", 
         StyleBox["4",
          FontWeight->"Bold"], 
         StyleBox["7",
          FontWeight->"Bold"], 
         StyleBox["2",
          FontWeight->"Bold"], 
         StyleBox["5",
          FontWeight->"Bold"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}],
     
    RowBox[{
     RowBox[{"Qr", "=", 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"1", "2", "3", "4"},
         {"2", 
          RowBox[{"-", "1"}], 
          RowBox[{"-", "4"}], "3"},
         {"3", "4", 
          RowBox[{"-", "1"}], 
          RowBox[{"-", "2"}]},
         {"4", 
          RowBox[{"-", "3"}], "2", 
          RowBox[{"-", "1"}]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
       ")"}]}], "\[IndentingNewLine]", 
     StyleBox[
      RowBox[{
       RowBox[{"{", 
        RowBox[{"5", ",", "6", ",", "7", ",", "8"}], "}"}], "  ", "becomes"}],
       "Text"], 
     StyleBox["\[IndentingNewLine]", "Text"], 
     StyleBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "4"}]}], "}"}], "Text"], 
     StyleBox["\[IndentingNewLine]", "Text"]}]},
   {
    RowBox[{"C9", "=", 
     FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"1", "2", "3", "  ", 
          StyleBox["4",
           FontWeight->"Plain"], 
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"], " ", 
          StyleBox["7",
           FontWeight->"Plain"], 
          StyleBox["8",
           FontWeight->"Plain"], 
          StyleBox["9",
           FontWeight->"Plain"]},
         {"2", "3", "4", " ", 
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["7",
           FontWeight->"Plain"], " ", 
          StyleBox["8",
           FontWeight->"Plain"], 
          StyleBox["9",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"]},
         {"3", "4", "5", " ", 
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["7",
           FontWeight->"Plain"], 
          StyleBox["8",
           FontWeight->"Plain"], " ", 
          StyleBox["9",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"], 
          StyleBox["2",
           FontWeight->"Plain"]},
         {" ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " "},
         {
          StyleBox["4",
           FontWeight->"Plain"], 
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"], " ", 
          StyleBox["7",
           FontWeight->"Plain"], 
          StyleBox["8",
           FontWeight->"Plain"], 
          StyleBox["9",
           FontWeight->"Plain"], " ", "1", "2", "3"},
         {
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["7",
           FontWeight->"Plain"], " ", 
          StyleBox["8",
           FontWeight->"Plain"], 
          StyleBox["9",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"], " ", "2", "3", "4"},
         {
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["7",
           FontWeight->"Plain"], 
          StyleBox["8",
           FontWeight->"Plain"], " ", 
          StyleBox["9",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"], 
          StyleBox["2",
           FontWeight->"Plain"], " ", "3", "4", "5"},
         {" ", " ", " ", " ", " ", " ", " ", "  ", " ", " ", " "},
         {
          StyleBox["7",
           FontWeight->"Plain"], 
          StyleBox["8",
           FontWeight->"Plain"], 
          StyleBox["9",
           FontWeight->"Plain"], " ", "1", "2", "3", " ", 
          StyleBox["4",
           FontWeight->"Plain"], 
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"]},
         {
          StyleBox["8",
           FontWeight->"Plain"], 
          StyleBox["9",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"], " ", "2", "3", "4", " ", 
          StyleBox["5",
           FontWeight->"Plain"], 
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["7",
           FontWeight->"Plain"]},
         {
          StyleBox["9",
           FontWeight->"Plain"], 
          StyleBox["1",
           FontWeight->"Plain"], 
          StyleBox["2",
           FontWeight->"Plain"], " ", "3", "4", "5", " ", 
          StyleBox["6",
           FontWeight->"Plain"], 
          StyleBox["7",
           FontWeight->"Plain"], 
          StyleBox["8",
           FontWeight->"Plain"]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
      TraditionalForm]}], 
    RowBox[{"    ", 
     RowBox[{
      RowBox[{"C9J", "=", 
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "2", "3"},
          {"2", "3", "\[DoubleStruckCapitalJ]"},
          {"3", "\[DoubleStruckCapitalJ]", 
           RowBox[{"2", "\[DoubleStruckCapitalJ]"}]}
         }], "\[NoBreak]", ")"}]}], "\n", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"4", " ", "&"}], " ", "5", 
         StyleBox[" ", "Text"], 
         StyleBox["become", "Text"], 
         StyleBox[" ", "Text"], 
         StyleBox["\[DoubleStruckCapitalJ]", "Text"]}], 
        StyleBox[" ", "Text"], 
        StyleBox["&", "Text"]}], 
       StyleBox[" ", "Text"], 
       StyleBox["2", "Text"], 
       StyleBox["\[DoubleStruckCapitalJ]", "Text"]}]}]}]}
  }]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[TextData[{
 "Figure 27. shows that C9J is a division algebra. It was developed to show \
that hoops were not restricted to \"traditional\" signs. After finding and \
applying the appropriate ",
 StyleBox["minsign",
  FontSlant->"Italic"],
 ", the shapes are seen to be conserved. Then multiplying Ainverse by AB \
recovers B, showing that C9J is a division algebra, though its products \
involve \[DoubleStruckCapitalJ]. The C9 conjugate determinant has one linear, \
one quadratic, and one 6th order factor; folding reduces these to a single \
cubic factor, the",
 StyleBox[" size",
  FontSlant->"Italic"],
 " for C9J."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"?", "minsign"}],
  FontSlant->"Italic"]], "Input"],

Cell[BoxData[
 StyleBox["\<\"minsign[g_] finds any signed elements of 'g' and sets up the \
appropriate simplification list from 'unitSigns'\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellTags->"Info3422431022-7699074"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Figure 27",
  FontWeight->"Bold"],
 ". Using the C9J multiplication table to multiply and divide:- "
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\"\<hoopShape[C9J] ={\!\(\*SuperscriptBox[\(a\), \
\(3\)]\)+\!\(\*SuperscriptBox[\(b\), \(3\)]\) \[DoubleStruckCapitalJ]-3 a b c \
\[DoubleStruckCapitalJ]+\!\(\*SuperscriptBox[\(c\), \(3\)]\) \
\!\(\*SuperscriptBox[\(\[DoubleStruckCapitalJ]\), \(2\)]\)}\\nA=\>\"", ",", 
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", "3"}], "}"}]}], ",", "\"\<\\nB=\>\"", ",", 
   RowBox[{"B", "=", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"-", "2"}], ",", "5"}], "}"}]}], ",", "\"\<\\nAB=\>\"", ",", 
   RowBox[{"AB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"A", ",", "B", ",", "\"\<C9J\>\""}], "]"}]}], ",", 
   "\"\<\\nshape[A] \>\"", ",", 
   RowBox[{"sa", "=", 
    RowBox[{"shape", "[", "A", "]"}]}], " ", ",", "\"\<\\nshape[B]\>\"", ",", 
   
   RowBox[{"sb", "=", 
    RowBox[{"shape", "[", "B", "]"}]}], ",", "\"\<\\nshape[AB]\>\"", ",", 
   RowBox[{"sab", "=", 
    RowBox[{"Expand", "[", 
     RowBox[{"shape", "[", "AB", "]"}], "]"}]}], ",", 
   RowBox[{"\"\<\\nApplying \!\(\*
StyleBox[\"minsign\",
FontSlant->\"Italic\"]\)= {\!\(\*SuperscriptBox[\(\[DoubleStruckCapitalJ]\), \
\(3\)]\)\[RightArrow]1,\!\(\*SuperscriptBox[\(\[DoubleStruckCapitalJ]\), \
\(any_\)]\)\>\"", "\[RightArrow]", 
    SuperscriptBox["\[DoubleStruckCapitalJ]", 
     RowBox[{"mod", "[", 
      RowBox[{"any", ",", "3"}], "]"}]]}], ",", 
   RowBox[{
    RowBox[{"mins", "=", 
     RowBox[{"minsign", "[", "AB", "]"}]}], ";", "\"\<\\nshAB gives\>\""}], 
   ",", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"shape", "[", "AB", "]"}], "]"}], "/.", "mins"}], ",", 
   "\"\<\\nshA shB = \>\"", ",", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"sa", " ", "sb"}], "]"}], "/.", "mins"}], ",", "\"\<\\n\!\(\*
StyleBox[\"Ai\",
FontSlant->\"Italic\"]\)=\>\"", ",", 
   RowBox[{"Ai", "=", 
    RowBox[{"hoopInverse", "[", "A", "]"}]}], ",", "\[IndentingNewLine]", 
   "\"\<\\n\!\(\*
StyleBox[\"AiAB\",
FontSlant->\"Italic\"]\)=\>\"", ",", 
   RowBox[{"AiAB", "=", 
    RowBox[{"hoopTimes", "[", 
     RowBox[{"Ai", ",", "AB"}], "]"}]}], ",", "\"\<\\n\!\(\*
StyleBox[\"minsign\",
FontSlant->\"Italic\"]\) simplifies this to \!\(\*
StyleBox[\"B\",
FontSlant->\"Italic\"]\) \>\"", ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "AiAB", "]"}], "/.", "mins"}], "]"}]}], 
  "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"hoopShape[C9J] ={\\!\\(\\*SuperscriptBox[\\(a\\), \\(3\\)]\\)+\
\\!\\(\\*SuperscriptBox[\\(b\\), \\(3\\)]\\) \[DoubleStruckCapitalJ]-3 a b c \
\[DoubleStruckCapitalJ]+\\!\\(\\*SuperscriptBox[\\(c\\), \\(3\\)]\\) \
\\!\\(\\*SuperscriptBox[\\(\[DoubleStruckCapitalJ]\\), \\(2\\)]\\)}\\nA=\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "3"}], "}"}], ",", "\<\"\\nB=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "2"}], ",", "5"}], "}"}], ",", "\<\"\\nAB=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"8", "-", "\[DoubleStruckCapitalJ]"}], ",", 
     RowBox[{"15", " ", "\[DoubleStruckCapitalJ]"}], ",", "20"}], "}"}], 
   ",", "\<\"\\nshape[A] \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"8", "-", 
     RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
     RowBox[{"27", " ", 
      SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}], 
   ",", "\<\"\\nshape[B]\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"64", "+", 
     RowBox[{"112", " ", "\[DoubleStruckCapitalJ]"}], "+", 
     RowBox[{"125", " ", 
      SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}], 
   ",", "\<\"\\nshape[AB]\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"512", "-", 
     RowBox[{"192", " ", "\[DoubleStruckCapitalJ]"}], "+", 
     RowBox[{"824", " ", 
      SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}], "+", 
     RowBox[{"899", " ", 
      SuperscriptBox["\[DoubleStruckCapitalJ]", "3"]}], "+", 
     RowBox[{"3375", " ", 
      SuperscriptBox["\[DoubleStruckCapitalJ]", "4"]}]}], "}"}], ",", 
   RowBox[{"\<\"\\nApplying \
\\!\\(\\*\\nStyleBox[\\\"minsign\\\",\\nFontSlant->\\\"Italic\\\"]\\)= \
{\\!\\(\\*SuperscriptBox[\\(\[DoubleStruckCapitalJ]\\), \\(3\\)]\\)\
\[RightArrow]1,\\!\\(\\*SuperscriptBox[\\(\[DoubleStruckCapitalJ]\\), \\(any_\
\\)]\\)\"\>", "\[RightArrow]", 
    SuperscriptBox["\[DoubleStruckCapitalJ]", 
     RowBox[{"mod", "[", 
      RowBox[{"any", ",", "3"}], "]"}]]}], ",", "\<\"\\nshAB gives\"\>", ",", 
   
   RowBox[{"{", 
    RowBox[{"1411", "+", 
     RowBox[{"3183", " ", "\[DoubleStruckCapitalJ]"}], "+", 
     RowBox[{"824", " ", 
      SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}], 
   ",", "\<\"\\nshA shB = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1411", "+", 
     RowBox[{"3183", " ", "\[DoubleStruckCapitalJ]"}], "+", 
     RowBox[{"824", " ", 
      SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"Ai\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"4", "-", 
       RowBox[{"3", " ", "\[DoubleStruckCapitalJ]"}]}], 
      RowBox[{"8", "-", 
       RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
       RowBox[{"27", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"9", " ", "\[DoubleStruckCapitalJ]"}]}], ")"}]}], 
      RowBox[{"8", "-", 
       RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
       RowBox[{"27", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"5", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "3"]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"AiAB\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)=\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"3", " ", "\[DoubleStruckCapitalJ]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"8", "-", "\[DoubleStruckCapitalJ]"}], ")"}]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]], "-", 
      FractionBox[
       RowBox[{"75", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "5"]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]], "+", 
      FractionBox[
       RowBox[{"20", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"9", " ", "\[DoubleStruckCapitalJ]"}]}], ")"}]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"15", " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"3", " ", "\[DoubleStruckCapitalJ]"}]}], ")"}], " ", 
        "\[DoubleStruckCapitalJ]"}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]], "-", 
      FractionBox[
       RowBox[{"100", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "4"]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8", "-", "\[DoubleStruckCapitalJ]"}], ")"}], " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"9", " ", "\[DoubleStruckCapitalJ]"}]}], ")"}]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"20", " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"3", " ", "\[DoubleStruckCapitalJ]"}]}], ")"}]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]], "-", 
      FractionBox[
       RowBox[{"5", " ", 
        RowBox[{"(", 
         RowBox[{"8", "-", "\[DoubleStruckCapitalJ]"}], ")"}], " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "3"]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]], "+", 
      FractionBox[
       RowBox[{"15", " ", 
        SuperscriptBox["\[DoubleStruckCapitalJ]", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"9", " ", "\[DoubleStruckCapitalJ]"}]}], ")"}]}], 
       RowBox[{"8", "-", 
        RowBox[{"17", " ", "\[DoubleStruckCapitalJ]"}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["\[DoubleStruckCapitalJ]", "2"]}]}]]}]}], "}"}], 
   ",", "\<\"\\n\\!\\(\\*\\nStyleBox[\\\"minsign\\\",\\nFontSlant->\\\"Italic\
\\\"]\\) simplifies this to \
\\!\\(\\*\\nStyleBox[\\\"B\\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "2"}], ",", "5"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["10. Exponent of Generalized Signs, Multiphase \
Sinusoids.",
 FontFamily->"Arial"]], "Subsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman",
 FontSize->12],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". An important property of generalized signs is that their exponents give \
generalized symmetric multiphase sinusoids, ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[ExponentialE]", "r", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"\[DoubleStruckS]", " "}], "j"], "x"}]], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sum]", "j"], TraditionalForm]]],
 " 2",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "j"], TraditionalForm]]],
 "/r Sin[p(x+2\[Pi] j/r)], with period p= Sin[2\[Pi] /r]. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "r"], TraditionalForm]]],
 " is a normalizing extrapolation of \[ExponentialE]  to r phases, expressed \
in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "r"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  RowBox[{"Re", "[", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{" ", 
     RowBox[{"Im", "[", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", "/", "r"}]], "]"}]}]], "]"}]]],
 ". The traditional ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "\[ImaginaryI]x"}]], TraditionalForm]]],
 "=Cos[x]+\[ImaginaryI] Sin[x] is an asymmetric folded case with r=4."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[TextData[{
 "\tExtended signs \[DoubleStruckS] are a significant generalization of \
complex mathematics. One important property is that their exponents \
generalize the sinusoids Cos[x] = Re[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
 "], Sin[x] = Im[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
 "] to multi-phase sinusoids ",
 StyleBox["genCos[x,r,j] ",
  FontSlant->"Italic"],
 "= Re[",
 StyleBox["j ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[ExponentialE]", "r", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"\[DoubleStruckS]", " "}], "j"], "x"}]], TraditionalForm]]],
 "] where ",
 StyleBox["j",
  FontSlant->"Italic"],
 " is a phase & ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "r"], TraditionalForm]]],
 " is a (normalizing) modification of \[ExponentialE] that depends on ",
 StyleBox["r",
  FontSlant->"Italic"],
 ", the number of phases, with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "3"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "6"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SqrtBox["3"], "/", "2"}]], TraditionalForm]]],
 "\[TildeEqual]2.3774, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "12"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SqrtBox["\[ExponentialE]"], TraditionalForm]]],
 "\[TildeEqual]1.6487. The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " implementation of the normalising element is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ExponentialE]", "r"], TraditionalForm]]],
 "= Re[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"Im", "[", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"2", "/", "r"}]], "]"}]], TraditionalForm]]],
 "]. The generation of these sinusoids as solutions to banded differential \
equations is described in ",
 StyleBox["GroupLoopDemo",
  FontSlant->"Italic"],
 " Appendix E",
 StyleBox[" ",
  FontSlant->"Italic"],
 "[1]."
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 StyleBox["Figure 28 & Figure",
  FontWeight->"Bold"],
 " 29 demonstrate ",
 StyleBox["genCos",
  FontSlant->"Italic"],
 " & ",
 StyleBox["genSin ",
  FontSlant->"Italic"],
 "by plotting three phases of the 3-phase & 12-phase sinusoids over their \
periods 2\[Pi]/Sin[2\[Pi]/3]=7.2552 & 4\[Pi]=12.5664. "
}], "Text",
 PageWidth->WindowWidth],

Cell["Multiphase sinusoids with ternary symmetry", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", "m", "]"}], ";", 
  RowBox[{"m", "=", "3"}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "3"], " ", 
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"m", "+", "0"}], ")"}]}], "m"]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Im", "[", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], ",", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"m", "-", "1"}], ")"}]}], "m"]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Im", "[", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], ",", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"m", "-", "2"}], ")"}]}], "m"]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Im", "[", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}]}], "}"}],
     ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]"}], 
       RowBox[{"Sin", "[", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "3"], "]"}]]}], "}"}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<Fig.28. genCos. Phases 0,1,2 for m = 3\>\""}]}], "]"}], ";", 
  RowBox[{"m", "=", "12"}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"Im", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"m", "+", "0"}], ")"}]}], "m"]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Im", "[", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], ",", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"Im", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"m", "-", "1"}], ")"}]}], "m"]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Im", "[", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], ",", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"Im", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"m", "-", "2"}], ")"}]}], "m"]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Im", "[", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}]}], "}"}],
     ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]"}], 
       RowBox[{"Sin", "[", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "12"], "]"}]]}], "}"}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<Fig.29. genSin. Phases 0,1,2 for m = 12\>\""}]}], "]"}]}]], "Input",\

 PageWidth->WindowWidth,
 CellOpen->False],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.131269 0.309017 0.441453 [
[.15508 .29652 -3 -9 ]
[.15508 .29652 3 0 ]
[.28635 .29652 -3 -9 ]
[.28635 .29652 3 0 ]
[.41762 .29652 -3 -9 ]
[.41762 .29652 3 0 ]
[.54888 .29652 -3 -9 ]
[.54888 .29652 3 0 ]
[.68015 .29652 -3 -9 ]
[.68015 .29652 3 0 ]
[.81142 .29652 -3 -9 ]
[.81142 .29652 3 0 ]
[.94269 .29652 -3 -9 ]
[.94269 .29652 3 0 ]
[.01131 .04415 -24 -4.5 ]
[.01131 .04415 0 4.5 ]
[.01131 .13244 -24 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .22073 -24 -4.5 ]
[.01131 .22073 0 4.5 ]
[.01131 .39731 -18 -4.5 ]
[.01131 .39731 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .57389 -18 -4.5 ]
[.01131 .57389 0 4.5 ]
[.5 .63053 -116 0 ]
[.5 .63053 116 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15508 .30902 m
.15508 .31527 L
s
[(1)] .15508 .29652 0 1 Mshowa
.28635 .30902 m
.28635 .31527 L
s
[(2)] .28635 .29652 0 1 Mshowa
.41762 .30902 m
.41762 .31527 L
s
[(3)] .41762 .29652 0 1 Mshowa
.54888 .30902 m
.54888 .31527 L
s
[(4)] .54888 .29652 0 1 Mshowa
.68015 .30902 m
.68015 .31527 L
s
[(5)] .68015 .29652 0 1 Mshowa
.81142 .30902 m
.81142 .31527 L
s
[(6)] .81142 .29652 0 1 Mshowa
.94269 .30902 m
.94269 .31527 L
s
[(7)] .94269 .29652 0 1 Mshowa
.125 Mabswid
.05006 .30902 m
.05006 .31277 L
s
.07632 .30902 m
.07632 .31277 L
s
.10257 .30902 m
.10257 .31277 L
s
.12882 .30902 m
.12882 .31277 L
s
.18133 .30902 m
.18133 .31277 L
s
.20759 .30902 m
.20759 .31277 L
s
.23384 .30902 m
.23384 .31277 L
s
.26009 .30902 m
.26009 .31277 L
s
.3126 .30902 m
.3126 .31277 L
s
.33885 .30902 m
.33885 .31277 L
s
.36511 .30902 m
.36511 .31277 L
s
.39136 .30902 m
.39136 .31277 L
s
.44387 .30902 m
.44387 .31277 L
s
.47012 .30902 m
.47012 .31277 L
s
.49638 .30902 m
.49638 .31277 L
s
.52263 .30902 m
.52263 .31277 L
s
.57514 .30902 m
.57514 .31277 L
s
.60139 .30902 m
.60139 .31277 L
s
.62765 .30902 m
.62765 .31277 L
s
.6539 .30902 m
.6539 .31277 L
s
.70641 .30902 m
.70641 .31277 L
s
.73266 .30902 m
.73266 .31277 L
s
.75891 .30902 m
.75891 .31277 L
s
.78517 .30902 m
.78517 .31277 L
s
.83768 .30902 m
.83768 .31277 L
s
.86393 .30902 m
.86393 .31277 L
s
.89018 .30902 m
.89018 .31277 L
s
.91644 .30902 m
.91644 .31277 L
s
.96894 .30902 m
.96894 .31277 L
s
.9952 .30902 m
.9952 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .04415 m
.03006 .04415 L
s
[(-0.6)] .01131 .04415 1 0 Mshowa
.02381 .13244 m
.03006 .13244 L
s
[(-0.4)] .01131 .13244 1 0 Mshowa
.02381 .22073 m
.03006 .22073 L
s
[(-0.2)] .01131 .22073 1 0 Mshowa
.02381 .39731 m
.03006 .39731 L
s
[(0.2)] .01131 .39731 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.4)] .01131 .4856 1 0 Mshowa
.02381 .57389 m
.03006 .57389 L
s
[(0.6)] .01131 .57389 1 0 Mshowa
.125 Mabswid
.02381 .06622 m
.02756 .06622 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .17658 m
.02756 .17658 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .26487 m
.02756 .26487 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .35316 m
.02756 .35316 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .44145 m
.02756 .44145 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .02207 m
.02756 .02207 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.28) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(genCos) show
147.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
159.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phases) show
201.000 12.750 moveto
(0) show
207.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
213.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
219.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
225.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
237.000 12.750 moveto
(for) show
261.000 12.750 moveto
(m) show
273.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
285.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
291.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01924 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01565 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38344 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .16187 m
.06244 .23088 L
.10458 .31175 L
.14415 .38761 L
.18221 .45561 L
.22272 .5178 L
.26171 .5637 L
.28302 .58185 L
.29279 .58839 L
.30316 .59406 L
.31266 .59809 L
.31807 .59988 L
.32313 .60121 L
.32777 .60215 L
.33201 .60277 L
.33436 .60301 L
.33568 .60312 L
.33691 .6032 L
.33809 .60325 L
.33917 .60329 L
.3404 .60331 L
.34157 .60332 L
.34273 .60331 L
.34398 .60327 L
.34515 .60322 L
.34622 .60316 L
.34885 .60295 L
.35133 .60267 L
.35627 .60188 L
.36165 .60066 L
.37124 .59758 L
.38012 .5937 L
.39878 .58239 L
.41939 .56509 L
.45959 .51812 L
.49828 .45906 L
.53942 .38569 L
.57904 .30965 L
.61715 .23641 L
.65771 .16358 L
.69676 .1032 L
.71667 .07742 L
.73825 .05399 L
.75906 .03629 L
.76896 .02965 L
.77824 .02451 L
.78728 .02053 L
.79193 .01888 L
.797 .01739 L
.79987 .01669 L
Mistroke
.80253 .01614 L
.80529 .01566 L
.80778 .01531 L
.81024 .01505 L
.81256 .01487 L
.81383 .0148 L
.815 .01475 L
.81628 .01472 L
.81693 .01472 L
.81764 .01472 L
.81895 .01473 L
.82016 .01476 L
.82079 .01479 L
.82149 .01482 L
.8229 .0149 L
.82546 .01512 L
.82787 .01541 L
.83236 .01613 L
.83719 .0172 L
.84251 .01873 L
.84811 .02071 L
.85811 .02524 L
.8779 .0378 L
.89628 .05361 L
.93537 .09936 L
.97619 .16187 L
Mfstroke
.02381 .16187 m
.06244 .10236 L
.08255 .07646 L
.10458 .05279 L
.12507 .03562 L
.13422 .02954 L
.14415 .0241 L
.14961 .02163 L
.15465 .01968 L
.15937 .01815 L
.16457 .01678 L
.16922 .01585 L
.17146 .0155 L
.17359 .01523 L
.17474 .0151 L
.17599 .01499 L
.17714 .0149 L
.17819 .01484 L
.17943 .01478 L
.18012 .01475 L
.18076 .01474 L
.18191 .01472 L
.18314 .01472 L
.18439 .01474 L
.18552 .01477 L
.18682 .01483 L
.18806 .01491 L
.19026 .0151 L
.19265 .01537 L
.19528 .01575 L
.19807 .01626 L
.20308 .01741 L
.2131 .02067 L
.22415 .02573 L
.2435 .03819 L
.26435 .05655 L
.30549 .10634 L
.34512 .16838 L
.38322 .23711 L
.42378 .31513 L
.46283 .38989 L
.50433 .46338 L
.54431 .52337 L
.58278 .56714 L
.60265 .58341 L
.61267 .58984 L
.62369 .59549 L
.62891 .59764 L
.63386 .59937 L
.63835 .60066 L
Mistroke
.64314 .60176 L
.64586 .60226 L
.64833 .60263 L
.65081 .60292 L
.65314 .60312 L
.65447 .6032 L
.65519 .60324 L
.65587 .60327 L
.65706 .6033 L
.65838 .60332 L
.65911 .60332 L
.65981 .60331 L
.66111 .60328 L
.66184 .60326 L
.66251 .60323 L
.66403 .60314 L
.66522 .60305 L
.66646 .60294 L
.66868 .60268 L
.67369 .60189 L
.67801 .60094 L
.68274 .59964 L
.69342 .59564 L
.70335 .59066 L
.72385 .57657 L
.74245 .55956 L
.78248 .51056 L
.821 .45017 L
.86197 .37609 L
.90143 .30008 L
.93937 .22749 L
.97619 .16187 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 PageWidth->WindowWidth,
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontSize->12,
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 1532.31}, {945.313, 0}} -> {-0.867888, -0.700007, \
0.0291556, 0.00866962}, {{0, 1149.25}, {709, 0}} -> {-0.867888, -0.700007, \
0.0291556, 0.00866962}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0757881 0.309017 1.76581 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.93327 .29652 -6 -9 ]
[.93327 .29652 6 0 ]
[.01131 .04415 -30 -4.5 ]
[.01131 .04415 0 4.5 ]
[.01131 .13244 -24 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .22073 -30 -4.5 ]
[.01131 .22073 0 4.5 ]
[.01131 .39731 -24 -4.5 ]
[.01131 .39731 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .57389 -24 -4.5 ]
[.01131 .57389 0 4.5 ]
[.5 .63053 -119 0 ]
[.5 .63053 119 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(2)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(4)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(6)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(8)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(10)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(12)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.0617 .30902 m
.0617 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.13749 .30902 m
.13749 .31277 L
s
.21328 .30902 m
.21328 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.28907 .30902 m
.28907 .31277 L
s
.36486 .30902 m
.36486 .31277 L
s
.40275 .30902 m
.40275 .31277 L
s
.44064 .30902 m
.44064 .31277 L
s
.51643 .30902 m
.51643 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.59222 .30902 m
.59222 .31277 L
s
.66801 .30902 m
.66801 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.7438 .30902 m
.7438 .31277 L
s
.81958 .30902 m
.81958 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.89537 .30902 m
.89537 .31277 L
s
.97116 .30902 m
.97116 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .04415 m
.03006 .04415 L
s
[(-0.15)] .01131 .04415 1 0 Mshowa
.02381 .13244 m
.03006 .13244 L
s
[(-0.1)] .01131 .13244 1 0 Mshowa
.02381 .22073 m
.03006 .22073 L
s
[(-0.05)] .01131 .22073 1 0 Mshowa
.02381 .39731 m
.03006 .39731 L
s
[(0.05)] .01131 .39731 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.1)] .01131 .4856 1 0 Mshowa
.02381 .57389 m
.03006 .57389 L
s
[(0.15)] .01131 .57389 1 0 Mshowa
.125 Mabswid
.02381 .0618 m
.02756 .0618 L
s
.02381 .07946 m
.02756 .07946 L
s
.02381 .09712 m
.02756 .09712 L
s
.02381 .11478 m
.02756 .11478 L
s
.02381 .15009 m
.02756 .15009 L
s
.02381 .16775 m
.02756 .16775 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .23838 m
.02756 .23838 L
s
.02381 .25604 m
.02756 .25604 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29136 m
.02756 .29136 L
s
.02381 .32668 m
.02756 .32668 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .36199 m
.02756 .36199 L
s
.02381 .37965 m
.02756 .37965 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45028 m
.02756 .45028 L
s
.02381 .46794 m
.02756 .46794 L
s
.02381 .50326 m
.02756 .50326 L
s
.02381 .52091 m
.02756 .52091 L
s
.02381 .53857 m
.02756 .53857 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .02649 m
.02756 .02649 L
s
.02381 .00883 m
.02756 .00883 L
s
.02381 .59155 m
.02756 .59155 L
s
.02381 .6092 m
.02756 .6092 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -180 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.750 moveto
(.29) show
99.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(genSin) show
147.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
159.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phases) show
201.000 12.750 moveto
(0) show
207.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
213.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
219.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
225.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
237.000 12.750 moveto
(for) show
261.000 12.750 moveto
(m) show
273.000 12.750 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
285.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
297.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02474 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .015 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
.02381 .16187 m
.06244 .23088 L
.10458 .31175 L
.14415 .38761 L
.18221 .45561 L
.22272 .5178 L
.26171 .5637 L
.28302 .58185 L
.29279 .58839 L
.30316 .59406 L
.31266 .59809 L
.31807 .59988 L
.32313 .60121 L
.32777 .60215 L
.33201 .60277 L
.33436 .60301 L
.33568 .60312 L
.33691 .6032 L
.33809 .60325 L
.33917 .60329 L
.3404 .60331 L
.34157 .60332 L
.34273 .60331 L
.34398 .60327 L
.34515 .60322 L
.34622 .60316 L
.34885 .60295 L
.35133 .60267 L
.35627 .60188 L
.36165 .60066 L
.37124 .59758 L
.38012 .5937 L
.39878 .58239 L
.41939 .56509 L
.45959 .51812 L
.49828 .45906 L
.53942 .38569 L
.57904 .30965 L
.61715 .23641 L
.65771 .16358 L
.69676 .1032 L
.71667 .07742 L
.73825 .05399 L
.75906 .03629 L
.76896 .02965 L
.77824 .02451 L
.78728 .02053 L
.79193 .01888 L
.797 .01739 L
.79987 .01669 L
Mistroke
.80253 .01614 L
.80529 .01566 L
.80778 .01531 L
.81024 .01505 L
.81256 .01487 L
.81383 .0148 L
.815 .01475 L
.81628 .01472 L
.81693 .01472 L
.81764 .01472 L
.81895 .01473 L
.82016 .01476 L
.82079 .01479 L
.82149 .01482 L
.8229 .0149 L
.82546 .01512 L
.82787 .01541 L
.83236 .01613 L
.83719 .0172 L
.84251 .01873 L
.84811 .02071 L
.85811 .02524 L
.8779 .0378 L
.89628 .05361 L
.93537 .09936 L
.97619 .16187 L
Mfstroke
.02381 .05414 m
.06244 .09948 L
.10458 .16424 L
.14415 .23528 L
.18221 .30837 L
.22272 .38611 L
.26171 .45584 L
.30316 .51926 L
.32392 .54541 L
.34309 .56563 L
.36173 .58138 L
.37125 .58784 L
.3815 .59356 L
.3917 .59797 L
.40103 .60086 L
.40552 .60186 L
.40789 .60228 L
.41042 .60265 L
.41284 .60293 L
.41504 .60312 L
.4161 .60319 L
.41725 .60325 L
.41834 .60329 L
.41933 .60331 L
.4206 .60332 L
.42179 .60331 L
.42287 .60329 L
.42403 .60324 L
.4253 .60318 L
.42665 .60309 L
.42907 .60286 L
.4313 .60259 L
.43339 .60228 L
.43816 .60135 L
.44335 .60002 L
.4481 .5985 L
.45882 .59403 L
.46862 .58869 L
.47775 .58268 L
.49845 .56539 L
.53749 .52011 L
.57899 .4568 L
.61897 .38533 L
.65744 .31153 L
.69836 .23295 L
.73776 .16243 L
.77565 .10386 L
.79673 .07659 L
.81599 .05559 L
.8359 .03817 L
Mistroke
.85481 .02595 L
.86442 .02141 L
.86969 .01942 L
.87466 .01786 L
.8793 .01668 L
.88174 .01617 L
.88431 .01572 L
.88649 .0154 L
.88887 .01512 L
.88991 .01502 L
.89103 .01493 L
.89208 .01486 L
.89306 .01481 L
.89428 .01476 L
.89493 .01474 L
.89563 .01472 L
.89632 .01472 L
.89705 .01472 L
.89836 .01473 L
.89957 .01476 L
.9007 .01481 L
.90193 .01488 L
.90325 .01498 L
.90625 .01528 L
.90906 .01567 L
.91434 .01668 L
.91937 .01796 L
.924 .01943 L
.93447 .02374 L
.94419 .02897 L
.95327 .03489 L
.97392 .05197 L
.97619 .05414 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 PageWidth->WindowWidth,
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontSize->12,
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 1532.31}, {945.313, 0}} -> {-1.68585, -0.175695, \
0.0506953, 0.00217583}, {{0, 1149.25}, {709, 0}} -> {-1.68585, -0.175695, \
0.0506953, 0.00217583}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "\n\tMulti-phase sinusoids have an exponential series formulation that \
simplifies, when ",
 StyleBox["m",
  FontSlant->"Italic"],
 " = 4, to half the standard Cos and Sin series, with alternate terms \
becoming zero. ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
 " = {Cos[x]/2, Sin[x]/2, -Cos[x]/2, -Sin[x]/2}. This is traditionally folded \
and mis-interpreted as two asymmetrical phases, {Cos[x], Sin[x]} instead of \
four symmetrical phases.\n\tIt is convenient to include a phase parameter \"j\
\" in the generalised sinusoid procedures ",
 StyleBox["genCos[x,m,j]",
  FontSlant->"Italic"],
 " & ",
 StyleBox["genSin[x,m,j],",
  FontSlant->"Italic"],
 " and to normalize the amplitude to 1. Cosh and Sinh functions are included \
via ",
 StyleBox["m",
  FontSlant->"Italic"],
 "=0 and ",
 StyleBox["m",
  FontSlant->"Italic"],
 "=2, which do not give sinusoids."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Figure 30.",
  FontWeight->"Bold"],
 "  genCos, genSin."
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "genCos"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"genCos[x_,m_:4,j_:0] creates the \!\(\*   \
StyleBox[\\\"j\\\",\\nFontSlant->\\\"Italic\\\"]\)'th phase of the \
generalized antisymmetric sinusoid or helix with \!\(\*   StyleBox[\\\"m\\\",\
\\nFontSlant->\\\"Italic\\\"]\) phases; generalised Cosh and Sinh functions \
are generated if \!\(\*   \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*   \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   StyleBox[\\\"0\\\",\
\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   \
StyleBox[\\\"or\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*   StyleBox[\\\"2\\\",\\nFontSlant->\
\\\"Plain\\\"]\).\"\>"], "Print",
 PageWidth->WindowWidth,
 CellTags->"Info3353843803-4044115"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"genCos", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"m_:", "4"}], ",", 
    RowBox[{"j_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"m", "==", "0"}], ",", 
    RowBox[{"j", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", "x"}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ")"}], "/", "2"}]}], ",", 
    RowBox[{"m", "==", "2"}], ",", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "x"], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "j"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", 
          RowBox[{"-", "x"}]}]]}]}], "]"}], "/", "2"}], ",", 
    "\[IndentingNewLine]", "True", ",", 
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"m", "-", "j"}], ")"}], "/", "m"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Im", "[", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "genSin"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData["\<\"genSin[x_,m_:4,j_:0] creates the \!\(\* StyleBox[\\\"j\\\",\
\\nFontSlant->\\\"Italic\\\"]\)'th phase of the generalized symmetric \
sinusoid or helix with \!\(\* \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]\) phases; generalised Cosh \
and Sinh functions are generated if \!\(\* \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"0\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"or\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"2\\\",\\nFontSlant->\\\
\"Plain\\\"]\).\"\>"], "Print",
 PageWidth->WindowWidth,
 CellTags->"Info3353241802-8811303"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"genSin", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"m_:", "4"}], ",", 
    RowBox[{"j_:", "0"}]}], "]"}], ":=", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"m", "==", "0"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{" ", "x"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "x"}]]}], ")"}], "/", "2"}], ",", 
    RowBox[{"m", "==", "2"}], ",", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "j"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", "x"}]]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "x"}]]}], "]"}], "/", "2"}], ",", "\[IndentingNewLine]", 
    "True", ",", 
    RowBox[{"Im", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"m", "-", "j"}], ")"}], "/", "m"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Im", "[", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 FontWeight->"Plain"],

Cell[TextData[{
 "\tNote that neither the phasality ",
 StyleBox["m",
  FontSlant->"Italic"],
 " nor the phase ",
 StyleBox["j",
  FontSlant->"Italic"],
 " need be an integer. Also ",
 StyleBox["genCos[x,m,m/4] \[Congruent] genSin[x,m]",
  FontSlant->"Italic"],
 ", so one of the series is redundant. Both are included for compatibility \
with normal mathematics, with ",
 StyleBox["genSin",
  FontSlant->"Italic"],
 " as the antisymmetric sinusoid. ",
 StyleBox["genSin",
  FontSlant->"Italic"],
 " is preferable to ",
 StyleBox["genCos",
  FontSlant->"Italic"],
 " in some situations such as Direction Sines, as ",
 StyleBox["genSin[x,m,0]\[ShortRightArrow] x",
  FontSlant->"Italic"],
 " for small ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and the value tends to zero with ",
 StyleBox["x",
  FontSlant->"Italic"],
 ". When x = 0, terms involving ",
 StyleBox["genSin[x,m,0]",
  FontSlant->"Italic"],
 " drop out of expressions, making them compatible with renormalization."
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "genCos"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"genCos[x_,m_:4,j_:0] creates the j'th phase of the generalized \
antisymmetric sinusoid or helix with m phases; generalised Cosh and Sinh \
functions are generated if m=0 or 2.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3422431319-7971780"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "genCos", "]"}], "=", 
      RowBox[{"{", "Protected", "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"genCos", "[", 
          RowBox[{"x_", ",", 
           RowBox[{"m_", ":", "4"}], ",", 
           RowBox[{"j_", ":", "0"}]}], "]"}], ":=", 
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{"m", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", "j", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", "x"], "+", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"-", "x"}]]}], ")"}]}], ",", 
           RowBox[{"m", "\[Equal]", "2"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Re", "[", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", "x"], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}], "j"], " ", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", "x"}]]}]}], "]"}]}], ",", "True", ",", 
           RowBox[{"Re", "[", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              FractionBox[
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"m", "-", "j"}], ")"}]}], "m"]], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"Im", "[", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], 
                 RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], 
          "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["genCos"],
  Editable->False]], "Print",
 CellTags->"Info3422431319-7971780"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "genSin"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"genSin[x_,m_:4,j_:0] creates the j'th phase of the generalized \
symmetric sinusoid or helix with m phases; generalised Cosh and Sinh \
functions are generated if m=0 or 2.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3422431339-9813653"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "genSin", "]"}], "=", 
      RowBox[{"{", "Protected", "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"genSin", "[", 
          RowBox[{"x_", ",", 
           RowBox[{"m_", ":", "4"}], ",", 
           RowBox[{"j_", ":", "0"}]}], "]"}], ":=", 
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{"m", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", "x"], "-", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"-", "x"}]]}], ")"}]}], ",", 
           RowBox[{"m", "\[Equal]", "2"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Re", "[", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}], "j"], " ", 
               SuperscriptBox["\[ExponentialE]", "x"]}], "-", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"-", "x"}]]}], "]"}]}], ",", "True", ",", 
           RowBox[{"Im", "[", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              FractionBox[
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"m", "-", "j"}], ")"}]}], "m"]], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"Im", "[", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], 
                 RowBox[{"2", "/", "m"}]], "]"}], " ", "x"}]]}], "]"}]}], 
          "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["genSin"],
  Editable->False]], "Print",
 CellTags->"Info3422431339-9813653"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["11. Generalizing Complex maths.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". Equations and functions containing \[ImaginaryI]  are often special cases \
of  more generalized functions containing the generalized sign \
\[DoubleStruckS]."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell["\<\
Clifford (Geometric) algebras involve a pseudoscalar \[DoubleStruckCapitalI] \
that replaces \[ImaginaryI] in many situations. See CliffordG.nb.\
\>", "Text",
 FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
 "\tJust as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
 " is a special case of ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[ExponentialE]", "r", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"\[DoubleStruckS]", " "}], "j"], "x"}]], TraditionalForm]]],
 "and Cos[x]+\[ImaginaryI] Sin[x] generalizes to multi-phase sinusoids, many \
other complex functions appear to be special cases of more general functions \
involving \[DoubleStruckS]. Others may be unique to the r=4 case, giving \
complex maths a unique central position in mathematics. The author has \
neither the time nor the ability to explore this vast topic, but makes the \
following observations.\n(1). Generalized signs act as relators for most \
groups. Only a subset have \[ImaginaryI] as a relator, and many of this \
subset have additional relators that are different fourth roots of unity. \
E.g. C4C4, C4iC4, Pauli-\[Sigma] algebra.\n(2). A lot of group theory is \
concerned with unitary complex matrices that dot-multiply to provide the \
elements of particular classes of groups. The Pauli-\[Sigma] algebra is \
archetypical, as it has a representation as \[Sigma]-matrices, which involve \
\[ImaginaryI]. Many other groups have representations via small matrices \
involving other signs. These are widely used in ",
 StyleBox["GroupLoopHoop.m",
  FontSlant->"Italic"],
 "\n(3). \[ImaginaryI] is an intrinsic feature of both Schroedinger's \
equation and Fourier analysis. Together [3] they lead to dispersive Gaussian \
wave packets that describe \"information about particles\". But particles do \
not disperse, and it is an article of the physicist's creed that mathematics \
is the language in which existence is written. Therefore there should be a \
mathematical formulation for particles, possibly as a version of \
Schroedinger's equation involving \[DoubleStruckS], where zitterbewegung \
becomes a multi-phase set of sinusoids.\nHoop algebras provide tantalizing \
glimpses of possibilities for physical mathematics using generalized signs."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["12. Unital \"Orbits\" & sub-algebras. Orbits with \"Offsets\".", \
"Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 StyleBox["Summary",
  FontSlant->"Plain"],
 ". Polar-duals become continuous \"Orbits\" when the non-zero offsets and \
squared radii (or their product) are constrained to be one, defining \"unital\
\" sub-algebras. Many orbits appear to be unstable and have zero size. The \
implications of the few cases with finite sizes are discussed later."
}], "Text",
 PageWidth->WindowWidth,
 FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["C3, K & C4 Orbits have fixed amplitudes.", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tFinite groups have finite \"orbits\", sets of points. These become \
continuous orbits (continuous multi-phase sinusoids) in algebras with \
polar-duals - the duals form an equivalence class if offsets and squared \
radii (or ulnae) are constrained to values of 0 or 1 whilst angles are \
allowed to vary. They constitute continuous closed unitary sub-algebras; \
group multiplication of two orbits gives another orbit.\n\tOnce a hoop is \
specified, Orbit vector values are given by ",
 StyleBox["toVector[P]",
  FontSlant->"Italic"],
 " using arbitrary or symbolic angles, all other parameters in P being 0 or \
1. The three C3 and four C4 orbits are set up in Figure 31; the names \
correspond to the sizes. Note that ",
 StyleBox["shape[\"C3\"]",
  FontSlant->"Italic"],
 " has one L1 (linear) and one L2 (quadratic) size whilst a C3 vector has 3 \
degrees of freedom. Similarly, ",
 StyleBox["shape[\"C4\"]",
  FontSlant->"Italic"],
 " has three size parameters to describe a 4-element vector. Each squared \
radius releases a degree of freedom. This is taken up by the angle parameter, \
which is a \"hidden variable\" for the cartesian form. Each polar-dual \
includes an angle for each quadratic size in the shape. The linear sizes \
become offsets from zero for the centre of rotation, providing conserved \
properties that are not present in the \"standard model\" of particles.\n\t\
Figure 31 also sets up and multiplies the C3 orbits, showing the product to \
be an orbit with the angles added. Then four C4 orbit pairs are set up and \
multiplied; the products have the correct sizes for orbits:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Figure 31. ",
 StyleBox["C3 & C4 Orbit Multiplication.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<C3 Orbits\>\"", ",", 
   RowBox[{
    RowBox[{"hoopShape", "[", "\"\<C3\>\"", "]"}], ";", 
    "\"\<\\nOC301 is {0,1,a} with vector form\>\""}], ",", 
   RowBox[{"OC301", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "a"}], "}"}], "]"}]}], ",", 
   "\"\<\\nOC311 is {1,1,b} with vector form\>\"", ",", 
   RowBox[{"OC311", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "b"}], "}"}], "]"}]}], ",", 
   "\"\<\\nProducts are orbits with added angles; the polar form of the \
product is\>\"", ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{"toPolar", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"OC301", ",", "OC311", ",", "C3"}], "]"}], "]"}], "]"}], ",", 
   "\"\<\\n\\nC4 Orbits\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"hoopShape", "[", "\"\<C4\>\"", "]"}], ";"}], ";", 
    "\"\<\\nOC4001 is {0,0,1,a} with vector form\>\""}], ",", 
   RowBox[{"OC4001", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "a"}], "}"}], "]"}]}], ",", 
   "\"\<\\nOC4011 is {0,1,1,b} with vector form\>\"", ",", 
   RowBox[{"OC4011", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1", ",", "b"}], "}"}], "]"}]}], ",", 
   "\"\<\\nOC4101 = {1,0,1,c} with vector form\>\"", ",", 
   RowBox[{"OC4101", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1", ",", "c"}], "}"}], "]"}]}], ",", 
   "\"\<\\nOC4111 is {1,1,1,d} with vector form\>\"", ",", 
   RowBox[{"OC4111", "=", 
    RowBox[{"toVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1", ",", "d"}], "}"}], "]"}]}], ",", 
   "\"\<\\n\\n\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<OC4001\[Times]OC4001 has the 001 shape\>\"", ",", 
      RowBox[{"shape", "[", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"OC4001", ",", "OC4001", ",", "C4"}], "]"}], "]"}], ",", 
      "\"\<\\nOC4101\[Times]OC4011 also has the 001 shape\\nas the two \
offsets disappear   \>\"", ",", 
      RowBox[{"shape", "[", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"OC4101", ",", "OC4011"}], "]"}], "]"}], ",", 
      "\"\<\\nOC4101\[Times]OC4111 has the 101 shape\>\"", ",", 
      RowBox[{"shape", "[", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"OC4101", ",", "OC4111"}], "]"}], "]"}], ",", 
      "\"\<\\nOC4111\[Times]OC4111 has the 111 shape\>\"", ",", 
      RowBox[{"shape", "[", 
       RowBox[{"hoopTimes", "[", 
        RowBox[{"OC4111", ",", "OC4111"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C3 Orbits\"\>", 
   ",", "\<\"\\nOC301 is {0,1,a} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "a", "]"}]}], "3"], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"a", "+", 
        FractionBox["\[Pi]", "6"]}], "]"}]}], ",", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"a", "-", 
        FractionBox["\[Pi]", "6"]}], "]"}]}]}], "}"}], 
   ",", "\<\"\\nOC311 is {1,1,b} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "b", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"b", "+", 
           FractionBox["\[Pi]", "6"]}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"b", "-", 
           FractionBox["\[Pi]", "6"]}], "]"}]}]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nProducts are orbits with added angles; the polar form of the \
product is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"a", "+", "b"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"a", "+", "b"}], "]"}]}], "]"}]}], "}"}], 
   ",", "\<\"\\n\\nC4 Orbits\"\>", 
   ",", "\<\"\\nOC4001 is {0,0,1,a} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Cos", "[", "a", "]"}], "2"], ",", 
     FractionBox[
      RowBox[{"Sin", "[", "a", "]"}], "2"], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Cos", "[", "a", "]"}], "2"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Sin", "[", "a", "]"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nOC4011 is {0,1,1,b} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "b", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "b", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "b", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "b", "]"}]}]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nOC4101 = {1,0,1,c} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "c", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "c", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "c", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "c", "]"}]}]}], ")"}]}]}], "}"}], 
   ",", "\<\"\\nOC4111 is {1,1,1,d} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "d", "]"}]}]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"Sin", "[", "d", "]"}], "2"], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "d", "]"}]}]}], ")"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Sin", "[", "d", "]"}], "2"]}]}], "}"}], ",", "\<\"\\n\\n\"\>",
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"OC4001\[Times]OC4001 has the 001 shape\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], 
     ",", "\<\"\\nOC4101\[Times]OC4011 also has the 001 shape\\nas the two \
offsets disappear   \"\>", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], 
     ",", "\<\"\\nOC4101\[Times]OC4111 has the 101 shape\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1"}], "}"}], 
     ",", "\<\"\\nOC4111\[Times]OC4111 has the 111 shape\"\>", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe group K (C2C2) cannot have a polar orbit as it has no L2 size, but \
the four L1 sizes can be combined in six ways to give paired \
difference-of-squares formulations. Hyperbolic orbits can be defined using \
any of these as (adjacent",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 ", opposite",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 ") pairs. Two orbits are set up in Figure 32 and multiplied. The product is \
shown to be an orbit with unit sizes; its \"angles\" appear in complex form \
but numeric substitutions show that they are the sums of those in the \
multiplicands."
}], "Text",
 PageWidth->WindowWidth],

Cell["Figure 32. Klein Group Hyperbolic Orbit Multiplication.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"hoopShape", "[", "\"\<K\>\"", "]"}], ";", 
    "\"\<OKh11a is {1,\[Alpha],1,a} with vector form\\n\>\""}], ",", 
   RowBox[{"OKh11a", "=", 
    RowBox[{"tohyVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Alpha]", ",", "1", ",", "a"}], "}"}], "]"}]}], 
   ",", "\"\<\\nOKh11b is {1,\[Beta],1,b} with vector form\>\"", ",", 
   RowBox[{"OKh11b", "=", 
    RowBox[{"tohyVector", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Beta]", ",", "1", ",", "b"}], "}"}], "]"}]}], ",", 
   "\"\<\\nTheir product Polar form is\\n\>\"", ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{"tohyPolar", "[", 
     RowBox[{"hoopTimes", "[", 
      RowBox[{"OKh11a", ",", "OKh11b"}], "]"}], "]"}], "]"}], ",", 
   "\"\<\\nSubstituting \[Alpha]\[Rule].1, \[Beta]\[Rule].3, a\[Rule].22, b\
\[Rule].28 shows that the angles have added; the product angles are \
{\[Alpha]+\[Beta], \
a+b}:-\\n{Log[(Cosh[\[Alpha]+\[Beta]]+Sinh[\[Alpha]+\[Beta]])],Log[(Cosh[a+b]+\
Sinh[a+b])]} = \>\"", ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cosh", "[", 
          RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}], "+", 
         RowBox[{"Sinh", "[", 
          RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}], ")"}], "]"}], ",", 
      RowBox[{"Log", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cosh", "[", 
          RowBox[{"a", "+", "b"}], "]"}], "+", 
         RowBox[{"Sinh", "[", 
          RowBox[{"a", "+", "b"}], "]"}]}], ")"}], "]"}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "\[Rule]", ".1"}], ",", 
      RowBox[{"a", "\[Rule]", ".22"}], ",", 
      RowBox[{"\[Beta]", "\[Rule]", ".3"}], ",", 
      RowBox[{"b", "\[Rule]", ".28"}]}], "}"}]}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 CellOpen->False],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"OKh11a is {1,\[Alpha],1,a} with vector form\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Cosh", "[", "a", "]"}], "2"], "+", 
      FractionBox[
       RowBox[{"Cosh", "[", "\[Alpha]", "]"}], "2"]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"Sinh", "[", "a", "]"}], "2"], "+", 
      FractionBox[
       RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Cosh", "[", "a", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"Cosh", "[", "\[Alpha]", "]"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sinh", "[", "a", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nOKh11b is {1,\[Beta],1,b} with vector form\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Cosh", "[", "b", "]"}], "2"], "+", 
      FractionBox[
       RowBox[{"Cosh", "[", "\[Beta]", "]"}], "2"]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"Sinh", "[", "b", "]"}], "2"], "+", 
      FractionBox[
       RowBox[{"Sinh", "[", "\[Beta]", "]"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Cosh", "[", "b", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"Cosh", "[", "\[Beta]", "]"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sinh", "[", "b", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"Sinh", "[", "\[Beta]", "]"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nTheir product Polar form is\\n\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"\[Piecewise]", GridBox[{
        {
         RowBox[{"0.`", "\[InvisibleSpace]", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Im", "[", 
            RowBox[{"Log", "[", 
             RowBox[{
              RowBox[{"1.`", " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}], "+", 
              RowBox[{"1.`", " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}]}], "]"}], 
            "]"}]}], "+", 
          RowBox[{"Re", "[", 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{"1.`", " ", 
              RowBox[{"Cosh", "[", 
               RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}], "+", 
             RowBox[{"1.`", " ", 
              RowBox[{"Sinh", "[", 
               RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}]}], "]"}], 
           "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"Cosh", "[", 
            RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}], "\[NotEqual]", 
           RowBox[{"Sinh", "[", 
            RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}], "&&", 
          RowBox[{
           RowBox[{
            RowBox[{"Cosh", "[", 
             RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}], "+", 
            RowBox[{"Sinh", "[", 
             RowBox[{"\[Alpha]", "+", "\[Beta]"}], "]"}]}], "\[NotEqual]", 
           "0"}]}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.84]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}], ",", "1", ",", 
     RowBox[{"\[Piecewise]", GridBox[{
        {
         RowBox[{"0.`", "\[InvisibleSpace]", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Im", "[", 
            RowBox[{"Log", "[", 
             RowBox[{
              RowBox[{"1.`", " ", 
               RowBox[{"Cosh", "[", 
                RowBox[{"a", "+", "b"}], "]"}]}], "+", 
              RowBox[{"1.`", " ", 
               RowBox[{"Sinh", "[", 
                RowBox[{"a", "+", "b"}], "]"}]}]}], "]"}], "]"}]}], "+", 
          RowBox[{"Re", "[", 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{"1.`", " ", 
              RowBox[{"Cosh", "[", 
               RowBox[{"a", "+", "b"}], "]"}]}], "+", 
             RowBox[{"1.`", " ", 
              RowBox[{"Sinh", "[", 
               RowBox[{"a", "+", "b"}], "]"}]}]}], "]"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"Cosh", "[", 
            RowBox[{"a", "+", "b"}], "]"}], "\[NotEqual]", 
           RowBox[{"Sinh", "[", 
            RowBox[{"a", "+", "b"}], "]"}]}], "&&", 
          RowBox[{
           RowBox[{
            RowBox[{"Cosh", "[", 
             RowBox[{"a", "+", "b"}], "]"}], "+", 
            RowBox[{"Sinh", "[", 
             RowBox[{"a", "+", "b"}], "]"}]}], "\[NotEqual]", "0"}]}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.84]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}]}], "}"}], 
   ",", "\<\"\\nSubstituting \[Alpha]\[Rule].1, \[Beta]\[Rule].3, \
a\[Rule].22, b\[Rule].28 shows that the angles have added; the product angles \
are {\[Alpha]+\[Beta], a+b}:-\\n{Log[(Cosh[\[Alpha]+\[Beta]]+Sinh[\[Alpha]+\
\[Beta]])],Log[(Cosh[a+b]+Sinh[a+b])]} = \"\>", ",", 
   RowBox[{"{", 
    RowBox[{"0.4`", ",", "0.5`"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C5, C7 & C8 Orbits have unstable amplitudes.", "Subsubsection",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "\tThe orbits of C3 are of fixed squared radius 2/3 and offsets {0,0,0} or \
{1/3, 1/3, 1/3).  Those of C4 are of fixed squared radii or ulnae of \
magnitude 1/2, and offsets {0,..} or {\[PlusMinus]1/4,..}. For C2 there is \
only one (hyperbolic) orbit with a unit ulna. Orbits of C5, C7, Cp (p \
prime>3) etc can be developed, with p sinusoidal phases, but their radii are \
unconstrained, though their offsets are 0 or 1/p. Examples in [1] shows that \
OC51r, a five-phase orbit with radius ",
 StyleBox["r",
  FontSlant->"Italic"],
 ", has a quartic size of zero and so is unconstrained. The angle, linear L1 \
and quartic parameters only use 3 of the 5 degrees of freedom. Similarly, a \
seven-phase orbit with radius ",
 StyleBox["r",
  FontSlant->"Italic"],
 " has a zero size in C7 (I have not found a polar expression for this group) \
and an eight-phase orbit in C8 has a zero size. These orbits also appear to \
be unstable - numerical integration of the relevant differential-equation \
sets is unstable."
}], "Text",
 PageWidth->WindowWidth],

Cell["Figure 33.  Zero-sized C5 orbit.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["\<\
{id[\"C5\"];\"OC51r is\",OC51r = 
    toVector[{d, r, \[Sigma]}], 
  \"\\nThe radius disappears from the shape\", 
  Simplify[shape[OC51r]]}\
\>", "Input",
 PageWidth->WindowWidth,
 CellOpen->False,
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"OC51r is\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "10"], "-", "\[Sigma]"}], "]"}]}]}], ")"}]}], 
     ",", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "5"], "-", "\[Sigma]"}], "]"}]}]}], ")"}]}], 
     ",", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "-", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "5"], "+", "\[Sigma]"}], "]"}]}]}], ")"}]}], 
     ",", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"d", "-", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "10"], "+", "\[Sigma]"}], "]"}]}]}], 
       ")"}]}]}], "}"}], 
   ",", "\<\"\\nThe radius disappears from the shape\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", "0", ",", 
     FractionBox[
      SuperscriptBox["r", "2"], "4"]}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
\t Stable, finite amplitude, orbits with 3, 4, 6, 9, and 12 phases have been \
found, some of which have polarization and chirality (Section 13).\
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["13. Dozal Orbits, Analogies with Particles & Forces.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["Dozal (the algebra of vectors with 12 elements) has elements that \
act as half-spin and unit-spin quantum operators, and stable orbits (some \
with polarization and chirality) that match the families of fundamental \
particles. Dozal is in a real subsymmetric relationship with Hexal (6 \
elements), and a ternal subsymmetric relationship with Tetral (4 elements). \
Multiplication with remainders may correspond to particle interactions, with \
fission and fusion. Instead of being \"point particles\", quarks may be \
multi-phase wave packets with ternary symmetry, and leptons may be wave \
packets with 4-fold symmetry. ",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tThe Appendix shows that the C3K algebra can be interpreted as having \
elements that act as half-spin quantum operators. They cannot be expressed in \
real or complex terms; they combine C3 (terplex numbers) and K (Study \
numbers, or the hyperbolic plane). Section 10. showed that 12-phase systems \
have a natural period of 4\[Pi] - i.e. they have \"half-spin\".\
\>", "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "\t Stable, finite amplitude, orbits with 3, 4, 6, and 12 phases have been \
found for \"Dozal\", the unitary algebra of 12 elements with several \
multiplication rules. Some of these orbits have polarization and chirality. \
In the following examples, the vector form is expressed as \
{a,b,c,d,e,f,g,h,i,j,k,l} and its polar-dual as {\[Alpha], \[Beta], \[Gamma], \
\[Delta], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \
\[Chi], ",
 StyleBox["\[CurlyKappa]\[CurlyKappa]",
  FontWeight->"Bold"],
 ", \[Psi]} for C3K & D3C2, or {\[Alpha], \[Beta], \[Epsilon]\[Epsilon], \
\[Sigma], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \
\[Chi], ",
 StyleBox["\[CurlyKappa]\[CurlyKappa]",
  FontWeight->"Bold"],
 ", \[Psi]} for C3C4 or Q12. The latter have a 4-phase {\[Epsilon]\[Epsilon], \
\[Sigma]} pair in place of the two linear sizes {\[Gamma] ,\[Delta]} of C3K \
and D3C2. Note that {\[Alpha], \[Beta]} and {\[Gamma], \[Delta]} can be \
replaced by hyperbolic orbits. The following expressions are edited to \
emphasise the inter-relationships between the vector and polar forms. In \
particular, square roots of quadratic polar elements such as \[Zeta]\[Zeta] \
become radii such as \[Zeta], and 2\[Pi]/3 is written as \[Omega]:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Figure 34. ",
 StyleBox["C3K Cartesian & Polar-Dual interconversions.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{
  RowBox[{"toPolar", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}], ",", 
    "\"\<C3K\>\""}], "]"}], ";"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Alpha]", "=", 
    RowBox[{
    "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h",
      "+", "i", "+", "j", "+", "k", "+", "l"}]}], ",", 
   RowBox[{"\[Beta]", "=", 
    RowBox[{
    "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", "h",
      "+", "i", "-", "j", "-", "k", "-", "l"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"\[Gamma]", "=", 
    RowBox[{
    "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "-", "g", "-", "h",
      "-", "i", "-", "j", "-", "k", "-", "l"}]}], ",", 
   RowBox[{"\[Delta]", "=", 
    RowBox[{
    "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "-", "g", "-", "h",
      "-", "i", "+", "j", "+", "k", "+", "l"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"\[Zeta]\[Zeta]", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
         "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-",
           "k"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
         "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-",
           "l"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "+", 
          "i", "-", "j", "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"\[Tau]", "=", 
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
       RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "+", 
       RowBox[{"2", " ", "g"}], "-", "h", "-", "i", "+", 
       RowBox[{"2", " ", "j"}], "-", "k", "-", "l"}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], " ", 
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-", 
         "l"}], ")"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]\[Lambda]", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
         "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", "+",
           "k"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "-", "g", "+", 
          "i", "+", "j", "-", "l"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
         "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", "+",
           "l"}], ")"}], "2"]}], ")"}], "/", "2"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"\[Phi]", "=", 
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
       RowBox[{"2", " ", "d"}], "+", "e", "+", "f", "+", 
       RowBox[{"2", " ", "g"}], "-", "h", "-", "i", "-", 
       RowBox[{"2", " ", "j"}], "+", "k", "+", "l"}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], " ", 
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", "+", 
         "l"}], ")"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"\[Eta]\[Eta]", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
         "a", "-", "b", "+", "d", "-", "e", "-", "g", "+", "h", "-", "j", "+",
           "k"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "+", "g", "-", 
          "i", "+", "j", "-", "l"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
         "b", "-", "c", "+", "e", "-", "f", "-", "h", "+", "i", "-", "k", "+",
           "l"}], ")"}], "2"]}], ")"}], "/", "2"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"\[Chi]", "=", 
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
       RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "-", 
       RowBox[{"2", " ", "g"}], "+", "h", "+", "i", "-", 
       RowBox[{"2", " ", "j"}], "+", "k", "+", "l"}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], " ", 
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "+", "e", "-", "f", "-", "h", "+", "i", "-", "k", "+", 
         "l"}], ")"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"\[CurlyKappa]\[CurlyKappa]", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
         "a", "-", "b", "-", "d", "+", "e", "-", "g", "+", "h", "+", "j", "-",
           "k"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
         "b", "-", "c", "-", "e", "+", "f", "-", "h", "+", "i", "+", "k", "-",
           "l"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "+", "g", "-", 
          "i", "-", "j", "+", "l"}], ")"}], "2"]}], ")"}], "/", "2"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"\[Psi]", "=", 
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
       RowBox[{"2", " ", "d"}], "+", "e", "+", "f", "-", 
       RowBox[{"2", " ", "g"}], "+", "h", "+", "i", "+", 
       RowBox[{"2", " ", "j"}], "-", "k", "-", "l"}], ",", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], " ", 
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "-", "e", "+", "f", "-", "h", "+", "i", "+", "k", "-", 
         "l"}], ")"}]}]}], "]"}]}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{"C3Kv", "=", 
  RowBox[{
   RowBox[{"toVector", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]", ",", 
       "\[Zeta]\[Zeta]", ",", "\[Tau]", ",", "\[Lambda]\[Lambda]", ",", 
       "\[Phi]", ",", "\[Eta]\[Eta]", ",", "\[Chi]", ",", 
       "\[CurlyKappa]\[CurlyKappa]", ",", "\[Psi]"}], "}"}], ",", 
     "\"\<C3K\>\""}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", 
       RowBox[{"\[Pi]", "/", "3"}]}], "\[Rule]", "\[Omega]"}], ",", " ", 
     RowBox[{
      RowBox[{"4", 
       RowBox[{"\[Pi]", "/", "3"}]}], "\[Rule]", 
      RowBox[{"2", "\[Omega]"}]}], ",", 
     RowBox[{
      SqrtBox["\[Zeta]\[Zeta]"], "\[Rule]", "\[Zeta]"}], ",", 
     RowBox[{
      SqrtBox["\[Lambda]\[Lambda]"], "\[Rule]", "\[Lambda]"}], ",", 
     RowBox[{
      SqrtBox["\[Eta]\[Eta]"], "\[Rule]", "\[Eta]"}], ",", 
     RowBox[{
      SqrtBox["\[CurlyKappa]\[CurlyKappa]"], "\[Rule]", "\[CurlyKappa]"}]}], 
    "}"}]}]}]], "Input",
 PageWidth->WindowWidth],

Cell[TextData[{
 "The above expression is not shown directly, but it tidies up to give\n",
 StyleBox["Figure 35",
  FontWeight->"Bold"],
 ":-"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"           ", 
  RowBox[{
   RowBox[{
   "C3K\[Alpha]\[Beta]\[Gamma]\[Delta]\[Zeta]\[Tau]\[Lambda]\[Phi]\[Eta]\[Chi]\
\[Kappa]\[Psi]", " ", ".", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "     ", "+", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "+", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "-", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "-", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "-", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "-", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "      ", "+", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", " ", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"2", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}]}], "}"}]}], "/", 
   "12"}]}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell["\<\
Here, \[Tau] occurs in four copies of a 3-phase system, \[Lambda], \[Eta], & \
\[Psi] each occur in two copies of different 6-phase systems. 12-phase \
systems can be obtained by making two of these systems have the same radii \
and period, but with a phase shift of \[Pi]/6. I conjecture that these are \
related to the three families of quarks.
\tThe C3C4 orbits duplicate the {\[Tau], \[Lambda]} orbits and replace the {\
\[Gamma], \[Delta]} linear sizes by a 4-phase {\[Epsilon], \[Sigma]} \
sinusoid. I conjecture that this is related to the leptons. The {\[Eta], \
\[Kappa]} orbits are more complicated in C3C4 than in C3K:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Figure", " ", "36.", "  ", "General", " ", "C3C4", " ", 
  RowBox[{"orbit", "."}]}]], "Input",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_"}], "}"}], ",", 
     "\"\<C3C4\>\""}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "=", 
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}]}], ",", 
       RowBox[{"e1", "=", 
        RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}]}], 
       ",", 
       RowBox[{"e2", "=", 
        RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"a1", "=", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-", 
         "k"}]}], ",", 
       RowBox[{"a2", "=", 
        RowBox[{
        "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", "+", 
         "k"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"b1", "=", 
        RowBox[{
        "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-", 
         "l"}]}], ",", 
       RowBox[{"b2", "=", 
        RowBox[{
        "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", "+", 
         "l"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"c1", "=", 
        RowBox[{
        "c", "-", "a", "+", "f", "-", "d", "+", "i", "-", "g", "+", "l", "-", 
         "j"}]}], ",", 
       RowBox[{"c2", "=", 
        RowBox[{
        "c", "-", "a", "-", "f", "+", "d", "+", "i", "-", "g", "-", "l", "+", 
         "j"}]}], ",", 
       RowBox[{"f1", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
            RowBox[{"2", "l"}]}], ")"}], "/", 
          SqrtBox["3"]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"f2", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
            RowBox[{"2", "i"}]}], ")"}], "/", 
          SqrtBox["3"]}], "-", "d", "+", "e", "+", "j", "-", "k"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"f3", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
            RowBox[{"2", "l"}]}], ")"}], "/", 
          SqrtBox["3"]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"f4", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
            RowBox[{"2", "i"}]}], ")"}], "/", 
          SqrtBox["3"]}], "+", "d", "-", "e", "-", "j", "+", "k"}]}]}], "}"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"(*", "\[Alpha]", "*)"}], 
      RowBox[{
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
        "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
       RowBox[{"(*", "\[Beta]", "*)"}], 
       RowBox[{
       "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
        "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Epsilon]", "*)"}], 
       RowBox[{
        SuperscriptBox["e1", "2"], "+", 
        SuperscriptBox["e2", "2"]}], ",", 
       RowBox[{"(*", "\[Sigma]", "*)"}], 
       RowBox[{"ArcTan", "[", 
        RowBox[{"e1", ",", "e2"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Zeta]", "*)"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a1", "2"], "+", 
          SuperscriptBox["b1", "2"], "+", 
          SuperscriptBox["c1", "2"]}], ")"}], "/", "2"}], ",", 
       RowBox[{"(*", "\[Tau]", "*)"}], 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"a1", "-", "c1"}], ",", 
         RowBox[{"r", " ", "b1"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Lambda]", "*)"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a2", "2"], "+", 
          SuperscriptBox["b2", "2"], "+", 
          SuperscriptBox["c2", "2"]}], ")"}], "/", "2"}], ",", 
       RowBox[{"(*", "\[Phi]", "*)"}], 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"a2", "-", "c2"}], ",", 
         RowBox[{"r", " ", "b2"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Eta]", "*)"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["f1", "2"], "+", 
          SuperscriptBox["f2", "2"]}], ")"}], 
        RowBox[{"3", "/", "4"}]}], ",", 
       RowBox[{"(*", "x", "*)"}], 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{"f1", ",", "f2"}], "]"}], "-", 
        RowBox[{"\[Pi]", "/", "6"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Kappa]", "*)"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["f3", "2"], "+", 
          SuperscriptBox["f4", "2"]}], ")"}], 
        RowBox[{"3", "/", "4"}]}], ",", 
       RowBox[{"(*", "y", "*)"}], 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{"f3", ",", "f4"}], "]"}], "-", 
        RowBox[{"\[Pi]", "/", "6"}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "  ", 
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "+", 
       RowBox[{"\[Eta]", "      ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"b", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Eta]", "      ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"c", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], 
       "                        ", "-", 
       RowBox[{"\[Eta]", " ", "r6", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "                  ", "-", 
       RowBox[{"\[Kappa]", " ", "r6", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"d", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "    ", "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], " ", "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"e", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "    ", "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], " ", "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"f", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", "r6", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "                       ", "+", 
       RowBox[{"\[Kappa]", " ", "r6", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}]}], "                   ", ")"}]}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"g", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
       RowBox[{"\[Eta]", "      ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"h", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Eta]", "      ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"i", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], 
       "                        ", "+", 
       RowBox[{"\[Eta]", " ", "r6", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "                   ", "+", 
       RowBox[{"\[Kappa]", " ", "r6", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"j", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "    ", "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "  ", "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"k", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "    ", "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "  ", "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"l", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", "r6", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "                       ", "+", 
       RowBox[{"\[Kappa]", " ", "r6", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}]}], "           ", ")"}]}]}], "}"}], 
  "/", "12"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 FontSize->9],

Cell["\<\
\tThe non-abelian groups D3C2 and Q12 are very closely related to C3K and \
C3C4 respectively - their shapes include some shared sizes.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["Figure 37. General D3C2 orbit..", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{"     ", 
  RowBox[{
  "D3C2\[Alpha]\[Beta]\[Gamma]\[Delta]\[Zeta]\[Tau]\[Lambda]\[Phi]\[Eta]\[Chi]\
\[CurlyKappa]\[Psi]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"4", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
       RowBox[{"4", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"4", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"4", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
       RowBox[{"4", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"4", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "      ", 
       "-", 
       RowBox[{"4", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
       RowBox[{"4", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "      ", 
       "-", 
       RowBox[{"4", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"4", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "      ", 
       "-", 
       RowBox[{"4", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"4", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"4", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
       RowBox[{"4", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"4", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"4", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
       RowBox[{"4", " ", "\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"4", " ", "\[Eta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Chi]", "+", 
          RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "      ", 
       "-", 
       RowBox[{"4", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
       RowBox[{"4", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "      ", 
       "-", 
       RowBox[{"4", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"4", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ")"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
      "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "      ", 
       "-", 
       RowBox[{"4", " ", "\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"4", " ", "\[CurlyKappa]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ")"}]}], 
    "}"}]}]}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{"toVec", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Alpha]_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
      "\[Zeta]\[Zeta]_", ",", "\[Tau]_", ",", "\[Lambda]\[Lambda]_", ",", 
      "\[Phi]_", ",", "\[Eta]\[Eta]_", ",", "\[Chi]_", ",", 
      "\[Kappa]\[Kappa]_", ",", "\[Psi]_"}], "}"}], ",", "\"\<D3C2\>\""}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Zeta]", "=", 
       RowBox[{"4", 
        SqrtBox["\[Zeta]\[Zeta]"]}]}], ",", 
      RowBox[{"\[Lambda]", "=", 
       RowBox[{"4", 
        SqrtBox["\[Lambda]\[Lambda]"]}]}], ",", 
      RowBox[{"\[Eta]", "=", 
       RowBox[{"4", 
        SqrtBox["\[Eta]\[Eta]"]}]}], ",", 
      RowBox[{"\[Kappa]", "=", 
       RowBox[{"4", 
        SqrtBox["\[Kappa]\[Kappa]"]}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"{", "      ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "+", "\[Gamma]", "+", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "+", "\[Gamma]", "-", "\[Delta]", "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "-", "\[Delta]", "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
        RowBox[{"\[Eta]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
       "\[Alpha]", "-", "\[Beta]", "-", "\[Gamma]", "+", "\[Delta]", "-", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
        RowBox[{"\[Kappa]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}]}], "}"}], "/", 
     "12"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 FontSize->9],

Cell["Figure 38. Q12 Cartesian & Polar-Dual interconversions.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Q12p", "[", 
    RowBox[{"{", 
     RowBox[{
     "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
      ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_"}], "}"}], "]"}], ":=",
    
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Alpha]", "=", 
      RowBox[{
      "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
       "h", "+", "i", "+", "j", "+", "k", "+", "l"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Beta]", "=", 
      RowBox[{
      "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
       "h", "+", "i", "-", "j", "-", "k", "-", "l"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Epsilon]\[Epsilon]", "=", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], 
         ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}], 
         ")"}], "2"]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], ",", 
        
        RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}]}], 
       "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Zeta]\[Zeta]", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "g", "-", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "c", "+", "h", "-", "i"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c", "-", "g", "+", "i"}], ")"}], "2"]}],
         ")"}], "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Tau]", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
         RowBox[{"2", " ", "g"}], "-", "h", "-", "i"}], ",", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["3"]}], " ", 
         RowBox[{"(", 
          RowBox[{"b", "-", "c", "+", "h", "-", "i"}], ")"}]}]}], "]"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"\[Lambda]\[Lambda]", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "e", "+", "j", "-", "k"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "f", "+", "k", "-", "l"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "d"}], "+", "f", "-", "j", "+", "l"}], ")"}], "2"]}],
         ")"}], "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Phi]", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "+", 
         RowBox[{"2", " ", "j"}], "-", "k", "-", "l"}], ",", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["3"]}], " ", 
         RowBox[{"(", 
          RowBox[{"e", "-", "f", "+", "k", "-", "l"}], ")"}]}]}], "]"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"\[Eta]\[Eta]", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "g", "+", "h"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c", "+", "g", "-", "i"}], ")"}], "2"], 
         "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "c", "-", "h", "+", "i"}], ")"}], "2"]}], ")"}], 
       "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Chi]", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
         RowBox[{"2", " ", "g"}], "+", "h", "+", "i"}], ",", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["3"]}], " ", 
         RowBox[{"(", 
          RowBox[{"b", "-", "c", "-", "h", "+", "i"}], ")"}]}]}], "]"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"\[CurlyKappa]\[CurlyKappa]", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "e", "-", "j", "+", "k"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "d"}], "+", "f", "+", "j", "-", "l"}], ")"}], "2"], 
         "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"e", "-", "f", "-", "k", "+", "l"}], ")"}], "2"]}], ")"}], 
       "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Psi]", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "-", 
         RowBox[{"2", " ", "j"}], "+", "k", "+", "l"}], ",", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["3"]}], " ", 
         RowBox[{"(", 
          RowBox[{"e", "-", "f", "-", "k", "+", "l"}], ")"}]}]}], "]"}]}]}], 
    "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[{
 RowBox[{"The", " ", "Q12", " ", "polar", " ", "reversion", " ", "has", " ", 
  "been", " ", "tidied", " ", "up", " ", "by", " ", "the", " ", 
  "substitutions"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "->", 
   SqrtBox["\[Epsilon]\[Epsilon]"]}], ",", 
  RowBox[{"\[Zeta]", "->", 
   SqrtBox["\[Zeta]\[Zeta]"]}], ",", " ", 
  RowBox[{"\[Lambda]", "->", 
   SqrtBox["\[Lambda]\[Lambda]"]}], ",", 
  RowBox[{"\[Eta]", " ", "->", 
   SqrtBox[
    RowBox[{"\[Eta]\[Eta]", " "}]]}], ",", 
  RowBox[{"\[CurlyKappa]", "  ", "->", 
   SqrtBox["\[CurlyKappa]\[CurlyKappa]"]}], ",", 
  RowBox[{"\[Omega]", "\[Rule]", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"\[Pi]", "/", "3"}]}], ":", 
    RowBox[{
     RowBox[{"-", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"4", " ", "\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
         RowBox[{"4", " ", "\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"4", " ", "\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"4", " ", "\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"4", " ", "\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"4", " ", "\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
         RowBox[{"4", " ", "\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
         RowBox[{"4", " ", "\[CurlyKappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
         RowBox[{"4", " ", "\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"4", " ", "\[CurlyKappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
         RowBox[{"4", " ", "\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
         RowBox[{"4", " ", "\[CurlyKappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"4", " ", "\[Zeta]", " ", 
          RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "-", 
         RowBox[{"4", " ", "\[Eta]", " ", 
          RowBox[{"Cos", "[", "\[Chi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"4", " ", "\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"4", " ", "\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
         RowBox[{"4", " ", "\[Zeta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"4", " ", "\[Eta]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Chi]", "-", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
         RowBox[{"4", " ", "\[Lambda]", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
         RowBox[{"4", " ", "\[CurlyKappa]", " ", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", "\[IndentingNewLine]",
         
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
         RowBox[{"4", " ", "\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"4", " ", "\[CurlyKappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "+", "\[Omega]"}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
         RowBox[{"2", " ", "\[Epsilon]", " ", 
          RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "     ", "+", 
         RowBox[{"4", " ", "\[Lambda]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
         RowBox[{"4", " ", "\[CurlyKappa]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]", "-", "\[Omega]"}], "]"}]}]}]}], "}"}]}], "/", 
     "12"}]}]}]}]}], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[TextData[{
 "\tIn all cases, orbits are created by conversion to unital sub-algebras, \
with arbitrary angles and with the other components \
(\[Alpha],\[Beta],\[Gamma],\[Delta],\[Epsilon],\[Zeta],\[Eta],\[Lambda],\[Xi],\
",
 StyleBox["\[CurlyKappa]) ",
  FontWeight->"Bold"],
 "all being either 0 or 1. They can be identified by appending names of the \
non-zero parameteres to that of the algebra, as in Figure 39:-"
}], "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Figure", " ", "39.", "  ", 
  StyleBox["Some",
   FontWeight->"Plain"], 
  StyleBox[" ",
   FontWeight->"Plain"], 
  StyleBox["C3K",
   FontWeight->"Plain"], 
  StyleBox[" ",
   FontWeight->"Plain"], 
  StyleBox[
   RowBox[{"orbits", "."}],
   FontWeight->"Plain"]}]], "Input",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[BoxData[GridBox[{
   {
    RowBox[{"     ", 
     RowBox[{"C3K\[Tau]\[Phi]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", "  ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Tau]", "]"}], "         ", "+", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ")"}], ",", "       ", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", "   ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"2", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Tau]", " ", "]"}], "        ", "-", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", "   ", "\[Omega]"}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Tau]", "]"}], "         ", "+", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", "   ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Tau]", "]"}], "          ", "-", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", "   ", "\[Omega]"}], "]"}], " ", "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}]}], "}"}], "/", 
       "6"}]}]}], 
    RowBox[{"              ", 
     RowBox[{"C3K\[Alpha]\[Tau]\[Chi]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", "  ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", "\[Tau]", "]"}], "         ", "+", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}]}], ")"}], ",", "       ", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", "   ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", " ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", "\[Tau]", " ", "]"}], "        ", "+", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", "   ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", "\[Tau]", "]"}], "         ", "-", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", "   ", "\[Omega]"}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "  ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", "\[Tau]", "]"}], "         ", "-", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}], "   ", "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Tau]", "+", 
             RowBox[{"2", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}]}], "}"}], "/", 
       "6"}]}]}]},
   {
    RowBox[{"  ", "\[IndentingNewLine]", "      ", 
     RowBox[{"C3K\[Alpha]\[Delta]\[Chi]\[Psi]", " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", "  ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}], "         ", "+", 
           RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{"1", "+", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "  ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{"1", "+", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", "       ", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Chi]", "]"}], "         ", "-", 
           RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", "       ", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "   ", "\[Omega]"}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", "       ", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", "     ", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Cos", "[", "\[Chi]", "]"}]}], "         ", "-", 
           RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", "     ", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Chi]", "+", "   ", "\[Omega]"}], "]"}]}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", "     ", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Chi]", "+", 
              RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}], "        ", "+", 
           RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "   ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}]}], "}"}], "/", 
       "6"}]}]}], 
    RowBox[{"\[IndentingNewLine]", "           ", 
     RowBox[{
     "C3K\[Beta]\[Gamma]\[Delta]\[Phi]\[Chi]\[Psi]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", "   ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.5", "+", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}], "         ", "+", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}], "          ", "+", 
           RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{"1.5", "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", "   ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "   ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", "  ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{"1.5", "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "-", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}], "         ", "+", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}], "         ", "-", 
           RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", "   ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "   ", "\[Omega]"}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "+", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}], "         ", "-", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}], "          ", "-", 
           RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", "   ", "\[Omega]"}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "    ", "\[Omega]"}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", "   ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"2", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", 
             RowBox[{"2", "\[Omega]"}]}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "-", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}], "         ", "-", 
           RowBox[{"Cos", "[", "\[Chi]", "]"}], "          ", "+", 
           RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", "   ", "\[Omega]"}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", "    ", "\[Omega]"}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", "  ", "\[Omega]"}], "]"}]}], ")"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", ".5"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"2", "\[Omega]"}]}], "]"}], "-", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Chi]", "+", 
             RowBox[{"2", "\[Omega]"}]}], "]"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]", "+", 
             RowBox[{"2", " ", "\[Omega]"}]}], "]"}]}], ")"}]}], "}"}], "/", 
       "6"}]}]}]}
  }]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell["\<\
\tThese orbits may be related to deBroglie waves or to zitterbewung. Elements \
of the generating algebras (e.g. C3K) act as unit-spin and half-spin quantum \
operators. This leads to the surmise that quarks are multi-phase wave packets \
with ternary symmetry, and leptons are wave packets with 4-fold symmetry. The \
orbit magnitudes may be related to the Planck size of \"extended\" particles; \
the number of types of particles may be related to the number of stable \
orbits. The 12-element algebras are in a \"subsymmetric\" relation to the \
algebras with 6 elements, \"Hexal\". (This respects the convention that \
unit-spin is supersymmetric to half spin. It also suggest that supersymmetry \
involves fewer, rather than the same number of, partners.) The symmetry is \
shown in Figure 40, where the elements of C3K are folded by replacing a & g \
by a/2 & -a/2, etc. The polar form loses 6 elements whilst the other elements \
match those of C3C2:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"Figure", " ", "40.", "  ", 
  StyleBox["C3K",
   FontWeight->"Plain"], 
  StyleBox[" ",
   FontWeight->"Plain"], 
  StyleBox["is",
   FontWeight->"Plain"], 
  StyleBox[" ",
   FontWeight->"Plain"], 
  StyleBox["Subsymmetric",
   FontWeight->"Plain"], 
  StyleBox[" ",
   FontWeight->"Plain"], 
  StyleBox["to",
   FontWeight->"Plain"], 
  StyleBox["  ",
   FontWeight->"Plain"], 
  StyleBox[
   RowBox[{"C3C2", "."}],
   FontWeight->"Plain"]}]], "Input",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[BoxData[
 RowBox[{"toPolar", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}], ",", 
      RowBox[{"-", "d"}], ",", 
      RowBox[{"-", "e"}], ",", 
      RowBox[{"-", "f"}]}], "}"}], "/", "2"}], ",", "\"\<C3K\>\""}], 
  "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "d", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f"}], ")"}], "2"]}], 
     ")"}], "/", "2"}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
      RowBox[{"2", " ", "d"}], "-", "e", "-", "f"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "d", "+", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "-", "e", "+", "f"}], ")"}], "2"]}], ")"}], 
    "/", "2"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
      RowBox[{"2", " ", "d"}], "+", "e", "+", "f"}], ",", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "-", "c", "-", "e", "+", "f"}], ")"}]}]}], "]"}]}], 
  "}"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9],

Cell[BoxData[
 RowBox[{"toPolar", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
   ",", "\"\<C3C2\>\""}], "]"}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "d", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f"}], ")"}], "2"]}], 
     ")"}], "/", "2"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "+", 
      RowBox[{"2", " ", "d"}], "-", "e", "-", "f"}], ",", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "b"}], "+", "c", "-", "e", "+", "f"}], ")"}]}]}], "]"}], 
   ",", "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "d", "+", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "-", "e", "+", "f"}], ")"}], "2"]}], ")"}], 
    "/", "2"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "b", "-", "c", "-", 
      RowBox[{"2", " ", "d"}], "+", "e", "+", "f"}], ",", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "b"}], "+", "c", "+", "e", "-", "f"}], ")"}]}]}], 
    "]"}]}], "}"}]], "Input",
 PageWidth->WindowWidth,
 FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell["14. Time as a parameter.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Inherent in my conjecture that orbits relate to particles is the concept \
that angles change with \"time\" in some way. C3C4 has the following angles:-\
\nArcTan[a+b+c-g-h-i,d+e+f-j-k-l]\nArcTan[2a-b-c+2d-e-f+ 2g-h-i+ 2j-k-l, -",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "(b-c+e-f+h-i+k-l)]\nArcTan[2a-b-c-2d+e+f+2g-h-i-2j+k+l, -",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "(b-c-e+f+h-i-k+l)]\nArcTan[2a-b-c+2d-e-f-2g+h+i-2j+k+l, -",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "(b-c+e-f-h+i-k+l)]\nArcTan[2a-b-c-2d+e+f-2g+h+i+2j-k-l, -",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "(b-c-e+f-h+i+k-l)].\n\nC3K has the same last four angles It folds to C3C2 \
with\nArcTan[2a-b-c+2d-e-f, -",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "(b-c+e-f)]\nArcTan[2a-b-c-2d+e+f, -",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]]],
 "(b-c-e+f)]\n\nC3C4 3-folds to C4, with these and \nArcTan[a-c,b-d]\nAll \
these angles increase with -a/b, so put t=-a/b, in the form b=-a t"
}], "Text",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", "a"}], "-", "b", "-", "c", "+", 
       RowBox[{"2", "d"}], "-", "e", "-", "f"}], ",", 
      RowBox[{
       FormBox[
        SqrtBox["3"],
        TraditionalForm], 
       RowBox[{"(", 
        RowBox[{"c", "-", "e", "+", "f", "-", "b"}], ")"}]}]}], "]"}], ",", 
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{"a", "-", "c"}], ",", 
      RowBox[{"b", "-", "d"}]}], "]"}]}], "}"}], "/.", 
  RowBox[{"b", "\[Rule]", 
   RowBox[{
    RowBox[{"-", "a"}], " ", "t"}]}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "a"}], "-", "c", "+", 
      RowBox[{"2", " ", "d"}], "-", "e", "-", "f", "+", 
      RowBox[{"a", " ", "t"}]}], ",", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{"c", "-", "e", "+", "f", "+", 
        RowBox[{"a", " ", "t"}]}], ")"}]}]}], "]"}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"a", "-", "c"}], ",", 
     RowBox[{
      RowBox[{"-", "d"}], "-", 
      RowBox[{"a", " ", "t"}]}]}], "]"}]}], "}"}]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "But there are the constant size constraints to maintain, such as ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "d"}], ")"}], "2"]}],
   FontFamily->"Times New Roman"]], "Text"],
 "=1. More work (and inspiration!) is needed here"
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
\tThe l22a & l22b sizes of C3C4 are factors of the L4s size, which is a \
6-Vector, the sum of six squared terms with a seventh squared term \
subtracted:-\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
L4s=l22a*l22b=(3((a-b+(d+e-2*f)/Sqrt[3])^2+((a+b-2*c)/Sqrt[3]-d+e)^2)/4)*(3((\
a-b-(d+e-2*f)/Sqrt[3])^2+((a+b-2*c)/Sqrt[3]+d-e)^2)/4).\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"l22a", "=."}], ";", 
  RowBox[{"l22b", "=."}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sh", "=", 
   RowBox[{"sh12", "[", 
    RowBox[{"{", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"sh", "[", 
  RowBox[{"[", "5", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"sh", "[", 
  RowBox[{"[", "6", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["3", "4"], 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"d", "-", "e", "-", 
       RowBox[{
        SuperscriptBox["3", 
         RowBox[{"-", 
          FractionBox["1", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", 
          RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
          RowBox[{"2", "i"}]}], ")"}]}], "-", "j", "+", "k"}], ")"}], "2"], 
    "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b", "-", "g", "+", "h", "+", 
       RowBox[{
        SuperscriptBox["3", 
         RowBox[{"-", 
          FractionBox["1", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"d", "+", "e", "-", 
          RowBox[{"2", "f"}], "-", "j", "-", "k", "+", 
          RowBox[{"2", "l"}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox["3", "4"], 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"d", "-", "e", "+", 
       RowBox[{
        SuperscriptBox["3", 
         RowBox[{"-", 
          FractionBox["1", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", 
          RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
          RowBox[{"2", "i"}]}], ")"}]}], "-", "j", "+", "k"}], ")"}], "2"], 
    "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b", "-", "g", "+", "h", "-", 
       RowBox[{
        SuperscriptBox["3", 
         RowBox[{"-", 
          FractionBox["1", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"d", "+", "e", "-", 
          RowBox[{"2", "f"}], "-", "j", "-", "k", "+", 
          RowBox[{"2", "l"}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"toPol", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
       ",", "h_", ",", "i_", ",", "j_", ",", "k_", ",", "l_"}], "}"}], ",", 
     "\"\<C3C4\>\""}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "=", 
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "3", "]"}]}]}], ",", 
       RowBox[{"e1", "=", 
        RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}]}], 
       ",", 
       RowBox[{"e2", "=", 
        RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"a1", "=", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-", 
         "k"}]}], ",", 
       RowBox[{"a2", "=", 
        RowBox[{
        "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", "+", 
         "k"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"b1", "=", 
        RowBox[{
        "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-", 
         "l"}]}], ",", 
       RowBox[{"b2", "=", 
        RowBox[{
        "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", "+", 
         "l"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"c1", "=", 
        RowBox[{
        "c", "-", "a", "+", "f", "-", "d", "+", "i", "-", "g", "+", "l", "-", 
         "j"}]}], ",", 
       RowBox[{"c2", "=", 
        RowBox[{
        "c", "-", "a", "-", "f", "+", "d", "+", "i", "-", "g", "-", "l", "+", 
         "j"}]}], ",", 
       RowBox[{"f1", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
            RowBox[{"2", "l"}]}], ")"}], "/", 
          SqrtBox["3"]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"f2", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
            RowBox[{"2", "i"}]}], ")"}], "/", 
          SqrtBox["3"]}], "-", "d", "+", "e", "+", "j", "-", "k"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"f3", "=", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"d", "+", "e", "-", 
            RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
            RowBox[{"2", "l"}]}], ")"}], "/", 
          SqrtBox["3"]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"f4", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", "c"}], "-", "g", "-", "h", "+", 
            RowBox[{"2", "i"}]}], ")"}], "/", 
          SqrtBox["3"]}], "+", "d", "-", "e", "-", "j", "+", "k"}]}]}], "}"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"(*", "\[Alpha]", "*)"}], 
      RowBox[{
       RowBox[{
       "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", 
        "h", "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
       RowBox[{"(*", "\[Beta]", "*)"}], 
       RowBox[{
       "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", 
        "h", "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Epsilon]", "*)"}], 
       RowBox[{
        SuperscriptBox["e1", "2"], "+", 
        SuperscriptBox["e2", "2"]}], ",", 
       RowBox[{"(*", "\[Sigma]", "*)"}], 
       RowBox[{"ArcTan", "[", 
        RowBox[{"e1", ",", "e2"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Zeta]", "*)"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a1", "2"], "+", 
          SuperscriptBox["b1", "2"], "+", 
          SuperscriptBox["c1", "2"]}], ")"}], "/", "2"}], ",", 
       RowBox[{"(*", "\[Tau]", "*)"}], 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"a1", "-", "c1"}], ",", 
         RowBox[{"r", " ", "b1"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Lambda]", "*)"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a2", "2"], "+", 
          SuperscriptBox["b2", "2"], "+", 
          SuperscriptBox["c2", "2"]}], ")"}], "/", "2"}], ",", 
       RowBox[{"(*", "\[Phi]", "*)"}], 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"a2", "-", "c2"}], ",", 
         RowBox[{"r", " ", "b2"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Eta]", "*)"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["f1", "2"], "+", 
          SuperscriptBox["f2", "2"]}], ")"}], 
        RowBox[{"3", "/", "4"}]}], ",", 
       RowBox[{"(*", "x", "*)"}], 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{"f1", ",", "f2"}], "]"}], "-", 
        RowBox[{"\[Pi]", "/", "6"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", "\[Kappa]", "*)"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["f3", "2"], "+", 
          SuperscriptBox["f4", "2"]}], ")"}], 
        RowBox[{"3", "/", "4"}]}], ",", 
       RowBox[{"(*", "y", "*)"}], 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{"f3", ",", "f4"}], "]"}], "-", 
        RowBox[{"\[Pi]", "/", "6"}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 FontSize->9],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "  ", 
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "      ", "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "     ", "+", 
       RowBox[{"\[Eta]", "      ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"b", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Eta]", "      ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"c", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], 
       "                        ", "-", 
       RowBox[{"\[Eta]", " ", "r6", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "                  ", "-", 
       RowBox[{"\[Kappa]", " ", "r6", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"d", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "+", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "    ", "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], " ", "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"e", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "    ", "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], " ", "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"f", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", "r6", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "                       ", "+", 
       RowBox[{"\[Kappa]", " ", "r6", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}]}], "                   ", ")"}]}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"g", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
       RowBox[{"\[Eta]", "      ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"h", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Eta]", "      ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "-", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"i", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], 
       "                        ", "+", 
       RowBox[{"\[Eta]", " ", "r6", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "                   ", "+", 
       RowBox[{"\[Kappa]", " ", "r6", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"j", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", "\[Tau]", "]"}]}], "     ", "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "      ", "-", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "    ", "+", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "  ", "-", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"k", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "+", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Eta]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "    ", "-", 
       RowBox[{"\[Eta]", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "+", 
       RowBox[{"\[Kappa]", " ", "r3", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "  ", "+", 
       RowBox[{"\[Kappa]", " ", 
        RowBox[{"Sin", "[", "y", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"l", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Tau]", "-", "\[Omega]"}], "]"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Omega]"}], "]"}]}], "+", 
       RowBox[{"\[Eta]", " ", "r6", " ", 
        RowBox[{"Cos", "[", "x", "]"}]}], "                       ", "+", 
       RowBox[{"\[Kappa]", " ", "r6", " ", 
        RowBox[{"Cos", "[", "y", "]"}]}]}], "           ", ")"}]}]}], "}"}], 
  "/", "12"}]], "Input",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
 FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
15. Particle interactions and decay via multiplication & remainders.\
\>", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell["\<\
A B = C +Rl +Rr is a conservative interaction in which the sizes of A & B are \
redistributed into C, Rl, and Rr. This suggests an analogy with \"particle\" \
interactions with conservation of properties. Stable particles, photons, \
electrons and protons, are irreducible and simple. \
\>", "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["16. Noncommutative Features.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "\tMost loops (and many hoops, including octonions) are noncommutative (NC). \
The ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " procedure employs the explicit NC features of the relators to create the \
protoloop as a table of lex-ordered-string elements, but converts this to an \
index-table for output. I conjecture that the repeated factors of NC loop \
determinants may split when the determinant is found by applying the NC \
rules.\n\tOPScalar` (from Mathsource/4271) extends the functionality of the \
operation NonCommutativeMultiply \"**\" as a \"Diamond\" operation \"\
\[Diamond]\". I modified ",
 StyleBox["det",
  FontSlant->"Italic"],
 " and ",
 StyleBox["ge ",
  FontSlant->"Italic"],
 "to use NC multiplication when the option ",
 StyleBox["o",
  FontSlant->"Italic"],
 " is negative, which can be used after Mathsource/4271 has been placed in ",
 StyleBox["ExtraPackages",
  FontSlant->"Italic"],
 ". Unfortunately it has several awkward side effects, and this investigation \
has been suspended.\n",
 StyleBox["\tI developed a split between non-commutative Lie products and \
commutative Jordan products, for any non-commutative hoop. I then discovered \
[5] that \"Geometric Algebra\" did this, as AB=A",
  FontSlant->"Plain"],
 Cell[BoxData["\[Wedge]"]],
 "B+A\[CenterDot]B, for the subset generated from orthogonal anti-commuting \
\"monovectors\" (aka generators, relators, or basis vectors).This topic is \
developed in CliffordG.nb."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["17. Particle interactions.", "Subsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["Basic ",
  FontSlant->"Italic"],
 StyleBox["Conjecture. Dozal describes the different particle families as \
Fermions, with Hexal describing Bosons as equivalence relations on Dozal \
elements, freed from the Pauli exclusion principle. ",
  FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["17a. Lepton interactions.",
 FontSize->10]], "Subsubsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "Summary. ",
 StyleBox["Conjecture. The electron family is described by the C3C4 and Q12 \
\[Alpha], \[Beta], \[Epsilon], & \[Sigma]  parameters; their lower analogs \
are photons. ",
  FontSlant->"Italic"]
}], "Text"],

Cell["\<\
\tElectrons have spin, charge, and mass; they are associated with neutrinos, \
muons and tauons; all have anti-particles. The Dozal 4-phase system {\
\[Epsilon] Cos[\[Sigma]], \[Epsilon] Sin[\[Sigma]], -\[Epsilon] \
Cos[\[Sigma]], -\[Epsilon] Sin[\[Sigma]]} wave system, together with the \
\[Alpha] and \[Beta] parameters, provides a possible description.
\tIf mass is related to velocity relative to an origin, perhaps the low-mass \
neutrinos have \[Alpha]=\[Beta]=0; the electron has \[Alpha]=0, \[Beta]=1 and \
the phases are displaced by \[PlusMinus]1; \[Alpha]=1, \[Beta]=1 displaces \
half of them by 2; \[Alpha]=1, \[Beta]=0 displaces all of them by 1\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "  ", 
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    RowBox[{"b", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    RowBox[{"c", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"d", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    RowBox[{"e", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    RowBox[{"f", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "+", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"g", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    RowBox[{"h", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    RowBox[{"i", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Cos", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"j", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    RowBox[{"k", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}], ",", 
    RowBox[{"l", "=", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Beta]", "-", 
       RowBox[{"\[Epsilon]", "  ", 
        RowBox[{"Sin", "[", "\[Sigma]", "]"}]}]}], ")"}]}]}], "}"}], "/", 
  "12"}]], "Input",
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"id", "[", "C3C2", "]"}], ";", 
  RowBox[{"shape", "[", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"toPolar", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
  "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], ",", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "d", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c", "+", "d", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}], "2"]}], ")"}]}], 
   ",", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "d", "+", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c", "-", "d", "+", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "-", "e", "+", "f"}], ")"}], "2"]}], ")"}]}]}],
   "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f"}], ",", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "d", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c", "+", "d", "-", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", "e", "-", "f"}], ")"}], "2"]}], ")"}]}], 
   ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "a"}], "-", "b", "-", "c", "+", 
      RowBox[{"2", "d"}], "-", "e", "-", "f"}], ",", 
     RowBox[{
      SuperscriptBox["3", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", " ", "b"}], "+", "c", "-", "e", "+", "f"}], ")"}]}]}], 
    "]"}], ",", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "d", "+", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c", "-", "d", "+", "f"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "-", "e", "+", "f"}], ")"}], "2"]}], ")"}]}], 
   ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "a"}], "-", "b", "-", "c", "-", 
      RowBox[{"2", "d"}], "+", "e", "+", "f"}], ",", 
     RowBox[{
      SuperscriptBox["3", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", " ", "b"}], "+", "c", "+", "e", "-", "f"}], ")"}]}]}], 
    "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"id", "[", "D3", "]"}], ";", 
  RowBox[{"shape", "[", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"toPolar", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
  "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "d"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "e"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "f"}], ")"}], "2"]}], ")"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f"}], ",", 
   RowBox[{"a", "-", "b", "+", "c", "-", "d", "+", "e", "-", "f"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"c", "-", "e"}], ")"}], "2"]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "d"}], ")"}], "2"]}], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "f"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "-", "f"}], ")"}], "2"]}], ")"}]}]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "a"}], "-", "c", "-", "e"}], ",", 
     RowBox[{
      SuperscriptBox["3", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", " ", "c"}], "+", "e"}], ")"}]}]}], "]"}], ",", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "e"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "e"}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "b"}], "-", "d", "-", "f"}], ",", 
     RowBox[{
      SuperscriptBox["3", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", " ", "d"}], "+", "f"}], ")"}]}]}], "]"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["17b. Hadron Interactions. Incomplete.",
 FontSize->10]], "Subsubsection",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"id", "[", "C3C4", "]"}], ";", 
  RowBox[{"shape", "[", 
   RowBox[{"A12", "=", 
    RowBox[{"{", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"toPolar", "[", "A12", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "a", "+", "b", "+", "c", "+", "d", "+", "e", "+", "f", "+", "g", "+", "h", 
    "+", "i", "+", "j", "+", "k", "+", "l"}], ",", 
   RowBox[{
   "a", "+", "b", "+", "c", "-", "d", "-", "e", "-", "f", "+", "g", "+", "h", 
    "+", "i", "-", "j", "-", "k", "-", "l"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "+", "b", "+", "c", "-", "g", "-", "h", "-", "i"}], ")"}], 
     "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"d", "+", "e", "+", "f", "-", "j", "-", "k", "-", "l"}], ")"}], 
     "2"]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "+", "d", "-", "e", "+", "g", "-", "h", "+", "j", "-", 
         "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "+", "e", "-", "f", "+", "h", "-", "i", "+", "k", "-", 
         "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "-", "d", "+", "f", "-", "g", "+", "i",
          "-", "j", "+", "l"}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "a", "-", "b", "-", "d", "+", "e", "+", "g", "-", "h", "-", "j", "+", 
         "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", "d", "-", "f", "-", "g", "+", "i",
          "+", "j", "-", "l"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
        "b", "-", "c", "-", "e", "+", "f", "+", "h", "-", "i", "-", "k", "+", 
         "l"}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["3", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "d"}], "+", "e", "+", 
         FractionBox[
          RowBox[{"a", "+", "b", "-", 
           RowBox[{"2", " ", "c"}], "-", "g", "-", "h", "+", 
           RowBox[{"2", " ", "i"}]}], 
          SqrtBox["3"]], "+", "j", "-", "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "+", 
         FractionBox[
          RowBox[{"d", "+", "e", "-", 
           RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
           RowBox[{"2", " ", "l"}]}], 
          SqrtBox["3"]]}], ")"}], "2"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["3", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "e", "+", 
         FractionBox[
          RowBox[{"a", "+", "b", "-", 
           RowBox[{"2", " ", "c"}], "-", "g", "-", "h", "+", 
           RowBox[{"2", " ", "i"}]}], 
          SqrtBox["3"]], "-", "j", "+", "k"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "g", "+", "h", "-", 
         FractionBox[
          RowBox[{"d", "+", "e", "-", 
           RowBox[{"2", " ", "f"}], "-", "j", "-", "k", "+", 
           RowBox[{"2", " ", "l"}]}], 
          SqrtBox["3"]]}], ")"}], "2"]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"V12", "=", 
  RowBox[{"toVector", "[", 
   RowBox[{"P12", "=", 
    RowBox[{"{", 
     RowBox[{
     "1", ",", "1", ",", "0.", ",", "0.", ",", "1", ",", "\[Tau]", ",", "1", 
      ",", "\[Phi]", ",", "1", ",", "\[Chi]", ",", "1", ",", "\[Psi]"}], 
     "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{"toPolar", "[", "V12", "]"}], "]"}], "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix. J.J.Hamilton's Half Spin operators.", "Section",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "\tJ.J.Hamilton published [2] a \"hypercomplex arithmetic\" with half-spin \
\"non-real, non-complex\" quantum operators as well as integer-spin complex \
quantum operators. He generalised complex conjugation, in which the conjugate \
of a conjugate is the original, ",
 StyleBox["i:(i*)*=+i",
  FontSlant->"Italic"],
 ", to include elements ",
 StyleBox["{a,b,a*,b*}",
  FontSlant->"Italic"],
 " demonstrating \"biconjugation\" (my term) in which the conjugate of a \
conjugate is the negated original, ",
 StyleBox["a:a** =-a, (a*)** =-a*,  b:b** =-b, (b*)** =-b*.",
  FontSlant->"Italic"],
 "  He demonstrated that ",
 StyleBox["{a,b,a*,b*}",
  FontSlant->"Italic"],
 "  are fundamental half-integral spin quantum operators with properties that \
cannot be expressed as real or complex numbers. (This is because they exist \
in the hyperbolic plane rather than the complex plane. They are different \
square roots of unity whilst the full-spin operators ",
 StyleBox["i ",
  FontSlant->"Italic"],
 "& ",
 StyleBox["k ",
  FontSlant->"Italic"],
 "are different fourth roots.) His multiplication table (Table II, reproduced \
below) uses the eight elements ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["E", 
     RowBox[{"n", " "}]], "="}], TraditionalForm]]],
 " {",
 StyleBox["1, i, h, k, a, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b", "*"], TraditionalForm]]],
 StyleBox[", ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "*"], TraditionalForm]]],
 StyleBox[", b",
  FontSlant->"Italic"],
 "}. However, he has several distinct \"-1\" elements (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["h", "2"], ",", " ", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "and", " ", 
     SuperscriptBox["a", 
      RowBox[{"*", "2"}]]}]}], TraditionalForm]]],
 " all equal +1); he also introduces several other elements and many aliases. \
Example 12a reproduces his Table II."
}], "Text",
 PageWidth->WindowWidth],

Cell["\<\
Example 12a. J.J.Hamiltons's Hypercomplex Multiplication Table.  (His Table \
II.)\
\>", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{"     ", 
  FormBox[GridBox[{
     {" ", 
      SubscriptBox["E", "0"], 
      SubscriptBox["E", "1"], 
      SubscriptBox["E", "2"], 
      SubscriptBox["E", "3"], 
      SubscriptBox["E", "4"], 
      SubscriptBox["E", "5"], 
      SubscriptBox["E", "6"], 
      SubscriptBox["E", "7"]},
     {
      SubscriptBox["E", "0"], "1", "i", "h", "k", "a", 
      SuperscriptBox["b", "*"], 
      SuperscriptBox["a", "*"], "b"},
     {
      SubscriptBox["E", "1"], "i", 
      RowBox[{"-", "1"}], "k", 
      RowBox[{"-", "h"}], 
      SuperscriptBox["b", "*"], 
      RowBox[{"-", "a"}], "b", 
      RowBox[{"-", 
       SuperscriptBox["a", "*"]}]},
     {
      SubscriptBox["E", "2"], "h", "k", "1", "i", 
      SuperscriptBox["a", "*"], "b", "a", 
      SuperscriptBox["b", "*"]},
     {
      SubscriptBox["E", "3"], "k", 
      RowBox[{"-", "h"}], "i", 
      RowBox[{"-", "1"}], "b", 
      RowBox[{"-", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["b", "*"], 
      RowBox[{"-", "a"}]},
     {
      SubscriptBox["E", "4"], "a", 
      SuperscriptBox["b", "*"], 
      SuperscriptBox["a", "*"], "b", "1", "i", "h", "k"},
     {
      SubscriptBox["E", "5"], 
      SuperscriptBox["b", "*"], 
      RowBox[{"-", "a"}], "b", 
      RowBox[{"-", 
       SuperscriptBox["a", "*"]}], "i", 
      RowBox[{"-", "1"}], "k", 
      RowBox[{"-", "h"}]},
     {
      SubscriptBox["E", "6"], 
      SuperscriptBox["a", "*"], "b", "a", 
      SuperscriptBox["b", "*"], "h", "k", "1", "i"},
     {
      SubscriptBox["E", "7"], "b", 
      RowBox[{"-", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["b", "*"], 
      RowBox[{"-", "a"}], "k", 
      RowBox[{"-", "h"}], "i", 
      RowBox[{"-", "1"}]}
    }],
   TraditionalForm]}]], "Input",
 PageWidth->WindowWidth,
 Evaluatable->False],

Cell[TextData[{
 "Example 12b shows that Table II is embedded in C3K. Completing an \
\"extended table\" using Hamilton's definitions for -",
 StyleBox["1,-h,-a",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["-a*",
  FontSlant->"Italic"],
 ", and for their products, gives a 12\[Times]12 table. Choosing generators  \
",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["i", "3"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", "2"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 "=1 (to match Hamilton's nomenclature) gives the elements that are shown \
above the table in Example 12b. If the supplementary and ill-defined \"-1\" \
term is converted to an arbitrary variable ",
 StyleBox["ii",
  FontSlant->"Italic"],
 " (it is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["i", "2"], TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["E", "1", "2"], TraditionalForm]]],
 " in Table II), the table becomes C3K. Deleting the rows and columns \
starting with negated elements reduces this table to the bold face elements \
in Example 12b; they match Table II, which is therefore embedded in C3K:-"
}], "Text",
 PageWidth->WindowWidth],

Cell["Example 12b. J.J.Hamiltons's Table II is embedded in C3K.", "Text",
 PageWidth->WindowWidth,
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{"(*", "    ", 
  RowBox[{"1", "    ", "i", "   ", 
   SuperscriptBox["i", "2"], "   ", "h", "   ", "hi", "   ", 
   SuperscriptBox["hi", "2"], "  ", "a", "  ", "ai", "   ", 
   SuperscriptBox["ai", "2"], " ", "ah", "  ", "ahi", " ", 
   SuperscriptBox["ahi", "2"]}], " ", "*)"}]], "Input",
 PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"jjh3", "=", 
  RowBox[{
   RowBox[{GridBox[{
      {"1", "i", 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain",
        FontSlant->"Italic"], "h", "k", 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], "a", 
       SuperscriptBox["b", "*"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       SuperscriptBox["a", "*"], "b", 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"]},
      {"i", 
       RowBox[{"-", "1"}], 
       StyleBox["1",
        FontWeight->"Plain",
        FontSlant->"Italic"], "k", 
       RowBox[{"-", "h"}], 
       StyleBox["h",
        FontWeight->"Plain"], 
       SuperscriptBox["b", "*"], 
       RowBox[{"-", "a"}], 
       StyleBox["a",
        FontWeight->"Plain"], "b", 
       RowBox[{"-", 
        SuperscriptBox["a", "*"]}], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"]},
      {
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"], 
       StyleBox["i",
        FontSlant->"Italic"], 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], 
       StyleBox["h",
        FontWeight->"Plain"], 
       StyleBox["k",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       StyleBox["a",
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["b", "*"],
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       StyleBox["b",
        FontWeight->"Plain"]},
      {"h", "k", 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain",
        FontSlant->"Italic"], "1", "i", 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       SuperscriptBox["a", "*"], "b", 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], "a", 
       SuperscriptBox["b", "*"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"]},
      {"k", 
       RowBox[{"-", "h"}], 
       StyleBox["h",
        FontWeight->"Plain",
        FontSlant->"Italic"], "i", 
       RowBox[{"-", "1"}], 
       StyleBox["1",
        FontWeight->"Plain"], "b", 
       RowBox[{"-", 
        SuperscriptBox["a", "*"]}], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       SuperscriptBox["b", "*"], 
       RowBox[{"-", "a"}], 
       StyleBox["a",
        FontWeight->"Plain"]},
      {
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], 
       StyleBox["h",
        FontWeight->"Plain"], 
       StyleBox["k",
        FontWeight->"Plain",
        FontSlant->"Italic"], 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"], 
       StyleBox["i",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       StyleBox["b",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       StyleBox["a",
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["b", "*"],
        FontWeight->"Plain"]},
      {"a", 
       SuperscriptBox["b", "*"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain",
        FontSlant->"Italic"], 
       SuperscriptBox["a", "*"], "b", 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], "1", "i", 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], "h", "k", 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"]},
      {
       SuperscriptBox["b", "*"], 
       RowBox[{"-", "a"}], 
       StyleBox["a",
        FontWeight->"Plain",
        FontSlant->"Italic"], "b", 
       RowBox[{"-", 
        SuperscriptBox["a", "*"]}], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], "i", 
       RowBox[{"-", "1"}], 
       StyleBox["1",
        FontWeight->"Plain"], "k", 
       RowBox[{"-", "h"}], 
       StyleBox["h",
        FontWeight->"Plain"]},
      {
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       StyleBox["a",
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["b", "*"],
        FontWeight->"Plain",
        FontSlant->"Italic"], 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       StyleBox["b",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"], 
       StyleBox["i",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], 
       StyleBox["h",
        FontWeight->"Plain"], 
       StyleBox["k",
        FontWeight->"Plain"]},
      {
       SuperscriptBox["a", "*"], "b", 
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain",
        FontSlant->"Italic"], "a", 
       SuperscriptBox["b", "*"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], "h", "k", 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], "1", "i", 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"]},
      {"b", 
       RowBox[{"-", 
        SuperscriptBox["a", "*"]}], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain",
        FontSlant->"Italic"], 
       SuperscriptBox["b", "*"], 
       RowBox[{"-", "a"}], 
       StyleBox["a",
        FontWeight->"Plain"], "k", 
       RowBox[{"-", "h"}], 
       StyleBox["h",
        FontWeight->"Plain"], "i", 
       RowBox[{"-", "1"}], 
       StyleBox["1",
        FontWeight->"Plain"]},
      {
       StyleBox[
        RowBox[{"-", 
         SuperscriptBox["a", "*"]}],
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["a", "*"],
        FontWeight->"Plain"], 
       StyleBox["b",
        FontWeight->"Plain",
        FontSlant->"Italic"], 
       StyleBox[
        RowBox[{"-", "a"}],
        FontWeight->"Plain"], 
       StyleBox["a",
        FontWeight->"Plain"], 
       StyleBox[
        SuperscriptBox["b", "*"],
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "h"}],
        FontWeight->"Plain"], 
       StyleBox["h",
        FontWeight->"Plain"], 
       StyleBox["k",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"-", "1"}],
        FontWeight->"Plain"], 
       StyleBox["1",
        FontWeight->"Plain"], 
       StyleBox["i",
        FontWeight->"Plain"]}
     }], "/.", 
    RowBox[{
     RowBox[{"-", "1"}], "\[Rule]", 
     RowBox[{"i", " ", "i"}]}]}], "//", "tf"}]}]], "Input",
 PageWidth->WindowWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "i", 
      SuperscriptBox["i", "2"], "h", "k", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "a", 
      SuperscriptBox["b", "*"], 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], 
      SuperscriptBox["a", "*"], "b", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}]},
     {"i", 
      SuperscriptBox["i", "2"], "1", "k", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "h", 
      SuperscriptBox["b", "*"], 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "a", "b", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["a", "*"]},
     {
      SuperscriptBox["i", "2"], "1", "i", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "h", "k", 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "a", 
      SuperscriptBox["b", "*"], 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["a", "*"], "b"},
     {"h", "k", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "1", "i", 
      SuperscriptBox["i", "2"], 
      SuperscriptBox["a", "*"], "b", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], "a", 
      SuperscriptBox["b", "*"], 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}]},
     {"k", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "h", "i", 
      SuperscriptBox["i", "2"], "1", "b", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["a", "*"], 
      SuperscriptBox["b", "*"], 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "a"},
     {
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "h", "k", 
      SuperscriptBox["i", "2"], "1", "i", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["a", "*"], "b", 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "a", 
      SuperscriptBox["b", "*"]},
     {"a", 
      SuperscriptBox["b", "*"], 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], 
      SuperscriptBox["a", "*"], "b", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], "1", "i", 
      SuperscriptBox["i", "2"], "h", "k", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}]},
     {
      SuperscriptBox["b", "*"], 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "a", "b", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["a", "*"], "i", 
      SuperscriptBox["i", "2"], "1", "k", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "h"},
     {
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "a", 
      SuperscriptBox["b", "*"], 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["a", "*"], "b", 
      SuperscriptBox["i", "2"], "1", "i", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "h", "k"},
     {
      SuperscriptBox["a", "*"], "b", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], "a", 
      SuperscriptBox["b", "*"], 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "h", "k", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "1", "i", 
      SuperscriptBox["i", "2"]},
     {"b", 
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["a", "*"], 
      SuperscriptBox["b", "*"], 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "a", "k", 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "h", "i", 
      SuperscriptBox["i", "2"], "1"},
     {
      RowBox[{
       SuperscriptBox["i", "2"], " ", 
       SuperscriptBox["a", "*"]}], 
      SuperscriptBox["a", "*"], "b", 
      RowBox[{"a", " ", 
       SuperscriptBox["i", "2"]}], "a", 
      SuperscriptBox["b", "*"], 
      RowBox[{"h", " ", 
       SuperscriptBox["i", "2"]}], "h", "k", 
      SuperscriptBox["i", "2"], "1", "i"}
    }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
 "\tHence Hamilton's hypercomplex algebra can be interpreted as the C3K \
algebra if his ",
 StyleBox["i",
  FontSlant->"Italic"],
 " is a cube root of 1, with ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["h",
  FontSlant->"Italic"],
 " being different square roots of 1. His half-spin operators {",
 StyleBox["a, a*, -a\[Congruent]a**,b, b*, -b\[Congruent]b**\[Congruent]-a*",
  FontSlant->"Italic"],
 "} are {",
 StyleBox["a, a h, a i i, a h i, a i , a h i i",
  FontSlant->"Italic"],
 "}; conjugation is multiplication by ",
 StyleBox["h",
  FontSlant->"Italic"],
 " (with ",
 StyleBox["h h",
  FontSlant->"Italic"],
 " =1), but biconjugation becomes multiplication by ",
 StyleBox["i",
  FontSlant->"Italic"],
 " or ",
 StyleBox["i i",
  FontSlant->"Italic"],
 ". This introduces ternary symmetry, and defies the prejudice that there \
must be ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "n"], TraditionalForm]]],
 " elements in an algebra - which is only true for real algebras without \
divisors of zero."
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["References.", "Section",
 PageWidth->WindowWidth,
 FontSize->12],

Cell[TextData[{
 "[1] http://library.wolfram.com/infocenter/",
 StyleBox["MathSource",
  FontSlant->"Italic"],
 "/4894/"
}], "Text",
 PageWidth->WindowWidth],

Cell[TextData[{
 "[2] J.J.Hamilton, Hypercomplex numbers and the description of spin states, \
J.Math.Phys. ",
 StyleBox["38",
  FontWeight->"Bold"],
 "(10) Oct. 1997. pp4914-4928"
}], "Text",
 PageWidth->WindowWidth],

Cell["[3] Remoissenet, Waves called Solitons, 1997 p29,p33.", "Text",
 PageWidth->WindowWidth],

Cell["\<\
[4] G.P.Nagy & P.Vojtechovsky, Loops package in GAP,  www.gap-system.org\
\>", "Text",
 PageWidth->WindowWidth],

Cell["\<\
[5] Doran, C. & Lasenby, L. Geometric Algebra for Physicists, CUP 2003.\
\>", "Text",
 PageWidth->WindowWidth],

Cell["[6] Landau, Foundations of Analysis, Chelsea 1960.", "Text",
 PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{1030, 740},
WindowMargins->{{54, Automatic}, {Automatic, 37}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], 
   Cell[
    TextData["29/8/2006"]], 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}},
ShowSelection->True,
Magnification->2.,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3422431022-7699074"->{
  Cell[317042, 9822, 217, 4, 114, "Print",
   CellTags->"Info3422431022-7699074"]},
 "Info3353843803-4044115"->{
  Cell[370931, 11935, 806, 13, 146, "Print",
   CellTags->"Info3353843803-4044115"]},
 "Info3353241802-8811303"->{
  Cell[373308, 12007, 784, 13, 146, "Print",
   CellTags->"Info3353241802-8811303"]},
 "Info3422431319-7971780"->{
  Cell[376708, 12116, 280, 4, 147, "Print",
   CellTags->"Info3422431319-7971780"],
  Cell[376991, 12122, 2468, 68, 170, "Print",
   CellTags->"Info3422431319-7971780"]},
 "Info3422431339-9813653"->{
  Cell[379583, 12201, 276, 4, 147, "Print",
   CellTags->"Info3422431339-9813653"],
  Cell[379862, 12207, 2457, 68, 170, "Print",
   CellTags->"Info3422431339-9813653"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3422431022-7699074", 544758, 16841},
 {"Info3353843803-4044115", 544871, 16844},
 {"Info3353241802-8811303", 544986, 16847},
 {"Info3422431319-7971780", 545101, 16850},
 {"Info3422431339-9813653", 545301, 16855}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 101, 2, 161, "Title"],
Cell[694, 27, 129, 3, 156, "Subtitle"],
Cell[826, 32, 150, 4, 56, "Subsubtitle"],
Cell[979, 38, 195, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[1199, 46, 84, 2, 131, "Section"],
Cell[1286, 50, 508, 8, 220, "Text"],
Cell[1797, 60, 9203, 258, 2505, "Text"],
Cell[11003, 320, 1442, 41, 385, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12482, 366, 106, 3, 131, "Section"],
Cell[12591, 371, 147, 5, 55, "Text"],
Cell[12741, 378, 1231, 36, 253, "Text"],
Cell[13975, 416, 1840, 34, 652, "Text"],
Cell[15818, 452, 257, 9, 88, "Text"],
Cell[16078, 463, 61705, 2095, 427, "Text"],
Cell[77786, 2560, 2679, 72, 685, "Text"],
Cell[80468, 2634, 1707, 36, 517, "Text"],
Cell[82178, 2672, 125, 4, 55, "Text"],
Cell[82306, 2678, 52, 1, 57, "Input"],
Cell[82361, 2681, 59, 1, 57, "Input"],
Cell[CellGroupData[{
Cell[82445, 2686, 260, 8, 50, "Input"],
Cell[82708, 2696, 946, 30, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83691, 2731, 232, 8, 50, "Input"],
Cell[83926, 2741, 367, 12, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84330, 2758, 285, 10, 50, "Input"],
Cell[84618, 2770, 849, 28, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85504, 2803, 232, 8, 50, "Input"],
Cell[85739, 2813, 207, 7, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85983, 2825, 222, 8, 50, "Input"],
Cell[86208, 2835, 368, 10, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86613, 2850, 138, 4, 53, "Input"],
Cell[86754, 2856, 724, 21, 135, "Output"]
}, Open  ]],
Cell[87493, 2880, 2303, 69, 450, "Text"],
Cell[89799, 2951, 152, 5, 55, "Text"],
Cell[89954, 2958, 27466, 931, 282, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[117445, 3893, 205, 6, 57, "Input"],
Cell[117653, 3901, 760, 24, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118450, 3930, 82, 2, 53, "Input"],
Cell[118535, 3934, 1179, 36, 135, "Output"]
}, Open  ]],
Cell[119729, 3973, 588, 9, 253, "Text"],
Cell[120320, 3984, 2700, 63, 846, "Text"],
Cell[123023, 4049, 669, 11, 220, "Text"],
Cell[123695, 4062, 1923, 39, 681, "Text"],
Cell[125621, 4103, 149, 5, 55, "Text"],
Cell[CellGroupData[{
Cell[125795, 4112, 1296, 32, 38, "Input",
 CellOpen->False],
Cell[127094, 4146, 1454, 39, 398, "Output"]
}, Open  ]],
Cell[128563, 4188, 2635, 81, 460, "Text"],
Cell[131201, 4271, 756, 13, 318, "Text"],
Cell[131960, 4286, 528, 20, 121, "Text"],
Cell[CellGroupData[{
Cell[132513, 4310, 942, 26, 38, "Input",
 CellOpen->False],
Cell[133458, 4338, 2080, 65, 416, "Output"]
}, Open  ]],
Cell[135553, 4406, 649, 10, 253, "Text"],
Cell[136205, 4418, 874, 14, 384, "Text"],
Cell[137082, 4434, 1387, 34, 418, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138506, 4473, 138, 4, 131, "Section"],
Cell[CellGroupData[{
Cell[138669, 4481, 87, 2, 69, "Subsection"],
Cell[138759, 4485, 526, 10, 220, "Text"],
Cell[139288, 4497, 4578, 142, 925, "Text"],
Cell[143869, 4641, 685, 17, 220, "Text"],
Cell[CellGroupData[{
Cell[144579, 4662, 62, 1, 56, "Input"],
Cell[144644, 4665, 2184, 34, 364, "Output"]
}, Open  ]],
Cell[146843, 4702, 1377, 28, 451, "Text"],
Cell[148223, 4732, 448, 11, 154, "Text"],
Cell[148674, 4745, 241, 5, 121, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148952, 4755, 101, 2, 69, "Subsection"],
Cell[149056, 4759, 299, 9, 121, "Text"],
Cell[149358, 4770, 1120, 34, 289, "Text"],
Cell[150481, 4806, 264, 8, 88, "Text"],
Cell[CellGroupData[{
Cell[150770, 4818, 1074, 32, 38, "Input",
 CellOpen->False],
Cell[151847, 4852, 1022, 30, 194, "Output"]
}, Open  ]],
Cell[152884, 4885, 910, 34, 220, "Text"],
Cell[CellGroupData[{
Cell[153819, 4923, 628, 19, 38, "Input",
 CellOpen->False],
Cell[154450, 4944, 2012, 60, 163, "Output"]
}, Open  ]],
Cell[156477, 5007, 273, 7, 121, "Text"],
Cell[CellGroupData[{
Cell[156775, 5018, 1093, 34, 38, "Input",
 CellOpen->False],
Cell[157871, 5054, 771, 23, 163, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[158691, 5083, 99, 2, 69, "Subsection"],
Cell[158793, 5087, 556, 13, 187, "Text"],
Cell[159352, 5102, 772, 22, 220, "Text"],
Cell[CellGroupData[{
Cell[160149, 5128, 618, 18, 38, "Input",
 CellOpen->False],
Cell[160770, 5148, 586, 13, 160, "Output"]
}, Open  ]],
Cell[161371, 5164, 1402, 46, 286, "Text"],
Cell[CellGroupData[{
Cell[162798, 5214, 2256, 57, 38, "Input",
 CellOpen->False],
Cell[165057, 5273, 3393, 96, 632, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168487, 5374, 1411, 37, 38, "Input",
 CellOpen->False],
Cell[169901, 5413, 2449, 68, 489, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172387, 5486, 1614, 42, 38, "Input",
 CellOpen->False],
Cell[174004, 5530, 2512, 66, 591, "Output"]
}, Open  ]],
Cell[176531, 5599, 724, 12, 319, "Text"],
Cell[CellGroupData[{
Cell[177280, 5615, 2110, 52, 38, "Input",
 CellOpen->False],
Cell[179393, 5669, 8171, 209, 1535, "Output"]
}, Open  ]],
Cell[187579, 5881, 155, 4, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187771, 5890, 97, 2, 69, "Subsection"],
Cell[187871, 5894, 736, 16, 253, "Text"],
Cell[188610, 5912, 1443, 31, 550, "Text"],
Cell[CellGroupData[{
Cell[190078, 5947, 1305, 34, 38, "Input",
 CellOpen->False],
Cell[191386, 5983, 1812, 52, 398, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[193247, 6041, 99, 2, 69, "Subsection"],
Cell[193349, 6045, 544, 10, 220, "Text"],
Cell[193896, 6057, 1030, 24, 352, "Text"],
Cell[194929, 6083, 4479, 121, 38, "Input",
 CellOpen->False],
Cell[199411, 6206, 303, 7, 121, "Text"],
Cell[CellGroupData[{
Cell[199739, 6217, 501, 16, 38, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[200265, 6237, 1164, 35, 151, "Print"],
Cell[201432, 6274, 864, 23, 163, "Print"],
Cell[202299, 6299, 536, 13, 78, "Print"]
}, Open  ]]
}, Open  ]],
Cell[202862, 6316, 203, 6, 88, "Text"],
Cell[CellGroupData[{
Cell[203090, 6326, 477, 15, 38, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[203592, 6345, 1147, 34, 151, "Print"],
Cell[204742, 6381, 828, 23, 163, "Print"],
Cell[205573, 6406, 514, 12, 78, "Print"]
}, Open  ]]
}, Open  ]],
Cell[206114, 6422, 728, 24, 154, "Text"],
Cell[CellGroupData[{
Cell[206867, 6450, 390, 13, 38, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[207282, 6467, 1010, 28, 139, "Print"],
Cell[208295, 6497, 814, 25, 163, "Print"],
Cell[209112, 6524, 415, 9, 78, "Print"]
}, Open  ]]
}, Open  ]],
Cell[209554, 6537, 287, 5, 154, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209878, 6547, 92, 2, 69, "Subsection"],
Cell[209973, 6551, 547, 10, 220, "Text"],
Cell[210523, 6563, 723, 19, 220, "Text"],
Cell[211249, 6584, 161, 7, 55, "Text"],
Cell[CellGroupData[{
Cell[211435, 6595, 179, 6, 57, "Input"],
Cell[211617, 6603, 772, 27, 130, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212426, 6635, 189, 6, 57, "Input"],
Cell[212618, 6643, 499, 16, 62, "Output"]
}, Open  ]],
Cell[213132, 6662, 368, 7, 154, "Text"],
Cell[213503, 6671, 145, 5, 55, "Text"],
Cell[CellGroupData[{
Cell[213673, 6680, 4064, 133, 38, "Input",
 CellOpen->False],
Cell[217740, 6815, 680, 17, 109, "Output"],
Cell[218423, 6834, 3197, 55, 221, "Output"]
}, Open  ]],
Cell[221635, 6892, 1207, 31, 352, "Text"],
Cell[222845, 6925, 177, 5, 55, "Text"],
Cell[CellGroupData[{
Cell[223047, 6934, 3124, 100, 38, "Input",
 CellOpen->False],
Cell[226174, 7036, 1898, 58, 368, "Output"],
Cell[228075, 7096, 2966, 53, 221, "Output"]
}, Open  ]],
Cell[231056, 7152, 848, 13, 352, "Text"],
Cell[231907, 7167, 163, 5, 55, "Text"],
Cell[CellGroupData[{
Cell[232095, 7176, 3514, 94, 38, "Input",
 CellOpen->False],
Cell[235612, 7272, 3157, 98, 531, "Output"],
Cell[238772, 7372, 2316, 52, 325, "Output"]
}, Open  ]],
Cell[241103, 7427, 223, 6, 88, "Text"],
Cell[CellGroupData[{
Cell[241351, 7437, 3867, 105, 38, "Input",
 CellOpen->False],
Cell[245221, 7544, 278, 8, 62, "Output"],
Cell[245502, 7554, 2139, 50, 405, "Output"]
}, Open  ]],
Cell[247656, 7607, 91, 2, 55, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[247784, 7614, 100, 2, 69, "Subsection"],
Cell[247887, 7618, 446, 9, 154, "Text"],
Cell[248336, 7629, 907, 25, 253, "Text"],
Cell[CellGroupData[{
Cell[249268, 7658, 582, 16, 38, "Input",
 CellOpen->False],
Cell[249853, 7676, 583, 14, 140, "Output"]
}, Open  ]],
Cell[250451, 7693, 219, 8, 55, "Text"],
Cell[CellGroupData[{
Cell[250695, 7705, 2128, 57, 38, "Input",
 CellOpen->False],
Cell[252826, 7764, 2431, 51, 547, "Output"]
}, Open  ]],
Cell[255272, 7818, 638, 16, 220, "Text"],
Cell[255913, 7836, 195, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[256133, 7846, 1137, 30, 38, "Input",
 CellOpen->False],
Cell[257273, 7878, 2333, 52, 302, "Output"]
}, Open  ]],
Cell[259621, 7933, 1017, 30, 253, "Text"],
Cell[260641, 7965, 185, 6, 55, "Text"],
Cell[260829, 7973, 151, 4, 88, "Text"],
Cell[CellGroupData[{
Cell[261005, 7981, 1700, 47, 379, "Input"],
Cell[262708, 8030, 1333, 35, 307, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[264078, 8070, 1197, 34, 276, "Input"],
Cell[265278, 8106, 1056, 27, 204, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[266371, 8138, 1199, 34, 276, "Input"],
Cell[267573, 8174, 1037, 27, 204, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[268647, 8206, 1205, 34, 276, "Input"],
Cell[269855, 8242, 1001, 25, 204, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[270905, 8273, 107, 2, 69, "Subsection"],
Cell[271015, 8277, 1303, 35, 323, "Text"],
Cell[272321, 8314, 3469, 121, 632, "Text"],
Cell[275793, 8437, 2454, 107, 228, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[278272, 8548, 1213, 42, 134, "Input",
 Evaluatable->False],
Cell[279488, 8592, 306, 7, 109, "Output"]
}, Open  ]],
Cell[279809, 8602, 483, 10, 154, "Text"],
Cell[CellGroupData[{
Cell[280317, 8616, 984, 32, 38, "Input",
 CellOpen->False],
Cell[281304, 8650, 321, 7, 126, "Output"]
}, Open  ]],
Cell[281640, 8660, 841, 15, 319, "Text"],
Cell[282484, 8677, 180, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[282689, 8687, 1284, 31, 262, "Input"],
Cell[283976, 8720, 235, 5, 92, "Output"]
}, Open  ]],
Cell[284226, 8728, 1235, 43, 253, "Text"],
Cell[285464, 8773, 196, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[285685, 8783, 408, 10, 92, "Input"],
Cell[286096, 8795, 5613, 142, 800, "Output"]
}, Open  ]],
Cell[291724, 8940, 603, 9, 286, "Text"],
Cell[292330, 8951, 185, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[292540, 8961, 683, 22, 160, "Input"],
Cell[293226, 8985, 105, 2, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[293380, 8993, 135, 4, 69, "Subsection"],
Cell[293518, 8999, 1474, 45, 220, "Text"],
Cell[294995, 9046, 9405, 348, 1136, "Text"],
Cell[304403, 9396, 186, 6, 88, "Text"],
Cell[304592, 9404, 11671, 392, 802, "Input",
 Evaluatable->False],
Cell[316266, 9798, 662, 15, 220, "Text"],
Cell[CellGroupData[{
Cell[316953, 9817, 86, 3, 58, "Input"],
Cell[317042, 9822, 217, 4, 114, "Print",
 CellTags->"Info3422431022-7699074"]
}, Open  ]],
Cell[317274, 9829, 164, 5, 55, "Text"],
Cell[CellGroupData[{
Cell[317463, 9838, 2429, 64, 38, "Input",
 CellOpen->False],
Cell[319895, 9904, 7575, 188, 721, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[327519, 10098, 194, 5, 69, "Subsection"],
Cell[327716, 10105, 1454, 49, 216, "Text"],
Cell[329173, 10156, 2310, 82, 313, "Text"],
Cell[331486, 10240, 357, 12, 88, "Text"],
Cell[331846, 10254, 58, 0, 55, "Text"],
Cell[CellGroupData[{
Cell[331929, 10258, 4695, 145, 38, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[336649, 10407, 16458, 742, 372, 11029, 649, "GraphicsData", \
"PostScript", "Graphics"],
Cell[353110, 11151, 16507, 735, 372, 10884, 638, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[369644, 11890, 1062, 30, 321, "Text"],
Cell[370709, 11922, 120, 5, 55, "Text"],
Cell[CellGroupData[{
Cell[370854, 11931, 74, 2, 57, "Input"],
Cell[370931, 11935, 806, 13, 146, "Print",
 CellTags->"Info3353843803-4044115"]
}, Open  ]],
Cell[371752, 11951, 1454, 48, 160, "Input"],
Cell[CellGroupData[{
Cell[373231, 12003, 74, 2, 57, "Input"],
Cell[373308, 12007, 784, 13, 146, "Print",
 CellTags->"Info3353241802-8811303"]
}, Open  ]],
Cell[374107, 12023, 1425, 47, 160, "Input"],
Cell[375535, 12072, 1073, 35, 253, "Text"],
Cell[CellGroupData[{
Cell[376633, 12111, 50, 1, 57, "Input"],
Cell[CellGroupData[{
Cell[376708, 12116, 280, 4, 147, "Print",
 CellTags->"Info3422431319-7971780"],
Cell[376991, 12122, 2468, 68, 170, "Print",
 CellTags->"Info3422431319-7971780"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[379508, 12196, 50, 1, 57, "Input"],
Cell[CellGroupData[{
Cell[379583, 12201, 276, 4, 147, "Print",
 CellTags->"Info3422431339-9813653"],
Cell[379862, 12207, 2457, 68, 170, "Print",
 CellTags->"Info3422431339-9813653"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[382380, 12282, 93, 2, 69, "Subsection"],
Cell[382476, 12286, 282, 8, 88, "Text"],
Cell[382761, 12296, 199, 4, 88, "Text"],
Cell[382963, 12302, 2173, 39, 755, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[385173, 12346, 126, 3, 69, "Subsection"],
Cell[385302, 12351, 421, 9, 154, "Text"],
Cell[CellGroupData[{
Cell[385748, 12364, 122, 2, 54, "Subsubsection"],
Cell[385873, 12368, 1667, 29, 616, "Text"],
Cell[387543, 12399, 155, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[387723, 12409, 2770, 67, 38, "Input",
 CellOpen->False],
Cell[390496, 12478, 5153, 159, 1061, "Output"]
}, Open  ]],
Cell[395664, 12640, 705, 17, 220, "Text"],
Cell[396372, 12659, 117, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[396514, 12665, 1896, 49, 38, "Input",
 CellOpen->False],
Cell[398413, 12716, 6013, 159, 1063, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[404475, 12881, 126, 2, 54, "Subsubsection"],
Cell[404604, 12885, 1070, 20, 385, "Text"],
Cell[405677, 12907, 94, 2, 54, "Text"],
Cell[CellGroupData[{
Cell[405796, 12913, 232, 8, 38, "Input",
 CellOpen->False],
Cell[406031, 12923, 1556, 52, 249, "Output"]
}, Open  ]],
Cell[407602, 12978, 194, 4, 88, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[407845, 12988, 114, 2, 69, "Subsection"],
Cell[407962, 12992, 728, 13, 286, "Text"],
Cell[408693, 13007, 415, 7, 187, "Text"],
Cell[409111, 13016, 1326, 23, 352, "Text"],
Cell[410440, 13041, 170, 6, 55, "Text"],
Cell[410613, 13049, 306, 9, 57, "Input"],
Cell[410922, 13060, 5847, 162, 817, "Input"],
Cell[416772, 13224, 1071, 30, 160, "Input"],
Cell[417846, 13256, 179, 6, 88, "Text"],
Cell[418028, 13264, 7388, 162, 403, "Input"],
Cell[425419, 13428, 679, 11, 253, "Text"],
Cell[426101, 13441, 175, 4, 56, "Input"],
Cell[426279, 13447, 5639, 149, 579, "Input"],
Cell[431921, 13598, 9282, 224, 673, "Input"],
Cell[441206, 13824, 184, 4, 88, "Text"],
Cell[441393, 13830, 93, 2, 54, "Text"],
Cell[441489, 13834, 5076, 127, 376, "Input"],
Cell[446568, 13963, 5337, 132, 426, "Input"],
Cell[451908, 14097, 117, 2, 54, "Text"],
Cell[452028, 14101, 5306, 149, 489, "Input"],
Cell[457337, 14252, 6245, 137, 408, "Input"],
Cell[463585, 14391, 460, 10, 154, "Text"],
Cell[464048, 14403, 358, 14, 56, "Input"],
Cell[464409, 14419, 16435, 413, 754, "Input"],
Cell[480847, 14834, 1007, 15, 418, "Text"],
Cell[481857, 14851, 535, 22, 56, "Input"],
Cell[482395, 14875, 428, 13, 92, "Input"],
Cell[482826, 14890, 1925, 58, 220, "Input"],
Cell[484754, 14950, 212, 6, 57, "Input"],
Cell[484969, 14958, 1897, 58, 220, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[486903, 15021, 86, 2, 69, "Subsection"],
Cell[486992, 15025, 1143, 31, 541, "Text"],
Cell[CellGroupData[{
Cell[488160, 15060, 643, 22, 125, "Input"],
Cell[488806, 15084, 610, 20, 102, "Output"]
}, Open  ]],
Cell[489431, 15107, 431, 14, 88, "Text"],
Cell[489865, 15123, 204, 5, 88, "Text"],
Cell[490072, 15130, 158, 3, 88, "Text"],
Cell[490233, 15135, 98, 3, 57, "Input"],
Cell[490334, 15140, 267, 8, 57, "Input"],
Cell[CellGroupData[{
Cell[490626, 15152, 159, 4, 92, "Input"],
Cell[490788, 15158, 852, 27, 147, "Output"],
Cell[491643, 15187, 852, 27, 147, "Output"]
}, Open  ]],
Cell[492510, 15217, 5639, 149, 579, "Input"],
Cell[498152, 15368, 9282, 224, 673, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[507471, 15597, 138, 4, 69, "Subsection"],
Cell[507612, 15603, 334, 6, 154, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[507983, 15614, 90, 2, 69, "Subsection"],
Cell[508076, 15618, 1513, 34, 518, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[509626, 15657, 88, 2, 69, "Subsection"],
Cell[509717, 15661, 314, 8, 121, "Text"],
Cell[CellGroupData[{
Cell[510056, 15673, 125, 3, 49, "Subsubsection"],
Cell[510184, 15678, 235, 6, 88, "Text"],
Cell[510422, 15686, 684, 10, 253, "Text"],
Cell[511109, 15698, 2489, 68, 170, "Input"],
Cell[CellGroupData[{
Cell[513623, 15770, 359, 10, 92, "Input"],
Cell[513985, 15782, 1064, 32, 187, "Output"],
Cell[515052, 15816, 1791, 56, 297, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516880, 15877, 357, 10, 92, "Input"],
Cell[517240, 15889, 854, 26, 130, "Output"],
Cell[518097, 15917, 1951, 66, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[520097, 15989, 137, 3, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[520259, 15996, 372, 10, 92, "Input"],
Cell[520634, 16008, 3308, 96, 633, "Output"]
}, Open  ]],
Cell[523957, 16107, 304, 8, 57, "Input"],
Cell[524264, 16117, 129, 3, 57, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[524454, 16127, 104, 2, 123, "Section"],
Cell[524561, 16131, 2013, 58, 451, "Text"],
Cell[526577, 16191, 152, 5, 54, "Text"],
Cell[526732, 16198, 1826, 63, 268, "Input",
 Evaluatable->False],
Cell[528561, 16263, 1239, 38, 286, "Text"],
Cell[529803, 16303, 119, 2, 54, "Text"],
Cell[529925, 16307, 337, 7, 95, "Input"],
Cell[CellGroupData[{
Cell[530287, 16318, 7325, 275, 408, "Input"],
Cell[537615, 16595, 4320, 136, 399, "Output"]
}, Open  ]],
Cell[541950, 16734, 1089, 37, 253, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[543076, 16776, 70, 2, 123, "Section"],
Cell[543149, 16780, 157, 6, 55, "Text"],
Cell[543309, 16788, 217, 7, 88, "Text"],
Cell[543529, 16797, 94, 1, 55, "Text"],
Cell[543626, 16800, 121, 3, 55, "Text"],
Cell[543750, 16805, 120, 3, 55, "Text"],
Cell[543873, 16810, 91, 1, 55, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
