(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    498566,      11303]
NotebookOptionsPosition[    461296,      10437]
NotebookOutlinePosition[    493827,      11152]
CellTagsIndexPosition[    493784,      11149]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Loop Glossary, Hoops, Primal Maths, Orbits, Abelian and Geometric Algebras.\
\>", "Subtitle",
 PageWidth->PaperWidth],

Cell["\<\
R.H.Beresford. 22nd August 2008.
\"Make things as simple as possible, but no simpler.\" (Albert Einstein.)\
\>", "Subsubtitle",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell["1. Introduction.", "Section",
 PageWidth->PaperWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 "This is a glossary for, and review of, the concepts developed in ",
 StyleBox["GroupLoopHoop6' ",
  FontSlant->"Italic"],
 "and",
 StyleBox[" CliffordG.nb",
  FontSlant->"Italic"],
 " and demonstrated in ",
 StyleBox["GroupLoopHoopdemo, Hoopdemo, ",
  FontSlant->"Italic"],
 "(in ",
 ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://library.wolfram.com/infocenter/MathSource/4894/"], None}],
 ".)",
 StyleBox[",",
  FontSlant->"Italic"],
 " ",
 StyleBox["Hoops ",
  FontSlant->"Italic"],
 "(in ",
 ButtonBox["http://library.wolfram.com/infocenter/MathSource/6198/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://library.wolfram.com/infocenter/MathSource/6198/"], None}],
 ") and CliffordDemo.nb (to follow) i.e. \"Primal\" (non-negative) numbers, \
\"generalized signs\", \"vector division\" Moufang Loops, and \"generalized \
partial-fraction division Hoop algebras\" with \"multiplicative remainders\" \
and conserved symmetries or \"sizes\" that are related to eigenvalues. \
Clifford (Geometric) Algebras are anti-commutative Hoops with wide \
applicability; they generalise geometry, vector analysis and spacetime to any \
number of dimensions. Abelian Hoops have \"orbit-generating\" polar forms \
that lead to powers and roots because angles add on multiplication. \
\"Orbits\" are multiphase sinusoids (Section 4) involving generalized signs, \
which are orthogonal (non-cyclotomic) roots of unity. Noether's theorem \
suggests relationships between orbits and fundamental particles. \
Multiplication (with \"remainders\" that carry symmetries) has analogies with \
particle interactions and decay. Non-Abelian hoops have repeated sizes and \
pseudo-polar duals that may introduce uncertainty. \nPlease send any comments \
to me at ",
 StyleBox["rhberesford@btinternet.com",
  FontSlant->"Italic"]
}], "Text",
 PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Glossary. ", "Section",
 PageWidth->WindowWidth,
 FontFamily->"Times New Roman"],

Cell[TextData[{
 StyleBox["a,b,..or",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], ",", 
    SubscriptBox["a", "2"], ","}], TraditionalForm]]],
 " ",
 StyleBox["Elements, usually representing Primal (non-negative) numbers, \
coefficients in a director.",
  FontWeight->"Plain"],
 StyleBox["\nA",
  FontSlant->"Italic"],
 "\t        ",
 StyleBox["A Director, an indexed set {",
  FontWeight->"Plain"],
 StyleBox["a,b",
  FontSlant->"Italic"],
 StyleBox["\[Ellipsis]} of ",
  FontWeight->"Plain"],
 StyleBox["m",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" primal elements; also written ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "m"], 
    StyleBox[
     RowBox[{
      SubscriptBox["a", "i"], 
      SubscriptBox["d", "i"]}],
     FontWeight->"Bold"]}], TraditionalForm]], "Input",
  FontWeight->"Plain"],
 StyleBox[".\na,b.. or ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[",",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 "  general elements or operators, coefficients in a vec, oftne involving \
generalised signs.",
 StyleBox["\n",
  FontWeight->"Plain"],
 "A\t        ",
 StyleBox["A Vec, an indexed set {a,b\[Ellipsis]} of ",
  FontWeight->"Plain"],
 StyleBox["m/n",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" signed elements; also written ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], 
     RowBox[{"m", "/", "n"}]], 
    RowBox[{
     SubscriptBox["a", "i"], 
     SubscriptBox["x", "i"]}]}], TraditionalForm]], "Input",
  FontWeight->"Plain"],
 StyleBox[". (introduced\n\t         because \"vector\" has conflicing \
interpretations).",
  FontWeight->"Plain"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"\[DoubleStruckCapitalA]", "=", 
     RowBox[{"0", "\[Union]", 
      SuperscriptBox["\[DoubleStruckCapitalR]", "+"]}]}]}], 
   TraditionalForm]]],
 " ",
 StyleBox["The Primal (unsigned continuous, Absolute) numbers, the union of \
zero and the half line.",
  FontWeight->"Plain"],
 "\nAdditive elimination. ",
 StyleBox["The generalization of subtraction ",
  FontWeight->"Plain"],
 StyleBox["A",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["+(-",
  FontWeight->"Plain"],
 StyleBox["A",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[")=0 to ",
  FontWeight->"Plain"],
 StyleBox["A",
  FontSlant->"Italic"],
 StyleBox["+",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "i"], TraditionalForm]]],
 StyleBox["+",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "j"], TraditionalForm]]],
 "+",
 StyleBox["...=0. ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "i"], TraditionalForm]]],
 " ",
 StyleBox["etc are negations.",
  FontWeight->"Plain"],
 "\nAi= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", "j"], 
    RowBox[{"(", 
     RowBox[{
      UnderscriptBox["\[Sum]", "i"], 
      RowBox[{
       SubscriptBox["\[Eta]", "i"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         SubscriptBox["a", 
          RowBox[{"i", " "}]]], 
        SubscriptBox["f", 
         RowBox[{"j", " "}]]}]}]}], ")"}]}], TraditionalForm]]],
 " /",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "j"], TraditionalForm]]],
 ". ",
 StyleBox["The multiplicative inverse of A. Calculated by ",
  FontWeight->"Plain"],
 StyleBox["hoopInverse",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[". Ai.A={1,0,..}\n",
  FontWeight->"Plain"],
 "Annihilator.",
 StyleBox["\tA non-trivial vector with all sizes zero. E.g.{1,1,1,1,-2,-2} in \
D3.\n",
  FontWeight->"Plain"],
 "arcTanh[a,o]  ",
 StyleBox["A generalization of",
  FontWeight->"Plain"],
 " ",
 StyleBox["Mathematica",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["'s ArcTanh[a/o] that gives a complex hyperangle depending\n\t      \
     on the a,o (adjacent,opposite) octant.\n",
  FontWeight->"Plain"],
 "binegation.  ",
 StyleBox["Ordinary (unary) negation -A, with -(-A)=A, resulting from \
negation by C2 equivalencing. \n\t        Often incorrectly conflated with \
subtraction, which is a binary operation B-A. (cf. ternegation)\n",
  FontWeight->"Plain"],
 "Bivector.",
 StyleBox["     The wedge product of two distinct monovectors, a grade-2 \
element of Geometric Algebra. It can\n\t         represent a directed area, \
but carries no shape information. (The geometric and wedge products\n\t       \
  are the same for monovectors.)\n",
  FontWeight->"Plain"],
 "Blade, \t        ",
 StyleBox["The Geometric Algebra name for set of objects of the same grade \
(dimensionality), the outer\n  ",
  FontWeight->"Plain"],
 "k-blade    ",
 StyleBox["   product of a set of monovectors. A 1-blade is a collection of \
monovectors, usually representing\n                     points. A 2-blade is \
a set of bivectors, usually representing directed areas. A 3-blade is a set \
of\n                     trivectors, usually representing directed volumes.",
  FontWeight->"Plain"],
 "\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "2"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "3"], TraditionalForm]]],
 " etc.,  ",
 StyleBox["The cyclic groups (associative loops) of 2,3, etc. primal \
elements. Do not confuse with Rings ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[DoubleStruckCapitalZ]", "2"], TraditionalForm]]],
 StyleBox["\n ",
  FontWeight->"Plain"],
 "or C2, C3.",
 StyleBox["   etc, for which negation is defined. Negation is undefined for \
loops or groups. ",
  FontWeight->"Plain"],
 "\n",
 StyleBox["C3C2",
  FontSlant->"Italic"],
 " etc.    ",
 StyleBox["The direct composition of ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "3"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[" with ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 " ",
 StyleBox["etc. Indirect composition is shown as e.g. ",
  FontWeight->"Plain"],
 StyleBox["KiC4, C8pC2",
  FontSlant->"Italic"],
 StyleBox[".",
  FontWeight->"Plain"],
 "\nC3\t       ",
 StyleBox["\"Ternal\", \"Terplex\"; the algebra of three elements, \
equivalence relationships on ",
  FontWeight->"Plain"],
 StyleBox["C3C2",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontWeight->"Plain"],
 StyleBox["C3C4 ",
  FontSlant->"Italic"],
 StyleBox["etc.\n",
  FontWeight->"Plain"],
 "Cartesian-",
 StyleBox["  A director or vec as an indexed set of coefficients with related \
directions or dimensions.\n    ",
  FontWeight->"Plain"],
 "Form.     ",
 StyleBox["Many algebras have dual ",
  FontWeight->"Plain"],
 "Polar Forms",
 StyleBox[" with offsets, radii, and angles. See toPolar, toVector.\n",
  FontWeight->"Plain"],
 "Clifford          ",
 StyleBox["A class of algebras, created by ",
  FontWeight->"Plain"],
 StyleBox["cl[p,q]",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[", with",
  FontWeight->"Plain"],
 " ",
 StyleBox["2^(p+q) anti-commuting elements, with p\n ",
  FontWeight->"Plain"],
 "(Geometric) ",
 StyleBox[" squaring to +1 and q squaring to -1. (Other orderings are \
isomorphic to one of these). The\n ",
  FontWeight->"Plain"],
 "Algebras. ",
 StyleBox["     elements partition into a scalar (first), pseudoscalar \
(last), p+q relators (my monovectors), and\n                sets of bi-, tri, \
etc-vectors. A \"k-blade\" is a a set of elements of the same grade. A \
multivector is a\n                set of coefficients (often including \
several zeroes). The non-abelian \"geometric product\" a\[SmallCircle]b \
(often \n                written a b) extends to multiple dimensions, unlike \
the related dot and cross products.\n                a\[SmallCircle]b=a.b+a\
\[And]b is sometimes wrongly used to define geometric algebra in terms of the \
dot and wedge\n                products, though it applies in any non-Abelian \
hoop, and corresponds to the Jordan & Lie products.\n",
  FontWeight->"Plain"],
 "Collapse.",
 StyleBox["        Used in earlier versions, now replaced by ",
  FontWeight->"Plain"],
 "Fold.",
 StyleBox["\n",
  FontWeight->"Plain"],
 "Compatible-",
 StyleBox["   The uniform nomenclature produced by putting A (\[Congruent]",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "i"], 
    SubscriptBox["d", "i"]}], TraditionalForm]],
  FontWeight->"Plain"],
 ") = ",
 StyleBox["f[",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["] where ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[" is an angle\n  ",
  FontWeight->"Plain"],
 "Coordinates",
 StyleBox["  measured ",
  FontWeight->"Plain"],
 "towards",
 StyleBox[" the direction ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", from the hyperplane ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["=0. f[",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["\[Phi]",
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontTracking->"Plain",
     FontVariations->{"Outline"->False,
     "Shadow"->False,
     "Underline"->False}], "i"], TraditionalForm]]],
 StyleBox["] = Sin[",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["\[Phi]", "i"],
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Outline"->False,
    "Shadow"->False,
    "Underline"->False}], TraditionalForm]]],
 StyleBox["] gives a \n  ",
  FontWeight->"Plain"],
 "Direction-    ",
 StyleBox[" generalised spherical \"direction Sines\" algebra with an \
euclidean metric; f[",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["\[Phi]",
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontTracking->"Plain",
     FontVariations->{"Outline"->False,
     "Shadow"->False,
     "Underline"->False}], "i"], TraditionalForm]]],
 StyleBox["] = ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     FormBox[
      StyleBox[
       SubscriptBox["\[Phi]", "i"],
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontVariations->{"Outline"->False,
       "Shadow"->False,
       "Underline"->False}],
      TraditionalForm], "]"}], "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[" gives\n  ",
  FontWeight->"Plain"],
 "Sines.",
 StyleBox["\t           a city block metric. The i'th component vanishes when \
",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 "=",
 StyleBox["0. (Direction Cosines lack this\n    \t           automatic \
elimination.)\n",
  FontWeight->"Plain"],
 "Conservative",
 StyleBox[".The property (discovered by Frobenius for group inverse tables) \
of some multiplication tables\n\t         to conserve their determinant on \
vec multiplication. Possessed by all \"Hoop algebras\" - many\n\t         \
signed tables, all groups, and some non-associative Moufang loops including \
Octonions. I found\n\t         (empirically) that direct table conjugate \
factors are conserved. I call these factors \"sizes\".\n",
  FontWeight->"Plain"],
 "cTimes[A,B] ",
 StyleBox[" The hoopTimes multiplication procedure, modified to give A\
\[SmallCircle]B, A.B, and A",
  FontWeight->"Plain"],
 Cell[BoxData[
  RowBox[{
   StyleBox["\[Wedge]",
    FontWeight->"Plain"], 
   StyleBox["B",
    FontWeight->"Plain"], " "}]]],
 StyleBox["for Cliffords.\n",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "i"], TraditionalForm]]],
 "                  ",
 StyleBox["A basis direction for a loop. cf ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 ", ",
 StyleBox["which is a basis dimension, folded from 2 or more directions.\n\t  \
       Directions can only be associated with operators or primal \
coefficients.\n",
  FontWeight->"Plain"],
 "det\t        ",
 StyleBox["A generalisation of Det, handling non-square tables and creating \
Permanents, Determinants,\n\t         tri-terminants etc. Related to \
Moore-Penrose pseudo-inverse.       \n",
  FontWeight->"Plain"],
 "Director.   ",
 StyleBox["   See ",
  FontWeight->"Plain"],
 StyleBox["A.",
  FontSlant->"Italic"],
 StyleBox[" Directors are the objects multiplied by loops. If",
  FontWeight->"Plain"],
 StyleBox[" ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["the loop has ",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["-fold symmetry, a director\n\t         may fold to give a vec with \
",
  FontWeight->"Plain"],
 StyleBox["m",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["/",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" signed elements & dimensions, operated on by an algebra.\n",
  FontWeight->"Plain"],
 "Dozal, Doz. ",
 StyleBox["The algebra of 12-element directors and vecs, and the unital \
algebra derived from it. (cf dozen.)\n",
  FontWeight->"Plain"],
 "Dual, polar  ",
 StyleBox["Polar description (if one exists) for a vec as a set of offsets, \
squared radii or ulnae, and angles.\n",
  FontWeight->"Plain"],
 "Dual, GA  ",
 StyleBox["   In Geometric Algebra a dual is a complementary blade.",
  FontWeight->"Plain"],
 "\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "3"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "4"], TraditionalForm]]],
 ", etc.  ",
 StyleBox["Dihedral groups, symmetries of the triangle, square, etc. Written \
D3, D4 when used as hoops.\n",
  FontWeight->"Plain"],
 "Element.",
 StyleBox["  ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["a", "1"],
    FontWeight->"Bold"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["d", "1"],
    FontWeight->"Bold"], TraditionalForm]]],
 StyleBox[",",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 StyleBox["c",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" etc. A constituent part of a director or vec, consisting of a \
coefficient (",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["a", "1"],
    FontWeight->"Bold"], TraditionalForm]],
  FontWeight->"Plain"],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 ",",
 StyleBox["c) and a\n\t     direction or dimension (",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "1"], TraditionalForm]]],
 StyleBox[",",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[") (often implied by the index or the position of the element in \
the set).",
  FontWeight->"Plain"],
 "\nEquivalencing.  ",
 StyleBox["The creation of a signed hoop (or vector) by \"folding\", an \
equivalence relationship\n\t     between sets (pairs, triples, quads etc) of \
primal elements ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["r", "i"], "~", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "i"], "-", 
       SubscriptBox["a", 
        RowBox[{"i", "+", 
         RowBox[{"m", "/", "r"}]}]]}], ")"}]}], 
    SubscriptBox["x", "i"]}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[". Impossible for\n  \t     some loops, such as ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "3"], TraditionalForm]],
  FontWeight->"Plain"],
 " ",
 StyleBox["&",
  FontWeight->"Plain"],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "3"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", which may, however, be folded after first composing with ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[".\n\t     Complex hoops and vectors are folded from quads of \
primal elements, i.e. ",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["=4. Generalized or \n\t     extended signs are created by folding. \
(See ",
  FontWeight->"Plain"],
 "Fold",
 StyleBox[".)",
  FontWeight->"Plain"],
 "\nExtended Signs. ",
 StyleBox["Generalizations of +,-,+\[ImaginaryI],-\[ImaginaryI] ;",
  FontWeight->"Plain"],
 " ",
 StyleBox["E.g. ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "\[DoubleStruckR]"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckD]", "12"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["\[DoubleStruckN]",
    FontWeight->"Plain"], "9"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckO]", "8"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckG]", "7"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckH]", "6"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckP]", "5"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["\[DoubleStruckCapitalI]",
    FontWeight->"Plain"], "4"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckCapitalY]", "3"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["\[DoubleStruckCapitalJ]",
    FontWeight->"Plain"], "3"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckK]", "2"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckL]", "2"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox[", ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckM]", "2"]],
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain"],
 StyleBox["=+1",
  FontWeight->"Plain"],
 "\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "j"], TraditionalForm]]],
 "\t  ",
 StyleBox["The j'th distinct factor of the determinant of ",
  FontWeight->"Plain"],
 StyleBox["G",
  FontSlant->"Italic"],
 StyleBox[". It is conserved, if ",
  FontWeight->"Plain"],
 StyleBox["G",
  FontSlant->"Italic"],
 StyleBox[" is a hoop, on multiplication;\n\t   if it is linear (L1) it is \
also conserved on addition. Every factor is a \"size\" for the hoop algebra.\n\
",
  FontWeight->"Plain"],
 "Faithful representation ",
 StyleBox["Sets of matrices that act as elements of a specified group. \
Created by ",
  FontWeight->"Plain"],
 StyleBox["ma",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" as sets\n               of 2x2, 3x3, or 4x4 unitary monomial \
matrices from matrix lists u2, u3, or u4.\n",
  FontWeight->"Plain"],
 "Fold.  ",
 StyleBox["See Equivalencing, signed table. The conversion of a loop with ",
  FontWeight->"Plain"],
 StyleBox["m",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" unsigned elements to a hoop with\n\t",
  FontWeight->"Plain"],
 StyleBox["m/r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" signed elements, often generating a signed multiplication table. \
Groups can operate as algebras\n\tover fields because any group X can be \
considered to be folded from XF, where F is a field group\n\tsuch as C2 \
(real) or C4 (complex). Vecs (generalized vectors) are folded from unsigned \
sets. ",
  FontWeight->"Plain"],
 "\nFragment. ",
 StyleBox["A linear term in a compact size expression e.g. ",
  FontWeight->"Plain"],
 StyleBox["(a-b)",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" in (",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], "2"], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"+", 
    FormBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "-", "c"}], ")"}], "2"],
     TraditionalForm]}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["+",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"c", "-", "a"}], ")"}], "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[")/2; also the\n\t     quadratic terms in compact expressions for \
quartic sizes. As they always occur as squares, they\n\t     are \"symmetric \
differences\" that do not introduce subtraction (despite the minus sign!).\n",
  
  FontWeight->"Plain"],
 "Frobenius conservation. ",
 StyleBox["The propery that Det[A] Det[B]=\[PlusMinus]Det[AB] when vecs are \
multiplied using a\n\t   Cayley Table. Det is of the Cayley table, mapped \
with the conjugate vec elements.\n\t   Frobenius proved that all associative \
tables (groups) are conservative. I found that Octonions and\n\t   a few \
other non-associative Moufang loops are also conservative, and the property \
survives on\n\t   folding to a signed table. As with fragments, the minus \
sign indicates a \"symmetric difference\".\n\t   For real tables, conjugation \
has no effect, so the sizes are factors of the Cayley table determinant.\n",
  FontWeight->"Plain"],
 "Gamma.",
 StyleBox[" The generators of Cayley-Dickson algebras are traditionally ",
  FontWeight->"Plain"],
 "\[Gamma]",
 StyleBox["'s, and are fourth roots of +1. \n",
  FontWeight->"Plain"],
 "Gaussian Pulse.",
 StyleBox["  Multi-dimensional",
  FontWeight->"Plain"],
 " ",
 StyleBox["Exp[go + \[ImaginaryI] \[Omega] T+ ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sum]", 
    RowBox[{"x", ",", "y", ",", ".."}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["[\[ImaginaryI] kx X - jx\.b2(X+xi-vx T)\.b2]. ",
  FontWeight->"Plain"],
 "\nG",
 Cell[BoxData[
  FormBox[
   RowBox[{":", 
    RowBox[{
     RowBox[{
      SubscriptBox["d", "i"], "\[Times]", 
      SubscriptBox["d", "j"]}], "\[RightArrow]", " ", 
     SubscriptBox["d", 
      StyleBox["ij",
       FontWeight->"Plain",
       FontSlant->"Italic"]]}]}], TraditionalForm]]],
 " ",
 StyleBox["A finite loop, group, hoop or groupoid giving the direction or \
basis dimension ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", 
    StyleBox["ij",
     FontWeight->"Plain",
     FontSlant->"Italic"]], TraditionalForm]]],
 StyleBox[" resulting\n\t   from the multiplication of two directions ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "i"], ",", 
    SubscriptBox["d", "j"]}], TraditionalForm]]],
 StyleBox[". Det[G] is that of the symbolic Cayley Table. In\n\t   Geometric \
algebras, the ",
  FontWeight->"Plain"],
 Cell[BoxData[
  StyleBox[
   SubscriptBox["d", "i"],
   FontSlant->"Italic"]]],
 "'",
 StyleBox["s are built from ",
  FontWeight->"Plain"],
 StyleBox["k",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" monovectors, so they have grade (dimension) ",
  FontWeight->"Plain"],
 StyleBox["k",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[".",
  FontWeight->"Plain"],
 "\nGeneralized Conjugate.",
 StyleBox[" An involute vec ",
  FontWeight->"Plain"],
 Cell[BoxData[
  StyleBox[
   SuperscriptBox["V", "\[Dagger]"],
   FontWeight->"Plain"]]],
 StyleBox[". Real vecs are their own conjugate. The terplex conjugate of\n    \
          {a,b,c} is {a,c,b}. The complex conjugate of {r,i} is {r,-i}. V",
  FontWeight->"Plain"],
 Cell[BoxData[
  StyleBox[
   SuperscriptBox["V", "\[Dagger]"],
   FontWeight->"Plain"]]],
 " ",
 StyleBox["may be related to a size.",
  FontWeight->"Plain"],
 "\nGeneralized Negation. ",
 StyleBox["Equivalence relations on sets of ",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" primal coefficients ",
  FontWeight->"Plain"],
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SubscriptBox["n", "i"],
    FontWeight->"Plain"], 
   StyleBox["~",
    FontSlant->"Italic"], 
   StyleBox[
    RowBox[{
     StyleBox["{",
      FontSlant->"Italic"], 
     RowBox[{
      SubscriptBox["a", "i"], ",", 
      SubscriptBox["a", 
       RowBox[{"i", "+", 
        RowBox[{"m", "/", "r"}]}]], ",", "...", ",", 
      SubscriptBox["a", 
       RowBox[{"i", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", "1"}], ")"}], 
         RowBox[{"m", "/", "r"}]}]}]]}], "}"}],
    FontWeight->"Plain"]}]], "Input"],
 StyleBox[".",
  FontWeight->"Plain"],
 "\nGeneralized Signs. ",
 StyleBox["Generalizations of +, -, +\[ImaginaryI], -\[ImaginaryI];",
  FontWeight->"Plain"],
 " ",
 StyleBox["with",
  FontWeight->"Plain"],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "\[DoubleStruckR]"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["=+1. See \"Extended Signs\" for a proposed standard.\n",
  FontWeight->"Plain"],
 "Geometric algebras ",
 StyleBox[" See Clifford.\n",
  FontWeight->"Plain"],
 "g",
 StyleBox["mmnn  ",
  FontSlant->"Italic"],
 StyleBox["A mnemonic for groups given by GAP>SmallGroup(mm,nn), or loops in \
the extended GAP Atlas.\n",
  FontWeight->"Plain"],
 "\[DoubleStruckH],\[DoubleStruckCapitalI],\[DoubleStruckCapitalJ],\
\[DoubleStruckK],\[DoubleStruckL] etc.",
 StyleBox["  Generalized signs, different roots of unity. Proposed usage in \
Extended Signs. 'h etc. in ASCII.",
  FontWeight->"Plain"],
 "\nHelix Identity.",
 StyleBox["  ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], 
    RowBox[{"n", "=", "m"}]], TraditionalForm]],
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     RowBox[{"t", "+", 
      RowBox[{"2", "n", " ", 
       RowBox[{"\[Pi]", "/", "m"}]}]}], "]"}], 
    RowBox[{"2", "p"}]], TraditionalForm]],
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["=m Binomial[2p,p]/",
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["4", "p"], TraditionalForm]],
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[" (p<m/2 if m is even, else p<m)",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["\n\t   The generalisation of  ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["Sin", "2"], "[", "x", "]"}], "+", 
     RowBox[{
      SuperscriptBox["Cos", "2"], "[", "x", "]"}]}], "=", "1."}], 
   TraditionalForm]],
  FontWeight->"Plain"],
 " ",
 StyleBox["Derived by J.J.Thwaites (personal communication).\n",
  FontWeight->"Plain"],
 "Hexal, Hex. ",
 StyleBox["The algebra of 6-element directors and vecs, and the unitary \
algebra derived from it.",
  FontWeight->"Plain"],
 "\nHeyting Algebras ",
 StyleBox["use intuitionistic (not Boolean) logic. The middle is not \
excluded; \[Not]\[Not]A is the interior of A.\n",
  FontWeight->"Plain"],
 "hmin. ",
 StyleBox["   A minimum size. If it exceeds the absolute value of a size, the \
size drops out of the algebra. See \"q\".\n",
  FontWeight->"Plain"],
 "Hoop.   ",
 StyleBox["An algebra (H,+,\[CenterDot],\\,/,1) with addition +, Moufang \
product \[CenterDot], left \\ & right / division, 1, generalized\n\t signs, \
and the ",
  FontWeight->"Plain"],
 "Frobenius determinant conservation",
 StyleBox[" property. All groups, a few non-associative\n\t Moufang Loops, \
and signed tables folded from them, are Hoops. They are in the database as\n\t\
 \"Protoloop\" preferred Cayley table isomorphs. Loops with names ending in ",
  
  FontWeight->"Plain"],
 StyleBox["n",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" are not Hoops.\n",
  FontWeight->"Plain"],
 "hoopInverse[A,hoop] ",
 StyleBox["The hoop multiplicative inverse Ai, defining division in the \
specified hoop",
  FontWeight->"Plain"],
 "; ",
 StyleBox["Ai\[CenterDot]AB=B.\n\t  Calculated as sums of derivatives of \
shapes wrt \"specific variables\" that are fixed by the location of\n\t  the \
1's in the index table. In signed tables, the terms have to be multiplied by \
the sign of each 1\n\t  The location and multiplier are supplied as ",
  FontWeight->"Plain"],
 StyleBox["gi",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" in the ",
  FontWeight->"Plain"],
 StyleBox["shape",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" of the hoop. This is a Cramer's rule\n\t  calculation, so the \
inverse has the determinant as a divisor. When this factorises, the inverse \
splits\n\t  into partial-fractions with each size becoming a denominator. \
Division is left-multiplication by an\n\t  inverse. Multiplication and \
division both eliminate infinite partial-fractions (created by zero sizes)\n\t\
  by \"ejecting\" remainders, giving a renormalised result matching a \
pseudo-inverse. The result is\n\t  \"projected\" onto a constrained \
sub-algebra. Closely related to differentiation.\n",
  FontWeight->"Plain"],
 "hoopPower[A,power] ",
 StyleBox[" A procedure to convert a vec to a power or root. It raises \
offsets and radii to the\n\t  required power, and multiplies angles by the \
power. The target hoop polar form must be known.\n\t  If angles exceed 2\[Pi] \
they \"wrap round\", and then",
  FontWeight->"Plain"],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      SuperscriptBox["A", "p"],
      TraditionalForm], ")"}], 
    RowBox[{"1", "/", "p"}]], TraditionalForm]]],
 StyleBox[" will be a rotated version of A. Not yet\n\t  defined for \
non-abelian hoops, which may introduce uncertainty related to constants of \
integration.\n",
  FontWeight->"Plain"],
 "hoopTest[table]  ",
 StyleBox["A procedure that reports whether the table is conservative and has \
division, powers, etc. \n",
  FontWeight->"Plain"],
 "hoopTimes[A,B,hoop]   ",
 StyleBox["The hoop multiplication rule, multiplying vecs A & B according to \
the specified\n\t  hoop",
  FontWeight->"Plain"],
 ".",
 StyleBox[" If either multiplicand has sizes that become zero in the product, \
these are \"ejected\" into\n\t  \"remainders\" so that size conservation is \
maintained. The product is \"projected\" into a sub-algebra.",
  FontWeight->"Plain"],
 "\nHoop Algebra",
 StyleBox[". Multiplication and Division of vecs using a hoop multiplication \
table, with addition and\n\t    generalized subtraction. Powers & roots exist \
for Abelian hoops.\n",
  FontWeight->"Plain"],
 "Horosphere.",
 StyleBox["  The multi-dimensional generalisation of the \"null cone\" of \
Minkowski space.\t    \n",
  FontWeight->"Plain"],
 "Hyperbolic,  ",
 StyleBox["The analog of \"polar\" where a size includes a ",
  FontWeight->"Plain"],
 StyleBox["difference",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" of 2 squared fragments. The Klein\n   ",
  FontWeight->"Plain"],
 "Hypolar.    ",
 StyleBox[" group is",
  FontWeight->"Plain"],
 " ",
 StyleBox["the archetype, with squared ulnae \
(a\[PlusMinus]c)^2-(b\[PlusMinus]d)^2 and angles arcTanh[a\[PlusMinus]c,b\
\[PlusMinus]d].\n",
  FontWeight->"Plain"],
 "\[ImaginaryI]\t        ",
 Cell[BoxData[
  FormBox[
   RadicalBox[
    RowBox[{"+", "1"}], "4"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", usually written ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RadicalBox[
    RowBox[{"-", "1"}], "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", a complex unit element. Many algebras have other fourth roots.\n\
",
  FontWeight->"Plain"],
 "Incantation. ",
 StyleBox["My name for the expressions used to create a Cayley table using \
any of the procedures ",
  FontWeight->"Plain"],
 StyleBox["ca, cd,\n\t         cl, co, ge, ma, md, ms, pe,",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" or",
  FontWeight->"Plain"],
 StyleBox[" ts.",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontWeight->"Plain"],
 "Isomorphs",
 StyleBox[", ",
  FontWeight->"Plain"],
 "Mutants",
 StyleBox[" I define Isomorphs as loops with renamed elements whilst mutants \
are loops\n\t with some changed signs that conserve the structure, but not \
the details, of the shape. The function\n\t \
mutant[indexTable,signedIndexList] converts a loop into another loop. Reorder \
uses an unsigned list.",
  FontWeight->"Plain"],
 "\nInvolutions. ",
 StyleBox[" See Plex-conjugates. Vecs with changed signs of some elements. \
[Lounesto p29]\n",
  FontWeight->"Plain"],
 "Indexed set",
 StyleBox[".  A set in which an index identifies each element, so that \
permuted sets are set isomorphs.",
  FontWeight->"Plain"],
 "\nK\t    ",
 StyleBox["The Klein four-group, and the corresponding algebra, which has \
three square roots of +1, and\n\t     equivalences to a \"double algebra\" \
with two. See Hyperbolic, Study numbers.\n",
  FontWeight->"Plain"],
 "KdVB",
 StyleBox["\t     Korteweg-deVries broadened equation.",
  FontWeight->"Plain"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", " ", 
    RowBox[{
     RowBox[{"n", "(", 
      RowBox[{"1", "+", 
       RowBox[{"n", " ", "r"}]}], ")"}], 
     SuperscriptBox["A", 
      RowBox[{"1", "+", 
       RowBox[{"2", "/", "n"}]}]], 
     SubscriptBox["A", "x"]}]}], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{"+", 
      RowBox[{"(", 
       RowBox[{"r", "-", "1"}], ")"}]}], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["A", "x"], "2"], "/", "A"}]}],
    FontWeight->"Plain"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox[
     RowBox[{" ", 
      RowBox[{"+", 
       SubscriptBox["A", 
        RowBox[{"x", " ", "x"}]]}], "]"}], "x"],
    FontWeight->"Plain"], TraditionalForm]]],
 " +\n\t     ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     SubscriptBox[
      RowBox[{"[", 
       RowBox[{
        SuperscriptBox["A", 
         RowBox[{"1", "+", "m"}]], 
        RowBox[{
         SuperscriptBox["n", "2"], "(", 
         RowBox[{"r", "+", "m"}], ")"}]}], "]"}], 
      RowBox[{" ", "t"}]],
     FontWeight->"Plain"], " "}], TraditionalForm]]],
 StyleBox["=0",
  FontWeight->"Plain"],
 ".",
 StyleBox[" ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["Some multi-dimensional cases have travelling pulse solutions.\n",
  FontWeight->"Plain"],
 "Large number ",
 StyleBox[" The observation that several ratios in physics are \
(approximately) low powers of ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["10", "40"],
    FontWeight->"Plain"], TraditionalForm]]],
 ";",
 StyleBox[" ",
  FontWeight->"Plain"],
 "\n  hypothesis.     ",
 StyleBox["expressed",
  FontWeight->"Plain"],
 " ",
 StyleBox["by Dirac as",
  FontWeight->"Plain"],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["\[TildeEqual]",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "40"], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["G", "m"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["t.",
  FontWeight->"Plain"],
 "\nL1, L2, etc. ",
 StyleBox["Linear (L1), quadratic (L2) etc. sizes, conserved in an algebra, \
and given by ",
  FontWeight->"Plain"],
 StyleBox["shape",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[". L26\[Zeta]\[Lambda]\[Phi] is\n\t       the quadratic (L2) size \
which splits into six squared fragments and contains \[Zeta], \[Lambda], & \
\[Phi] in its polar\n\t       form. L1 sizes are conserved on addition, all \
sizes are conserved on multiplication for hoops.\n\t       Originally \
misnamed \"lengths\"; the n'th root of Ln may be a length, and may provide a \
metric.\n",
  FontWeight->"Plain"],
 "Length.   ",
 StyleBox["  A constituent of a Polar, corresponding to either a scalar or, \
if ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SqrtBox["L2"]],
  FontWeight->"Plain"],
 StyleBox[", to a radius or ulna in\n\t      polar or hypolar coordinates. \
(The other constituents are angles.)\n",
  FontWeight->"Plain"],
 "Limiting     ",
 StyleBox["The non-linear partial differential equation that has any \
fixed-shape fixed speed wave, travelling",
  FontWeight->"Plain"],
 "\n  Velocity    ",
 StyleBox["in any direction",
  FontWeight->"Plain"],
 " ",
 StyleBox["in d spatial and 1 time direction, as a solution. Massive and \
light-like particles",
  FontWeight->"Plain"],
 "\n  Equation.  ",
 StyleBox["arise if pairs or directions combine to give dimensions, or if \
some directions are \"rolled-up\" \n\t       (Kaluza-Klein). \
Gtt-\[Sum][Gxx]=0 (with Gxx=",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["G/d",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[" etc. and summation is over x1...xd).\n",
  FontWeight->"Plain"],
 "Loop.\t   ",
 StyleBox["An ",
  FontWeight->"Plain"],
 StyleBox["m\[Times]m",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" quasigroup Cayley multiplication table with a 1, for a set with ",
  
  FontWeight->"Plain"],
 StyleBox["m",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " unsigned",
 StyleBox[" ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["elements. See \n\t    Moufang Loop. Protoloops include signed \
tables as well as strict (unsigned) loops.",
  FontWeight->"Plain"],
 "\n",
 StyleBox["m",
  FontSlant->"Italic"],
 "\t   ",
 StyleBox["The number of primal elements in a loop, group or director. ",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["-signed Hoops have ",
  FontWeight->"Plain"],
 StyleBox["m/r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" elements.\n",
  FontWeight->"Plain"],
 "Moufang Loop. ",
 StyleBox["An ",
  FontWeight->"Plain"],
 StyleBox["m\[Times]m ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["multiplication table for a set with ",
  FontWeight->"Plain"],
 StyleBox["m",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" elements with L & R inverses ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["=",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[" and\n\t     the Moufang properties, including the division \
property ",
  FontWeight->"Plain"],
 StyleBox["zx.yz=(z.xy)z,",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" relaxed to \"up to a sign\" for\n\t     signed tables. This \
ensures that every vec has a multiplicative inverse. All groups are Moufang\n\
\t     Loops. A few non-associative Moufang Loops (e.g. octonions, split \
octonions) are Hoops. \n",
  FontWeight->"Plain"],
 "Monovector.",
 StyleBox[" My name for the generators of Cayley-Dickson & Clifford algebras, \
often written ",
  FontWeight->"Plain"],
 Cell[BoxData[
  StyleBox[
   SubscriptBox["e", "i"],
   FontWeight->"Plain"]]],
 StyleBox[". The unit\n\t   is scalar, products are bivectors, trivectors, \
etc. Commonly and confusingly called vectors in\n\t   Geometric algebra. They \
square to \[PlusMinus]1 and anti-commute,",
  FontWeight->"Plain"],
 " ",
 Cell[BoxData[
  SubscriptBox["e", "i"]],
  FontWeight->"Plain"],
 StyleBox[".",
  FontWeight->"Plain"],
 Cell[BoxData[
  SubscriptBox["e", "j"]],
  FontWeight->"Plain"],
 StyleBox["=0, ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SubscriptBox["e", "i"]],
  FontWeight->"Plain"],
 Cell[BoxData["\[Wedge]"],
  FontWeight->"Plain"],
 Cell[BoxData[
  SubscriptBox["e", "j"]],
  FontWeight->"Plain"],
 StyleBox["= - ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SubscriptBox["e", "j"]],
  FontWeight->"Plain"],
 Cell[BoxData["\[Wedge]"],
  FontWeight->"Plain"],
 Cell[BoxData[
  SubscriptBox["e", "i"]],
  FontWeight->"Plain"],
 ".",
 StyleBox["\n",
  FontWeight->"Plain"],
 "Multiplicative Inverse",
 StyleBox["  Ai, with AiA={1,...}. See hoopInverse.\n",
  FontWeight->"Plain"],
 "Multivector. ",
 StyleBox[" The Geometric Algebra name for a list of vector elements. This \
can be a flat list, or can be\n\t\tpartitioned into \"blades\" of different \
grades (dimensionalities).\n",
  FontWeight->"Plain"],
 "Multi-phase ",
 StyleBox["  ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "m"], 
     RowBox[{"c", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Omega]\[Tau]", "+", 
        RowBox[{"2", "n", " ", "k", " ", 
         RowBox[{"\[Pi]", "/", "m"}]}], "+", "\[Phi]"}], "]"}], 
      SubscriptBox["\[Zeta]", "n"]}]}], 
    StyleBox["+",
     FontWeight->"Plain"], 
    StyleBox[
     RowBox[{"f", "[", "t", "]"}],
     FontWeight->"Plain"]}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", a solution to ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["\" = ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["-2",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["+",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "+", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[")",
  FontWeight->"Plain"],
 "+",
 StyleBox["f\"[t]",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" or \n   ",
  FontWeight->"Plain"],
 "Sinusoid.",
 StyleBox["\t",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["'= ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["-",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "+", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[")",
  FontWeight->"Plain"],
 "+",
 StyleBox["f'[t].  ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox[
     SubscriptBox["e", "r"], 
     RowBox[{"\[DoubleStruckS]", " ", "x"}]],
    FontWeight->"Plain"], TraditionalForm]]],
 " ",
 StyleBox["generalizes ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]],
  FontWeight->"Plain"],
 " ",
 StyleBox["to define them. See Section 4.\n",
  FontWeight->"Plain"],
 StyleBox["n",
  FontSlant->"Italic"],
 "-potent.  ",
 StyleBox["A vec which is its own ",
  FontWeight->"Plain"],
 StyleBox["n",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["'th power in a particular algebra, ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["=",
  FontWeight->"Plain"],
 StyleBox["A",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[". An Idempotent if ",
  FontWeight->"Plain"],
 StyleBox["n",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["=2.",
  FontWeight->"Plain"],
 "\nOC311\t    ",
 StyleBox["A typical continuous orbit, being the C3 orbit with both sizes \
equal to 1.\n",
  FontWeight->"Plain"],
 "Offset.",
 StyleBox["     The L1 sizes after conversion to polar form. See Radius, \
Polar Form, ulna. Symbols \[Alpha], \[Beta], \[Gamma], \[Delta].",
  FontWeight->"Plain"],
 "\nOrbit.\t    ",
 StyleBox["A unital parametric representation of a director or vec, with \
multi-phase sinusoidal elements\n\t     depending on at least one free \
frequency parameter {\[Sigma],\[Tau]..}. Greek letters \[Alpha]\[Ellipsis]\
\[Kappa] are used as the\n\t     size parameters. An example is given under \
\"Size\". Putting \[Tau] = -(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["E", "p"], " ", "t"}], "-"}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["P.x)/\[HBar]  gives the orbit the\n\t     properties of a \
multi-phase deBroglie wave. (Related to the \"discrete orbits\" in a group.)\n\
",
  FontWeight->"Plain"],
 "Pauli-\[Sigma] Algebra. ",
 StyleBox["The algebra defined by the Pauli-\[Sigma] 2\[Times]2 matrix \
multiplication table, conserving ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["t", "2"],
    FontWeight->"Plain"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["x", "2"],
    FontWeight->"Plain"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["y", "2"],
    FontWeight->"Plain"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["z", "2"],
    FontWeight->"Plain"], TraditionalForm]]],
 StyleBox["\n",
  FontWeight->"Plain"],
 "Phase.",
 StyleBox["\t One or more cyclically varying element in an orbit. Each phase \
has a phase angle and a radius or ulna.\n",
  FontWeight->"Plain"],
 "Plex-Conjugate.",
 StyleBox["The generalization of complex-conjugate to some hoops, a vec with \
some elements negated or\n\t     (in ternary algebras) with \
\[DoubleStruckCapitalJ]\[LeftRightArrow]",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["\[DoubleStruckCapitalJ]",
     FontWeight->"Plain"], "2"], TraditionalForm]]],
 StyleBox[" ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["exchanges. Elements of the product of the vec and the conjugates \n\
\t     (which are involutions) are related to the sizes of the vec, often as \
signed sums of squared elements.\n\t    The generalised complex-conjugate ",
  FontWeight->"Plain"],
 StyleBox["plex",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" is supplied (if known) in ",
  FontWeight->"Plain"],
 StyleBox["shape",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" for a  hoop.\n",
  FontWeight->"Plain"],
 "Polar Form. ",
 StyleBox["A Dual representation of a vec as scalars, radii and angles, \
generalising polar coordinates.\n",
  FontWeight->"Plain"],
 "Polar Angle.",
 StyleBox[" An angle parameter in a polar form or orbit. Symbols \[Sigma], \
\[Tau], \[Phi], \[CurlyPhi], \[Chi], \[Psi].\n",
  FontWeight->"Plain"],
 "PolyHelix Identity.",
 StyleBox["  ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Sum]", 
    RowBox[{"i", "=", "0"}], 
    RowBox[{"i", "=", 
     RowBox[{"m", "-", "1"}]}]], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", "+", 
       RowBox[{"2", 
        RowBox[{"i\[Pi]", "/", "m"}]}]}], "]"}], ")"}], 
    RowBox[{"2", "p"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["= ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["4", 
    RowBox[{"-", "p"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["m ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
      {
       RowBox[{"2", "p"}]},
      {"p"}
     }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[", {p<m if m is even, else p<2m}. See Helix.\n",
  FontWeight->"Plain"],
 "Polymorphs.     ",
 StyleBox["Quartic sizes with several fragmentations and plex (involution) \
formulations.\n",
  FontWeight->"Plain"],
 "Polyvectors.      ",
 StyleBox["My term for generating elements of Hoops that are not square roots \
or fourth roots of unity. \n",
  FontWeight->"Plain"],
 "PowerSinusoid.  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["v",
     FontWeight->"Plain"], 
    StyleBox["=",
     FontWeight->"Plain"], 
    RowBox[{
     StyleBox["a",
      FontWeight->"Plain"], 
     FormBox[
      StyleBox[
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Omega]t", "+", "\[Phi]"}], "]"}], "p"],
       FontWeight->"Plain"],
      TraditionalForm]}]}], TraditionalForm]]],
 StyleBox[", which is a solution to ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["v", "\[DoubleDot]"], " ", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "/", "p"}], "-", "1"}], ")"}], 
      RowBox[{
       FormBox[
        RowBox[{" ", 
         SuperscriptBox[
          RowBox[{
           FormBox[
            OverscriptBox["v", "."],
            TraditionalForm], " "}], "2"]}],
        TraditionalForm], "/", "v"}]}], "+", 
     RowBox[{"p", " ", 
      FormBox[
       SuperscriptBox["\[Omega]", "2"],
       TraditionalForm], "v"}]}], "=", "0"}], TraditionalForm]], "Input",
  Evaluatable->False,
  FontWeight->"Plain"],
 ". ",
 StyleBox["The travelling\n\t        wave V=(a Sin[",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sum]", 
    RowBox[{"x", ",", "y", ",", ".."}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["kx*(x+xi-jx*t)]",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[")", "p"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[" is a solution to Vtt+(1/p-1) ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Vt", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["/V-pV",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sum]", 
    RowBox[{"x", ",", "y", ",", ".."}]], TraditionalForm]],
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"jx", " ", "kx"}], ")"}], "2"], TraditionalForm]],
  FontWeight->"Plain"],
 ".",
 StyleBox["\n",
  FontWeight->"Plain"],
 "Primal,  \[DoubleStruckCapitalA].  ",
 StyleBox["Non-negative continuous, Absolute. Real and Complex numbers are \
equivalence-relationships\n\t  on pairs or quads of primal numbers. Other \
equivalence relations on ",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" primals give Terplex (",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["=3) etc.\n",
  FontWeight->"Plain"],
 "Protoloop. ",
 StyleBox["A prefered isomorph of a table, showing any structure; shapes are \
defined for the protoloop. The \n\t   ",
  FontWeight->"Plain"],
 StyleBox["makeProtoloop (mp)",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" procedure generates the Cayley table (with options to create some \
isomorphs).\n",
  FontWeight->"Plain"],
 "Projection.  ",
 StyleBox["If a vec has a size that is zero in a particular hoop, it \
constrains products to a sub-hoop with the\n\t   same size fixed at zero - it \
projects onto the case with reduced symmetries.\n",
  FontWeight->"Plain"],
 "Pseudo-root.  ",
 StyleBox["  Non-abelian polar duals involve non-conserved size parameters \
and angle that do not add on\n\t   multiplication, but which have valid \
reversions to the cartesian form. When calculating roots and\n\t   powers, \
arbitrary angles and uncertainty are introduced, giving rotated \
\"pseudo-roots\".\n",
  FontWeight->"Plain"],
 "q, q-deformed. ",
 StyleBox["h=1-q. See ",
  FontWeight->"Plain"],
 "http://math.ucr.edu/home/baez/week183.html .",
 StyleBox[" ",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["q-deformed algebras become\n\t   classical when q",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[RightArrow]",
 StyleBox["1 or h",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[RightArrow]",
 StyleBox["0, corresponding to a hoop algebra being projected onto a simpler\n\
\t   algebra when a size becomes smaller than hmin.",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 StyleBox["\n",
  FontWeight->"Plain"],
 "Radius.   ",
 StyleBox["The length associated with an angle in a polar representation. \
Symbols ",
  FontWeight->"Plain"],
 "\[Epsilon], \[Zeta], \[Eta], \[Kappa], \[Lambda]",
 StyleBox[". See Ulna.\n",
  FontWeight->"Plain"],
 "Rational Pulse.",
 StyleBox[" ",
  FontWeight->"Plain"],
 StyleBox["v",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["=",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["\[Sum]", 
          RowBox[{"x", ",", "y", ",", ".."}]], 
         RowBox[{
          RowBox[{"jx", "(", 
           RowBox[{"xi", "+", "x", "-", 
            RowBox[{"kx", " ", "t"}]}], ")"}], "^", "2"}]}]}], ")"}]}], ")"}],
     "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[".\n",
  FontWeight->"Plain"],
 "Relator.  ",
 StyleBox["The GAP term for a generator, gamma, or monovector, a primitive \
root of unity. Algebraic Loops,\n\t    groups, Hoops and Cayley Tables have \
elements consisting of products of powers of relators.\n",
  FontWeight->"Plain"],
 "Remainder. ",
 StyleBox["Multiplication (or division) by vectors with zero-sizes create \
left and right \"remainders\" Rl, Rr\n\t with the sizes that are present in \
the multiplicands but lost from the product, ensuring that hoops are\n\t \
conservative and \"division by zero\" is eliminated. A \
B\[RightArrow]AB+Rr+Rl, AB Bi+Rr=A, AiAB+Rl=B\n",
  FontWeight->"Plain"],
 "Rotor.",
 StyleBox["  See Spinor.\n",
  FontWeight->"Plain"],
 "\[DoubleStruckS] \t",
 StyleBox["The generalised sign or ",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["'th root of unity, ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", 
    StyleBox["r",
     FontSlant->"Italic"]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["=1, often incorrectly treated as a unique point on the\n\t complex \
unit circle, but best considered as a \"direction\". I write it as 's in \
printable ASCII.",
  FontWeight->"Plain"],
 "\nSize.",
 StyleBox["\tThe value of a single conserved property of a director or orbit, \
for a given hoop algebra. Thus the orbit\n\t ",
  FontWeight->"Plain"],
 StyleBox["OC3\[Alpha]\[Gamma]={\[Alpha]+2\[Gamma] Cos[\[Tau]],\[Alpha]+2\
\[Gamma] Cos[\[Tau]+2\[Pi]/3 ], \[Alpha]+2\[Gamma] Cos[\[Tau]+4 \[Pi]/3]}/3 \
has individual sizes L1\[Alpha]=\[Alpha], \n\t L23\[Zeta]2=",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[Zeta]", "2"],
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Outline"->False,
    "Shadow"->False,
    "Underline"->False}], TraditionalForm]]],
 ", ",
 StyleBox["and so has a shape {",
  FontWeight->"Plain"],
 StyleBox["\[Alpha],",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[Zeta]", "2"],
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Outline"->False,
    "Shadow"->False,
    "Underline"->False}], TraditionalForm]]],
 StyleBox["}, in the algebra C3; (hyper)complex-conjugate \"Eigenvector\n\t \
pairs\" ",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 StyleBox["are sizes factorized into complex pairs (etc) but are not \
conserved. Sizes are always\n\t symmetrical ideals.",
  FontWeight->"Plain"],
 StyleBox["\n",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 StyleBox["Shape.",
  FontFamily->"Times New Roman"],
 StyleBox["  All the sizes ",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 StyleBox["of a director or orbit, supplied in ",
  FontWeight->"Plain"],
 StyleBox["shape[vec,mnemonic]",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["; used by ",
  FontWeight->"Plain"],
 StyleBox["genInverse, toPol",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" etc.",
  FontWeight->"Plain"],
 StyleBox["\n",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 "sh[mnemonic]  ",
 StyleBox["The symbolic determinant factors of the named loop, with ",
  FontWeight->"Plain"],
 StyleBox["gi",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" for use with ",
  FontWeight->"Plain"],
 StyleBox["genInverse",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" and ",
  FontWeight->"Plain"],
 StyleBox["gp\n\t  ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["for use with ",
  FontWeight->"Plain"],
 StyleBox["toPolar, toVector",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[". It also defines a ",
  FontWeight->"Plain"],
 StyleBox["plex",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" for many small hoops.",
  FontWeight->"Plain"],
 "\nshape[{a_,b_...}]  ",
 StyleBox["Factor (size) data for the target hoop, supplying the shape of \
{a,b,..} as a list of individual\n\t sizes {",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[",\[Ellipsis]",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "k"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["} & setting ",
  FontWeight->"Plain"],
 StyleBox["gi, gp",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" for ",
  FontWeight->"Plain"],
 StyleBox["genInverse, toPolar",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[". It also sets ",
  FontWeight->"Plain"],
 StyleBox["plex",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" for many small hoops.",
  FontWeight->"Plain"],
 "\nSigned Table. ",
 StyleBox["A multiplication table for a set which forms a group or loop on \
appending its signed elements.\n\tThe multiplication table is the upper left \
quarter (ninth, sixteenth, etc.) of the full Cayley table with\n\t (possibly \
signed) elements that are folded, by equivalence relationships, from the full \
table elements.\n",
  FontWeight->"Plain"],
 "Spin. \t",
 StyleBox["A property of an orbit, which is reversed by reversing the \
sequence of the phases. Clockwise spin \n\t   (Cos, -Sin, -Cos, Sin) is taken \
to be positive or Up.\n",
  FontWeight->"Plain"],
 "Spinor",
 StyleBox[".     (or Rotor) An even Versor that describes a rotation (via \
pairs of half-angle reflections).\n\t     R=(a+b)a = b(a+b) is the simplest \
rotor that rotates a into b\n",
  FontWeight->"Plain"],
 "Splitting.  ",
 StyleBox["The primal vector equivalent of subtraction, Split[A,B]=C if \
B+C=A. See SymDiff.\n",
  FontWeight->"Plain"],
 "Study Numbers. ",
 StyleBox[" a+\[DoubleStruckK] b, ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["\[DoubleStruckK]",
     FontWeight->"Plain"], "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["=1,",
  FontWeight->"Plain"],
 " ",
 StyleBox["folded K, the C2 algebra of the hyperbolic plane. Louenesto 2001 \
p24.\n\t     Also called Cayley-Klein algebra.\n",
  FontWeight->"Plain"],
 "SymDiff.",
 StyleBox["  Unsigned difference between numbers ",
  FontWeight->"Plain"],
 "m",
 StyleBox["=|a,b| : ",
  FontWeight->"Plain"],
 "m",
 StyleBox["+Min[a,b]=Max[a,b]. Primal \"additive inverse\".\n",
  FontWeight->"Plain"],
 "toPolar[v,h].    ",
 StyleBox["The procedures to convert cartesian representations ",
  FontWeight->"Plain"],
 StyleBox["v",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" into polar forms using hoop ",
  FontWeight->"Plain"],
 StyleBox["h",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[".\n",
  FontWeight->"Plain"],
 "toVector[p,h].\t",
 StyleBox["The procedures to convert polar representations ",
  FontWeight->"Plain"],
 StyleBox["p",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" into cartesian forms using hoop ",
  FontWeight->"Plain"],
 StyleBox["h",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[".\n",
  FontWeight->"Plain"],
 "Ternegation.\t",
 StyleBox["-(-(-A))=A in systems with ternary symmetry, instead of -(-A)=A in \
simple (bi)negation.\n",
  FontWeight->"Plain"],
 "Terplex.  ",
 StyleBox["The algebra of the C3 table over the real or complex field.\n",
  FontWeight->"Plain"],
 "Tetral.    ",
 StyleBox["The algebra of the C4 and K tables over the real or complex field.\
\n",
  FontWeight->"Plain"],
 "Triality",
 StyleBox[".  \"sends a simple rotation to a positive isoclinic rotation and \
a positive isoclinic rotation to a negative\n             isoclinic \
rotation\". The Moufang identity results in a special case of Cartan's \
triality. Louenesto p309.\n             See \"Loops\" in the GAP package.\n",
  FontWeight->"Plain"],
 "Trivector.",
 StyleBox["  The wedge product of three distinct monovectors, a grade-3 \
element of Geometric Algebra. It\n\t  can represent a directed volume but \
carries no shape information. (The geometric and wedge\n\t   products are the \
same for monovectors.)          \n",
  FontWeight->"Plain"],
 "Ulna.\t",
 StyleBox["My name for the hyperbolic analogue of radius.",
  FontWeight->"Plain"],
 StyleBox[" ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["u", "2"], TraditionalForm]],
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["=",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]],
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["-",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]],
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 ".\nUnivector.  ",
 StyleBox["My name for a unit vector in Geometric Algebra, to indicate a \
normalised set of monovectors.",
  FontWeight->"Plain"],
 "\nUnity.  ",
 StyleBox["The ",
  FontWeight->"Plain"],
 "UnitVector",
 StyleBox[" {1,0,..0} in unitary algebras, which leaves any object unchanged \
after\n\t multiplication. Not to be confused with the identity matrix. The \
Hoop product of a vec and its\n\t inverse is unity.",
  FontWeight->"Plain"],
 "\nUnit.    ",
 StyleBox["An object (e.g. {2/3,-1/3,-1/3} in C3) having all sizes 0 or 1 in \
a particular algebra.\n",
  FontWeight->"Plain"],
 "Unital.\t",
 StyleBox["A vec or vector with sizes that multiply to 1 in a specific \
algebra, ignoring zeroes, is unital. Orbits\n\t are unital. (Clashes with \
\"unital algebras\", which are monoids and include all hoops).\n",
  FontWeight->"Plain"],
 "UnitVector.  ",
 StyleBox["The ",
  FontWeight->"Plain"],
 StyleBox["Mathematica",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" symbol for {1,0...}, the ",
  FontWeight->"Plain"],
 "Unity",
 StyleBox[".\n",
  FontWeight->"Plain"],
 "Univector.  ",
 StyleBox["A normalised set of monovectors, a direction, a point on the unit \
sphere. The usual symbol is ",
  FontWeight->"Plain"],
 Cell[BoxData[
  OverscriptBox["n", "^"]],
  FontWeight->"Plain"],
 ".",
 StyleBox["\n",
  FontWeight->"Plain"],
 "Vector.  ",
 StyleBox["An ambiguous term that causes confusion. I restrict it to lists \
(or sparse arrays) of elements that do\n             not contain contain \
sublists (i.e. VectorQ[",
  FontWeight->"Plain"],
 StyleBox["expression",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["] gives ",
  FontWeight->"Plain"],
 StyleBox["True",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" in Mathematica.) Hamilton defined\n             it as the \
non-scalar (Imaginary) part of a quaternion or octonion. Many texts define it \
as an entity\n             defined by magnitude and direction. Geometric \
algebra texts confusingly use vector for the\n             \"grade-1 elements \
of the algebra\", i.e. the basis directions, gammas, generators, or relators \
for the\n             multiplication table. I have coined \"monovectors\" for \
these, so that bivectors, trivectors, etc. are the\n             products \
(geometric and wedge are the same) of 2, 3, etc monovectors. See also \
multivector,\n             polyvector, unit, UnitVector, univector.\n",
  FontWeight->"Plain"],
 "Vec.\t ",
 StyleBox["My name for an ordered list of m elements, used because Vector is \
ambiguous.\n",
  FontWeight->"Plain"],
 "Versor.",
 StyleBox["  \"any multvector that can be expressed as the geometric product \
of invertible vectors\" [16, p16],\n\t   U=",
  FontWeight->"Plain"],
 Cell[BoxData[
  StyleBox[
   SubscriptBox["u", "k"],
   FontWeight->"Plain"]]],
 "...",
 Cell[BoxData[
  StyleBox[
   SubscriptBox["u", "2"],
   FontWeight->"Plain"]]],
 Cell[BoxData[
  StyleBox[
   SubscriptBox["u", "1"],
   FontWeight->"Plain"]]],
 StyleBox[". Versors describe all orthogonal transformations as ",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["U",
    FontSlant->"Italic"], "*"]],
  FontWeight->"Plain"],
 StyleBox["x",
  FontWeight->"Plain"],
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["U",
    FontSlant->"Italic"], 
   RowBox[{"-", "1"}]]],
  FontWeight->"Plain"],
 StyleBox[". When k=1 they reverse\n\t   a set of vectors, effecting a \
reflection in a hyperplane. (Named by Hamilton.) \n",
  FontWeight->"Plain"],
 "Zitterbewegung. ",
 StyleBox["\"trembling motion\", an oscillation implicit in the Schroedinger \
equation. Generalised signs\n\t  may convert this to multi-phase \
oscillations.\t   \n",
  FontWeight->"Plain"],
 "\[Alpha],\[Beta],\[Ellipsis]\[Lambda]  ",
 StyleBox["Size parameters in an orbit, also the corresponding length \
parameters in a Polar Dual.\n",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "i"], TraditionalForm]]],
 StyleBox["\t  The i'th basis dimension. Two or more directions may fold to a \
real dimension ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["~{",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "i"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[",",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", 
    RowBox[{"i", "+", 
     RowBox[{"m", "/", "2"}]}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["}. \n",
  FontWeight->"Plain"],
 "\[Sigma],\[Tau],\[Ellipsis],\[Psi]",
 StyleBox["  A frequency parameter in an orbit. Additive in abelian \
multiplication.\n\t  Also an angle parameter in a Polar.",
  FontWeight->"Plain"]
}], "Text",
 PageWidth->WindowWidth,
 CellMargins->{{Inherited, -107.938}, {Inherited, Inherited}},
 TextAlignment->Left,
 TextJustification->0,
 FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Primal Maths.", "Section"],

Cell[TextData[{
 "The key concepts of \"Primal Maths\" (the background to Hoop algebras) \
are:-\n1) Unsigned Natural numbers \[DoubleStruckCapitalN], {0,1,2,...} arise \
from labelling the empty set \"",
 StyleBox["0",
  FontWeight->"Bold"],
 "\", the set containing the empty set \"",
 StyleBox["1",
  FontWeight->"Bold"],
 "\", etc. Natural numbers (shown as ",
 StyleBox["bold",
  FontWeight->"Bold"],
 " letters",
 StyleBox[")",
  FontWeight->"Bold"],
 " have trichotomous order ",
 StyleBox["i<j ",
  FontWeight->"Bold"],
 "or ",
 StyleBox["i=j",
  FontWeight->"Bold"],
 " or",
 StyleBox[" i>j",
  FontWeight->"Bold"],
 "; addition, ",
 StyleBox["i+j=s",
  FontWeight->"Bold"],
 " (sum); multiplication ",
 StyleBox["i*j=t",
  FontWeight->"Bold"],
 " (times); powers ",
 StyleBox["i^j=p",
  FontWeight->"Bold"],
 " (power); factors ",
 StyleBox["j | k",
  FontWeight->"Bold"],
 " if ",
 StyleBox["i*j=k",
  FontWeight->"Bold"],
 " for some ",
 StyleBox["i",
  FontWeight->"Bold"],
 ", division with remainders ",
 StyleBox["k/j=i+r",
  FontWeight->"Bold"],
 " where ",
 StyleBox["r<j",
  FontWeight->"Bold"],
 "; every natural number has a unique set of prime divisors. Subtraction is \
undefined, but the symmetric difference ",
 StyleBox["m",
  FontWeight->"Bold"],
 " is defined by Min[",
 StyleBox["i,j",
  FontWeight->"Bold"],
 "] + ",
 StyleBox["m",
  FontWeight->"Bold"],
 " = Max[",
 StyleBox["i,j",
  FontWeight->"Bold"],
 "].\n2) Unsigned rational numbers ",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalQ]", 
   RowBox[{"0", "+"}]]]],
 " are equivalence relations on ordered pairs of Natural numbers, q ~ {",
 StyleBox["i,j",
  FontWeight->"Bold"],
 "} ~ {",
 StyleBox["k,l",
  FontWeight->"Bold"],
 "} iff ",
 StyleBox["i*l ",
  FontWeight->"Bold"],
 "=",
 StyleBox[" j*k",
  FontWeight->"Bold"],
 ". Rational infinity is \[Infinity] ~ {",
 StyleBox["i,0",
  FontWeight->"Bold"],
 "}, rational zero is 0 ~ {",
 StyleBox["0,i",
  FontWeight->"Bold"],
 "}, both with ",
 StyleBox["i",
  FontWeight->"Bold"],
 ">",
 StyleBox["0",
  FontWeight->"Bold"],
 ". {",
 StyleBox["0,0",
  FontWeight->"Bold"],
 "} is undefined. (These differ from Landau's ",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalQ]", "+"]]],
 " because he did not include ",
 StyleBox["0",
  FontWeight->"Bold"],
 " as a Natural number.)\n3) Any continuity axiom can be used to extend ",
 Cell[BoxData[
  SubscriptBox["\[DoubleStruckCapitalQ]", 
   RowBox[{"0", "+"}]]]],
 " to Primal numbers (the half line). The (often implicit) introduction of \
negative numbers (integers, signed rationals, reals, complex) as equivalence \
relations on a pair or quad of unsigned natural, rational or primal numbers \
is postponed until it can be generalised in 5.\n4) Algebraic Loops are Cayley \
Index Tables that define multiplication tables for unsigned \"vecs\", indexed \
sets of unsigned coefficients and/or operators. Signed numbers are not needed \
in their definition. The name \"vec\" is introduced because \"vector\" is \
ambiguous.)\n5) Generalised signs are orthogonal powers of distinct ",
 StyleBox["r'",
  FontSlant->"Italic"],
 "th roots of unity. If a loop has ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-fold symmetry, it can be ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-folded to a smaller table that multiplies ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-signed vecs. This equivalences each set of ",
 StyleBox["r",
  FontSlant->"Italic"],
 " unsigned numbers to a single ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-signed number. Signs provide the second operation (generalised addition / \
subtraction) that converts a loop into an algebra. ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2 gives Real algebra with signs {+, -; ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", "-", ")"}], "2"]]],
 "=+1}. The C4 and K groups give Complex {+, \[ImaginaryI], -, \
-\[ImaginaryI]; ",
 Cell[BoxData[
  SuperscriptBox["\[ImaginaryI]", "4"]]],
 "=+1} and Study (hyperbolic) algebras \
{+,-,\[DoubleStruckK],-\[DoubleStruckK]; ",
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckK]", "2"]]],
 "=+1}; ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=3 gives \"Terplex\" {+, \[DoubleStruckCapitalJ], \[DoubleStruckCapitalJ]\
\[DoubleStruckCapitalJ] ; ",
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckCapitalJ]", "3"]]],
 "=+1}, a complete algebra with divisors of zero. Non-abelian Clifford \
algebras have ",
 Cell[BoxData[
  SuperscriptBox["2", "n"]]],
 " elements, with ",
 StyleBox["n ",
  FontSlant->"Italic"],
 "generators that are distinct square roots or fourth roots of +1. Thus an \
algebra can have several different ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'th roots. Projecting them onto the complex plane (as cyclotomic numbers) \
destroys orthogonality and distinctness.\n6) All groups, and a few (mainly \
octonionic) non-associative loops, have the Frobenius determinant \
conservation property Det[A] Det[B] = \[PlusMinus] Det[AB], where Det is \
calculated for the table mapped with the conjugate of the vector. The \
\[PlusMinus] arises from a symmetric difference interpretation of the \
unsigned nature of loops. The factors of the symbolic determinant are \
\"conserved sizes\" (real Eigenvectors, symmetries) that define metrics for \
multiplication. Symmetry conservation leads to forces and particles by \
Noether's laws. \n7) If the table has the Moufang division property ",
 StyleBox["zx.yz=(z.xy)z",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 ", every vector has a multiplicative inverse. This splits into \
partial-fractions having sizes as denominators. Whenever a size is zero, the \
results are projected onto a constrained sub-algebra of reduced symmetry. \n\
8) To maintain symmetry conservation, both multiplication A*B and division \
A",
 StyleBox["inverse",
  FontSlant->"Italic"],
 "*B create \"remainders\" that carry the sizes of A and B that are lost in \
the result. This corresponds to particle interaction and decay. Different \
algebras conserve overlapping sets of symmetries, just as different forces \
conserve overlapping sets of particle properties. A*B=AB+Rl+Rr, A",
 StyleBox["inverse",
  FontSlant->"Italic"],
 "AB+Rl=B, AB*B",
 StyleBox["inverse",
  FontSlant->"Italic"],
 "+Rr=A.\n9) Every Abelian algebra corresponds to sets of polar or hyperbolic \
planes. These provide polar and/or hyperbolic dual formulations that lead to \
powers and roots. Constraining vecs to unit or zero sizes gives \"continuous \
orbit\" sub-algebras, generalised circles with centres displaced from the \
origin. These are described by multi-phase sinusoids.\n10) Non-Abelian \
algebras have repeated sizes (Eigenvalues with different signs) that may \
introduce uncertainty. Products split into commutative (Jordan, dot, inner) \
and non-commutative (Lie, wedge, outer) products AB=A.B+A",
 Cell[BoxData["\[Wedge]"]],
 "B.\n(11) Clifford algebras are an important sub-set of non-Abelian hoop \
algebras. They are generated from orthogonal anti-symmetric \"monovectors\" \
",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 ", with ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 "=\[PlusMinus]1, ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 ".",
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 "=0, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["e", "i"], "\[Wedge]"}]]],
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 "=-",
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 Cell[BoxData["\[Wedge]"]],
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 ". Bivectors ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 Cell[BoxData["\[Wedge]"]],
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 ", trivectors ",
 Cell[BoxData[
  SubscriptBox["e", "i"]]],
 Cell[BoxData["\[Wedge]"]],
 Cell[BoxData[
  SubscriptBox["e", "j"]]],
 Cell[BoxData["\[Wedge]"]],
 Cell[BoxData[
  SubscriptBox["e", "k"]]],
 ", etc., can be interpreted as directed areas, volumes, etc. in Geometric \
Algebra. Clifford algebras unify 2D, 3D, spacetime, non-commutative, \
projective and conformal geometries. They are developed in a different \
package, ",
 StyleBox["CliffordG.m",
  FontSlant->"Italic"],
 ".\n(12) The ",
 StyleBox["GroupLoopHoop6.m",
  FontSlant->"Italic"],
 " package implements these concepts. It contains a database of over 800 \
loops (including all groups with up to 73 elements and all non-Abelian \
Moufang Loops with up to 32 elements), together with their sizes where known. \
Because of computational limitations, very few sizes have been found for \
tables with over 16 elements. Procedures are supplied to generate, identify, \
and test algebraic loops, and to perform algebraic operations on those with \
known sizes."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Multiphase Sinusoids, Orbits.", "Section",
 PageWidth->WindowWidth],

Cell["\<\
The following demonstrations include results that were created with:- \
\>", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"Quit", "[", "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"<<", "GroupLoopHoop6`"}], TraditionalForm]], "Input"],

Cell[CellGroupData[{

Cell["Multiphase Sinusoids.", "Subsection"],

Cell[TextData[{
 "I had long mistrusted the lack of symmetry in ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]]],
  CellChangeTimes->{{3.425107139*^9, 3.425107398515625*^9}}],
 "=Cos[x]+\[ImaginaryI] Sin[x]:-"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Series", "[", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "8"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"Cos", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "8"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"Sin", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "8"}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   RowBox[{"\[ImaginaryI]", " ", "x"}], "-", 
   FractionBox[
    SuperscriptBox["x", "2"], "2"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["x", "3"]}], "6"], "+", 
   FractionBox[
    SuperscriptBox["x", "4"], "24"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["x", "5"]}], "120"], "-", 
   FractionBox[
    SuperscriptBox["x", "6"], "720"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["x", "7"]}], "5040"], "+", 
   FractionBox[
    SuperscriptBox["x", "8"], "40320"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "9"],
    SeriesData[GroupLoopHoop6`x, 0, {}, 0, 9, 1],
    Editable->False]}],
  SeriesData[GroupLoopHoop6`x, 0, {1, 
    Complex[0, -1], 
    Rational[-1, 2], 
    Complex[0, 
     Rational[1, 6]], 
    Rational[1, 24], 
    Complex[0, 
     Rational[-1, 120]], 
    Rational[-1, 720], 
    Complex[0, 
     Rational[1, 5040]], 
    Rational[1, 40320]}, 0, 9, 1],
  Editable->False]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox[
    SuperscriptBox["x", "2"], "2"], "+", 
   FractionBox[
    SuperscriptBox["x", "4"], "24"], "-", 
   FractionBox[
    SuperscriptBox["x", "6"], "720"], "+", 
   FractionBox[
    SuperscriptBox["x", "8"], "40320"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "9"],
    SeriesData[GroupLoopHoop6`x, 0, {}, 0, 9, 1],
    Editable->False]}],
  SeriesData[GroupLoopHoop6`x, 0, {1, 0, 
    Rational[-1, 2], 0, 
    Rational[1, 24], 0, 
    Rational[-1, 720], 0, 
    Rational[1, 40320]}, 0, 9, 1],
  Editable->False]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"x", "-", 
   FractionBox[
    SuperscriptBox["x", "3"], "6"], "+", 
   FractionBox[
    SuperscriptBox["x", "5"], "120"], "-", 
   FractionBox[
    SuperscriptBox["x", "7"], "5040"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "9"],
    SeriesData[GroupLoopHoop6`x, 0, {}, 1, 9, 1],
    Editable->False]}],
  SeriesData[GroupLoopHoop6`x, 0, {1, 0, 
    Rational[-1, 6], 0, 
    Rational[1, 120], 0, 
    Rational[-1, 5040]}, 1, 9, 1],
  Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A plot of Cos[x] and Sin[x] is asymmetric. I developed multi-phase \
sinusoids (solutions of banded differential equations), and the concept of \
\"folding\". Symmetric four-phase sinusoids (See Fig.2) fold to asymmetric \
Cos[x] and Sin[x]; 6-phase sinusoids fold to three phase sinusoids, and \
involve the third and sixth roots of unity. This suggested the investigation \
of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"\[DoubleStruckS]", " ", "x"}]], TraditionalForm]]],
 ", where \[DoubleStruckS] is a generalised sign, an ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-th root of +1. The result was a symmetric set of oscillatory phases, but \
they grew or shrank exponentially. Each phase was related to a power of \
\[DoubleStruckS]. I found that the amplitude was stable if \[ExponentialE] \
was modified to be a function of ",
 StyleBox["r",
  FontSlant->"Italic"],
 ". This led to the following analysis, and the definition of multiphase \
sinusoids as selections from an infinite series according to the different \
powers of \[DoubleStruckS]. "
}], "Text"],

Cell[TextData[{
 "The generalised sign is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "j"], TraditionalForm]]],
 ", with ",
 Cell[BoxData[
  SuperscriptBox["\[DoubleStruckS]", "r"]]],
 "=1, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", "j"], TraditionalForm]]],
 "\[RightArrow]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckS]", 
    RowBox[{"Mod", "[", 
     RowBox[{"j", ",", "r"}], "]"}]], TraditionalForm]]],
 ". The exponent ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["e", "r"], 
    RowBox[{"\[DoubleStruckS]", " ", "x"}]], TraditionalForm]]],
 " ",
 StyleBox["generalises ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"\[ImaginaryI]", " ", "x"}]], TraditionalForm]]],
 " ",
 StyleBox["to define multiphase sinusoids; ",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" is now the",
  FontWeight->"Plain"],
 " number of phases. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "r"], TraditionalForm]]],
 "=\[ExponentialE] Sin[2 \[Pi]/r] is a modification of ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 " that gives stable cycles for all ",
 StyleBox["r",
  FontSlant->"Italic"],
 " values greater than 2; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "3"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "6"], TraditionalForm]]],
 "=\[ExponentialE]",
 Cell[BoxData[
  SqrtBox["3"]]],
 "/2, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "4"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox["\[ExponentialE]", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "8"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox["\[ExponentialE]", TraditionalForm]]],
 "/",
 Cell[BoxData[
  SqrtBox["2"]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "12"], TraditionalForm]]],
 "=\[ExponentialE]/2. The period is 2\[Pi]/Sin[2\[Pi]/r] and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["e", "r"], 
    RowBox[{"\[DoubleStruckS]", " ", "x"}]], TraditionalForm]]],
 " can be calculated in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as Exp[s x]/Exp[Re[s] x], where s = (-1)^(2/r).\n",
 StyleBox["Multiphase sinusoids are solutions (for ",
  FontWeight->"Plain"],
 StyleBox["r",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" >2) to\n ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["'= ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["-",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "+", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[")",
  FontWeight->"Plain"],
 "+",
 StyleBox["f'[t] ",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["and",
  FontWeight->"Plain"],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["\" = ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["-2",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["+",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "+", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[")",
  FontWeight->"Plain"],
 "+",
 StyleBox["f\"[t].",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 "\nJust as ",
 Cell[BoxData[
  SuperscriptBox["\[ImaginaryI]", "0"]]],
 ",  ",
 Cell[BoxData[
  SuperscriptBox["\[ImaginaryI]", "1"]]],
 ",  ",
 Cell[BoxData[
  SuperscriptBox["\[ImaginaryI]", "2"]]],
 ",  ",
 Cell[BoxData[
  SuperscriptBox["\[ImaginaryI]", "3"]]],
 " pick out Cos, -Sin, -Cos, Sin when r=4,  Re[",
 Cell[BoxData[
  SuperscriptBox["s", "phase"]]],
 "] picks out each phase. Figs.1 to 6 demonstrate this for r={3,4,5,6,8,12} \
over a full cycle. Note the half-spin r=12 case."
}], "Text",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", "3"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "r", "}"}]}], "]"}]}], ";", 
  RowBox[{"pp", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "6", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "phase", "]"}], "]"}], "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["s", 
          RowBox[{"phase", "-", "1"}]], "  ", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", " ", "x", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"phase", ",", "3"}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"pp", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\!\(\*
StyleBox[\"Fig1\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"3\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"phases\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"0\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"l\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"4\",
FontSize->9]\)\!\(\*
StyleBox[\"\[Pi]\",
FontSize->9]\)\!\(\*
StyleBox[\"/\",
FontSize->9]\)\!\(\*
StyleBox[SqrtBox[\"3\"],
FontSize->9]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r", "=", "4"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "r", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "phase", "]"}], "]"}], "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["s", 
          RowBox[{"phase", "-", "1"}]], "  ", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", " ", "x", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"phase", ",", "3"}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"pp", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\!\(\*
StyleBox[\"Fig2\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"4\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"phases\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"0\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"l\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"\[Pi]\",
FontSize->9]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r", "=", "5"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "r", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "phase", "]"}], "]"}], "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["s", 
          RowBox[{"phase", "-", "1"}]], "  ", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", " ", "x", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"phase", ",", "3"}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"pp", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "  ", ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\!\(\*
StyleBox[\"Fig3\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"5\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"phases\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"0\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"l\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"6.607\",
FontSize->9]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r", "=", "6"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "3", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "phase", "]"}], "]"}], "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["s", 
          RowBox[{"phase", "-", "1"}]], "  ", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", " ", "x", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"phase", ",", "3"}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"pp", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\!\(\*
StyleBox[\"Fig4\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"6\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"phase\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"0\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"l\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"4\",
FontSize->9]\)\!\(\*
StyleBox[\"\[Pi]\",
FontSize->9]\)\!\(\*
StyleBox[\"/\",
FontSize->9]\)\!\(\*
StyleBox[SqrtBox[\"3\"],
FontSize->9]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r", "=", "8"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "3", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "phase", "]"}], "]"}], "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["s", 
          RowBox[{"phase", "-", "1"}]], "  ", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", " ", "x", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"phase", ",", "3"}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"pp", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\!\(\*
StyleBox[\"Fig5\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"8\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"phases\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"0\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"l\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\"\[Pi]\",
FontSize->9]\)\!\(\*
StyleBox[SqrtBox[\"2\"],
FontSize->9]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r", "=", "12"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "r", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "phase", "]"}], "]"}], "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["s", 
          RowBox[{"phase", "-", "1"}]], "  ", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", " ", "x", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"2", 
          RowBox[{"Pi", "/", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}]}], "}"}]}], "]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"phase", ",", "3"}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"pp", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "  ", ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\!\(\*
StyleBox[\"Fig6\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"12\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"phases\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"0\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"l\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\"2\",
FontSize->9]\)\!\(\*
StyleBox[\",\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\"=\",
FontSize->9]\)\!\(\*
StyleBox[\"4\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"\[Pi]\",
FontSize->9]\)\>\""}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pp", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"pp", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pp", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{"pp", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pp", "[", 
       RowBox[{"[", "5", "]"}], "]"}], ",", 
      RowBox[{"pp", "[", 
       RowBox[{"[", "6", "]"}], "]"}]}], "}"}]}], "}"}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk4FM7/AHA6nLuuFNklHTqkVEqlY97Up5tSQo5EKYlKd1IhJEeudFCU
oovkyJFjhJIzuRXlPnd3HIuW6De+v/1nn9czz+zMvOc9szPPzLU5s992ipCQ
UJKwkNDkt4rbb3zt963NKf8mPwS53Dc2LdKxQdO0JVh/qbNmWT2K0jmHUlMd
HfqoN7YEizSZXENPLJbxG6gbjVvT7+q4o7Rm/cRP1I83Xj+7rNALaXVXx0RQ
W8xTWFRi4ovsR0u/n6dmiSU02ncEoCY30NKl5l5SK/LQCUa639cXi1CXnDyn
VuV2D1nN+foof4KgWAvsOr/wPlrqPRbhTO23l9FwTuYR+sDo+LGY2kHv0Npc
k3C0MCRc/9s4QXvWxATLRj5BHztWjjhSL108yD3SEYlwak7tNOohr20VN3Wi
0GnGis2svwQdE+LeXHT4Oco/uTM/bIygqqshy765vUDVIyVuctTJDk3eKoUx
qF3z0fMeAUELOry0v3BeIsGPJWK7qe9ZLWtzlHmNmtKSXzz/Q9CF/c4oy+Qt
2tpm6bVphKC2YlXusWuxaNGhyuIbwwQZ/VcQxoiMQ/f29u9MGyJIa538sHlH
PBJu7e6bwSdIIGVifF0nEaUE+BPHPoLe71ZfZliSiF5kCP6dJQTZeY9PVTuc
hPY1f97lwCOoTvhFQolbMlrz9Xrgbg5Bafw+BrswBWnGVbbGdhJ0dmV+KzFL
RfJyYWVOHQQtPv3gYx4nFd0f6hta3k7Qw85Ndqdk0pHvUb+xoBaCrvzwyfto
koHMyrx7RxsIWqFwOOxudwbqaKrKc/tJUNeBlU421zKRc7PZT6EfBJmW1qpI
RGYhe13/ws4agtbmLHA+1IGRr4ZunGk5QWP7rRRddHLRZq9c7pdPBCkp7VLw
vpOLzK4J7F9ignSaV8+6V5eLdhk7Vd7IIsj5jIR87KU8tC4owk4unaA/vh+k
GxLz0b7/Gj6UxBPEz5cU3bi0ADXGlp+/G06QvN/w9B3OBehTdj2/8SGN54Hm
aUaFBWh51QaHBfcJOtecMsXhxFcU9G6p7v1AgvrGrSfCnxeiDn3NMKYnQRzt
tKExVgmao9yZv9uBIMZEFF/0VAl6/P6tlORJmj+f/QdnfCxBBqzLFp9sCbI/
cLR/qWkpeiDaJTrDisbjjBTX/F4ZMp5YnL7LkLZntGrA0qscBVpst2WsJui0
v3d31kQFUm7UOtU0wEMaNUZ20fMrUYZF3qMSHg91q8zt9NtRibZlBsom9PDQ
sffpbebBlSiC/GuyaeEh88qe3wK1KnQxxIRt/52HdszWr1mjX43cn57ji77j
oXnRsnlx4bXI/D1H4o41DzVxG3VDc2rRxmtH3V0teOiJ9pscl/ZaxCsJOXHW
hIcUv+pl79asQye/aLqu1+ch6d7z6d25dWh4SE3KaR0P/V1RE6/WU4+Oj2V/
usTkoerMsMdP1jUgpdsR0h0JXLRYrflrsUUDusc71SwZy0XO/ouGBK4NyHKp
z331GC5SOZysb1zYgPYwD7/fH8ZFx/+VTkiZNSJhlf+K9N25aFhX2Nr12i8k
aI//2bePi/xak4JXWjWhdQFRA/wuDoqzUzKRj2pByi2bzQymcZBIp/JA0ocW
5Bv60Uj+by86YjvX/0BhC7pfFW1fMdiL5G0W5wX3tSBLEZUB7dZe5GKurSmL
WhFImSQ8+9SL9hjsF5VqaEUn/2wUEbreizhaPqmis9rRMeP4Rf3cHqT+T6Aw
dqcTNRVJ71uT3o2sN6Tkyapw0PupuwJcNDpRl1tu5QKfPmQ5lsLMndKG7H7v
fvJWMIC0ErfMG/VvQl8CtljsQkPIIaTjqvSCHwi8tqYKPoyg5d3udmYLKtDD
b0min6aMIu0R7X6ZvHy0Tu6z5uCWv2giZNTWlvsC8cN+D65JmUAsi9VhXbap
ePuGZOMdN4VgZcvpdxcMi/G8PdeFJzKE4a9OZEd8SzV+dkhBsXtgCtSW9VTh
e404INBuSZP8NDhl0jpwfmEL9rXP9rbaOx3cNvo5iru042HH4paeCyLQ0JZ5
6ahuFw5MPrWy9aoIzIt1Lgrb04XVxyRdf94QgR6TiJnFJl34sPce5RJvEZgr
ruY563QX/hxVahL3WAQiB4TPmIZ14Xu130rO5ItAgGDHc8/+LrxKtyqFP0MU
xOcERp8J68Zn5Bt9JhJFYaRgQW59dQ/+G6ER/ztVFPiqy1dI/u7B3ktcKnMy
RWHmhd8qa7p68NPNLPatL6LQ2S984dxoD66wOxQn+kMUtqlqpQSr9GLtrOpv
MsJiYLzsvt0J2148YVsmP3+vGHzJPXBiH7cX+/Qpr59mJAbWy9Xm+A/1YoVr
jpbtpmIg5tEtnjvei1cEMmJe2oiBldWCM/JSHGzzcddajUtisFLl2zrz5Rz8
Warg0JonYpDB8qk87cjBfqk4YnuvGEgIfvIi2jk4W2V0oIqIQX3gsJ81h4P7
PFdvt+GLAa9thpryIAcfNHpNXMbF4I5h2cabQlys0h8MidLi8Ki2o4GnxMXx
6sdb2KvFYV62vbOzARdXPGEsHHARBz3nfebr3nPxtOnbnW+6iUPgw7krFFK4
WNvBrYzhJQ7FtqOlvAwuDtcZvrQoQBxsFBWtvAu4+Fjt7wKLZ+KQeSY9/tgv
Lh6SSTpZ8FkcKlum1+RI8LCix6G4x1ISEP5LgYxb8nDNePE8vxkS8D78dZXl
UR4Ovbz54TVFCbhkEs38YMfDcqfm3zKbJwFbtPLP7zzPw5L7uaaK2hKQuMyv
Q9ybhyfmuE27ZykBvObvyl3xPJz5aPDqLRsJ2DDk5p2ZzMPXZhwn507Q8glr
Te90Hv4jsvuHoZMEbM/R0Ziex8MDXPn30p4SMKv0YWZoNQ+3Z7wy942VgJjP
QXIyAh5+sYb13TlBAgLvOD8zGedhm3j/bfYpEsB5VW9yX5jgX1HnVu7MkYDM
lAXaAnGC6+5sFBWtkoDB/MgHRkoEl5iUJ7qPSQB3oQjnyHqCEwdHxJ13ScLB
nBKDr2cJnrXrYPzMvZJwQ+O1etZ5gp2fJholHJCEKwX/Vr25RLCevmNkl4Uk
1PG1vji4EFwZ07La5IwkWG0sbwm5TTD/UKnV6nuSMF76z/zkY4JN36tPL38o
CbVnbGObIgjOFPF+c+qJJFTtuKOy7xnBHkl6Q1ExkpDGfGarEEPwTGaaj2y6
JIyE3ju9PZ5g7ZyoD7xGScjdo8jTyCE4bJaQuU+LJEiuGZy5MJfgCQdLoYWd
kqDq/dlYIZ/gL7MVd1v2SULIlaNzWwoINjnv31Q8hQG7Bi+XKn6j7Rf2eJ4Q
ZcDj34PxFeUEq6ruWDqVwQDrCzkvPSoI7iqZcklnJgNMI59Ul1cTfGXhFcnX
ixgwFCA/R6KB4AaX6vdbNRhg75v81KORYKhcZdy0ggHvbrqsHvlFsLgr96mC
DgPCz88Mym+m/a230fbaw4CE4e/yQp20v5o5P+caMmC5iYTKhi6CbbyU3bIO
MqDqvxzt090Eq2vVFfMPM8BQ5WJoZi/BGX761kedGLApfL7QKCFYbpFZQ+dF
BnSOv3za10ew3afjJg7ODBDLinzyu5/O3/BN/Yu3GPDWUyQ2ZpBgh0C/r4Lb
DJDKEMu6wSc4T/3Rlht+DMh98WLJ3iGCz1olrr8dyoD1om3y9cMEFwiykyXD
GNCxa0lI8AjBKveKNQMjGFBet9th6x+Ci7+2qT16yQAPT9flQQKC5x3tf6oc
y4BY6S0KGqM0XuPjrKj3DGj8uMUMUy9cpSD3Np0Bs09e4JWNEXy9ZL6/ZjYD
1K4eRbv/Elx1fIVYci4DduZL0c2Pjl940611BQwoPGrG0xgn2C1850RmMQP0
/tPYE0xdt8b4qm45AxLVHab2US8vt+F/rmLA9TdT5bdNEOxpf+bMrnoGXND8
df0edcM0l56yRgbU/umCn9Rakd62B1oYcFhphqXSP4J91oc21XYwYK2LfoUh
dVPlM3OLXhqvnz5P3ajXnn5X00QYIPcVF7ymviuWYWjLZwB51bK9iLotqqCk
+w8DGlJ7VVupN2yq2n56nAEhU6v386mDa5tyB4SZcOhMWOM4dbcTd9NlESYI
Etd/ovcHDIzRtDEJJpSYJY4LqO/HiKx2lWZCYsH0EA41F2bET5NnwizNtW61
1Ft/zlG/o8iE3rDdXz9Sh13UiGYqMyGue6fdfep+6fWqwXOZYFmmY21PvePN
f+GzFjLBtXxxkjZ1xNb9s8LVmaC8R/XwGI3H0K/DQXM0mfDRSdMmjXrP1VOM
F1pMMNl2HDtSR824cnvxOiY4PK+5yKIWxHlMidvIhFbte56faPz37Qi6vlKX
9u9WMs+KetzlzXmdXUxQuuhS6knn00ghlZdtwITQ/0y3MKnfJOSd3HKACXIL
/sn503ww7Wiw2mPBhKmu6jkXab68c+3+UX6ECU+L+p/8ovk1nTV88KAtE25k
idcg6sS90nsOn2bCM6PPB3tpfor3sApazjHB/8THJ2uoj3gs1jtxmQkj/6Lg
Cs1nZrruurOuTNiSMf1hB81/u3kXFrgHM6Hi7pXgE3S97P6WlmP3gAmf1CRz
reh6Wu4ybrH3MROSVXbwDeh641d7hbJjmNDYNGwtxyXY9c4jkdR0Juwb0ji1
jK7fo9q/op5kM+HBapH0xg6Ct7XOQx55TFjN0WZ4thPM2BR72bCUCVamavlp
LQQ/6Mvu6m1iQvcbJ89kup84P5nqWdHOhGC3FeLKPwm22LVjbnoPnd8XoaEu
9XR9vfh+yIvPhGot9SLVGhofk7YiVTEpED/OjR8vo/tdtnjcQU0p2K73ulkc
E/z6lMHOjaulgBerp9GaSbCfYkj7vPVSYKo/zTvpI8H7z7FV+vRoef6Vi+tT
CG5U0wzwMZaCoMP/1v+IpeP1M3LC16VgWrSX0NmHBNeuf8SMcZcC5x8jsR9D
Cf7Y0fja77YUoK/3L/4NpvGAEy2HgqTgbOulw7b+dLz8qwf4L6RAInvsRYkb
wfPNI9csKZECWLEI99sRHNtWJpxZLgW+hauiOmwJXn16otSgWgpaT0tVVtrQ
+LlZHr/wSwquLdsw94EFna+XrAe4j/Z/rcDj0146/sEHfw7OlIb9WW/YMasJ
XucXmOF+WBpco4M8kv/wcM7MnNszj0rDi47kjGQ+D++MJAdenZCGKvETFnF9
PGyWaMApPSsNtqKOv2538fD1Ooby7FvSEGTNEm6p5eHcBXduxL+UhvMJgy+X
fuBh/Sw33YY+adDxXCHPtqf/t4e6l38fkgbL1MS1n47x8KWhfewvo9KwZYgf
ZmnFw+WzAsdMpshA/mjfQhcjHh41sKrRZchAXFOt677N9PfwuO9MVRm4eWZ+
tIkMD/MjdUYyt8vAZvbwld44Lp5w5Dmu3SUDvVYRX6695GLxjVFtCXtkYO4N
T5+pz+h5qU68IsZQBuS0vVwEIVy8Q6Y+NtBcBkQuym++eZWef1wv2xw7IwPR
HPf2QT0u1rNOLpV8IANMC5uUgG8cvO07ind+JANn1b68XvOVg3fpFgd2h8uA
wtJzTytzONhwbsuBgqcyoK1cGzmSwMFHmqV/uL+RgUs/slSbQjj4hvWpDkGW
DDglegivMebgdOt5/zrbZGC23uLj41X0/GgTuCJ/lSykS+5j3MnowV4gqy6+
RhYiH6acaE7swY0qwfMN1srCpU2ihlpverDPz5BZdRtkwVirqDrvYQ9uM3rw
t3erLCg4t7c8uNiDH22P+DrDRBa2aQu6mMt78JRlsUeOXpOF088Mm4Gen6tH
CgKn5MvChPo3M90jXXjKb2FFT2s5mPPm6goZu3bcYfbgsT9fDn7flZt6a1cL
Zh+cWfveYwYo+17aWchpxPVPQ9cpzpWHU7lhtVirBuu7OT2YniQP9qXPy7J3
luKdSXuV1xrOhE9/MmsCv6Xhv1fvPOW1zYRCrXhbSa/HSBi/rc+5OAuWzTh4
OWtpHvI/WL6+Vk4BIjdrm4m3fEflrvsenI9WgPCsDwrOpvUofLyCZbRVEcr+
Bd1OuNGE0v5sMt7bpAiv9tp9Nx9qRX7e0+6WO80GhfdRLalNHajzZCknVFoJ
VPMsj7+O6UY5Y5uUWmWVgOhB3PL33eih/7vtK+SVIOCIeUgcvY/tSAiIKlJU
Ak5pmdbDkm705o+h6b+5SiBZKuGhOtCNHG7X5NmtVoJgy1lmYxt6UN+L32Eb
DilBeicZKCzqQYLf/Tuao5Tg74bn3fuqelHRDJ3medHUlbmj0xp60ePt7leP
vVSCLVnixxPp/RHi5d50vlWCKWoZWwQDvcjrhpYkL1kJ9qXnd2nLcpCc8sXS
0S9K0G12bvvZPRy01OyPoXyvEkwdcGZ9y+Kgv/7Qc5CrBAqBP6a+zeegsk/e
7g+IEvxLb5RyLeagc0tmJynxlaCoY5fXzHoOjdd6+bnjShAu7F7KHeSgrQ+u
1SyTZsHVhCrT/Yu5yLJqwmy7FgvkjjqHNvly0QXZ1qkf17Dge/PMZKtgen82
KIjVWMeCRUEGHjUPuSjza8CE7CYWfAk3XvU2mouUslSjGrax4MXI9eC+bC6q
i9brdjJjwZ1f2XXdhIsOXPa6/NiNBYnmxtE+u3nIPtleVdqDBfIrfZ7+3cdD
7v0GhW5eLHg25bvCcWMeSjylwDrhS8ttPC/MseYhmSOvsleGsiD/dUDm0ks8
VLajaHrBKxYcs0HodQQP7VSSutf/jQU+IRsMlnfzUPLnTiOdChb4JdRf1+Py
kIrTp5m3qljQ0KGqvLefh/gFFx7I17Og6UBKjKGAhyIu/gxb28KCl7KpRWNi
BA2Uv3p2nc+C7A6+W+tCgixc3G2+DLPgsab5+hvqBBUsspgvLWBBQupZQ9nl
BD2+IR39dJwFO5ZoPFVdQ9A2jUuv8kTY8OrO78hWPYLCbm+JF5/Nhi0uK0+P
WhA0TUv57H4WG342pBUrHSHozK/hFeHKbAiorXDROkrQ1jVvEjXmsaFGKL1G
/yRBvBaZlL1L2XBKIdBo4UWCtmz+lRm6iQ3v3F/U2foS9K479fovxIY3OEhR
8i5BiqFBmxfpscHlUPXTV4G0fu/WnLRtbND2rrhdEkrQw0dv837uZYNKzaqI
1EiCOPwrRXNt2DDdVvOEUiIdz2teePgxNtSjqFGnZIL0Dx9znHmCDUfSeE45
KbS9gr0y4g5suON8VlwvgyCnsIXGfRfZ0J+yrKg2j6B5ex8vsr/CBrNnTvYd
nwmqmConaHWm/V3r291bQNBqx/Hw2ptsCELE7WcxQcOoqjn7DhsaHzVI6lcS
9JK/M2mdHxvO2yqHyFUTZPoaeyTepfEpreWX1RCULvd2UUwIGwqNsv7T+EGQ
S7ubo/8TNijECKSvNhGkETayWfQpGwQmzy2HmglqNHCUcYtig1+hnLtdK0Gb
00yTLrxkw5OxMH2tDoKEfTUF5glssHfd02bWS1Aiii6qTmKDxStmoz+HIBu+
0uO9KWz4suTO61QuQfmWImhLBhsqQs0zCSHogpyLTFYWG0S3SU+Z6CNIraC/
WTuHDTI/tZWmDhDktaLRQ/0zG6whLad/kKC17fuNXxSwgUVuGfzkE9T16Osi
lSI2pKOXcRlDBO2cmlwk+40Nid5Dv46MEDSauuSx73c2cJxfvlf7Q9Abh0jH
6VVs6JqC9zdTM2p8ZAR1bFhQvlN00yhBmT5CLed+0vnTODS7kdoRXUriNLLB
1EBk7PwYQSr8Xo/jTbR/P9Rihf8SVPbK2riphQ0OswM0vKhvWtYuMmun9QUs
F+FxglbI6QsqO9lQy3gddp666UtukX4PGyZuz/RuoA66tu5xAYcNEv9t2bpx
giC9Fe8cdQkb2j/N+hZMPdA2H2X0s+Gt6uXFTdTPHz2SWcNnw4dFBvsW/CPI
yEC65d0wG8J1vbdZUU+b6pm0WMAGdF1eMoj6Q+qoR9QYG8r9256kUx93OGvM
nqDzX8SZqKOeNbdj0X0hZRjXXLCcUL9xZ8x+TX3z24ukSW9qWyWRSb1xk+Ta
yfeFYy9vcpqpt9+6s7afOnHZ7IRlwsqQkrZ7ziD1tgAUBdRLC0dDJl3fZxty
gDrsZYAIvZ8goeTEi1epd5XZt09aX2ePzmfqBbkdd4apm8LPLa2jfqabz530
hfGH7F7qpru3945Qh+W0T8hMUQafYMz4Q9217WaeBXXnpiFHweT7yKvo5DPU
herCnyYtLVES7U69qX1AdpRau1TR+xV1Qe7tuEl7HEjcw6f+Medy8Ri14oe6
TaJTlSH3SgJz8n3l7ax/y5WoFSK/60+6on63LFAPHsgrmPTxDeemHKA+13JP
mN63kODxw0Fbav3Ne9ZPWvVIe7Uvtfhhh6hJJ3+SLIigbplbXTnp7fNXpSVQ
SyTNnzpBfbrjRlgt9dpN58wnPWVHtG8Ptbb2OY9Jh74udhmnvvLX5O2kMx0U
reZPU4b0vqqBSe8r27xPmzpJxWHG5HtRq6at7k7qztndKyd9Kch3lQW1Yctu
g0lLDCbMP0Pdf/me3aQjjOrk3anzf+S6TnplysT0UOpCidr7k85XUBt5ST0h
+v3NpE2v7u76SH204n3mpDk/nOpLqYdOXiqZ9M2ND4uaqJPL5v6YtFxEdsYg
9VOhpPZJx/xrixWZTvPn3xIy6fXWkhGzqUeKvYYnXZK7MkCD2sa2cGzSRxaY
uqL/lfdPTHrQ84bT/v/V///3sf8Djk75tw==
           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4lF8bB3BbpcgyM7JlyxKVUtpI3af8olBkX0OF0iLaVMiSQkT2Nkl7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           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4VN8bAPAxYyyJLMPcsZSikCVtKqrzaiORpYWkrEmhKEl9EWmhVLZE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           "]]}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       PlotLabel->FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"Fig1\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\".\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"3\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"phases\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"0\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\\
*\\nStyleBox[\\\"l\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"4\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"\[Pi]\\\",\\nFontSize->9]\\)\\!\
\\(\\*\\nStyleBox[\\\"/\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[SqrtBox[\\\
\"3\\\"],\\nFontSize->9]\\)\"", TraditionalForm],
       PlotRange->
        NCache[{{0, (4 3^Rational[-1, 2]) Pi}, {-0.9999998830731719, 
          0.9999999999999918}}, {{0, 7.255197456936872}, {-0.9999998830731719,
           0.9999999999999918}}],
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {192., -119.58957682310464`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk41N/3AHC7GWv2oUhKSVKfLC3onlQKJVooW6WUpEJFH2lRiTbZkz6h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           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd2Xk4VO/bAHBrITFzhqJSVFpJSmmh+6lsRaKkTQgJyVqSpNKGJFsq2VKW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           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk41N/3AHC7GWv2oUhKSVKfLC3onlQKJVooW6WUpEJFH2lRiTbZkz6h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           "]]}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       PlotLabel->FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"Fig2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\".\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"4\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"phases\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"0\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\\
*\\nStyleBox[\\\"l\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"\[Pi]\\\",\\nFontSize->9]\\)\"\
", TraditionalForm],
       PlotRange->
        NCache[{{0, 2 Pi}, {-0.9999998830731719, 0.9999999999999918}}, {{
          0, 6.283185307179586}, {-0.9999998830731719, 0.9999999999999918}}],
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {576., -119.58957682310464`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk4VN8fB3BLYWYsJWVmVFSUEL4ppcX5tEuIvhVfS7KXaKEkSRSRFkoK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           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4VN8bAPAZS1H6EjNDCaVI2lQkVO+RKFERsldKtpRWKUupZKlEJZQi
RYQQSZaOJGkhjOyR7Ga5lX2d3/n9Nc/nmefc8973fc97711y2GvfUSEajZZL
p9H+/yvmQjuTIHdla0zfllx+ORumLN3/3Yg9BHvLcvZ2p7Bh8oTae9fYkyB5
30K5IYx4MjjFKvYyFBlahqXvYYNvqXacaWwEBLifXK9UXwuFSZKsnbEJIDzX
b696Vw3YR0/WGsZmgd/qNa9YE99hZcSp7O2xJRC1UvXZuh0V4KCkHTZhUgOG
U5kMW70MiDfZr535qgkeo1n+afuysav8q4bY0V8QrZlXqKVRgQ/bBezU9uqG
p9eW5WTsqcOtwvKjVx70A7TpvJB/3oILR/yaVyjx4Uei6uKPER04eFmaucOO
v2CnlDXZyuvCf4RoPyZsBqF0hnklrLgXT/3yFh1yGgSRV2UzYxW9WBzztHge
g7DcXunNobperOzbcr/dbxAGqtsr5Tm92HIwz6YsYRAK9qzSQXJ9+E3n8dZb
fYPgE2qqC6f6cEBZS+dinyFYND+pT6DQjyWuv/lnFD0Mu7pi4n47DWC+yItL
z+OHYcBaorvTYwB/vxonIZYyDIf7EhPazgzgO4GBqp/zh+HpIgu3kqABLOdv
YmfSPAwaq79PaqYO4KVn29/vVRiBXuf/jH/xB7Du4dmRNk9HQG1oOFDjHAcv
6hhXeJs2Aqk7jWfs/Tl4+iD3xYLcEZDLyU69HMTBJY41Zc1lI7CvJzPodRQH
G9o+HHPoGYE7HgYLK19zsJnZ2kNOK0aBttJtInuIg123Wq/1yByF0NA7TMPj
XCyWzriZ8GYUwrZJjBw/y8UpC2r76vEoNAe+/i/Cl4v7hkwTDapH4XH81w4c
ysUeaduYCn+JreraK5O42FNuzeT39WMQkCb/6UkrF5/+J/JJK28Mjp87PKJg
yMPSh0qXer4bg7Eig2wPEx7Oqbx0ObF8DFZULDiVZc7DQykTOpINY5C+M21c
9QAPnzv4J71vdAxuyA+KlHjzsM+3ljsPdcZh4uGcdwnJPOyf/OoAvXgcOPeW
/Jam83HW46ZTAx/HoXvHJtrgLD7uuk8LYleNQ+8mXvYXCT7eFbwnLenXOHz9
lfT5kBwfs9wGRo1FJkB7ifCj5Wv5OHOFcuQdkwmIryw6qWjPxx3pkR+WNk/A
B8WSDcnpfMxIyq+X6JyAEq935eey+Xjno/b+Yc4EdLYEFW/O4+OXt1ZLVUxP
QJgqqyYL8/HFE58dPJdMQnnjnmPravlYRoM+kus2CXLXkk3vDvOxYc5JNaPR
SehI+mBUo0XhPaYyMfcFk/ArYflBEx0K7+9+Pbt39hQ4lRg1FG+msIvsZE+w
3BQ4qNl13jCg8HXfoKTPOlNQuTjf4psZhcsNHijv9psC/YZrv3+6U7iqdfOd
R9emYLNMStRPTwrXn2un829Ogdoo7+EPLwr3PF/WEf5oCt4xph+/PEfh2RKZ
8dXvpmDG0PyYSCCFd9Z9WGRJnwZtGXRt630Kmx13uflMfBrauEmsDzEUtpkl
PjU0fxocKs/9hYcUdtu0pyVKeRqW2fT6KydQODSuMbbBYBp+qgZ1hKVS+I6W
r7ia6TSkxDxJrkmj8IMqhQs+ltOwMPRyptRLCr+gHbFZcHQaQuj7w86/ovAX
Zx7L/vo0cLgXrPoKKFw7fft6Wvg0PHzzZsXfIgo3318/Mnl/Gr44hW75947C
AxXnf8Q9n4aisaElP0spPHe10L22imnwK8mstvpCYdNh1vzDc2cgLIB2uLaB
wr1yS7WPMmag0Kl34FITha9sXuvopjADdmNDe5e1UDj/6o7UE2uJdz9LN2+j
8FJpH31fixkI7yl/urWLwu+0rrkGOMwAtt1Of9pN8mEbcSvw6Az4N3pqz/RQ
ODwhpSn4/Ax0i21YFdtP4Yk1TafuPZyBeVUWq534FI7a1x0d/WwGctj1hn4U
hTW8/xY/yJiB+3brNMP/kHoXi895gmfggrxW5P1/FKZ3MDWeVczAK5qx4OYg
heNElPc/r5mBj8Xi2y4OkfyY6CZmdM7AxtnXtuuMUPi4l1FFFncGyk2KheeO
Uljs7j5+zvAM5DUm3mcTb2320C2YLYBEjdsbjccp3DTtfahYSgAyH9QNRojP
Lrl6vWSBAPir4pQfTFA41e1hbflKAUjO22FbPknh7Tefj33WFMCkvXrWnikK
t2XmKFZuEcDrDdpNlcQX2Hh7tZEA9rOM6wymKcwY/erB3isAW7WtT7KIMxc2
RtTbCOCZxigwZii8a2tXXpOTAO7HWGedIO52+tPa6iGA2Z6G/zDx5aApoV9n
yPVsU0XFBBSWTxVb0eknAK/sEwNGxHnfGHt7ggRQ6Xo1wY/Y/M/ic/3hArgi
3bg8lZgrs/ohN1oAMHDw8jfiYG2d91SCAHZ/kXrRQ6xsb9j7L1UAjzQ6n40S
FweYzxt5JYCSLbUnBcQ2iY4bxgsFQOW2zJshHvzobjtVRuKbEvgOEof3n7sk
qBSQebWtsJ14xbwrSUINAnj67vnXUuIyjfCvor8EIL9BJyOO+KDlg79i/QI4
5E4/dJx44nyyrMQ/AfgOzevSJI56+GqL5KQApOd46QyS+4852L5OXIiGHK9o
H0ohdjnVXRY2i4ZUG/1sLIk3XOVYS8ylIaxmrTxK8kuL+jtwS5KGaJodxRHE
Vcmj/pIMGtrosGnlEuKH+dNSkXJkfbKfRwqpl9sX4WfSCjQkyK/2VSUW5kt+
YarS0AAdMWeTemucn9x+RZ2GbAx77nqSfnCg9WL+GhoKsj6s+5n0S570u9ef
tGlIdv5dgesYhTsfpmpobqYhS49UxRek36RUotISEA11D9u4dJL+9ND2fHLB
mIaW8J1O6g1TOLrEelHPbhpKjNPYYEf6uczYIHrfPhqaRb+qdJL0u6LDwlsr
7WmoZV/+ucC/pN8vV/j89KSh1RUyi3V5FBaI5w4an6Khk3mPNkpzKbzqbvyJ
vHM09DZr2KdjgMzLJG/n2wEkPscjV472UVjnyzIz/Qga4u6b/Uq4k+TTQupr
xj0a+mpUqhHVQeZV66ThwlgaMulc16bwi/QPv1Zv8AkNvX5XXc74SeEEmcDl
STk09EOJ3hJTT+HKOM/E+fk0pOmyvaWzjtRTxUYhoIiGekXwPFU2hS03rZWx
/khDVRzjuRHfybx1/Dkj1kDyI/nNe+IThTV7Ki6ca6Gh8MIqluAjhQ955Q51
tJN4ti/nTXygcEHgjYGCPhoKdJaFRkzhE8k69Z4TpB6K6iEr3pB6rlUxb5qh
oTODNE5vLoUr8qW+GQrTkUleb8gjMk+Vv/a+V5Sgo0srTvrwM8jzgIrKqFag
o41XSjctf0bhLTr/rmnq09E8xrymoXAK192Rf2lpSEfov9Rf1jcp7Mnd3nDW
mI7Mh33Mc0LJ/I6PXvHanI4sHPRPWVyj8Jjoliqtw3TUeT63cNMFCufWBstq
X6WjGiFFRowTmb+rspF1MB1p3wBB4AHSH0HN7udv0JFX4sMDzvYUltZZXfTm
Lh3t/iriL21FYa/42kObntGRWaH4HsZOCqt7KrzQ+UhHR+0M/71cReHSj0Zs
28901GY+GrB4BYVtlU5OXaiko0blwpthKhQOqS3dU/CDjuiHeWt2KpJ5sslt
ULeHjg6m30t2lyT1E83ZvHm2EMraELPa6A8fy8bv/L7VWAiZLe/f7Ume92PF
yRb5u4WQUoK3cfhzPm5sFWlct08IaUWbxTxP5OMHC9//WmYvhNa/8NEqieFj
xfs6/+YcF0K+luJRodf4eNktdWZDhBB6dTxnVYAdH2v4Sth7NQqhIWsTu3EB
D89/4NHe1yqEmmc9eSw2wcP/8iuOHO4QQlZJjq6SQ+T9aOSap9WAENKfU3NT
uI+HN56e9tebEkJv5W9aX//Ow1vc+QmzFwuj3fkhZ0bjeHiXdXVPvKswGpFU
8bu3joejjDwXVB4TRjfD/q6VXMnDv7TETCe8hJFBbNerK8t4+DwDZVv6CCMX
r9erLGV5+FlNpq94qDDaPpOk8GSKi2dMbkudeSGM9H6nu3Z95OIctEfXiCeM
BqZLbi+y4OJF6t9ucU+LoDeun33zbTg4uy1O/sx5EdTIvZXxYS8HG909njru
K4LcL10eLTfiYK+p/z7OChJBARzbtteaHFxaZT61OFoElV3frq8lRd5HzzR4
WBWKoMPw9GXRxwH8quj3jnfCosjl3LoN9JUDeMfecXrEPVHk5pEZRGvvw2am
17x4WbPQ/eyfmc20Hjx25KrnxoLZKCEndTdM/sbjlTkb65vEkEfIAVH7D234
wT6bCKcecTTo726seqMBy2XadSbz5iC7PI/yVYuq8R/HcGGDuRJI8WKvvcoi
jF2Xb8z5wpyHPlYgM+3+g6BtIKmRuvE/tAlE5n9wfA/dG42S9fdJIu+kS2W6
VDXEJo79OLxaClUGXom5cqARuLUuUF0khaT33+jJpv+CcKnbJ3O2zUf+q7Sd
W807QUnX5fHgx/nozjfaBYMdPfBTon79QUtpJK4rzhFT6IcDuUb5p/dLo9ir
+murVfuhzf7Nlus20sj0u/W+SA3iFzE7Mxyk0Zy3j1bStxPvtD8w6SyNzL87
9t336Idf136FRp+TRouPyAbE5PVD19TAr+/3pdEB27OiXcYD5L1KEI6apFGi
rQ9/sSMHpEbnlF5ukUZ2z72rp49yQJPOGi75KY2+9L1pqj3BgQDmKnv939LI
6GCv9dHLHJDearN8G4f8z88tWvmUA7q3s7DBtDRarbh7Wq+XAyHrnP4YLZFB
qllqfrbuXMjQ81wavFQGvW3pvrHxFBdqDc/v/6Qig14fOeA99wIXFtndKtqh
LoPoijdq40K4kHnlbcjODTJovm6su+NzLtSz5y/ZZSiDdI95qFl2ckHFu9R8
t7sM4vh3yohb8eCyG9fe9ZgMWqmj8NXdngfNdiyXwOMyKO/Os9UfnHgQDh4X
X5+SQTUnjfgHT/BgREz6qcJFGeT3tnudfjAPKh46DfHCZNDLzvnuT97wwOM9
LTo8XQZFJiusqpLmQ1mO+pOUlzKIpe1wQF+OD4rJlmmlWTLI6lCJRIYCH2rD
UvBIrgyS2BHZeFyND3qWZn0Hikl8at2zorbwQaI3XmdtlQzyOEKP9XHhQ6YE
tH6nZNCAbN7XG6/4kF9gb9f+VwZJlh27NpzHh1I3n0b+oAyygPaf1oV8qC/L
rps3JoOU276emFXGhxm/ZZUmNAY6djOXM+cHH/bwxN99kmIg7lsHr6xhPtg8
VN3cIM1Ab63C3j4d58NhY4OCHgYDPb539t7taT54J/nliS5goO7pojEzUQoe
OVIvDZYwUM+9DU4XGRRwK+vi8ToGykQ7+lzWUTDi+1fh+wYGql+oXfNbkwKa
+n9xbVoMlKSZttl6EwWM6ztipnUYKLqhOnoFUKC3tSBCbxsD7T1psvOsKQVh
L+MD3+xjIBvJ3I6EoxTccygSlFsy0Bt167vP3Ch4PKfJv34/A92zlC5MOEbB
Kxfpi8N25PrTQ+5XTlHQpBh0esMRBpq7rmodx48CtdseRzLPMNC57Q215nco
qI9fcptzjoGsI5VsZaIoCMpqLFjuw0AHt6wd+hpNwe8aI+kEPwYKsLp3VPkR
BXGMpe8jghioXz5isfNzCnapNHO/BZP7t160qS2VgnGtSDnxMAaa/BhxYG86
BfutBV6B4QzUe/f0D1Y2BfMftCiejmagxGF3G90CCkpe3Nn1MpaBtjO96zyL
KDhRaOw98JDE+2OV3f13FHxrfVN5OIGBNHxXXq4qpeC60j0/i1Ri+SEV9hcK
Jp6ZNmsWkv226TiubqIg5bXwrFPFJB9BmhrVzRRYlxesy8AMtDvIUMSjlYLc
XrVQlTIGSrBqzbjSToGXuugmViUDnSqum9jRTYGiXtGRfd8ZSCHpyJfEHrK/
yZnb4TUM1Hc3O3qolwL14x09s+oZ6KW/pLr/AAVdmcVRo20MxPwoskyZouBO
ydn3GzoY6JpdWoPmHwr0a1byvDoZyFHa8frWv6Re/2K39/Uy0FqbfPbGQQpM
hc1PLhtgIIEv+5TKEAWTMmJxh7gMNJ/fKj53mAIbLe/Bxj8MpPznrWrhCAWz
jFYrMQcZqNlHJi1olILX+7t2mQ8zkIe+q9qOMQqkffYlfh5nIJFwlXmZ4xS8
DxGvEp1ioGov9bNWExScjC0Z159hILndB9j/iCsL1pgXCDHRs9KnF6SnKMjK
EbGsFmGiYKuFNjeJ76U37++ZxURbp3bazBD7JGXZTokxUX2azEW3aQocHl93
kJ7LRB07DxV/IUbRDgfV5jGR33OWssoMBcsi1h/eKslEFjcWp5wnFgsVO2o5
n4meP3ffW0rMDWxz9ZBhIqv4dllRAQXVF3M9LjOZqFnkNB0R554JO35flon2
2UlLnCGO8Tx0Mn0BiW9+rvZjYt+jG8+UyjNR9w3Ta++JDxyQ8G5UYKLQhey/
rcTbrH/78JVI/DPo8h9iVbN8XxFlJgp0jVw7RTzHODxg4TIm8vV+LyDfK8DX
dw7UUGWi//Sq/0wS1+rqXjNSY6LPue+E/r8+b4NUsIM6E/2pva31/+s/WNUT
enoVE50/uzO0hDhApehmyBomEnWjpsn3ChxWvHP7sQYTcY7dunuK2EjW7U7u
eiZauWb1rq3EK6S2Rn3RZKITpi1LhIklxBkxvzYykYhl8sISkp8/9IEHI5tI
ft8/1jxHXDeBH0noMVG0UIOXMnH+YFSC8haS39NHvn0i+Y/jHnu6CZio0cFu
11Hiy936yXv0mejiNLt/gtRvZwMv7aIhE4lNvb31H/Gq6g8vI3Yw0bqAQ3du
TlIg9Tk2O9mYiX7PTOcLETcUGL6p3c1EBuHPPRtIPxXkyBf07WWi2M3T41rE
j9P/Fs2YM1G22s/Um6T/XB4/KlXfz0Tt+l2nlEl/7oo+8xHZkPhDnMOcSP+u
iTCu2G/HRJ76S8pjSH+PBA5XXjnARNcDZVMoch6Cju5uanYh+W5vkAdyftwO
LG3948ZElV/+swRyvkytx9tmHWOi+U4G2dp8Mj+Nk7rWezFRRPeLFikuBc9W
TVNh55noX6PImDM5ryEq7H8JF5hIb0nGQVVynj0VU4fzfEn847f57V0UbJCy
mvx9idTPb+dVvd8UlA6mz9ILYaL88vLIe2Re7Nqr8MY/jIlmjYhMjJB5wn5x
y7XkJhP1OISsMSPzpsvpRIVhJBON0HfN9Pwg57N6bZjZAyaK/1xolFxFQfjK
BN27cUxkosNQwt8okA2W4vx4TOprUfmpiswvta1/TeyfMpFG5pObteVkv/RX
81zSmcilUG3oGJl/tbOXvkt5yUSyMZ8P6pH5aH/k7glOFhOdco5IoJP56bnw
7PeTr0k+Pi17dvo12S9EK9L3HRM9/iRZ3pNG1jvnMyKrSX0C66TlyDy3K1H7
yK4l5/Pqh6VW9yjolI89x/rBRCESB5mhkRQM1V6of9jERJkFTY9+3KCApa8X
k/yb3P/Kpfb0y2S9wjv5oiEm8ubUGT9zIet/fFDulWMhxbqBaMXVFCziqe5Q
kmehzQf6S01WUGApEnbMWoGFpHAhOqlCQdl6s9xPS1goc7u6TrwCBUm3Ww1T
1FnI36hJL2oeBa7Gw27um1mIe+pd0G8OHzhFqpmcgyzkuCv/7pxEPiyrC2Uv
PcxCy4NDHZY94oMDhztq78xCkVgzXiuGD98W5KBvbixU0xEbvTWcDxneUJt+
ioWo9hTfgQt88NKwGT5+lYXyXblmaXv5MPg0VO9PMgt9WmCS3jLEg0NP52oL
pbLQuYhhtT0UD6oSb61npLFQbV+H89t+HqQ+iVyxKZOF1uQOKF1s48HB+FjZ
y29YaI6G2Odnn3jw9UHqoGQFC72fc0spIYYHTyM/p63tZyHfRrGJTVo8kIo0
ea7PYaFGMX+l8jU8CIioTLTgsdBq+ab1pmo8sL1dE3v+Lwvtdo1cYSDPA8lb
TcF4nJjneLWVxgPfkP4je+fIIoeMJrN3X7hgcUl8kddKWRS6b5IytuWCS4fK
x4zVssjvfHCOrTkXfAy2neCulUWus4VcnIy5EDfbt8RdUxbdu96UYKPDha7b
XGfnLbLoxRbNlz1yXPBO+J5hu1cWhVxaoXG1ngMP3kfB9jOy6B96dbPKhAO/
hJWPLCiURXFSds16SgOgtsexc12xLIpQWt0gxBoAr5iYI7uwLNpx7I/tB4kB
mFkl6ez7QRaVRftMaEz0w6L9U84/v8qiDnXoe1fXD9Yp9S5PWmXRiWNOgc9D
+qHK9IbHihlZ1DXN21fE6YOiqKFTOvpyaG66HzsgvheCZbz988rk0GkfPw3j
mi64pBtBHbBYgBx9g9eneHZA+QnnFf6NC9BpW7OVwSMtoGta87ncbSESNTNn
7Ratgxcux8Qbif8kLf1iIVIHCwNFjfuJTS2S/OyE62D8tU7FXPeFSDCc99OV
Xgf5SonlZsQWKsyIK9Ns0Bo8/aGZ+HLg19dvhtmg8YBRzPdYiM633RFd0sOG
hNyXUwLirb+8bi/vZoPk952b5x9biN4bzsiu6WIDX9i/cAPxBf+1Knq/2ZBx
vPutD3GLR/daqzY2qOvn5Ql5LkS6URmzQuvZ8MDebESG+H5giu/tH2yY4z2g
pUI81GBFRdWxof+F4usdxEdFKmoTa9mQwgjOuUn8UFUirKiKDXJrlww+IpZe
EzdUWsmGYOPC9ZnEH5XbHT9/Y4NLAJVdQ7yDGbCq/gsb6mNC//4mrt3QHNn6
mQ1GOUvXDREvDuwf/l3BhrzK4pOixxeilHnpNv2f2KDSZ53FIi7pX1JAlbPh
fz5b3Tk=
           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2XdYTf8fAPCWNO+IhkKKKKOSdvT+FCVKZorKiOIboSElpUVFFNpEQoUQ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           "]]}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       PlotLabel->FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"Fig3\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\".\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"5\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"phases\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"0\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\\
*\\nStyleBox[\\\"l\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"6.\
607\\\",\\nFontSize->9]\\)\"", TraditionalForm],
       PlotRange->
        NCache[{{
          0, (2 (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
             Rational[-1, 2]) Pi}, {-0.9999998830731719, 
          0.9999999999999918}}, {{0, 6.606531998388248}, {-0.9999998830731719,
           0.9999999999999918}}],
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {192., -358.76873046931394`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk81M//AHA6nLuuFNklHTqVSlQ65kV9OpFKyJFSSqKidEiFkEREOihJ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           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VF8bAPBZjCVRGOaOpZQKRbSpUOfRRiJLi5KyS0VRknoj0UKpbEkR
JckSSQuVOiIlFGmRpexhzMwVhSTe8/trPt/PzNx5nvMs984MtwP2niwGg/GE
yWD89zrtZAv+X0v4yuX8soiJiRZ0PGHrtkpjN6SSe1N4q7MFPVdxvppmfBBl
aJ+8AG9b0LetHU8uGoehRxLiG26xLUgUOLvylHEsOtuU8NZyVgv6fWZd3Qnj
NKRXP8y4v+47+iPvsDXYuAA59HfvlDjTjP7aO1PHjUuRtdSGheb9X9H+CxG9
z8fr0LPTCYlfm2rR5+JrydeXNaPrum9iHbmlKNdb1YGb1o5upviFpr+NQ3Mn
/vD+RnYj/njT+8ejxdjV5HGZwjQhkjE2Yz+n3uOek6UfZ53rR1Ps1m3IWVGP
vVs2XM/5M4B8KrS7n7R+x68vrXayRL9RXVbTg3ul7RjOrCn882gYJVPw223S
D5xY80DqJWsUBf1JfDu7pAencTfXlsuOovHC0ksylT04d/uvxEruKGpYXeTb
/bEHl3YsnvtpzigKS7qxO6a7BwuHH1l1W46inDUChRT5XgyaRTFycaNorqHu
8sQdvbjHr1jNUesvsrha1jHR34uXKZYbDK4eQ/X30v7NkOnDO45/Ni62HkNL
F8V6GSj24ZAfXWtPO4yhKWf2Ll2i1odfPZV04u0bQ0MdhZJz9fuwrbtFhEns
GGLO8FUusu3Dux9WtYa3jiHPmRFv3BP6cMLWuhhu8D8kDtaL7VET4icl7cnf
zvxD4UMhxuNaQtw8d/BORvQ/dK5D8E9WT4hnTii9WJb+D+l9kHo3xVSI8+5s
EThV/UPrIdW6aIcQl498XXWbP44KQr71nrsqxL+utQwueTyOmn2VY7SniLDb
i/JdDngcPbZlO5Ypi/CHtpy3QRXj6BH2kt6mLsJ5OkGpzxrH0VutmVN8dEV4
9+OpG8wmyPVO1V9ZuVqEGz+YpVlZTKCx/G1Low6L8EvpdFv3xgm0alq0Ev4k
woZ6556d6phA2as+XQpoFOEUG785GcIJNFQW/nJmqwgfSzAd6xmfQD7DV9Ge
PhFWjRVsKlRgQHeRcWgKU4w/TQ+fMDVigGC4uytTT4zNTR5utTjBgKZPkkaL
g8X4nLOzvskpBuxf8M7dI0yM34dPkpgfyQCnL4a158+K8eZql/tKcQzYIOze
VRIjxm475Sa3ZDDA5MP6eSW3xTjkhNfLw+8Z8O7wazN+tRiX3lJI9P7IgDi7
3bnFtWLMqSjev+MrA67V6Jo5fBbjqKlK6mbtDDDd/q7J/7sYX72JAycPMWDZ
McMnpv1i/LCM0rulwYSiVzV/tBVpPNJdxkqYyYSwkuiNK1RobDL5QEOENhM2
bzlZuF6VxqWby8/sX8AEdZ2NL81n0ri2y79t+Vom0FL58V8X0LhPqiqh1ocJ
UwLerbayofF8vUDfMn8mSHU+2VJnT+ODtjPWPA5kwuflh/babCW/l3jkZ1Io
E34wNibO30ljybmzrHbHM2F20EpB6F4az7QKZo4/Y4JvtGN8QDiNtz2sz20o
YUJ91dhVpzM0vqi+0PFRORNM/S92m0TSeFT4o8CnhgmtfZsdWi/SuO6CrUdT
OxPkXSsOlVylsfRQ9tTCbiZ0Vc+/5ZZM45W7OM9jhUwQWfpyx1JonD3/qbLl
EBOSnsY/4abTOKxG602RDAsaYyX+NufSuGhpyKF4eRZUv4+ZvTyfxuLUr9P9
lFhw4vSxqKgCGjv6XQjS1mCB0rT3k/mFNF6oMKybYMgCeYHS6wpM43b7yqhD
DixY7VtyJayGxtSzWcttnFggCtMC+w803qh1omuuKwvMU5+q8T/S+OngopXt
e1ngOzt6b9QXGsfGX6dtQ1iwYPO97TLfaFwxNpykF86CreFBF2O/03jcw95C
OoIF0SFVA4qtNN67ROomjmFBpLS3xZ92Gq/64mc//zYLHq8LUHfqoXHQyqpx
mWwWVKYdKk3ppXFexuycrjwWFMaL478KaKx6pJF9vYgFYcfHny8Q0di2ZXF+
0HMWLJkvUrIT0/iM+SWnzaUsSBJNurybpvEAb80j2WryfcFN3rGfNNYJTXHt
riW/vz+CChyg8a6eEbmyzyw4EBW0es8gjSuLcr2OtZDzZO9TWfKbxowZ0kpb
O1lgYCh+LjdEY6NIN7yglwVpyccvfiO+uZ1H9Q6woBzXZ7mN0Ph4itMvv2EW
1IY/YE/+Q/qj42btyF8WtEhfv5tLPNVXL1Kaw4bAtAlBwyiNhff9PaNl2LA/
2DDU4y+N3ww9NqPk2bAr47t7N3FIqNmoNo8NFpVGKl/GSD3Lz3y5p8aGzu13
Os3+kXgmVRcs1WRDictMZgaxoo3CJTyLDV/eXtrHGqexKG7rPnNdNkg4Nmg5
EFd8TTKv0WeDUr5AN504XaNNy2EhG0rX3A/uJQ51m8NoMWJD+V716doTNHa6
s6/Zy4QNFRs15HcSLxPmF4kRG44MZ1ieJ+YuGIoPXMOGkLV5n+4T9x828R+3
YMOFQd27tcRVT0Otz1izYXuC4odu4oyJcl15ezbcTHZbPUwctkZWMmErG3Rt
VNgTxLsibds1drChrHbe1P9s/P7yi9vObDCfdmvvf59XUWq6pu/BhiT5EMUe
4gEHzSOPvNmQZ18i9YH4fbLnphW+5HwPH7AsIM5qyzYo92fDYFNs43/xnprT
L2sdyAad8kVF/+Xjsm9Jz6djbJhuubPjv3xN84+9cjrBhvad6k4Cch7Ub3yj
M5zk++7EzNvEv5Zzgn0i2NCCEo22EdeGWG7/FcUGBaOgRDbx3bJLS47HsGF0
0mKLO6QeZ6U/K0gkkPoOtq1dTexmrSo+f43kO341pp7Uc2Wsc6VSKhtqlALn
eRAPqQnCtDLZcGW1rKUXqX+di4Fzzl0Srx+zpon0S97tAJNF99ngV305bT2x
p8HE4KqnbHCL1zaSJ/0FAWtqK1+wYW+r35AH6Uf1J5F37cvYUKvez3k4TONP
q7iebtVssD5pqmRC+jf/7HYzQS0borZ6KBwi/R5VnaJx8DMb3AOPON/6RePV
W3W/nPzOBkMLXaGQzEvBnpXmN/vZ4Jma8U6LzNfFvHAt3d9sUFwlZTeNzN+e
wYqJ/D9smHNbZY4CmU/N4E1FJSwJqDm17nULmd9L0d66rVwJeM0J+KH5g+Tb
3TWnki8BB+QE9qWdpP7IfdbDaRJw6HBvkWMH2dfindMjdCTg7LjGIT+yP95v
2KRsaCoBN5Q17xo0kv6/VauoaiYBps4x/RFfaZwyaj1VYp0EVCYwFzaQ/bQ/
y0L2q40E3JpSmbuL7C95qZXMUHcJMLgzkvCvisaBu56N7/GWgA0S1h/kK2n8
/dGysU2+EnBc4clkXgU5b49Fw9pHJMCYqRw5+RXZh6U6oppzElChzM08/4zG
F4KVGqYXkHhj1so0ZZL++BT9RaZQAh7dP3LdKYPMj578p8FnElB4oMn08y0a
6zVJ17wplwC+Mu9GDtnv1cvGXx1okIBFctJyojgaT/7Vk48ZHFCw9ppfdpzG
ARu88rI4HChiqn14dJTGzWkdOXGTOCApkX4+NZD0m933jN1cDmSOPdiwzY/G
Vvc+Jk/R4cAp5dapzu40Pr/3RYSzDQeWhliFlprTODFlzuPfmzgQXKHT5LGG
zGPdxY7z2zjAz3gQOgHkfmrsvLLIlQNBlob3NIzJ/XAS49fUAA7M/Jx7/988
GnvlmDmXJnJg0tmlitbypN+Er5bMbucAd9rDWoN3YrxRU9/92Q8OtP+1Xfut
QoydNl+OtuvjgFvMVK3wV2J8pNizL/gXB3p81kwreibGeVGSN79ISoKv7cSC
N1lirKZvMTliniQYaHdWHDslxkO+Ve2CAEkQrlPsRovFOPrhvgUdRyVBzte5
6vx8MZ77Vza0KUQSSv3mDr7XEeNdEVYa1RGSYLymTclEQ4zL09455CZLwrne
nxXZHDGOr6+pPvBKEm4Et4X1kuerhWafHv9SkgIJn9tl/T4iXH02gCOipKDT
YEaojpcIe73nbu7SkAJUpfbUwVmEr+3Y8vOzthQEzQ7IS7YTYWbgl3mFJlKg
5RFZW7JEhGuzv9446i4FDroKLw+NCfEB7rdz4wVSEJ3fKhMXLsRjKXr3Wgql
IDTNa1LH/4Q4Qvf4x5JiKegDD2pegBDfWKmmHv5aCs6NeXre8hDiOu/tuVKN
UuCUvYOxZK0QGz3/XDOVKQ1+bHmd7xJCPO75nqtlIw0KmUdnbAvpw1GFOMW8
Txpe5sv2+jkK8ItpowOfaGm4fDy46n92Atx/erG52y9p+DHSvj7UQoC3bM6i
j/+TBjG1RivQSICn/YyFgikyYG768bSyogDfm+vVrr5YBuiHn0dnVfTiuuuT
5wwcl4H/uWgfSzDoxdSp7bnJ8pPg2lCCt7mwGxcMDsscs5SF66UTBvptnfhZ
lLWru/9kyNl5f1nogzbsPTNgVlisHNw9NrG3Mq0Za+1IXaJbLQ9ayxk1D2s/
YevnJ82a+6eASqv/sPeuSrzK9eE72StT4ckjH8ng0gJs6BZt+GqhAsjn/ZzV
2JSLPg+/iWa9UgCoqhA9mfoGsVqY1GlXRfBzMIHMyo/oh+OV5Au/FGFBOstN
2rAJqW9Rrs8/pQQOeou5Y+w21HDj8jJqBheSt5Q2D/t1IuuT/lc4D7iwo6/f
frJdN+KORuwMecSF3oFt58uculHzwRtaw4VcSKP7FAO8u5GPR829nmIujMQZ
sl6e6EZR5voVVa+50FzXz56U142q5XpHYhq58GlzZP4WmR604ZqL4zSWMgyw
qoaKn/ag9Q9sNJbaKcO1LxunqEsLkMc1p7+nNynDm+7bCZ4KAhRyck/Dpy3K
MLnyQlKmqgA9tAm/fNBRGby3fuCq6QuQpvCxXJ67MiTNrj51306AhmZNG58V
qAzzLnJ3pl0VoLQE4XfFJGUIfPl0+6lZfeh58J9i1+vKsNerdekfvT701UMy
KT9VGborXlvtXtKH5BZpOmxMV4axb/sUDdb1oaCaTTWRucrwWS6mzmd3H7KR
foYZJcqgL5nnkJrZh8aORt4QdyrDR8NYx7rZQjSVvb93QbcyLI4s5q7RF6JZ
UfYLD/cqw7o/8bL3FguRVYraq78iZTC7tjDTb7UQJZfmdksPK0O7Ze6+NBch
WiFbN19LRgViQ3ddfnFViEKSVZ876KuA4OrHK+8kRSh29gQnyUAFpBJc4t3l
RCgjr2Pj9wUqwAisvTKgJELvS+62ehipQHScfO5fTRGa3rVS4iBSgWNSjl1P
jEWoRN99Q5SdCmTquizp8hEhJs5pKDmsAqz8QJGwSoSc7PQWLQlSgWUV8frq
dSL0uONuVNYxFdge9Im5+qsI7ZXOQ7EnVGCucoXzkU4RqrPLv+0eqQK76/1f
HhsTofTOh/6S11WgevrCW4K5YmQ+6YWM1SsV+FTkf9X9pBilJa90L3mtAm1y
QfPDzojR2HxcvPgtiWdx3qzE82KUv6nkgMZ7FbjwSDQ/+7IYUddLP4vrVWBk
qXqcV5YYCQze3IzpUwHfc7aeqEaMLmypXV6vyIO0liuTvLk0Mt66LmeGMg/C
s5KS51E06tlarO7D44Fo+umIbjUardqWOcFQ58Ef5117LbRoNOQYWj53Ng9+
lvaY5i2g0S4XQ7uQpTzAEmHbZaxpJOuaUVqxnAfThK+n29vSqMhVfbGSKQ8i
o2YsjNtEI0V3aV4m8GD93B9Lx7fT6LVna/OH9TxI3f30/hEvGs3fF+0924kH
V1YZPRoOplHTPsnGA7t4MDVG3PoqlEYRPsc3PHXhwYq7H6zOhdOo3dd7vo0n
D95ou7T/i6BRgh/8CtrPg97pjIGzcTSaONx/ojqUB5uCU7nad2h0N9Drp0o4
DwYjPX4fyaKR45FmN9fTPAj1sZv8ModGD4Mq1g5F8mBM4NFokk8j7//dkNWM
44HFXf2ej0U0qg21vXLoNg8Gar23XqigUdk5Nz59hweU8IV2RCWNHscHJO3N
JtcP4lcerabR9czEVNd7PNC4kHrCrJZGe2tb79g84cFI+bcUt3oa7Wwc0K16
xoMwiUW9Sg00su2UuLvuBQ9KOdsZxY00MhrRyV9RxgO/nwZx/d9oxNb0L5r3
jgcOhZYr+zpIPXTDje/U8KD22eZ2+y4aCRZdLp5Zx4Pxnts293+QeM2flPDr
eeAWfP6UfS+J165q1eUGHrj47NxwWUDi3fHt1dRmHjTG/Wx430ej5APMt1Jt
POj5MWI1R0yjS0eVNoR38OBezwvDNTSNwsJnvxvv4sHZGmHjtn4a7bmy/sNv
AQ9sLFaf9Bog8eKYho5fPJgnXy6nNEQj3be3djgP8yDuyU31bmL1j4++Nf7h
wY+Y+/T9YRqxuhvaPozzgEOFt837Q6Pf/X3u1kwKjifWTzQS94z+66pgU2Df
d6otdJRGNfIzBViagi5JfXH+XxqVUot9TGQp6ButoUzGSD4z14kfy1EwwlOX
LCbO0tvmt3AqBW+nCx8t+kfyM9o7kKtIge8JDZ004ktwPEBXmQJbm2gnqXGS
n+XFoXQeBWabtDe5Ex/efCNIU5XEM/pG9jGx966C0SR1Ch46O56ZIN7h/eo4
bzoFvPVvS9EEjTYe/DIeO4PEq8N6GUi86nhPqPwsCm6o/g5NJ15yZpR1bg4F
L3viWW+JdaInn+boUjBJqn5tJ7H6tWlSJ+dR4HL5geUQ8ZR0w8gxfQpWOM9W
IP9vECtvlWyQIQUPmnSvjhP/Ltx8YXAhBT76L9t/Efe89JpyYAkFd2aKRW3E
TVVBMYKlFBgvefy0nPj953NKXsYUxJ6bsf4G8cuW5MttphTkDhpf9Sd+2JvH
24lIPqIpOcuJMwdLrn41o6A3JT9khOSb9K9ObfMaCsqbDbh5xBFZxdKv1lFw
9JaWlBNxwJaM34vWU/BmeqICk9iFGd1+awMFprczFl0n522Ve7RGaSMFDqx9
vobEy7a7F4fbUnAqlI2fknrN5lhnDdpTINcZrWNKPO6kGf7RgYLrdfw1s0i9
BdKT/FY7UrDJyn3oHOmH+oeDTg+cSPwRK172kH7Jn/zGKM6VgoM+O25GjpB6
F+VrsT0o+F3PKKwm/RbpcW3qIS8K5l8c7ZIkdiv2Fdjvo+BExttol9+kft4O
9aW+FLje4MqF/qKRCdfs1UI/Cg5zU28lDNKI68NNUTxMQXxTkGbWTxoxqPFz
YUcoUE60k7pN5kFU1n1k4CgFl24el0kk8/Ja7ZldXQgF4pxhF3cRjQrepK9c
dZK839X52ERIo9RDF+cVhFMQ+G2XriyZv6AqV05sBAX+DzZ6Xuqh0dz/ST+x
i6Xg+2LGan0y7yraA7dfxlNQtH7W2RdtZB98bIpdcIWCA69KBOtaadQ8956P
QjIF7KdSiivIvrjYuEXzw20K2jIbhC++0OjYGSRnlklB0s1ny2Q+02j3Qt3R
/GwK1tSn3rH8SCPyIPkx+h4Fte/c+gtqaPRz+a2ztk8oyGqUMuWTffe9Kyqg
5BkFS72m56m/plFlTKCr4QsKDIZczHmvaJTWu95kahkF7Y3pP39iGm2+2i+u
qabgRXLUkhWF5H4wsmKrTSsFQQmfOXrpNBpW1NhxuZ28b7dv+vubZH/ojzk3
dVJQHTF20TuVRo9cn+7Z3UtBTa/nwTPXyPlVGgWfGKCgrk12h1c0jXKTDdLv
SfDhgMNhVHiMRsLH8lm/JfmAkkJZLUdopPdBlGsiw4fMnfmzJwJolM25W/hG
jg/r3Cwu6Rwg/b1fp6pFhQ/bf2xka7qT+GHGwBRdPjSe8uKmradRmyNjeMs8
PgRmbFlgu45Gmodb/ibp82HP3H1Ph1aR+mVd5+gs5IP7YkuuvinpN0VVPpjw
YbU0Z3zlfBpd6STPltZ8OLHoi/fIVBpFRUhcrPXnw2uu4vCbWjFSvHvilnkA
H2YWNXN0q8XoSs1o0YtAPuxwLdl48g25/6v87Lj7P3K9eVrxvBdiVJT+bXnk
aT4wDZSVmrLFqKPkcZfZVT4oLa3m4TAxMv7jveJBCR9krL4e4OiJUYl6p/3c
Mj7c/5MTbjtHjNaCs/fNcj6cGfjCiNMUI9uzW+IuVfKhIQOvGOeKkafyqt59
n8h5TUH9vv9EKHqB2uVZPXzYnTD5wYNqEere8054eYoq3FHsleryIM9Hf1eo
diioQvy/CWHcLhFKvJBnbshVBYXzm86abBMhi/uX0iopVbh7Y6ItYIMIZY/Y
bZuYoQrZB0d3RC8QIZ+zX8q8F6uCTXZj9b4xIepPb7lmsl0VTnHdNpVECdGf
lp8WbWmq8CD4t9XqxD5UqWTcNvO2KqzZcbVmS3QfSjYPO+pxRxVsGw+9cI3o
Q3BPMbs7RxUYBZ49nkF96EzIIlnxQ1VI0ytLm76tDylqHH43+loVrksVujmq
9KF5jiN23D5VWBzj2jd6QYB2fhp3NF+kBjnaZgynvb1ovap8/M8aNSjSyhss
Sf2BhL+CKme4qYPRsMw2lawOpDLjh3YCQwPSjlicdVVvRdlhk/lZxEzrnVr9
aq1oRefCScXEmovcX4QQe9w5IWwjNrRZ9TNJtRUV6PPv6zM14PSVjZZfqFZk
bWxlXE6sI7791lK5FZ3aVGD1i6UBz1vC/y2Ub0XUo68rpNgaQJu8PfJSrhXl
qEzMVyV2u8L4aUNc17BBAYjL96xt9ZncijRduj6fJw6x1inImNSKin0oZy0J
Dci8sl1LVaoV2b5faWv0n71KozIlW1GHgafZemKLuxq/jYgnDd7XOkA870lO
6SZOK9p2dEPPU+I92XPsLrBbkbDRv+Edsf6EVoEa8QnTxMpWYiTJVcxmtaKM
ic67khwN0Fpf/f41sxUtd5VN4RML4uLnbSGuLl1wSY+4Oc/mbAejFbnM2haK
iPfc/NfmTzx4OsTfnljlUIoJg/j/UvGUVg==
           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4lF8bB3Bbq7LMjCxFCYVS2iO6j/qFosieJbSoRKKUCiHKGmWtVGgv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           "]]}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       PlotLabel->FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"Fig4\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\".\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"6\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"phase\\\",\\nFontSize->9]\\)\\\
!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"0\\\",\
\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\"l\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"4\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"\[Pi]\\\",\\nFontSize->9]\\)\\!\
\\(\\*\\nStyleBox[\\\"/\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[SqrtBox[\\\
\"3\\\"],\\nFontSize->9]\\)\"", TraditionalForm],
       PlotRange->
        NCache[{{0, (4 3^Rational[-1, 2]) Pi}, {-0.9999998830731719, 
          0.9999999999999918}}, {{0, 7.255197456936872}, {-0.9999998830731719,
           0.9999999999999918}}],
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {576., -358.76873046931394`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk81M//AHBSIdfuIkWx70/SQRdRCjPRhVwlRLcUpUukRBGiUm6JkkrJ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           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Xc81P8fAHDZd3ZKcufuFKLQpCHer1AZUVahpSVRNBHSoEWiYUXLSGVl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           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8ld8fAPB7r5GWPe5AVEhFJdF0PhmlaAiVhpWMUlaloUEISZIkX1Ea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           "]]}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       PlotLabel->FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"Fig5\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\".\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"8\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"phases\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"0\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\\
*\\nStyleBox[\\\"l\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"\[Pi]\\\",\\nFontSize->9]\\)\\!\
\\(\\*\\nStyleBox[SqrtBox[\\\"2\\\"],\\nFontSize->9]\\)\"", TraditionalForm],
       PlotRange->
        NCache[{{0, (2 2^Rational[1, 2]) Pi}, {-0.9999998830731719, 
          0.9999999999999918}}, {{0, 8.885765876316732}, {-0.9999998830731719,
           0.9999999999999918}}],
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {192., -597.9478841155233}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499622}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl2Xk81Nv/B3DUzZY224wtZBmSFluFzjsVSYkWylYpS1KhpCstKtEmS1S6
WSqkSPYkHaSyJbKTQsgyM8cuJL/j+5t/5vF8fGbmfM45r3M+834cBceTu5z4
eHh4Mnh5eGbf52Chyp86oRuyZ2ZfBCn3vtOXCz+J5uoKSf+hnny18khT2EWU
k3PcfYA6bQzVLX4ZiB7ZrRj5Rt0l5vo7O+wOet2+I72Q+hazRORlXjjS6q1L
iKZOYNnF8Ly8h9wmP1efoi7QG1i1O/YhavMHrY3UzcZXi+LDYtDG6nXl82bb
U5+v7lcUhw4sLXlQ/JegwDX1XvF5T9DyoKloX2qx9bF5lZnxKGt+dzOLOm6j
29zfKYlIJfzhji/TBGmaau9QSExCb7pXjx+nzrP4G7Et9gXCOQUNc6nrDoSp
PgpLRSfmr9og/Yf2R0tz7c8Pr1DxUdPiqCmCfPTCv/kUpaG68Qr/JdRzkb1y
XF4G6lr54EnfBEFlRkWlOq8z0USzmoAZdaix6omyzCzU9jrz6ZPfBMmZD2YP
p+SgzZ321wzHCeq0tLINev4aqe6vKb8wRtCLvXkzMom56O7OQdPXowSttQ/Y
ahybh3h/9g6IjhC0y53ZfD8Mo+w7t8nxAYLmr0U40qQAPc2bmPEgBA3kei5u
/1CALNo/bHPnEpSdX5/lXVSIdErOh5ixCdr0IfZvdN57tDKl5mfyL4JUTGos
etcVI7ElUZWe3QQJlf7zROt1MYocHRjV7CKoqsLNpCTzA7p1+NZUaAdB9rXa
IYMpn5BNZVD/5DeCwMqlQ1+jBHW31b73byFIqfGB9rXnJci33aaFp5mgvpa/
jVKJpcht4+3SX/V0/H6WKGyOLUc3NTam7Kui4zNklxEZ9gVtuFbE+VhI0G3x
KIMCkSpkc27CLRET9DUtYKnOriq0zcqz5kI+QbZ9dl1yLVVobWi065Jcgk7Y
CnsOsauRxZZvWRWpBN01dA16sKgWfU+uOhX8kKCmpt3HFuytRYXvmkZa79Px
P4PMrzyoRZq1+u5KkQQlvpQQO65Yh0JfLt8YGULQm6UfYkC7HnXvWBklEkDQ
D17FnF/WjWip7K9iM3fav2iRKLv/GtF/r14sED5KkOv6Cb/qtkZkLu1jV+hE
0JBXlVHe0SZ0j7+HX/QAzUfnhcrgc83I6i8rd5slQeofW7p0Yr6hEDsTp/na
BOl/2CZkdKoNybZqHWsb4qJFtQlf9MLbUJ7d+wcVXC7q7OCLWJHRhkzehixO
6+OiYJ68pczhNhRNZtocO7ioQ3+5zoBXO/IOt5Zxq+aioHThg9FeHehKrNcI
/0suqo+pyJr07ES2r9hC1w9x0YuXrHMDoZ3I4Nzhy5fsuOhS/lXoTutE3Ipw
Fw9rLlJrMSivHuxERz+uvLRuBxf5SaS0PfPsQmOjygs813LRstu3ha09u5Hz
1LvCMyJc5OFrfijDowdJBUYv7E7joG0nDJ4JhPSgCO6xduFkDlrmqE7sU3uQ
w/IbkeoJHFRvOu+8ALcH7RBxeLUrioMMme/u2x/rRXxyW8p2XOYgodcrqvid
+9BkV2rLgAUHxY/OR3a2bLTuzuOhkR42Ov7aKZhv2QCS69hgYz6XTdezpTyv
9gC6FfFmj9iffjTQZJA+s3kA3auNd/s63I9OT4nW/3EeQPbz5IZ0f/Yj3w1F
suPPBxAssE6LK+xH14rlUvrXDCK33wbzeM73o9iqhvJaoyHkbJWqOsjpQ7U9
poKJjiOoo2yhhU5uL7qxcowne/9vlD5n2x0/jV/Ic3lJREH8H3RgKlukiK8T
TR4+9rL1BA9op29SnLzdhhzzrSxCnPnAJ7z734VKzejwYG1BQdBcWNd72dVG
6Su6tSrnZMK1ebB3XHdw0ftixFeQo3fVVwCi7046OXGeosXqZpU/7gtBua12
VI9TDt4aY/RkIGw+CHWceHnashxLkgrjizkLoGt9THdqRx2O+vSGd87RRVBU
2VeL77ZiA9mNM/JHFoOD9c+hUyodeHnbos7zp5eAt8Gt44J+XTjl2RLXLC9R
qO58e+bwxh58tQ5vnOMjCuLJvmVR23uwHd9xactzovDDOlq83LoHC9l9qmRf
EQUxQeUAiRM92Hmhn45ShCiEDfGe3BfVg+XPdPGF54jC5YmtTwIGe/DdTa8f
efwRhRm5kPiTUb3Y77t9zfJrYsD9pFTUVNeHR0wMHzndEINeec1Vwj/6sHua
jEtMsBjMP/1DTqenD9tebZlcck8Mvg/ynvaa7MPr1fcrTiaKwQZ5rewwuX48
4b3Hs6RUDMxXRLq6OPXjMyJmC51ExOFt0W4XC04/5p5Rb4peLA7WmspLb4/2
Y+c2wSeN4uLw90qvYNF0P7bKKNHdLicOew8onRRbwMY6+40dtFaKg6rcl7W2
mmw88nRjCq+lOKRL36g5cZyNPQ3WmkXfFQfeiRZudBcb85y4e/HOfXH4GjJ2
6xCbjYNjBjIu/ScOPZ2iyrLDbPycL0nm8FNxuGRZaXCRh4M7Sphc1UxxCGno
/saV4uA9e6dC0mrEQfqdm6+vOQfrnnhXX7xEAvR9LWzXvuLg4hgp4WwJCQi6
r7BKMpuDd1WfQYlSEvDeafIzN4+DT2ivfHZdUQJsGIwDQZ84OHEy5l/zNRKQ
dTI39ch3DmYE+ss0WkpARcc/9QVCXDwZs9mxP0QC7n6XJNP2XLxh3DBsdYQE
vHiYVGt/mIv9zfWKfB5IgId1vEiWKxcLTKspzn0sAYZaxadMT3GxuM3CDpkM
CUhecatbMIiLV4k1HzKvk4De9mrZnlQuPnWsJvRukwTojfoHvc3k4uyiisLm
Vgno+XtoZVAuFxt6YgWXbgkwKliv8c97Lt5W+bT94rgELPp8/21EHRc7BZ08
lMaUhLgPoUsWTXDxsx+uoeOyknDjum+c9TQXs3UdCw0VJeHXsybrSF6Cvbr2
KJSpS0JOtpLuhCDBl4zWt3foSwK3OObeHimCo/7MPSTmIAk9KvPYB9cRXOUR
ddDnsSRYFlSYl3gQrB6yaOp0giT4aiSp558i+ErqtQiv55Jw+tPMmudnCNbl
epUdT5eE2hGtj+5+BD86ZqZ9pEgSbA2qOsIDCXZz/sNv2SEJk59nbI/+R3Bx
gNdj8276+ZNOyW3RBMvG9xhs75OE6q3X5SziaPs/az1NhiQhSyTOSTKBYL1D
KS2GfAwYjbh7wiSV4Ll2DqnqigzA2xlcjQKCHc7VmrJUGCCoMyyuUkRwTtS2
TmV1BsgGfbCSLKbtN+kyFdYwIPTsYYWOTwRXWy28ImnEAJNhn8+ML7R/ZwJk
xY0Z8ODHcOrXKoKvRkzlLNnGAIfTBYlXvxK8tvYXW2QXA6xiHtVV1REcbVlg
NdeRAcN3xJYKfSP4t4fuIK8zA1xvZsZebSV4V0jyzZmjDEi+6Kc9/p3gf77c
L5j0pL9/Sjy0uJ1g9+2e6oP+DEgdqxbj+UXwx2O/irkBDFhhLSSn30Pw0pv2
B9jXGVCzpUD3RC/BX0tN7/4KZcBOOe+It/0ErzNR/NsaxwCDh8t4JgnB2k/K
gj7FM6B7OjF2YIBgzRkv0bQkBvDnxzz6MUiwYs571tU0BjwPmJecMEywjKh7
xvEsBszPE8i/MEKwxEmxDda5DCh8+lRt5yjBwqpOu9ULGbCWv1OsaYzgeVdE
vot+YEDXNrXwsHGCeX5kuU6XMOBLo5n75t8Ej0TOu1BVxYArAZc0QycI5g69
FHhTy4AXCzdJakwS3GNuHf6kkQHf3myywdSt8549O9PGAObR09zKKYIbHS20
DnYyQOnfw8jsD+3vu9/5pj0MMC1e0IepK6TitmqxGVB62IarMU3H64xpjcwA
A4y2aGwPoy74Omg/b4QBaerucwao32hG9ZBxBpx/PkfM+C/BmTeMTjVNMeD0
yu/n71KndvdNF80woOF3D7RQPzcKD0qewwQHKVF7qRmCn0bri0byM0HXb8dX
S+royZ+PLgozYUHLjVh/6vtWt1hHFzJhcQn+lEQdlq6dsUuUCeRZh0kZ9a0F
rYYGkkz4ltMv/5P6mltAibI0E8Ln1O0aofb/uGL3wqVM2H8yqnWa2k+xvvW3
IhMm0tcV0voBn7lwwbVDhQkVNunTE9QezSrD5epMSP/0Tzib2k33y/ksTSZI
rNTzb6A+EuYjELOGCf1RZiVvqB24S8ODdJmQ0mvqGkm9b1uJrNd6JthXrj/k
Rr07weOZ7QYmXKpiZehSm/MxtbYYMUFuu7zDFB2PrQ6F+ZrGTMjzXOn4mtro
zdGtjG1M2GfsjI9TG0gsqeE1Z8LxJ/Xe0tS6Xm/s+y2Z0Kl7N6CQjv+qSsee
2r1MkLySyT1ArXwtYzrRngnS3n6fA+h8ynfYBoUeYkLkln2bRKilNswVPefE
BFGlmSW3aR4WjO1hmR9nwtxL6gXeNC8Cu6bT9TyZEFc2+Og7zRffy3hDBW96
//mC9Yh63Gls14gfEx7v+bC3n+ZzqDC6tfUSE4Jd3jzSoWbLmrh+usqE3zOP
4SzNc1vdvfNRt5iwOe+f+900/6Vb1j2D/5hQG3w2zIWul7OfLmhejGXCe2Xh
ogN0PbFMizPznzIhW27riDldb9e27yxcn8KEH21jh5ZwCN6826lZ+x0Tdo1q
HFtB1+9I7fODp4qY8EB7Xm5rN8FPrAa60z7SPLF15wd00fu3OTes+YUJh/Yp
F7/uoPk9GDpfrY0J7OeeAZl0P/HoqA9z6WRChP8qQdkWuh8ckWEm9DCB8zQi
wq+J4AsuicrLBpnQoKVeJl9P5+NE/gZZPikQduakTlfS/e9cr8diJSkwM0pq
F8QEO09rju9kScFQspHGz7d0vV88fT5YQwrsdswNynhD8OnLM9eFdej14rPe
67IJXnNd/Mk/xlIQ4TCzrjmZ4JeRG+smXKRAMP4aj8d9mi9GoO1adym40Dye
/CaCYJGoivYzHlKwqSTS+08Y3d8eWXOHz0qB988zDk636f769Dg/97oULHw3
9bTCn+D4tAfrOl5IgfEqVTzoSvM8ZavemCoFYaVrHnc70fxskZOuzJCCnhML
amocCX7b+PhPbp4UXFqhr3DPjuCamRc4tFwK7PUmrhbuJJjX/N2Wjf1SsD//
uUyCNsH2fR2WserSEBgfejXzNxcrascbRWpKw4vuzLzMES7uOe+idWuNNHwT
dLFLGeDi04vZYmfXS4M7//HvgT1cfHPtaMPObdLw4JA0b0cDF+de43eYOSoN
59KGE5dn0ef7Mg03hyRp2BywSkzGjYtDwm5aJaVIg0tOul7hES4W4us3GkmT
hh2jI1H2B7iYpz1J+sYbaaicHFDx20Ofz9Gqn7PKpSGnreGSxQYuLpZatkqE
Kw1BJ5fFWy+i97NEaixvjQyYyIyd7U/hYOL/b8c8PRkYPhD98VwiB7sNNlZa
6suA+oWAG3PiOPhg1b3EX5tkQEb3mt9EOAdvDxbfL7pXBhZ7i224+C8HLxNa
/NbNRwZS2Ze7ho04+CuvwGXmWxmQtHPMvvOFjbkpDxwsCmTAT/ljkk4JGwva
LNcPLJYB5eVesTUFbAzp5iMjFTJgJNsQM57Gxi8dI5yrWmXgcnO+fFs4G998
r2gWOCMDF9Kv8upYsfHmAEOxUSNZUDZiOU/X9uMsgVMJVaWyUCJsMf96Xh/u
9vPnvPssC6n3s13a0/swY/COdkq1LAQY8ltqPe/Dfk3JRdebZMFZq6zu/f0+
vPl593ejXllQ8u3quOfdh7+a2UhmCciBle5Ej4hmHx4I3hj0wEQO/OIs24H+
f9YQX+Tm+EEOFi//YrPxYA8mwWNiWvVLQe/5v6sWuXbhZYGBK0+6yQPPnSVz
rmzrwB02Lc1Gv+ThyM0zpqXsVry1q2Yi64QCJBZFNWCtenzWy8lVgqMAnz4/
qXxn+hmbZz/cJnFGES5NvK0P+fIac/+4+c0ZU4Sy1alOwtf+Q3EN/pknTi0D
7pK9PvnL36NJV8OD/04tg0sbdG0EO6qR7HSoraevEtzKz5L03deEuk1ulgnM
VYbCmdDAtAtt6L1KBZK7qQyPd7pW247+RG4CCXMVBFVA8tXjjpy2bpQTq2T4
PlQF5N/bOycl9CKlmc3nCsNVgBhBiuarXhRi75SLI1TgzkHb8BRaj7lKJei8
faAC7M+VWvcrepHUXVXNrDgVEP4sdFV+qBf5BaovTUxTgWB7CZsp/T5kdGIV
781qFcj9RYZKy/pQpb7Bh12LVYHH4EmvRW0/uvHae8pYlLq2aHLut35kopO6
Wl9cFYzzBZ3Taf1YoKkYvYypCnzKeZsmhvpRhoKAz4i8KuzOLe7RXcxG9/lr
WZGrVIFj42XisZ2NDtccu9W0UxWEhnylv+SzkbxFfNFnS1VQDGme86KYjb5V
fP9duFsV5r1pXXCpnI2sPlo6PbdWhcrubdfEm9hoa67ehnMHVCGG9/JnzjCt
d2PmDMicVIWLabX7drE46Lfbw90Hg1WBedg3ou0mB93xfcJ/MUQVGtrFMw+E
cZDKjRd5j8JUYUWo+dX6+xy0NylvWUukKlQ8tFrzIp6D0n+1DO+NUYWU8fNh
A+84yP2IzF2zV6pw5/u7xl7CQW32j2p1v6pCjq1V/A0zLvI5Hh+0t5a2t/pG
7B8LLlpwPsXgdL0qJPBVSzpbcZHhf/lP05rpdceA00sPcVFUc+tpjZ+qUJp0
5+3yM1y0x1pOXHFEFY46IpQUzUUlFjF7RSRYEByub67Zy0VuxV3v+BnUaU3n
jThcJLJWg8UnxYK2bnnZnYNctGtp7uSYLAs6d2cnWE5wUQvna0ybMguSFueU
TQkQxL0xry9DhwUF3SP+P1UICvm7ffdLPRZEr7Rdd0GdIC2v8LfP1rEgM8fD
crEmQWf3y995ZMiC7WoasfI6BPGx1msHbmHBi+s/Yn4aEST+4fgFm70sMPZb
fWLSjqDXazN/7bFmQfu31+VSBwmySZ602LmfBeENX/20DhMUHR64bLM9C5p4
cut3HCWI5RhXssKJBR6SIXtUvAkymKldwuvNgvTLTxudbhL03Uvab+oMC1Jw
KEM4mCD/7kNdo2dZcGl/XeyzEII+fubm9PmxYF3Q18CKCIJ2/idgX3uVBfL1
a6JzYghyXGeQmHiXBfxOK12k0gn6gSyDKyJZ8A09nvTMJMjO2Nl78D4LDr/m
ehZkE2S1O2ST/iMW3PL1EDTKI2jb8c4flfEsGM5eUdbwnqBPpyY+DieywC7O
0637A0GbfRe8ZDxnwSu9m739nwjaELjWz/El7S8i/i3lBK2Ju8UYy6bz8+Cb
8I4aglIT42akclng7SQbvqSOII2X2d0ojwWhnxtGKusJUslry7yOWVC+J3+L
RjNBUnXalrIlLGAmTCz8t42gey2ma43KWDBl/cR+tJ0gsQ6HpS4VLLhduuSy
60+CFpAgzqsqFsRMRe3Q6qbzJdh6fXMTC45d2t5p00/QxYVDHkdbWGD/TKT1
NpugP+L8+4JbWVCidj0ph0PQmOJqlcZ2FtRE2L4lhKBTasYi0z9ZIGC8kO/v
AEEDK21HFLpZsLhFV2rOEEF9BgFFx/pYcAheFwwOE+SyKSophM0CGXLFvGWE
oE7T1JAsLgtyUWJK3iidT6smh5khFmQEjX4/OE6QrT13i9IoCzi+ia+UfxPU
eHjOCtNxFvTy4V3t1F89VkyFTbFAqcqU33CSzq+PUUfONM2Pxn5mK3XFeevS
bzMs2Gc+b+rUFEGmV91f8fKpwaJm5WTePzQfN/zvqcxVA3fmHY1r1JtCIy+Y
zVODpglpP95pggruvXDyEFCDhvlJUaeoDaMLtkcIqcHfQPGgb9RvntZpvZmv
BsJbNm02+EuQ3os+qR8L1KC7UOJLGHVm2gzv3MVqkCzvw2qjXv1arJclqgZZ
quYWSjMEvXynVrVDXA0ebgwyPkC9/MOGHC9JNYDzYsKh1M/Kd0ffY6pB1e3O
R7mz5wdfXQPeSqtBaRn7byP148bz7u2yajC9UkmTUGtcm6wZpL745WnGrLO1
fPT55NTAwFBYb/Z8oTzYQ2gZtcmV63qD1CObDz87Qp392mzpMPWFoR8LvamX
l06Gz1og1s4ngDoq8c48Wp8g2am9xgnU2yrdumZtnLa18xe1UlH39THqKocP
Zr+p4zYWc2ZtM98oQ2CpGrQFB+4cpz7pon9ZjfpGGJ7/m/q+rKb8MepfhqPH
aT2DFMufB56jLlXnLZx18llVcpPasGto8SR1YY38u2TqT0WBKbPuuy5qx6Vu
XupTPkV9Wi/k/V/qorNpIrPnK3875y9fKK8GkjHVO2YtCvMmV1IP737/adbR
nMuHgNqr4y4vrbcQ6+FMiQX1jg3b183aYOz3PU9qQQf3x7P++MR7xp+6Q6Gu
ZtYWlkPOYdRCGcvm/KV2Su7XyaDWM/SynfXAftdH76l1db2uztqXv2tuLfXZ
P9YvZh3s+L1mhDp3oHZo1oxFtvr/KKhBhpy76Ox50eP8hsfi1L+YvatnrXFs
j5AKtWWHmfmscxjVnrrUgz53XWdt9HFHkzF1cXPRpVlXnCoDa+pSoYbIWVsp
mDxzof7LX/181m2V7xeepT789dXbWbv5gU8Q9ejRMxWzHlHL/36fOrNSoXnW
FxrWGSdRx/JkdM1aICA7JZc6e0aNzDpsjZZ4GfV4+bWxWcu0pfo1Uzs6lU7N
OuG2Rmff/64P/p31av0ks6n/ff//z8f+D0Ug+8Q=
           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13dczf8XB/AWEpr3Nkj73tuiCKF4HwkJaVuhoVBp0EAlGQ36piESbU2z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           "]]}}, {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VO8XB3Ah+zIzhlSyzR2yhDYl6jlFkkqlTSGyJVS0IFEqX2khW5Y2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           "]]}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       PlotLabel->FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"Fig6\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\".\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"12\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"phases\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"0\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\\
*\\nStyleBox[\\\"l\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"2\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\",\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\"=\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"4\\\
\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"\[Pi]\\\",\\nFontSize->9]\\)\"\
", TraditionalForm],
       PlotRange->
        NCache[{{0, 4 Pi}, {-0.9999998830731719, 0.9999999999999918}}, {{
          0, 12.566370614359172`}, {-0.9999998830731719, 
          0.9999999999999918}}],
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {576., -597.9478841155233}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499622}]}}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Figs.7 and 8 show how ",
 Cell[BoxData[
  SubscriptBox["\[ExponentialE]", "r"]]],
 " and the period vary with the number of phases, ",
 StyleBox["r.",
  FontSlant->"Italic"],
 " The significance of the non-integral values is not obvious."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "r"], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "2", ",", "12"}], "}"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"PlotLabel", "->", "\"\<\!\(\*
StyleBox[\"Fig\",
FontSize->9]\)\!\(\*
StyleBox[\".7\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[SubscriptBox[\"\[ExponentialE]\", \"r\"],
FontSize->9]\)\!\(\*
StyleBox[\"/\",
FontSize->9]\)\!\(\*
StyleBox[\"\[ExponentialE]\",
FontSize->9]\)\!\(\*
StyleBox[\"  \",
FontSize->9]\)\!\(\*
StyleBox[\"as\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"a\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"function\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"of\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\>\""}], "}"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"\[Pi]", "/", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", 
        RowBox[{"\[Pi]", "/", "r"}]}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "2.1", ",", "12"}], "}"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"4", "\[Pi]"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "->", "\"\<\!\(\*
StyleBox[\"Fig\",
FontSize->9]\)\!\(\*
StyleBox[\".8\",
FontSize->9]\)\!\(\*
StyleBox[\".\",
FontSize->9]\)\!\(\*
StyleBox[\"  \",
FontSize->9]\)\!\(\*
StyleBox[\"Period\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"as\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"a\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"function\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"of\",
FontSize->9]\)\!\(\*
StyleBox[\" \",
FontSize->9]\)\!\(\*
StyleBox[\"r\",
FontSize->9]\)\>\""}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"%%", ",", "%"}], "}"}], "}"}], "]"}]}], "Input",
 CellOpen->False],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k0VF8cAPAZxj5mHiklskaWKPJLwv0mWyEq2iwVSlQUIRWpUCqRJSQU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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotLabel->FormBox[
       "\"\\!\\(\\*\\nStyleBox[\\\"Fig\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\".7\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"\[ExponentialE]\\\
\", \\\"r\\\"],\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"/\\\",\\nFontSize->\
9]\\)\\!\\(\\*\\nStyleBox[\\\"\[ExponentialE]\\\",\\nFontSize->9]\\)\\!\\(\\*\
\\nStyleBox[\\\"  \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"as\\\",\\nFontSize->9]\\)\\!\\\
(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"a\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"function\\\",\\nFontSize->9]\\\
)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"of\
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\"", 
        TraditionalForm],
      PlotRange->{{0, 12}, {0, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {192., -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Hk4lF0fB3AxYyyzGZJ7xjJ2StkVwtfSRshWSUk9SBtSKlEpEim0EK2y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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotLabel->FormBox[
       "\"\\!\\(\\*\\nStyleBox[\\\"Fig\\\",\\nFontSize->9]\\)\\!\\(\\*\\\
nStyleBox[\\\".8\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\".\\\",\\\
nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"  \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"Period\\\",\\nFontSize->9]\\)\
\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"as\\\",\\nFontSize->9]\\)\\!\\\
(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"a\\\",\\nFontSize->9]\\)\\!\\(\
\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"function\\\",\\nFontSize->9]\\\
)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"of\
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->9]\\)\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSize->9]\\)\"", 
        TraditionalForm],
      PlotRange->
       NCache[{{0, 12}, {0, 4 Pi}}, {{0, 12}, {0, 12.566370614359172`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {576., -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The differential equations ",
 StyleBox[" ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "n"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["'= ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["(",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox["-",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"n", "+", "1"}]], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[")",
  FontWeight->"Plain"],
 StyleBox["; n={0,1,..r-1}",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" have solutions",
  FontWeight->"Plain"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "'"}], "[", "t", "]"}], "==", " ", 
      RowBox[{"a", " ", 
       RowBox[{"x", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "[", "t", "]"}], "==", 
      RowBox[{
       RowBox[{"-", "a"}], " ", 
       RowBox[{"y", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "==", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"a", " ", "t"}], "]"}]}], "]"}]}], ",", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", " ", "t"}], "]"}]}]}], "]"}]}]}], "}"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "'"}], "[", "t", "]"}], "==", 
      RowBox[{"a", " ", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], "-", 
          RowBox[{"z", "[", "t", "]"}]}], ")"}], "/", 
        SqrtBox["3"]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "[", "t", "]"}], "==", 
      RowBox[{"a", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"z", "[", "t", "]"}], "-", 
          RowBox[{"y", "[", "t", "]"}]}], ")"}], "/", 
        SqrtBox["3"]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"z", "'"}], "[", "t", "]"}], "==", 
      RowBox[{"a", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "-", 
          RowBox[{"x", "[", "t", "]"}]}], ")"}], "/", 
        SqrtBox["3"]}]}]}], ",", 
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], "==", 
      SqrtBox["3"]}], ",", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"z", "[", "0", "]"}], "==", 
      RowBox[{"-", 
       SqrtBox["3"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "t"}], "]"}]], "Input",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", 
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", " ", "t"}], "]"}]}]}], "]"}]}], ",", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", 
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"a", " ", "t"}], "]"}]}], "-", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", " ", "t"}], "]"}]}]}], "]"}]}], ",", 
    RowBox[{"z", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox["3"]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"a", " ", "t"}], "]"}]}], "-", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", " ", "t"}], "]"}]}]}], "]"}]}]}], "}"}], 
  "}"}]], "Output",
 PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["Series Summation", "Subsubsection"],

Cell[TextData[{
 "The series form for multiphase sinusoids is illustrated by the r=3 case, \
truncated at ",
 Cell[BoxData[
  SuperscriptBox["x", "21"]],
  CellChangeTimes->{3.425131134859375*^9}],
 ". Each phase is the summation of a general infinite series involving (in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ") the following definitions of \[DoubleStruckS] and ",
 StyleBox["rs.",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=."}], ";", 
  RowBox[{"s", ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"rs", ":=", 
   RowBox[{"Re", "[", "s", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "3"}], ";", 
  RowBox[{"phase", "=", "0"}], ";", " ", 
  RowBox[{
   SuperscriptBox["s", "phase"], 
   RowBox[{
    SubsuperscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "21"], 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
      RowBox[{"n", "!"}]}], "/", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"rs", " ", "x"}]]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"x", "/", "2"}]], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"2", "/", "3"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", "/", "2"}]], " ", "x"}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"1", "/", "3"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", "/", "2"}]], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", "/", "2"}]], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{
   FractionBox["1", "24"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"2", "/", "3"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", "/", "2"}]], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{
   FractionBox["1", "120"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"1", "/", "3"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", "/", "2"}]], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{
   FractionBox["1", "720"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", "/", "2"}]], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "7"]}], "5040"], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "8"]}], "40320"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "9"]}], "362880"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "10"]}], "3628800"], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "11"]}], "39916800"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "12"]}], "479001600"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "13"]}], "6227020800"], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "14"]}], "87178291200"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "15"]}], "1307674368000"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "16"]}], "20922789888000"], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "17"]}], "355687428096000"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "18"]}], "6402373705728000"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "19"]}], "121645100408832000"], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "20"]}], "2432902008176640000"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "/", "2"}]], " ", 
    SuperscriptBox["x", "21"]}], "51090942171709440000"]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The sum of the real part is plotted in Fig.9 for each value of ",
 StyleBox["phase",
  FontSlant->"Italic"],
 ". Obvious truncation errors occur before a cycle has been completed."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"phase", "=", "0"}], ";", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "21"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "7.65"}], "}"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"phase", "=", "2"}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "21"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "7.65"}], "}"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"phase", "=", "1"}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "21"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "7.65"}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{
     "{", "\"\<Fig.9. r=3. 7 terms summed for phases 0,l,2.\>\"", "}"}]}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", "%%", ",", "%%%", ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}]}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8ld8fAHAUZXPvtcq9GSlllyTJOWUmSvRFViKhiKyQ7IykpElWhbSo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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4lN8XAHBm7JISZjBDWrRLkmx1D0mrSpG0WipLWcNXEgpZiiylVERF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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VN8bB3Ak6wxjC2X0bd+klIos56ESWlR2qZCIRAmhhJAtspUlISWp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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
    RowBox[{"{", "\"Fig.9. r=3. 7 terms summed for phases 0,l,2.\"", "}"}], 
    TraditionalForm],
  PlotRange->{-1.1, 1.1},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]],

Cell["\<\
Figs. 10 & 11 show the breakdown when only a few terms are summed for r=4 & \
8, and for phases 0,1,2. The series has to be re-calculated for each case.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", "4"}], ";", 
  RowBox[{"phase", "=", "2"}], ";", 
  RowBox[{"s", " ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"rs", "=", 
   RowBox[{"Re", "[", "s", "]"}]}], ";", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "20"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"phase", "=", "1"}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "20"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"phase", "=", "0"}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "20"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "9"}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{
     "{", "\"\<Fig.10. r=4. 21 terms summed for phases 0,l,2.\>\"", "}"}]}]}],
    "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", "%%", ",", "%%%"}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdl3k8lN8Xx+1mLGnBzCBmUlKWJLJU7gklpaIkStGCkmSJpBKShEQkiZR2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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwll3k81N/3xy0pacHMULYZFJIIRZLcq5CSJW2SsiWSJFvIB6lElhAiKbIr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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdl3k8lN8Xx20xY22xzCBmUpKtElkq94SSUlESpWhBSbJEUglJQiKSRKRd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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
    RowBox[{"{", "\"Fig.10. r=4. 21 terms summed for phases 0,l,2.\"", "}"}], 
    TraditionalForm],
  PlotRange->{{0, 9}, {-0.9999995629014262, 1.0003017407743324`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", "8"}], ";", 
  RowBox[{"phase", "=", "2"}], ";", 
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "r"}], ")"}]}]}], ";", 
  RowBox[{"rs", "=", 
   RowBox[{"Re", "[", "s", "]"}]}], ";", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "12"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"phase", "=", "1"}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "12"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"phase", "=", "0"}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["s", "phase"], 
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "12"], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", " ", "x"}], ")"}], "^", "n"}], "/", 
         RowBox[{"n", "!"}]}], "/", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"rs", " ", "x"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "9"}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{
     "{", "\"\<Fig.11. r=8. 13 terms summed for phases 0,l,2.\>\"", "}"}]}]}],
    "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", "%%", ",", "%%%"}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8ld8fAHBFw4h7Lyr7PomSldAyzkdISqWSUFJWS1bSMlOSFZEkZFWU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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk8VN8bB3BZZ7HvzNyZsaSFFiqVlvOI0iZkqa8kpZJIlkSpJJI9JClK
pV2l1FelcpAtOxWKryUMM8PckKKi3/39Na/368yZc+55Ps+Zq7fn8NZ9khIS
EvdmSEj8//N7wMyhiTsxq4s2mC65dp2P9sYT7qyr+1HhRQ1Z24t8pPPMWFmY
dRT98slY9COWj75XmHk3ZUWjW/T6vKVBfNRjX6BRnpWO6A0XT4Ss5aM2jQlR
UdYdlPdHSTA02I8cJ7RbX2cVIJ3cR7vfGfejFO/7mwuzKtCbtN2t5Td6UWTU
xfL5ya2o/tvBLldGNwrh0g1pET1IIVz9PWptQxtZ8vtXEgPIvLL1xq4dTWgd
Tc/GeNEwUhhLDxf3lCDbcYF8iv8IWkJrvk7QkpD8rtpy76jv6JPJu7PCP0VY
V1sF9cX+RKaXR66U6TfijzWGT/fs+IXqBRe3H37eig1CSwKLvKfQ798TGp6n
uvD58+maSvoSQFuu4yvB68XP46Y+KMXMgMXObwt8DfnYQHLO8nB5KdjytTPD
kSbAP2zzpmerSkHSmCN/o6oAV19eUtasJQWHnB6IVrAF2N90jZ2RgRSs3SGr
zlwowG88duyrWy4F/s4G6Tu3CbATTkxheUnBgdP7LJpuCXD0iVHBixIpMCpt
nvvVQogHf7y+8u2oNPRbalvPcRThh049uuonpeGu3pO4+W4i7J8vm7k0Uhos
N7q8M94nwpOHHDJPnZeGMfkVEoohIszo52fK35OGLeVC94ArImzyQeXq7M/S
UKjY6fO0i5qf55XtsUIG7iW468vsHcKLFRK5UZYyEMie80rKdwhPHMzPvmsj
A9bpMqOTQUM4wmgqW+woAw1EBtRFDuHUq6nXT/jKwN/a2cpKOUP4efzbGxlX
ZUDmkM2xqa4h/NNL7VbjXxmY805xMthxGLvGvfJqlZGFC77ndaxdh/Gbh7uM
O5my8PDXYj599zA+M5KbL9KSBdUgqxMn/IaxYph1iexCWcj3tdo/FTOMDZOC
O1d6yELYoY3Jvm+G8dbnrdr3i2VhXX77ozG2GP/bcrIjr0IWTqxSeP9MX4y1
Jw2uF9TKgsXQpW0+s8W4c5X/rLI2WVD6D6qKF4mxdyXNvOubLDie16+R3ijG
p78sd9TQk4MI9uJJ8ogYP5bISoyIkAOtr+Xn1peJsWzJon945+TARmtTfU6V
GLtH1BjiBDnYXvzPiZ+1Yqwk+fv1n0tyYN/dzIj5JMb+Uq7CkMdyUN/7+YMt
X4xNZbVt/Nrl4F3kJVMfWRLHVeSpKvTIwbIjjODNDBJ/jbbpzOXLQW1Il5KR
IolT5UKCBSNy0KA1aFOqQeJRWkvOXhoNXj84cPeaIYmfM9MkdiyhwSaS6coH
EsvXGtdOWtBA+fXcO5utSbw34d2lDKBBWJH3ilwbEmsojM1v2USDoWe/Vjls
IfFRxa07HfbQoOXQswTYQeJlKsqFNudpoNGkdyM3iMTJTXfP8tNo4LCby0s/
SuLBFORw9goNGmP72kOPkfiy6uHB0ts0kHg6KjsrnMS/1Oo1V7+hwefYci2j
OBK/1kwIWiyggdOS5vOPr5FYWlA6uZmkgU2gZb39DRJveT0Zvm+cBh07czsF
OSTu3uWVkD6DDoQoKFDiPoll76+5PaFDh5bUJAecT2K7sGPGKjw6fF8ZwtT+
l8QZtk+ezjGiw4ys+yleL0hsPEoUuZrRYWB8rYToNYntV0y2vNlIh/wfvk6R
ZSS+orBw5yd7Oki7XXdPrSBxb9f+3mEXOqyx116YUUWdR9RHkuNJhzbfaKOY
WhJn1uXRIsLoUDle7jD5gcR92fykyxF0gBPB0UWfSDw/kNDIP0cHg/vKp463
krhYM16v9wIdtF8pP2/5QmL+rv0Wax/SwUJveh6vh8QLza4W78ynw5ODRb6Z
X0l8TPrjuqMv6bBVoeigQh9Vv/uWjnfL6CAR03bzE5/EzmGhn3E1HfIKZncY
D5L4mm3errZGOhgP6X8IFZDYdJTtS/+PDptar078EJH4eJnjqF4vHdrPehvN
HiZxWXpcqIWADoHzgpXtxSR2WTER5TNOh2JCQjvqG4lPRH24WqfAgAit/UMn
vpO4woVhyFdjwBqz62Oe4yRWmmP5YFqHAQ3aVc8tf5D4Zt3jggVGDPj7QOTZ
85PEouz+letNGMDcEuSQM0HixYHsdx5mDPiVKzGxY5LElZpxDSmrGfD2nz2H
n/4isbKg2PmBNQNqHNrQlt8kdn39s710IwPsnS9V9VDOSZy/p92eAVYSIXTf
PyQe2rVvcMyFAetuO0gOUzY3y/KT38mA3bbSz/ZOkThc+sN3Q08G+L70Y32g
XNVCD1vlzYA2t6AVy6ZJrHofZrgcZsC010/VNMoOOt7nZYMZ4HTksU8P5eTY
FOLFcQbk7O94ZPSXxPWTr3K9TjNg6lPAZ0/KCge/LteOZoDgwG5xBuXNXxhV
VfEMiPyUPVROOW7jIpdjKQw40mPwUUj5feGOvjmXGDC5MKhZSuIbphlHBX7J
YsAYEbBAkfK6zIcS8TcZIDRlRKhTPsv8lLTiHgMmxKsqNSmXhU2xhx4xQKtL
XlKDsuTQzNysZ5TTQk2VKFu6bVlu+4oB9+9GOstQPl17tHKqiAEVRz07xNT6
RSuznR+XMSB8RPFnNeWph5W97tUMsNTX+H2N8kriW4BSIwMywyIHD1I+nqgt
UfyJer5wbzyf8qspSPJvZ8C+krZwIXU+E4e82Xo9DDD+2jfnGmXzzpQHTXwG
qKflvN1AOXhL4bIzQwzgZ5isGKbOf3Q+07n3JwPOjsh+Z1E2zV7Ue2GKAYR2
6oK7VP38ldwCrKWYoLt0h/NcysPkw8TbikxQyjf10Kbqb+LxieWizoSwXbFr
I6m8HGycui+rywT9e880+FSeBp9sqfCayQTBDuOQC1TeZumFOGkbM6E6/QOt
k8rj/pTsr1ULmXBAXjqaR7k34Nv0nJVM8Pj+3iqRyrP+V+3EL5ZMgOfVUS+o
vHtstWTF2zChdMPc/M9jJO40S106tJUJF1eONcuMkpjIKSzP2s6ErXvbKpRG
SOym1uto684E+x9q91So/vk8tsj/sTcTjmRkLZqi+u3j80/3/E8z4fZw9dEg
qj/VZk6b60UzIV3N5L+VVP9uvWhU3hTPhNlPlyyapvq7ITikx+wSEwaPp+Yd
oPq/2lxHd/wREw7e1Rzr6CQxfukWf6ydCWeEJpNrmkkstjD8mNPDhKebrvjt
byQx562IXT9Arb/lXNDpehKfKjn+WP87E3wGFs/PqCbx6uqMphp5eViP60Jc
Skn8tv2jFme1PFzofjWk+ITqr51ZHuut5SH6P8HtzEckZnd73g/cKA85fosn
ObnU/dA3alHpIg+94/oB9DtUfoaV3f0Py8OxZTZvDmVS9/v05lul1+Xh7o/J
kCNRJBaeVh8euiMPrak1i3wiSKwr1bFE6xE1vm/mpe2nqLzJ+VT6vJIHv6wF
27VCSWyhHCtUb5aHbt1DnYY+VP70yhd6SSnArt6l7aftSPzCetVb5n4FsAvz
NrJWIXF0/NkNOr4KcCjoyYmZCiR2aq77ZBSoAAMNdaNTNBJ/2+UutjylAGjv
Aas0CRLPDQvnhqYrwHZWQYYLKcbXnpZE9FUoQL0GuXBRjRhHc9ateztLEfZW
H45xPiHGTvuSmqvnKcLpF9/3EiFibPCwxb1tkSJs/KuT2BEgxsXLvULGkCJ4
9ntXgJcY/3KKuTdnuyK4Tjyg3XAQY7/4akZ6jCIIknctLDUUY5eJLQ1+AkXw
S3EtSC0bxrr/xXiqk4qw7kpX2rOiYdxZUvrz1XdFuK3erlj3chjvizfnyUgo
QYeyebvg4TA+wuEEZGoqwfQe4d/qtGF8wXpYtcpKCY5N8ptNPIdxY3K8i941
JZBcrVd/7NcQvq3eJ/aeowy/2s7eylAbwhLJ9unHTJSh1sr8lQ1zCLsy366K
XaAMON8pWyw5RL2vpCfcW6IM+obtAoNRET5G2swdsFSGaquLRSaNImxbnbtv
r6syvCui5byKE+Hx8KAO93hlcN9xsbB5UojXiiSrHYeVQe2qpsHVYgG+suRA
8IJvyjDoszBV+oUAfwuv4zHHlGHsCids3yNqXD0jpHRCGSqOx5epXRFg8ap5
M02lVSDBNfmEfpAAZyRvO63IUgFtZVTEMBRg4ZKH5u/Xq8BKn8XV2hGDOPm0
c87qWyoAoYXXS2cP4Mf3i4dStqlC3mjpLFWrPjyqrBjH1lWDCaxYGVjRjXvM
z8+816AGD1YZz9x/5gsevzKq7pOmDqtuf/xmergZ/5fqdyTdWQOS0Sftc95l
+PAGTnMpXRNc3w2cZS7NwbNWP4k0qtOEsB/378QseIniRoIXxUdqgUrR4hcW
8TWoeJmT43Zzbdi6/bT6acVPiF2kXuk2oQ2mtgW6Zic6kIEkffmeRzpwIajP
jXWwB9lFdU1fC9CFwLlBb0VH+tDWR+R42BFdsFv8d9orvA+5tPwd2h6iC8bV
Fr7/xfYht9m8dtWTunDtmFzhs2t96GCtx4voGF34s4jzr0JVH4pS/3rYL1sX
bgYWvQ3S6UeFt/q6V9Xpwpb88pGhgn5kVC4o7ZjNgu+zzugUtfNRqH3hjlxj
Fnzc4nBxRR8f1bTHfT82nwXOH4rSnw7xkf+osZHWYha81rzNPjfFR6+5frEO
iAVFM4w/tnIGkP3xUbsKZxZcvSM1Ku8xgMIW/O7IO8MCdy8lvccdA6i+sCb4
1Flq/KnL8yV9A4i3LkvRNoYFl9bUe/wrGkAVbqtAmMgCi2uMiaxfA0g5LjzH
8DILFAI57+S1B9GdPqmDl/NYkOx4Q+jjMIgaL8v/PNPBgn1X5Z6pFA0i1mOT
Q0ldLFjP1ZEyKB9E+0s3917+yoKMsssJc2sH0ZQwoeHJIAuU6l6tYH8ZRHNX
Ktzr/M6CkOm4y7HjgyiqU+EfCwU20E2zmmLmCtAyA6XXI6vYkK5je3IqQYAi
ly4wnQI2PNjkYl2fKkD1m+zu0qzZII44X5GWIUD7jpy/wN3Ihj7JVcOStwQo
tVzJ19aFDTdPXdjuWShAQ17KxH0/NoCkr7NpvwBdf6gS7pHNBr2ZHQUDZkLE
Pz93culNNpQYKjLYS4XIJMgqSOk2G0aSnkvZrBCil8uDvYoesGEBcaPztJUQ
NVa02bEL2LBtk3ZPpKMQ/e3O5rXVsiHCTj6pLECIrMteXslrYEOYpplod7AQ
xd1tUj/XzIZ7xqHF46FCpOknRTdvo/bnM6NK4rQQzf+9f+RCLxuaa7N+5yQK
kbvG/FK7X2zY6bbuFPuuEN2aWLdy1hQbCrbnMXgPhEjYvqtg+i8bVgVu+arz
SIiO3kx58EiGgOhUowPf8oUoccF4KlOFgL6jThGzi4SoWVVRoVeNgO5lx3U7
i4VI+4fRuUJNAnCrcDD2HfX7b7aHebMJuJzerFtWJURvNrzxrJxFwKSC1rnS
ZiGSnPfpv2tzCfhypu/UnE9CtF5ZvO3oPAJupPilR7cK0ccW7uaZiwiY1lfQ
NegQoiHPyMWRqwmQbdec098nRGY2WY9dLQlg3Nn98Q9fiELn/jvbzJqA2uRl
cQyBEEmP8Nk9GwhQjFdk0oaFiHVqowxyJkDKc712/HchchXmuzluJyBg6ffj
oT+EKMOF9dxrB7WfXhk11wkh0lgwtCd5NwH5h6Fl8rcQOWU6Fd7aSwBvQ8+v
F1NClCr3VuWVFwGZZKvNwb9CpNSdWNxziACOdZ1trqQIbdn8Q+uHPwFrfJ0k
LKRFKOGl+2HGEQKaXdbUv5ERIXrKAs6i4wR8Mj6ed40mQlJrmsKiogl4oN03
74OCCK15vPxDRiwBRSxij6SSCJ3WvTn3UQIBO7etyZipLEJTo4GfP6US8Kvy
9ZSNqgit3NW+UHiRgC73aiMbNRE6XmMVM51BjY8uX2uhLkI/c9SXzsomIL67
0vmPhgiZK59MWnGTgKFdTy1rNEXoyIn+frvbBByek6qZpCVC+YO2q/beI8BF
xbnJWluERpwK0kJzCfgrO+BHUl5YwhlKeExAiMbSoUQdEfKbd87qxlMC7nma
r+PpitDDy+SVf58TMHtJ27E7lEUy20ffvyAgQ6gSxWOJ0NzA4g2dhQQYSrbv
TqJ8oHP2jdG3BMzQnqf8jfKdjSkTsiUEjPClEtayRai/YNKOVUbAo/U7m5Mo
GxrsubugkoBL5su7ayjvOV89bVVNQNv7y/l/KF//beayvY4AWBm5To8QoS6v
zEe+jQT4Df7OWE6Z81FKJuIDAakb5e+upewGvm4XWwjIlcCH/u8rDz8+u/+Z
2l8NT7iM8mftVcyiDgIsEkGHR1n77O09zV1Uvm0XTPyi1nMZUSjkfyUgylwi
6j3ltJ1HVX73U/VMr3oVT/nD+84DSgICdvRkp1tSVjW3KTYYIoCbl60lop7X
/mae1jKSWq+od3kM5SRF7cObR6l8jcb+0qZcd/x0hcc4AY7b8l2uUucpPzBI
BE8QMJ8TvkmD8kZHh+DY3wSsv67ecpqqR6WxvmH+DA4ESZnfMKPqJZsRF1Yh
zQHw0OgIpeprLT3W/EWOA/X+e2/kU/Uv6XgXIaXIAQVf5WIJKh8SG0w+a6lw
YILbrKZB5Wf1v2kLTdQ5UKlbx2dT+XqduK/LSZcD9K32f2VVRGi9W1KbK8GB
BtrGFDGV15a5L5o8eBw46RjKrFYUodFKWpmvEQf2Jyg8dpOn8pxu+jZwDgca
p9Y1qTFFSHGfa0GoCQc2M1ybi+hUPiQf3osy40DUuirPb7Ii9LLx4424JRw4
aCZLHqX6Z1321JXkZRzYbdZrOyIlQrtX2iVmreaAupXLiRIJEco4OhrwfCMH
WGcuOjdMCpHRWpZPoS0HXuWZLf3+U4ieq1nvLbbngHvGjjZ5qv8bnlx0qXXh
gE/hITudUSGSFS1b0beHA0Y1TTXXqPskeFe4tHoYB04t3ND5Twt1f82/N6Vz
igM/GjemvfogRMl/Gn9wIzigV2/RK98kpPKvLzA+x4HE69FrkmqEqO9DeZ3V
BQ6E1t0p/42FaOt6+UtBuRwYvJndHn5HiLo1lyQfe8yBjJa7TO0cIfLr3xkb
/pQDvuMqT3KyhSj2TF5Y/AsOpN0ytb2YIUTFb7Z65LzjwK2zrMyeWCFaYHp5
zod2DrzRd7vOPkj9v9QXGt3u5MCI/ezURfuFCHw7DEJ6OCCxzisM7REi+7tc
DmuAA9vFx+aZuwpRIHFH1XOUAxUeo93XNghRAf3Z71EaF7pEh1TdjIRo9d2P
E2VMLnDuVz0r0ROiSusf4+mKXChjWpqxCSFqC1/+zUKdC04n5hXnqQnRr3Hc
d4bLhTa50jF7CWr+19o6VXMu+J8/t/N4qwBVhIur+5Zx4c0fPY15zQJkRyhX
FazggsNhbsrHWgHy2O5Y6mrJhTyWbeOMUgE6U/+54OZmLrAkVNd8yqXmF/Kz
zTy5oLw28pH7SQHackEicGsyF/JnateMaAlQw6uAzbsvcMFmg2HjPWUBsu/+
auSfzoUP5YU+W+kCtHVeeXtiFhf0JX/uOvlrELlUxq59f48L4k0rlcw6BtGu
36o6UMKFl1ZdhhpXB5G/58zieaNcaNWwO/NCfRCNxKZfWTnOBUP1e85FzEEU
+EQueNMEF4Ie7Tj/QnIQHZkSzPGe5kJ48N6FEd8G0JtNrRu2yvDg5ZcQqYCa
AVTcn/ksUYUHZt3jVSWnBtB7nZnnpOfyoFI8y4BLvb9Fq7v+CDDmweMqQ0ej
Jj6yVjq/r8uEB2l1p6L1KvmoWHrSqnABD+QNa8bG8vnoJVkr4b+EB7ejchtp
cXx0t/zI8XbggbT3obaRJXx0NqDsUP42HpB1ozdeR/Ujy/eeTh5neeDFLm6X
m+5FRuOhaRXRPNjfkpm+aaQXyeslfTSJ4cFM1dicyL5e1Bb60mkyjgce4uGn
jdW9yG+2gnNqMg8e/HvhYmd6L7pyrsC5LJMHBw5wDd6b9KLRtfRts/N58PDF
vhmtdl9RTunjf751UvNF+52qAruR9DMfWnA3D0a0LnPe7+5G+3Nmv5js4QHj
TIb2G/tuNDfqprpUPw8QdyAzdH43yl+b3qAh4gHvoAm+1NyFiqtOrl3xkwfV
2WMlBS870X/1m02jlfQg7y+3bZV/B9JqF9KotzG4OHI2MiahFfU0w9KqK3pw
PlptKiqxGr0VnFNSntKD6R0v0+Q8TiGOgWkDi/IKuau9sT9PolNuX5JmUb71
zP024/xJtLrBRBFRvupwKkKu6AQqet4k70c546pTlpgVhnA4i1FLeSM/cWdg
awgq0ciTjpnWgwsjL7XsbQOQvt32sguUvc07y673+aMzMTOisikfkpbvJ8P8
0ZrfjlIvKIOhwpSq82FU2j0xg0/5o+wKEyclX/Qud81fq796sBTT8y0j9yHD
flGRHWWra7l+T5/uRVGci6d2UP6jH6fC6fZE1ikDU4GUI4DGEK/cg8qOJvy5
Qdme9SChaWgnMnyy5M0jyvy/DgfDN7ihKEFn2CvKT+Wz1WfdcUXWbqa/GykX
Oa1u8Ny1Dd26+KWwg7LmzcyuidfOSLoh8vgg5eJfz96c03ZCe2nzLL7///sT
CfuVg7eicsuWyb+UL1cb/5faZI/+B/PJySE=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk8VN8bB/BZrGULYRZrSBtCheQ8SaUQqSQJLYiviNJGtqRCRBJF2suW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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
    RowBox[{"{", "\"Fig.11. r=8. 13 terms summed for phases 0,l,2.\"", "}"}], 
    TraditionalForm],
  PlotRange->{{0, 9}, {-0.998892835001291, 1.1205897373467948`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Complex and Hyperbolic Duals.", "Subsection"],

Cell[TextData[{
 "The Argand-Wessel diagram shows the relationship between the complex number \
x+\[DoubleStruckI] y and the polar representation r=",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["y", "2"]}]], TraditionalForm]]],
 ", \[Theta]=ArcTan[x,y]. Fig 12 shows this, together with the hyperbolic \
analogue (Study numbers, Cayley-Klein algebra, etc). Here ",
 Cell[BoxData[
  SuperscriptBox["u", "2"]]],
 " = ",
 Cell[BoxData[
  SuperscriptBox["X", "2"]]],
 " - ",
 Cell[BoxData[
  SuperscriptBox["Y", "2"]]],
 ", \[Phi] = arcTanh[X,Y]. ArcTanh [z] has been generalized to distinguish \
between the different quadrants, so that the Cartesian form {X,Y} can be \
recovered from {u,\[Phi]}."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cosh", "[", "a", "]"}], ",", 
         RowBox[{"Sinh", "[", "a", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", "a", "]"}], ",", 
         RowBox[{"Sin", "[", "a", "]"}]}], "}"}], ",", 
       RowBox[{".1", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{".46", "a"}], "]"}], ",", 
          RowBox[{"Sin", "[", 
           RowBox[{".46", "a"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", "a"}], ",", 
         RowBox[{"2", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", "a"}], ",", "a"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{".895", ",", 
         RowBox[{".5", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.156", ",", 
         RowBox[{".65", "a"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", 
       RowBox[{".3", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", ".72"}], "}"}]}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "->", 
      "\"\<   Fig. 12  Complex  \!\(\*SuperscriptBox[\(x\), \
\(2\)]\)+\!\(\*SuperscriptBox[\(y\), \(2\)]\)=1,       Hyperbolic \
\!\(\*SuperscriptBox[\(X\), \(2\)]\)-\!\(\*SuperscriptBox[\(Y\), \(2\)]\)=1\>\
\""}]}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", " ", 
       RowBox[{"\"\<Asymptote\>\"", ",", 
        RowBox[{"{", 
         RowBox[{".49", ",", ".6"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", " ", 
       RowBox[{"\"\<x=y\>\"", ",", 
        RowBox[{"{", 
         RowBox[{".49", ",", ".54"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", " ", 
       RowBox[{"\"\<a\>\"", ",", 
        RowBox[{"{", 
         RowBox[{".12", ",", ".03"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", " ", 
       RowBox[{"\"\<x,y \[RightArrow]\>\"", ",", 
        RowBox[{"{", 
         RowBox[{".84", ",", ".45"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", " ", 
       RowBox[{"\"\<X,Y \[RightArrow]\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"1.09", ",", ".58"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw11Hs0lNsbB3BMLiEVIv0kBiedFELFxHO6UpFLcgnVUEhEUkl1ULlfkpFU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      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJw11As01NkfAHDPVsuWSO8y1iSPtJJml8o30qKtiF1JUSmPROXdJrQlEnkN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      "]]}, 
    {Hue[0.14213595499957954`, 0.6, 0.6], LineBox[CompressedData["
1:eJwt1Xs41NkbAHA/lwjbTi0biy2JyJTSRf1c3uxGERoxZSqXlCmXIaNIqTGE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      "]]}, 
    {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJxdxV1MkmEYgGHUGuakJUhN22wVQja3NIfRGOHQA+dSkBhsTsr8YqsTTdkY
NS1lbVYiltNm2uYydTmTjbAizc20LVq5VNQaDH8QwUQpCMmo7Ofked+4t3vX
/tJysSKSRCIV/P2f4VXllki0PgH/f8VhloZZGaYmzKYwO0F/c9147bAR3CJr
3++QDIOxb+0+tnwMlHBumM6qzKCZWa9XcsbBF/JbaVlpk+AHr2Inz2QBr4+4
ovrjZ0GpwiBL7PoIDuaxxkJkG+gIsoyTZ+wgS1UZ0bM6D0bsHTAGGYvgFaeF
nlDmAOVxxwczDUtg3ZxytWHOCfJbLG+IZBcoWItmK6VucDqVEEbcXwHNE5GP
bi5/Asl0dXN+vAecEVBTG4vXQO8ujTCmcR08Lzj2pGbICz7XRy8Pkr6AhLaE
PdWKnJ7Lsz/k+cCgQ8asnkfyngnZZSo/eJJkbU9K/ArWJAjNnsdIhdPV8jQ3
AMYx4oayPMilDGaPW7MBVpnGV/JZQZBLKfFNjCD7aPT2Qtk30KErvnc7hORb
dYS3aRMk2k5pYjjfQU4sV8CwIo8WUMxFFSEwsK2yW0T/AdrqX+YSeqTyVUaD
MucnOFXBScl2I2WfWfVHrv4CHyz25tgOboGj7tMBL+bCOq0rkoFMClVHHcZs
pYpH1Zi67BB/dzLycncet5CJvNv3e/Ucpskw0KbG3BhOCnVgXpz1m7yYCnJ7
ppaFvEYRuTowO2nb7xgxF/aVb1gxizjZAymHkJdObBI8zNacfloh5oxoj1KN
GZC+O6DFpMprpzow04lMjRFTdMGT/hrzD7mQZGA=
      "]]}, 
    {Hue[0.6142719099991583, 0.6, 0.6], LineBox[CompressedData["
1:eJxdz2tIE1AYxvGphSYZqVloYFTqKoJS0RZiT0w/iJS3REGyrDWoL5UOxEIr
R9DFaRcqKgOpVApTsFktS6iMWpTkvdK8zbmp05PTOW3V6sR5CdqBw4//8+mc
1fuPpCndJRJJEr9/dT2FCTnpGqscwggyDf/v+132PJdd7bJfdtnv/Nunr5xp
KW7Sknfh9NR8XJTeRNZi8fs+a1R2M6lFuuycbl++ntRBH1ZSp5K1kE14nn1x
8/bNbeRLfGLKJbG6DrIZZ1+YPGqXdZNvkKGszwyq/Ezq0ZgobXZ49pLvYbBL
tW17+8gWSPPz3KrHB8iPcFvZoLWHDJFtOGHsCAg8bCDbke27tTG6fpjswJl+
1Xhpv5HsBK52vFOEmshuyCe8olQZZvITOjcqkt1uj5KfoW91f3B+ZIz8As+A
gis7l1nIXnTJ/TZe2D1BfgVbqk72vjBJ9uGgfMujU88Y2Y+ndV4jjZIpchAK
TU5U+/UpchCd/Yl992Kt5BDshsywogErOYTYJ8lRh/OnSQN2SHrKg4NmyGGc
CkzWWx7OkMNQGk1XHyfYSCN8Q3yfbbfYSCOGI8OqzepZcgSFupbRnVI7aUKM
T4619YWdNKHGP6A8NXOONMNQtvvWJcccaQZ6yhTs8jw5CsXNXWpv2XdyDLLF
MfKQnu/kGCKSfPRZuQ5yHLYFeVUpAT9IC3pLXiYo6n6QFqheR5aq4n+SE2jP
la2PM/8kJ5D5TVqy6eQvchJ3h+7H9651kgyvzHtsjLeQYXDSv9I9xEkyBDuK
PDbwFjJc90t7VcBbyFAW58DyUCfJcLwqMSY1zEky3Kj5PX6At5BBV99ws4C3
kGG2KdhRwVvIcLR7Wsd4CxmUnuXRGqmTZDjtk2Kq4C1kuOO/8JqWt5C/f9WR
2R7eQoYsWVzD+nVOkuHYtnlFLG8h/098rX8qbyFDV8oKVQFvIYMt48MaDW8h
g192cXsFbyFDuCJareUtZEg5ZAl/y1vI8AdBS1+Q
      "]]}, 
    {Hue[0.8503398874989481, 0.6, 0.6], 
     LineBox[{{0.895, 0.}, {0.895, 0.004624889528729633}, {0.895, 
      0.009249779057459266}, {0.895, 0.019277599496395355`}, {0.895, 
      0.028640893261588467`}, {0.895, 0.037820516371445206`}, {0.895, 
      0.04777818086277877}, {0.895, 0.057071318680369354`}, {0.895, 
      0.06714249787943677}, {0.895, 0.0770300064231678}, {0.895, 
      0.08625298829315586}, {0.895, 0.09625401154462074}, {0.895, 
      0.10559050812234264`}, {0.895, 0.11474333404472817`}, {0.895, 
      0.12467420134859052`}, {0.895, 0.1339405419787099}, {0.895, 
      0.1439849239903061}, {0.895, 0.15384563534656595`}, {0.895, 
      0.16304182002908282`}, {0.895, 0.1730160460930765}, {0.895, 
      0.1823257454833272}, {0.895, 0.19241348625505472`}, {0.895, 
      0.20231755637144588`}, {0.895, 0.21155709981409407`}, {0.895, 
      0.22157468463821908`}, {0.895, 0.23092774278860112`}, {0.895, 
      0.24009713028364676`}, {0.895, 0.25004455916016927`}, {0.895, 
      0.25932746136294876`}, {0.895, 0.26938840494720506`}, {0.895, 
      0.279265677876125}, {0.895, 0.2884784241313019}, {0.895, 
      0.2984692117679557}, {0.895, 0.3077954727308665}, {0.895, 
      0.3169380630384409}, {0.895, 0.3268586947274921}, {0.895, 
      0.3361147997428004}, {0.895, 0.34614894613958547`}, {0.895, 
      0.3555185658626276}, {0.895, 0.36470451493033335`}, {0.895, 
      0.3746685053795159}, {0.895, 0.3839679691549555}, {0.895, 
      0.3940454743118719}, {0.895, 0.40393930881345197`}, {0.895, 
      0.413168616641289}, {0.895, 0.4231759658506029}, {0.895, 
      0.4325187883861738}, {0.895, 0.44167794026640833`}, {0.895, 
      0.45161513352811966`}, {0.895, 0.46088780011608804`}, {0.895, 
      0.4709385080855332}, {0.895, 0.4710887030620011}, {0.895, 
      0.47123889803846897`}}]}, 
    {Hue[0.08640786499873876, 0.6, 0.6], 
     LineBox[{{1.156, 0.}, {1.156, 0.006012356387348523}, {1.156, 
      0.012024712774697046`}, {1.156, 0.025060879345313963`}, {1.156, 
      0.03723316124006501}, {1.156, 0.04916667128287877}, {1.156, 
      0.0621116351216124}, {1.156, 0.07419271428448017}, {1.156, 
      0.0872852472432678}, {1.156, 0.10013900835011814`}, {1.156, 
      0.11212888478110263`}, {1.156, 0.12513021500800697`}, {1.156, 
      0.13726766055904543`}, {1.156, 0.14916633425814663`}, {1.156, 
      0.16207646175316767`}, {1.156, 0.17412270457232287`}, {1.156, 
      0.18718040118739793`}, {1.156, 0.19999932595053574`}, {1.156, 
      0.21195436603780768`}, {1.156, 0.22492085992099944`}, {1.156, 
      0.23702346912832536`}, {1.156, 0.25013753213157114`}, {1.156, 
      0.26301282328287967`}, {1.156, 0.2750242297583223}, {1.156, 
      0.2880470900296848}, {1.156, 0.3002060656251815}, {1.156, 
      0.3121262693687408}, {1.156, 0.32505792690822005`}, {1.156, 
      0.33712569977183343`}, {1.156, 0.3502049264313666}, {1.156, 
      0.3630453812389625}, {1.156, 0.3750219513706925}, {1.156, 
      0.3880099752983424}, {1.156, 0.40013411455012643`}, {1.156, 
      0.4120194819499732}, {1.156, 0.4249163031457398}, {1.156, 
      0.43694923966564053`}, {1.156, 0.44999362998146114`}, {1.156, 
      0.4621741356214159}, {1.156, 0.47411586940943334`}, {1.156, 
      0.48706905699337066`}, {1.156, 0.4991583599014422}, {1.156, 
      0.5122591166054336}, {1.156, 0.5251211014574876}, {1.156, 
      0.5371192016336758}, {1.156, 0.5501287556057838}, {1.156, 
      0.562274424902026}, {1.156, 0.5741813223463309}, {1.156, 
      0.5870996735865556}, {1.156, 0.5991541401509145}, {1.156, 
      0.6122200605111933}, {1.156, 0.6124153139806015}, {1.156, 
      0.6126105674500096}}]}}, {InsetBox["\<\"Asymptote\"\>", {0.49, 0.6}], 
    InsetBox["\<\"x=y\"\>", {0.49, 0.54}], 
    InsetBox["\<\"a\"\>", {0.12, 0.03}], 
    InsetBox["\<\"x,y \[RightArrow]\"\>", {0.84, 0.45}], 
    InsetBox["\<\"X,Y \[RightArrow]\"\>", {1.09, 0.58}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
   "\"   Fig. 12  Complex  \\!\\(\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)+\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\)=1,       Hyperbolic \
\\!\\(\\*SuperscriptBox[\\(X\\), \\(2\\)]\\)-\\!\\(\\*SuperscriptBox[\\(Y\\), \
\\(2\\)]\\)=1\"", TraditionalForm],
  PlotRange->{{0, 1.3}, {0, 0.72}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Abelian Hoop algebras, Duals, Powers.", "Section",
 PageWidth->WindowWidth],

Cell[TextData[{
 "Commutative (Abelian) algebras are in the minority. They have ",
 StyleBox["generators",
  FontSlant->"Italic"],
 " (aka ",
 StyleBox["relators, gammas, monovectors, polyvectors",
  FontSlant->"Italic"],
 ") that combine to form ",
 StyleBox["elements",
  FontSlant->"Italic"],
 " without regard to order. Each generator is an ",
 StyleBox["r'th root-of-unity",
  FontSlant->"Italic"],
 " so it generates r-1 powers. E.g. if ",
 StyleBox["a",
  FontSlant->"Italic"],
 " has ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=3 (a polyvector), there are elements 1, ",
 StyleBox["a, ",
  FontSlant->"Italic"],
 "and",
 StyleBox[" aa",
  FontSlant->"Italic"],
 ", and 1. If ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2 for ",
 StyleBox["b",
  FontSlant->"Italic"],
 " (a monovector) there also are elements ",
 StyleBox["b, ab, & aab.",
  FontSlant->"Italic"],
 " The product of two elements is their lex-ordered concatenation, with ",
 StyleBox["aaa & bb",
  FontSlant->"Italic"],
 " replaced by 1. In the example, ",
 StyleBox["ab.b = abb = a ",
  FontSlant->"Italic"],
 "and",
 StyleBox[" ab.ab = aabb= aa. ",
  FontSlant->"Italic"],
 "The result is identified as ",
 StyleBox["C3C2.",
  FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"ge", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", "}"}], ",", "1"}], "]"}]}], ";", 
  RowBox[{"{", 
   RowBox[{"genel", ",", 
    RowBox[{"matel", "//", "tf"}], ",", 
    RowBox[{"idc", "[", "tst", "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "\<\"a\"\>", ",", "\<\"aa\"\>", ",", "\<\"b\"\>", 
     ",", "\<\"ab\"\>", ",", "\<\"aab\"\>"}], "}"}], ",", 
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "\<\"a\"\>", "\<\"aa\"\>", "\<\"b\"\>", "\<\"ab\"\>", \
"\<\"aab\"\>"},
        {"\<\"a\"\>", "\<\"aa\"\>", 
         "1", "\<\"ab\"\>", "\<\"aab\"\>", "\<\"b\"\>"},
        {"\<\"aa\"\>", 
         "1", "\<\"a\"\>", "\<\"aab\"\>", "\<\"b\"\>", "\<\"ab\"\>"},
        {"\<\"b\"\>", "\<\"ab\"\>", "\<\"aab\"\>", 
         "1", "\<\"a\"\>", "\<\"aa\"\>"},
        {"\<\"ab\"\>", "\<\"aab\"\>", "\<\"b\"\>", "\<\"a\"\>", "\<\"aa\"\>", 
         "1"},
        {"\<\"aab\"\>", "\<\"b\"\>", "\<\"ab\"\>", "\<\"aa\"\>", 
         "1", "\<\"a\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"C3C2\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A single ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2 generator will allow the table to be 2-folded to a real algebra. \
Provided that it has some ",
 StyleBox["r",
  FontSlant->"Italic"],
 ">2, any abelian hoop will have a polar-dual because each root-of-unity can \
be projected onto a complex plane and describes an ",
 StyleBox["r",
  FontSlant->"Italic"],
 "-phase sinusoid. Extra ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=2 cases will provide offsets for the orbits. Pairs of offsets always \
appear as X+Y and X-Y; as (X+Y)(X-Y) =",
 Cell[BoxData[
  SuperscriptBox["X", "2"]]],
 "-",
 Cell[BoxData[
  SuperscriptBox["Y", "2"]]],
 ", hyperbolic orbits can be created from them. These should be avoided as \
they involve a loss of information."
}], "Text"],

Cell[TextData[{
 "The ",
 StyleBox["toPolar",
  FontSlant->"Italic"],
 " and ",
 StyleBox["toVector",
  FontSlant->"Italic"],
 " functions are provided for many Abelian Hoops. The previous example makes \
C3C2 the active hoop, so it need not be specified. Reversion of a symbolic \
polar form is slow; numeric cases are fast."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "d1", ",", "d2", ",", "rr", ",", "\[Theta]", ",", "ss", ",", "\[Phi]"}], 
   "}"}], "=", 
  RowBox[{"toPolar", "[", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w", ",", "x", ",", "y", ",", "z"}], "}"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", "+", "v", "+", "w", "+", "x", "+", "y", "+", "z"}], ",", 
   RowBox[{"u", "+", "v", "+", "w", "-", "x", "-", "y", "-", "z"}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"u", "-", "v", "+", "x", "-", "y"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"v", "-", "w", "+", "y", "-", "z"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "u"}], "+", "w", "-", "x", "+", "z"}], ")"}], "2"]}], 
     ")"}]}], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "u"}], "-", "v", "-", "w", "+", 
      RowBox[{"2", " ", "x"}], "-", "y", "-", "z"}], ",", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "v"}], "+", "w", "-", "y", "+", "z"}], ")"}]}]}], "]"}], 
   ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"u", "-", "v", "-", "x", "+", "y"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "u"}], "+", "w", "+", "x", "-", "z"}], ")"}], "2"], "+",
       
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"v", "-", "w", "-", "y", "+", "z"}], ")"}], "2"]}], ")"}]}], 
   ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "u"}], "-", "v", "-", "w", "-", 
      RowBox[{"2", " ", "x"}], "+", "y", "+", "z"}], ",", 
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "v"}], "+", "w", "+", "y", "-", "z"}], ")"}]}]}], 
    "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"toVector", "[", 
   RowBox[{"{", 
    RowBox[{
    "d1", ",", "d2", ",", "rr", ",", "\[Theta]", ",", "ss", ",", "\[Phi]"}], 
    "}"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", "w", ",", "x", ",", "y", ",", "z"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "d1", ",", "d2", ",", "rr", ",", "\[Theta]", ",", "ss", ",", "\[Phi]"}], 
   "}"}], "=", 
  RowBox[{"toPolar", "[", 
   RowBox[{"{", 
    RowBox[{"3.", ",", "5.", ",", "1.", ",", "2.", ",", 
     RowBox[{"-", "1."}], ",", "4."}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"toVector", "[", "%", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "14.`", ",", "4.`", ",", "1.`", ",", "1.0471975511965976`", ",", "61.`", 
   ",", 
   RowBox[{"-", "1.6348585760479506`"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.`", ",", "5.`", ",", "0.9999999999999997`", ",", "2.`", ",", 
   RowBox[{"-", "1.`"}], ",", "4.`"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Non-commutative algebras, Geometric algebra.", "Section",
 PageWidth->PaperWidth],

Cell[TextData[{
 "Non-commutative hoops have some generators that do not commute. This can \
often be implemented in ",
 StyleBox["ge",
  FontSlant->"Italic"],
 " by specifying a re-write rule such as {\"ba\"",
 "\[Rule]",
 " \"aab\"}:-"
}], "Text",
 PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst", "=", 
   RowBox[{"ge", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<ba\>\"", "->", "\"\<aab\>\""}], "}"}], ",", "1"}], "]"}]}],
   ";", "genel"}], "\[IndentingNewLine]", 
 RowBox[{"matel", "//", "tf"}], "\[IndentingNewLine]", 
 RowBox[{"idc", "[", "tst", "]"}]}], "Input",
 PageWidth->PaperWidth],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "\<\"a\"\>", ",", "\<\"aa\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"ab\"\>", ",", "\<\"aab\"\>"}], "}"}]], "Output",
 PageWidth->PaperWidth],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "\<\"a\"\>", "\<\"aa\"\>", "\<\"b\"\>", "\<\"ab\"\>", \
"\<\"aab\"\>"},
     {"\<\"a\"\>", "\<\"aa\"\>", 
      "1", "\<\"ab\"\>", "\<\"aab\"\>", "\<\"b\"\>"},
     {"\<\"aa\"\>", 
      "1", "\<\"a\"\>", "\<\"aab\"\>", "\<\"b\"\>", "\<\"ab\"\>"},
     {"\<\"b\"\>", "\<\"aab\"\>", "\<\"ab\"\>", 
      "1", "\<\"aa\"\>", "\<\"a\"\>"},
     {"\<\"ab\"\>", "\<\"b\"\>", "\<\"aab\"\>", "\<\"a\"\>", 
      "1", "\<\"aa\"\>"},
     {"\<\"aab\"\>", "\<\"ab\"\>", "\<\"b\"\>", "\<\"aa\"\>", "\<\"a\"\>", 
      "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 PageWidth->PaperWidth],

Cell[BoxData["\<\"D3\"\>"], "Output",
 PageWidth->PaperWidth]
}, Open  ]],

Cell["\<\
Others are created by the generalised Cayley-Dickson procedure, which \
specifies the square of each gamma and gives a signed table:-\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tst", "=", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], "]"}], "//", 
   "tf"}]}], "\[IndentingNewLine]", 
 RowBox[{"id", "[", "tst", "]"}]}], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8"},
     {"2", 
      RowBox[{"-", "1"}], "4", 
      RowBox[{"-", "3"}], "6", 
      RowBox[{"-", "5"}], 
      RowBox[{"-", "8"}], "7"},
     {"3", 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "1"}], "2", "7", "8", 
      RowBox[{"-", "5"}], 
      RowBox[{"-", "6"}]},
     {"4", "3", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "8", 
      RowBox[{"-", "7"}], "6", 
      RowBox[{"-", "5"}]},
     {"5", 
      RowBox[{"-", "6"}], 
      RowBox[{"-", "7"}], 
      RowBox[{"-", "8"}], 
      RowBox[{"-", "1"}], "2", "3", "4"},
     {"6", "5", 
      RowBox[{"-", "8"}], "7", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}], "3"},
     {"7", "8", "5", 
      RowBox[{"-", "6"}], 
      RowBox[{"-", "3"}], "4", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}]},
     {"8", 
      RowBox[{"-", "7"}], "6", "5", 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], "2", 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"],

Cell[BoxData["\<\"Octr\"\>"], "Output"]
}, Open  ]],

Cell["\<\
Adding {2} to the gamma list \"unfolds\" the result to an unsigned table:-\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tst2", "=", 
  RowBox[{
   RowBox[{"cd", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"{", "2", "}"}]}], "}"}], "]"}], "//", 
   "tf"}]}], "\[IndentingNewLine]", 
 RowBox[{"id", "[", "tst2", "]"}]}], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"},
     {"2", "9", "12", "3", "14", "5", "8", "15", "10", "1", "4", "11", "6", 
      "13", "16", "7"},
     {"3", "4", "9", "10", "15", "16", "5", "6", "11", "12", "1", "2", "7", 
      "8", "13", "14"},
     {"4", "11", "2", "9", "16", "7", "14", "5", "12", "3", "10", "1", "8", 
      "15", "6", "13"},
     {"5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "1", 
      "2", "3", "4"},
     {"6", "13", "8", "15", "2", "9", "4", "11", "14", "5", "16", "7", "10", 
      "1", "12", "3"},
     {"7", "16", "13", "6", "3", "12", "9", "2", "15", "8", "5", "14", "11", 
      "4", "1", "10"},
     {"8", "7", "14", "13", "4", "3", "10", "9", "16", "15", "6", "5", "12", 
      "11", "2", "1"},
     {"9", "10", "11", "12", "13", "14", "15", "16", "1", "2", "3", "4", "5", 
      "6", "7", "8"},
     {"10", "1", "4", "11", "6", "13", "16", "7", "2", "9", "12", "3", "14", 
      "5", "8", "15"},
     {"11", "12", "1", "2", "7", "8", "13", "14", "3", "4", "9", "10", "15", 
      "16", "5", "6"},
     {"12", "3", "10", "1", "8", "15", "6", "13", "4", "11", "2", "9", "16", 
      "7", "14", "5"},
     {"13", "14", "15", "16", "1", "2", "3", "4", "5", "6", "7", "8", "9", 
      "10", "11", "12"},
     {"14", "5", "16", "7", "10", "1", "12", "3", "6", "13", "8", "15", "2", 
      "9", "4", "11"},
     {"15", "8", "5", "14", "11", "4", "1", "10", "7", "16", "13", "6", "3", 
      "12", "9", "2"},
     {"16", "15", "6", "5", "12", "11", "2", "1", "8", "7", "14", "13", "4", 
      "3", "10", "9"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"],

Cell[BoxData["\<\"Oct\"\>"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The Clifford tables are created by ",
 StyleBox["clf",
  FontSlant->"Italic"],
 "; composition with C2 (but nothing else) gives a conservative table. They \
are developed in ",
 StyleBox["CliffordG.m.",
  FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tst03", "=", 
   RowBox[{"clf", "[", 
    RowBox[{"0", ",", "3"}], "]"}]}], ";", 
  RowBox[{"tst03", "//", "tf"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"\"\<This is \>\"", ",", 
   RowBox[{"id", "[", "tst03", "]"}], ",", "\"\<\\nwhich composes to \>\"", 
   ",", 
   RowBox[{"id", "[", 
    RowBox[{"co", "[", 
     RowBox[{"tst03", ",", "C2"}], "]"}], "]"}]}], "}"}]}], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8"},
     {"2", 
      RowBox[{"-", "1"}], "4", 
      RowBox[{"-", "3"}], "6", 
      RowBox[{"-", "5"}], "8", 
      RowBox[{"-", "7"}]},
     {"3", 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "1"}], "2", "7", 
      RowBox[{"-", "8"}], 
      RowBox[{"-", "5"}], "6"},
     {"4", "3", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "8", "7", 
      RowBox[{"-", "6"}], 
      RowBox[{"-", "5"}]},
     {"5", 
      RowBox[{"-", "6"}], 
      RowBox[{"-", "7"}], "8", 
      RowBox[{"-", "1"}], "2", "3", 
      RowBox[{"-", "4"}]},
     {"6", "5", 
      RowBox[{"-", "8"}], 
      RowBox[{"-", "7"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "4", "3"},
     {"7", "8", "5", "6", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}]},
     {"8", 
      RowBox[{"-", "7"}], "6", 
      RowBox[{"-", "5"}], 
      RowBox[{"-", "4"}], "3", 
      RowBox[{"-", "2"}], "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"This is \"\>", ",", "\<\"CL03\"\>", 
   ",", "\<\"\\nwhich composes to \"\>", ",", "\<\"Q8C2\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"tst032", "=", 
    RowBox[{
     RowBox[{"co", "[", 
      RowBox[{
       RowBox[{"cl", "[", 
        RowBox[{"0", ",", "3"}], "]"}], ",", "C2"}], "]"}], "//", "tf"}]}], 
   ",", 
   RowBox[{"id", "[", "tst032", "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    FormBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
         "14", "15", "16"},
        {"2", "9", "12", "3", "14", "5", "8", "15", "10", "1", "4", "11", "6",
          "13", "16", "7"},
        {"3", "4", "9", "10", "15", "16", "5", "6", "11", "12", "1", "2", "7",
          "8", "13", "14"},
        {"4", "11", "2", "9", "8", "15", "6", "13", "12", "3", "10", "1", 
         "16", "7", "14", "5"},
        {"5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", 
         "1", "2", "3", "4"},
        {"6", "13", "16", "7", "2", "9", "12", "3", "14", "5", "8", "15", 
         "10", "1", "4", "11"},
        {"7", "8", "13", "14", "3", "4", "9", "10", "15", "16", "5", "6", 
         "11", "12", "1", "2"},
        {"8", "15", "6", "13", "12", "3", "10", "1", "16", "7", "14", "5", 
         "4", "11", "2", "9"},
        {"9", "10", "11", "12", "13", "14", "15", "16", "1", "2", "3", "4", 
         "5", "6", "7", "8"},
        {"10", "1", "4", "11", "6", "13", "16", "7", "2", "9", "12", "3", 
         "14", "5", "8", "15"},
        {"11", "12", "1", "2", "7", "8", "13", "14", "3", "4", "9", "10", 
         "15", "16", "5", "6"},
        {"12", "3", "10", "1", "16", "7", "14", "5", "4", "11", "2", "9", "8",
          "15", "6", "13"},
        {"13", "14", "15", "16", "1", "2", "3", "4", "5", "6", "7", "8", "9", 
         "10", "11", "12"},
        {"14", "5", "8", "15", "10", "1", "4", "11", "6", "13", "16", "7", 
         "2", "9", "12", "3"},
        {"15", "16", "5", "6", "11", "12", "1", "2", "7", "8", "13", "14", 
         "3", "4", "9", "10"},
        {"16", "7", "14", "5", "4", "11", "2", "9", "8", "15", "6", "13", 
         "12", "3", "10", "1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ",", "\<\"Q8C2\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tst", "=", 
  RowBox[{
   RowBox[{"co", "[", 
    RowBox[{
     RowBox[{"cl", "[", "3", "]"}], ",", "C2"}], "]"}], "//", 
   "tf"}]}], "\[IndentingNewLine]", 
 RowBox[{"id", "[", "tst", "]"}]}], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"},
     {"2", "1", "12", "11", "14", "13", "8", "7", "10", "9", "4", "3", "6", 
      "5", "16", "15"},
     {"3", "4", "1", "2", "15", "16", "13", "14", "11", "12", "9", "10", "7", 
      "8", "5", "6"},
     {"4", "3", "10", "9", "8", "7", "14", "13", "12", "11", "2", "1", "16", 
      "15", "6", "5"},
     {"5", "6", "7", "8", "1", "2", "3", "4", "13", "14", "15", "16", "9", 
      "10", "11", "12"},
     {"6", "5", "16", "15", "10", "9", "4", "3", "14", "13", "8", "7", "2", 
      "1", "12", "11"},
     {"7", "8", "5", "6", "11", "12", "9", "10", "15", "16", "13", "14", "3", 
      "4", "1", "2"},
     {"8", "7", "14", "13", "4", "3", "10", "9", "16", "15", "6", "5", "12", 
      "11", "2", "1"},
     {"9", "10", "11", "12", "13", "14", "15", "16", "1", "2", "3", "4", "5", 
      "6", "7", "8"},
     {"10", "9", "4", "3", "6", "5", "16", "15", "2", "1", "12", "11", "14", 
      "13", "8", "7"},
     {"11", "12", "9", "10", "7", "8", "5", "6", "3", "4", "1", "2", "15", 
      "16", "13", "14"},
     {"12", "11", "2", "1", "16", "15", "6", "5", "4", "3", "10", "9", "8", 
      "7", "14", "13"},
     {"13", "14", "15", "16", "9", "10", "11", "12", "5", "6", "7", "8", "1", 
      "2", "3", "4"},
     {"14", "13", "8", "7", "2", "1", "12", "11", "6", "5", "16", "15", "10", 
      "9", "4", "3"},
     {"15", "16", "13", "14", "3", "4", "1", "2", "7", "8", "5", "6", "11", 
      "12", "9", "10"},
     {"16", "15", "6", "5", "12", "11", "2", "1", "8", "7", "14", "13", "4", 
      "3", "10", "9"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"],

Cell[BoxData["\<\"P16\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tst", "=", 
  RowBox[{
   RowBox[{"co", "[", 
    RowBox[{
     RowBox[{"cl", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", "C2"}], "]"}], "//", 
   "tf"}]}], "\[IndentingNewLine]", 
 RowBox[{"id", "[", "tst", "]"}]}], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
      "14", "15", "16"},
     {"2", "1", "12", "11", "14", "13", "8", "7", "10", "9", "4", "3", "6", 
      "5", "16", "15"},
     {"3", "4", "9", "10", "15", "16", "5", "6", "11", "12", "1", "2", "7", 
      "8", "13", "14"},
     {"4", "3", "2", "1", "8", "7", "6", "5", "12", "11", "10", "9", "16", 
      "15", "14", "13"},
     {"5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "1", 
      "2", "3", "4"},
     {"6", "5", "16", "15", "2", "1", "12", "11", "14", "13", "8", "7", "10", 
      "9", "4", "3"},
     {"7", "8", "13", "14", "3", "4", "9", "10", "15", "16", "5", "6", "11", 
      "12", "1", "2"},
     {"8", "7", "6", "5", "12", "11", "10", "9", "16", "15", "14", "13", "4", 
      "3", "2", "1"},
     {"9", "10", "11", "12", "13", "14", "15", "16", "1", "2", "3", "4", "5", 
      "6", "7", "8"},
     {"10", "9", "4", "3", "6", "5", "16", "15", "2", "1", "12", "11", "14", 
      "13", "8", "7"},
     {"11", "12", "1", "2", "7", "8", "13", "14", "3", "4", "9", "10", "15", 
      "16", "5", "6"},
     {"12", "11", "10", "9", "16", "15", "14", "13", "4", "3", "2", "1", "8", 
      "7", "6", "5"},
     {"13", "14", "15", "16", "1", "2", "3", "4", "5", "6", "7", "8", "9", 
      "10", "11", "12"},
     {"14", "13", "8", "7", "10", "9", "4", "3", "6", "5", "16", "15", "2", 
      "1", "12", "11"},
     {"15", "16", "5", "6", "11", "12", "1", "2", "7", "8", "13", "14", "3", 
      "4", "9", "10"},
     {"16", "15", "14", "13", "4", "3", "2", "1", "8", "7", "6", "5", "12", 
      "11", "10", "9"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output"],

Cell[BoxData["\<\"P16\"\>"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tAll non-commutative hoops split into a commutative (Jordan, dot, inner) \
product and a non-commutative (Lie, wedge, outer) product ab = a.b+a",
 Cell[BoxData["\[Wedge]"]],
 "b. Some Geometric Algebra texts wrongly offer this as a definition of \
Geometric algebras.\n\tGeometric algebras CLpq are built from anticommutative \
\"monovectors\" with p that square to +1 and q that square to -1. They are \
graded algebras, with scalar, monovector, bivector, ..., pseudovector grades. \
They have sizes that are (if p+q>2) repeated four times; some split into \
signed sums of squared fragments whilst others are quarticsthat do not \
factorise:-"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<Shape for CL2 \>\"", ",", 
   RowBox[{"sh", "[", "\"\<CL2\>\"", "]"}], ",", "\"\<\\nShape for CL21 \>\"",
    ",", 
   RowBox[{"sh", "[", "\"\<CL21\>\"", "]"}], ",", 
   "\"\<\\nShape for CL12 \>\"", ",", 
   RowBox[{"sh", "[", "\"\<CL12\>\"", "]"}], ",", 
   "\"\<\\nShape for CL31 \>\"", ",", 
   RowBox[{"sh", "[", "\"\<CL31\>\"", "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Shape for CL2 \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"]}], "}"}], ",", "\<\"\\nShape for CL21 \"\>", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "+", "e"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "h"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", "-", "e"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "f"}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "g"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "h"}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nShape for CL12 \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "-", 
          RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", 
         RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", 
         RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", 
         RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"d", "+", 
          RowBox[{"\[ImaginaryI]", " ", "e"}]}], ")"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "+", 
         RowBox[{"\[ImaginaryI]", " ", "f"}]}], ")"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", 
         RowBox[{"\[ImaginaryI]", " ", "g"}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"]}]}], "}"}], 
   ",", "\<\"\\nShape for CL31 \"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"], "-", 
        SuperscriptBox["d", "2"], "-", 
        SuperscriptBox["e", "2"], "-", 
        SuperscriptBox["f", "2"], "+", 
        SuperscriptBox["g", "2"], "+", 
        SuperscriptBox["h", "2"], "+", 
        SuperscriptBox["i", "2"], "+", 
        SuperscriptBox["j", "2"], "-", 
        SuperscriptBox["k", "2"], "-", 
        SuperscriptBox["l", "2"], "-", 
        SuperscriptBox["m", "2"], "-", 
        SuperscriptBox["n", "2"], "+", 
        SuperscriptBox["o", "2"], "+", 
        SuperscriptBox["p", "2"]}], ")"}], "2"], "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "g"}], " ", "i"}], "+", 
            RowBox[{"h", " ", "j"}], "+", 
            RowBox[{"e", " ", "k"}], "-", 
            RowBox[{"f", " ", "l"}], "-", 
            RowBox[{"c", " ", "m"}], "+", 
            RowBox[{"d", " ", "n"}], "+", 
            RowBox[{"a", " ", "o"}], "-", 
            RowBox[{"b", " ", "p"}]}], ")"}], "2"]}], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "b"}], " ", "i"}], "+", 
           RowBox[{"a", " ", "j"}], "-", 
           RowBox[{"d", " ", "k"}], "+", 
           RowBox[{"c", " ", "l"}], "-", 
           RowBox[{"f", " ", "m"}], "+", 
           RowBox[{"e", " ", "n"}], "-", 
           RowBox[{"h", " ", "o"}], "+", 
           RowBox[{"g", " ", "p"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "b"}], " ", "e"}], "+", 
           RowBox[{"a", " ", "f"}], "-", 
           RowBox[{"d", " ", "g"}], "+", 
           RowBox[{"c", " ", "h"}], "-", 
           RowBox[{"j", " ", "m"}], "+", 
           RowBox[{"i", " ", "n"}], "-", 
           RowBox[{"l", " ", "o"}], "+", 
           RowBox[{"k", " ", "p"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "b"}], " ", "c"}], "+", 
           RowBox[{"a", " ", "d"}], "+", 
           RowBox[{"f", " ", "g"}], "-", 
           RowBox[{"e", " ", "h"}], "-", 
           RowBox[{"j", " ", "k"}], "+", 
           RowBox[{"i", " ", "l"}], "+", 
           RowBox[{"n", " ", "o"}], "-", 
           RowBox[{"m", " ", "p"}]}], ")"}], "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", "b"}], "-", 
           RowBox[{"c", " ", "d"}], "-", 
           RowBox[{"e", " ", "f"}], "+", 
           RowBox[{"g", " ", "h"}], "+", 
           RowBox[{"i", " ", "j"}], "-", 
           RowBox[{"k", " ", "l"}], "-", 
           RowBox[{"m", " ", "n"}], "+", 
           RowBox[{"o", " ", "p"}]}], ")"}], "2"]}], ")"}]}]}], "}"}]}], "}"}]
  ], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1042, 750},
WindowMargins->{{Automatic, 114}, {15, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Footer"], 
   Cell[
    TextData[{
      ValueBox["Date"]}], "Date"], 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Footer"], 
   Cell[
    TextData[{" 15/07/08"}]], 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 36}, {54, 36}}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          ScriptMinSize -> 12, FontSize -> 16], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Margins" -> {1, 1}, "Widths" -> {0, 5}}, 
          ScriptMinSize -> 8, FontSize -> 11], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          5, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, CellFrameLabelMargins -> 
          6, StyleMenuListing -> None]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], CellMargins -> {{12, Inherited}, {20, 40}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
             "Times New Roman", FontSize -> 36, FontWeight -> "Bold"], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 40}}, LineSpacing -> {1, 0}, 
             FontFamily -> "Times New Roman", FontSize -> 44], 
            Cell[
             StyleData["Title", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, FontFamily -> 
             "Times New Roman", FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], 
             CellMargins -> {{2, 10}, {15, 30}}, FontFamily -> 
             "Times New Roman", FontSize -> 24]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], 
             CellMargins -> {{12, Inherited}, {10, 15}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, CounterIncrements -> "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> 
             "Times New Roman", FontSize -> 24, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {15, 20}}, LineSpacing -> {1, 0}, 
             FontFamily -> "Times New Roman", FontSize -> 36, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 4}}, FontFamily -> 
             "Times New Roman", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{2, 10}, {10, 15}}, FontFamily -> 
             "Times New Roman", FontSize -> 18, FontWeight -> "Bold"]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], 
             CellMargins -> {{12, Inherited}, {10, 20}}, 
             CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Times New Roman", FontSize -> 14,
              FontWeight -> "Bold", FontSlant -> "Plain"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 20}}, LineSpacing -> {1, 0}, 
             FontFamily -> "Times New Roman", FontSize -> 24, FontWeight -> 
             "Bold", FontSlant -> "Plain"], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {8, 12}}, FontFamily -> 
             "Times New Roman", FontSize -> 12, FontWeight -> "Bold", 
             FontSlant -> "Plain"], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{2, 10}, {8, 10}}, FontFamily -> 
             "Times New Roman", FontSize -> 14, FontWeight -> "Bold", 
             FontSlant -> "Plain"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Times New Roman", FontSize -> 18, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{40, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontFamily -> "Times New Roman", FontSize -> 18], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{18, Inherited}, {6, 12}}, FontFamily -> 
             "Times New Roman", FontSize -> 18], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{13, 0}, {7, 22}}, FontFamily -> 
             "Times New Roman", FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Times New Roman", FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{36, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontFamily -> "Times New Roman", FontSize -> 16], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{16, Inherited}, {6, 12}}, FontFamily -> 
             "Times New Roman", FontSize -> 16], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {7, 22}}, FontFamily -> 
             "Times New Roman", FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> 
             "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times New Roman", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{34, 10}, {11, 26}}, LineSpacing -> {1, 0}, 
             FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{17, Inherited}, {6, 12}}, FontFamily -> 
             "Times New Roman"], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{9, 0}, {7, 14}}, FontFamily -> 
             "Times New Roman"]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Body Text", "Section", FontFamily -> "Times New Roman"], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {7, 7}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Text", FontFamily -> 
             "Times New Roman"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {6, 6}},
              LineSpacing -> {1, 1}, FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}, 
             FontFamily -> "Times New Roman"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {6, 6}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "SmallText", 
             FontFamily -> "Times New Roman", FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{24, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Times New Roman", FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {5, 5}}, LineSpacing -> {1, 2}, 
             FontFamily -> "Times New Roman", FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{2, 2}, {5, 5}}, FontFamily -> "Times New Roman",
              FontSize -> 7]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{45, 10}, {5, 7}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{11, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontFamily -> "Times New Roman", 
             FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{72, Inherited}, {8, 10}}, LineSpacing -> {1, 0},
              FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {2, 3}}, FontFamily -> 
             "Times New Roman"], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{39, 0}, {4, 6}},
              FontFamily -> "Times New Roman"]}, Closed]], 
         Cell[
          StyleData["InputOnly"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, DefaultFormatType -> 
          DefaultInputFormatType, AutoItalicWords -> {}, FormatType -> 
          InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
          CounterIncrements -> "Input", StyleMenuListing -> None, FontWeight -> 
          "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{47, 10}, {7, 5}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, 
             CellLabelMargins -> {{11, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Output", FontFamily -> "Times New Roman", 
             FontSize -> 12], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{72, Inherited}, {10, 8}}, LineSpacing -> {1, 0},
              FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{41, Inherited}, {3, 2}}, FontFamily -> 
             "Times New Roman"], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{39, 0}, {6, 4}}, FontFamily -> 
             "Times New Roman"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelMargins -> {{11, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Message", StyleMenuListing -> None, 
             FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 8, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, CellLabelMargins -> {{11, Inherited}, {
               Inherited, Inherited}}, DefaultFormatType -> 
             DefaultOutputFormatType, AutoItalicWords -> {}, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None, FontFamily -> "Times New Roman", FontSize -> 12], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}, FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}, 
             FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontFamily -> "Times New Roman"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{4, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             ImageMargins -> {{62, Inherited}, {Inherited, 0}}], 
            Cell[
             StyleData["Graphics", "Condensed"], ImageSize -> {175, 175}, 
             ImageMargins -> {{38, Inherited}, {Inherited, 0}}], 
            Cell[
             StyleData["Graphics", "Printout"], ImageSize -> {250, 250}, 
             ImageMargins -> {{30, Inherited}, {Inherited, 0}}, FontSize -> 
             9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 9], 
            Cell[
             StyleData["CellLabel", "Printout"], FontFamily -> "Courier", 
             FontSize -> 8, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
         "Formulas and Programming", "Section", FontFamily -> 
          "Times New Roman"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineFormula"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 1, 
             SingleLetterItalics -> True, FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["InlineFormula", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["InlineFormula", "Condensed"], 
             CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1}, 
             FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["InlineFormula", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}, FontFamily -> 
             "Times New Roman"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{42, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 0, 
             SingleLetterItalics -> True, StyleMenuListing -> None, 
             FontFamily -> "Times New Roman", 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             LineSpacing -> {1, 5}, FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], LineSpacing -> {1, 1}, 
             FontFamily -> "Times New Roman"], 
            Cell[
             StyleData["DisplayFormula", "Printout"], FontFamily -> 
             "Times New Roman"]}, Open]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontSize -> 10, FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          StyleMenuListing -> None, FontSize -> 9, FontSlant -> "Italic"], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 10]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell["Palette Styles", "Section"], 
         Cell[
         "The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.", "Text"], 
         Cell[
          StyleData["Paste"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, After]}]& )}], 
         Cell[
          StyleData["Evaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["EvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionMove[
                FrontEnd`InputNotebook[], All, Cell, 1], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"]], 
            Cell[
             StyleData["Hyperlink", "Condensed"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"]], 
            Cell[
             StyleData["MainBookLink", "Condensed"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"]], 
            Cell[
             StyleData["AddOnsLink", "Condensed"]], 
            Cell[
             StyleData["AddOnLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuideLink", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"]], 
            Cell[
             StyleData["RefGuideLink", "Condensed"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"]], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"]], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Placeholder Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making placeholder objects \
in palette templates.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Placeholder"], Editable -> False, Selectable -> False,
              StyleBoxAutoDelete -> True, Placeholder -> True, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["Placeholder", "Presentation"]], 
            Cell[
             StyleData["Placeholder", "Condensed"]], 
            Cell[
             StyleData["Placeholder", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SelectionPlaceholder"], Editable -> False, Selectable -> 
             False, StyleBoxAutoDelete -> True, Placeholder -> 
             PrimaryPlaceholder, StyleMenuListing -> None, DrawHighlighted -> 
             True], 
            Cell[
             StyleData["SelectionPlaceholder", "Presentation"]], 
            Cell[
             StyleData["SelectionPlaceholder", "Condensed"]], 
            Cell[
             StyleData["SelectionPlaceholder", "Printout"]]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "FormatType Styles", "Section", FontFamily -> "Times New Roman"], 
         Cell[
         "The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.", "Text", FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["CellExpression"], PageWidth -> Infinity, 
          CellMargins -> {{6, Inherited}, {Inherited, Inherited}}, 
          ShowCellLabel -> False, ShowSpecialCharacters -> False, 
          AllowInlineCells -> False, AutoItalicWords -> {}, StyleMenuListing -> 
          None, FontFamily -> "Times New Roman", Background -> GrayLevel[1]], 
         
         Cell[
          StyleData["InputForm"], AllowInlineCells -> False, StyleMenuListing -> 
          None, FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["OutputForm"], PageWidth -> Infinity, TextAlignment -> 
          Left, LineSpacing -> {1, -5}, StyleMenuListing -> None, FontFamily -> 
          "Times New Roman"], 
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0}, 
          StyleMenuListing -> None, FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["TraditionalForm"], LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> True, TraditionalFunctionNotation -> True, 
          DelimiterMatching -> None, StyleMenuListing -> None, FontFamily -> 
          "Times New Roman"], 
         Cell[
         "The style defined below is mixed in to any cell that is in an \
inline cell within another.", "Text", FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["InlineCell"], TextAlignment -> Left, ScriptLevel -> 1, 
          StyleMenuListing -> None, FontFamily -> "Times New Roman"], 
         Cell[
          StyleData["InlineCellEditing"], StyleMenuListing -> None, 
          FontFamily -> "Times New Roman", Background -> 
          RGBColor[1, 0.749996, 0.8]]}, Open]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> "6.0 for Microsoft Windows (32-bit) (May 21, 2008)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 127, 3, 121, "Subtitle"],
Cell[720, 28, 161, 4, 95, "Subsubtitle"],
Cell[CellGroupData[{
Cell[906, 36, 91, 2, 79, "Section"],
Cell[1000, 40, 1949, 44, 286, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2986, 89, 89, 2, 79, "Section"],
Cell[3078, 93, 69697, 2311, 6663, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72812, 2409, 35, 0, 79, "Section"],
Cell[72850, 2411, 8688, 258, 1129, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81575, 2674, 76, 1, 79, "Section"],
Cell[81654, 2677, 94, 2, 41, "Text"],
Cell[81751, 2681, 81, 2, 38, "Input"],
Cell[81835, 2685, 88, 2, 38, "Input"],
Cell[CellGroupData[{
Cell[81948, 2691, 43, 0, 68, "Subsection"],
Cell[81994, 2693, 288, 8, 43, "Text"],
Cell[CellGroupData[{
Cell[82307, 2705, 592, 19, 96, "Input"],
Cell[82902, 2726, 1106, 38, 63, "Output"],
Cell[84011, 2766, 635, 21, 63, "Output"],
Cell[84649, 2789, 549, 18, 63, "Output"]
}, Open  ]],
Cell[85213, 2810, 1107, 23, 164, "Text"],
Cell[86323, 2835, 4475, 184, 246, "Text"],
Cell[CellGroupData[{
Cell[90823, 3023, 15195, 595, 537, "Input"],
Cell[106021, 3620, 172080, 2855, 666, "Output"]
}, Open  ]],
Cell[278116, 6478, 268, 8, 66, "Text"],
Cell[CellGroupData[{
Cell[278409, 6490, 2534, 105, 28, "Input",
 CellOpen->False],
Cell[280946, 6597, 14914, 255, 196, "Output"]
}, Open  ]],
Cell[295875, 6855, 795, 34, 41, "Text"],
Cell[CellGroupData[{
Cell[296695, 6893, 640, 21, 38, "Input"],
Cell[297338, 6916, 501, 17, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297876, 6938, 1349, 46, 90, "Input"],
Cell[299228, 6986, 1046, 35, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300311, 7026, 41, 0, 59, "Subsubsection"],
Cell[300355, 7028, 433, 12, 68, "Text"],
Cell[300791, 7042, 283, 10, 38, "Input"],
Cell[CellGroupData[{
Cell[301099, 7056, 472, 16, 51, "Input"],
Cell[301574, 7074, 4875, 162, 220, "Output"]
}, Open  ]],
Cell[306464, 7239, 210, 5, 66, "Text"],
Cell[CellGroupData[{
Cell[306699, 7248, 2209, 70, 195, "Input"],
Cell[308911, 7320, 30425, 508, 359, "Output"]
}, Open  ]],
Cell[339351, 7831, 176, 3, 66, "Text"],
Cell[CellGroupData[{
Cell[339552, 7838, 2338, 75, 195, "Input"],
Cell[341893, 7915, 39073, 649, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381003, 8569, 2333, 75, 195, "Input"],
Cell[383339, 8646, 27462, 459, 362, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[410862, 9112, 51, 0, 68, "Subsection"],
Cell[410916, 9114, 772, 22, 133, "Text"],
Cell[CellGroupData[{
Cell[411713, 9140, 2525, 74, 153, "Input"],
Cell[414241, 9216, 15953, 267, 354, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[430255, 9490, 84, 1, 79, "Section"],
Cell[430342, 9493, 1235, 46, 139, "Text"],
Cell[CellGroupData[{
Cell[431602, 9543, 339, 11, 38, "Input"],
Cell[431944, 9556, 1380, 35, 147, "Output"]
}, Open  ]],
Cell[433339, 9594, 784, 24, 117, "Text"],
Cell[434126, 9620, 338, 10, 66, "Text"],
Cell[CellGroupData[{
Cell[434489, 9634, 287, 9, 38, "Input"],
Cell[434779, 9645, 1803, 57, 155, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[436619, 9707, 215, 6, 38, "Input"],
Cell[436837, 9715, 116, 3, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[436990, 9723, 378, 11, 64, "Input"],
Cell[437371, 9736, 185, 5, 38, "Output"],
Cell[437559, 9743, 160, 3, 38, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[437768, 9752, 90, 1, 79, "Section"],
Cell[437861, 9755, 273, 9, 66, "Text"],
Cell[CellGroupData[{
Cell[438159, 9768, 413, 12, 89, "Input"],
Cell[438575, 9782, 188, 5, 38, "Output"],
Cell[438766, 9789, 1067, 27, 147, "Output"],
Cell[439836, 9818, 61, 1, 38, "Output"]
}, Open  ]],
Cell[439912, 9822, 157, 3, 41, "Text"],
Cell[CellGroupData[{
Cell[440094, 9829, 297, 10, 64, "Input"],
Cell[440394, 9841, 1512, 50, 191, "Output"],
Cell[441909, 9893, 39, 0, 38, "Output"]
}, Open  ]],
Cell[441963, 9896, 98, 2, 41, "Text"],
Cell[CellGroupData[{
Cell[442086, 9902, 336, 11, 64, "Input"],
Cell[442425, 9915, 2136, 46, 367, "Output"],
Cell[444564, 9963, 38, 0, 38, "Output"]
}, Open  ]],
Cell[444617, 9966, 255, 8, 66, "Text"],
Cell[CellGroupData[{
Cell[444897, 9978, 429, 12, 64, "Input"],
Cell[445329, 9992, 1512, 50, 191, "Output"],
Cell[446844, 10044, 165, 4, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[447046, 10053, 290, 10, 38, "Input"],
Cell[447339, 10065, 2382, 51, 367, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449758, 10121, 228, 7, 64, "Input"],
Cell[449989, 10130, 2136, 46, 367, "Output"],
Cell[452128, 10178, 38, 0, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[452203, 10183, 255, 8, 64, "Input"],
Cell[452461, 10193, 2136, 46, 367, "Output"],
Cell[454600, 10241, 38, 0, 38, "Output"]
}, Open  ]],
Cell[454653, 10244, 676, 11, 139, "Text"],
Cell[CellGroupData[{
Cell[455354, 10259, 403, 9, 64, "Input"],
Cell[455760, 10270, 5496, 162, 227, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
